@@ -28,11 +28,9 @@ namespace dom {
 // due to B2G ICS uses old complier (C++98/03) which forbids local class as
 // template parameter, we need to move this class outside.
 class SurfaceHelper : public Runnable {
-public:
+ public:
   explicit SurfaceHelper(already_AddRefed<layers::Image> aImage)
-    : Runnable("SurfaceHelper")
-    , mImage(aImage)
-  {}
+      : Runnable("SurfaceHelper"), mImage(aImage) {}
 
   // It retrieves a SourceSurface reference and convert color format on main
   // thread and passes DataSourceSurface to caller thread.
@@ -44,9 +42,8 @@ public:
     if (surface->GetFormat() == gfx::SurfaceFormat::B8G8R8A8) {
       mDataSourceSurface = surface->GetDataSurface();
     } else {
-      mDataSourceSurface = gfxUtils::
-        CopySurfaceToDataSourceSurfaceWithFormat(surface,
-                                                 gfx::SurfaceFormat::B8G8R8A8);
+      mDataSourceSurface = gfxUtils::CopySurfaceToDataSourceSurfaceWithFormat(
+          surface, gfx::SurfaceFormat::B8G8R8A8);
     }
     return NS_OK;
   }
@@ -59,7 +56,7 @@ public:
     return mDataSourceSurface.forget();
   }
 
-private:
+ private:
   RefPtr<layers::Image> mImage;
   RefPtr<gfx::DataSourceSurface> mDataSourceSurface;
 };
@@ -69,26 +66,24 @@ private:
 // image formats should be referenced or dereferenced on main thread, it uses a
 // sync class SurfaceHelper to retrieve SourceSurface and convert to B8G8R8A8 on
 // main thread.
-already_AddRefed<DataSourceSurface>
-GetBRGADataSourceSurfaceSync(already_AddRefed<layers::Image> aImage)
-{
+already_AddRefed<DataSourceSurface> GetBRGADataSourceSurfaceSync(
+    already_AddRefed<layers::Image> aImage) {
   RefPtr<SurfaceHelper> helper = new SurfaceHelper(Move(aImage));
   return helper->GetDataSurfaceSafe();
 }
 
-class EncodingCompleteEvent : public CancelableRunnable
-{
+class EncodingCompleteEvent : public CancelableRunnable {
   virtual ~EncodingCompleteEvent() {}
 
-public:
-  explicit EncodingCompleteEvent(EncodeCompleteCallback* aEncodeCompleteCallback)
-    : CancelableRunnable("EncodingCompleteEvent")
-    , mImgSize(0)
-    , mType()
-    , mImgData(nullptr)
-    , mEncodeCompleteCallback(aEncodeCompleteCallback)
-    , mFailed(false)
-  {
+ public:
+  explicit EncodingCompleteEvent(
+      EncodeCompleteCallback* aEncodeCompleteCallback)
+      : CancelableRunnable("EncodingCompleteEvent"),
+        mImgSize(0),
+        mType(),
+        mImgData(nullptr),
+        mEncodeCompleteCallback(aEncodeCompleteCallback),
+        mFailed(false) {
     if (!NS_IsMainThread() && GetCurrentThreadWorkerPrivate()) {
       mCreationEventTarget = GetCurrentThreadEventTarget();
     } else {
@@ -96,14 +91,13 @@ public:
     }
   }
 
-  NS_IMETHOD Run() override
-  {
+  NS_IMETHOD Run() override {
     nsresult rv = NS_OK;
 
     if (!mFailed) {
       // The correct parentObject has to be set by the mEncodeCompleteCallback.
       RefPtr<Blob> blob =
-        Blob::CreateMemoryBlob(nullptr, mImgData, mImgSize, mType);
+          Blob::CreateMemoryBlob(nullptr, mImgData, mImgSize, mType);
       MOZ_ASSERT(blob);
 
       rv = mEncodeCompleteCallback->ReceiveBlob(blob.forget());
@@ -114,24 +108,20 @@ public:
     return rv;
   }
 
-  void SetMembers(void* aImgData, uint64_t aImgSize, const nsAutoString& aType)
-  {
+  void SetMembers(void* aImgData, uint64_t aImgSize,
+                  const nsAutoString& aType) {
     mImgData = aImgData;
     mImgSize = aImgSize;
     mType = aType;
   }
 
-  void SetFailed()
-  {
-    mFailed = true;
-  }
+  void SetFailed() { mFailed = true; }
 
-  nsIEventTarget* GetCreationThreadEventTarget()
-  {
+  nsIEventTarget* GetCreationThreadEventTarget() {
     return mCreationEventTarget;
   }
 
-private:
+ private:
   uint64_t mImgSize;
   nsAutoString mType;
   void* mImgData;
@@ -140,65 +130,43 @@ private:
   bool mFailed;
 };
 
-class EncodingRunnable : public Runnable
-{
+class EncodingRunnable : public Runnable {
   virtual ~EncodingRunnable() {}
 
-public:
+ public:
   NS_INLINE_DECL_REFCOUNTING_INHERITED(EncodingRunnable, Runnable)
 
-  EncodingRunnable(const nsAString& aType,
-                   const nsAString& aOptions,
-                   UniquePtr<uint8_t[]> aImageBuffer,
-                   layers::Image* aImage,
+  EncodingRunnable(const nsAString& aType, const nsAString& aOptions,
+                   UniquePtr<uint8_t[]> aImageBuffer, layers::Image* aImage,
                    imgIEncoder* aEncoder,
                    EncodingCompleteEvent* aEncodingCompleteEvent,
-                   int32_t aFormat,
-                   const nsIntSize aSize,
-                   bool aUsePlaceholder,
+                   int32_t aFormat, const nsIntSize aSize, bool aUsePlaceholder,
                    bool aUsingCustomOptions)
-    : Runnable("EncodingRunnable")
-    , mType(aType)
-    , mOptions(aOptions)
-    , mImageBuffer(Move(aImageBuffer))
-    , mImage(aImage)
-    , mEncoder(aEncoder)
-    , mEncodingCompleteEvent(aEncodingCompleteEvent)
-    , mFormat(aFormat)
-    , mSize(aSize)
-    , mUsePlaceholder(aUsePlaceholder)
-    , mUsingCustomOptions(aUsingCustomOptions)
-  {}
+      : Runnable("EncodingRunnable"),
+        mType(aType),
+        mOptions(aOptions),
+        mImageBuffer(Move(aImageBuffer)),
+        mImage(aImage),
+        mEncoder(aEncoder),
+        mEncodingCompleteEvent(aEncodingCompleteEvent),
+        mFormat(aFormat),
+        mSize(aSize),
+        mUsePlaceholder(aUsePlaceholder),
+        mUsingCustomOptions(aUsingCustomOptions) {}
 
-  nsresult ProcessImageData(uint64_t* aImgSize, void** aImgData)
-  {
+  nsresult ProcessImageData(uint64_t* aImgSize, void** aImgData) {
     nsCOMPtr<nsIInputStream> stream;
-    nsresult rv = ImageEncoder::ExtractDataInternal(mType,
-                                                    mOptions,
-                                                    mImageBuffer.get(),
-                                                    mFormat,
-                                                    mSize,
-                                                    mUsePlaceholder,
-                                                    mImage,
-                                                    nullptr,
-                                                    nullptr,
-                                                    getter_AddRefs(stream),
-                                                    mEncoder);
+    nsresult rv = ImageEncoder::ExtractDataInternal(
+        mType, mOptions, mImageBuffer.get(), mFormat, mSize, mUsePlaceholder,
+        mImage, nullptr, nullptr, getter_AddRefs(stream), mEncoder);
 
     // If there are unrecognized custom parse options, we should fall back to
     // the default values for the encoder without any options at all.
     if (rv == NS_ERROR_INVALID_ARG && mUsingCustomOptions) {
-      rv = ImageEncoder::ExtractDataInternal(mType,
-                                             EmptyString(),
-                                             mImageBuffer.get(),
-                                             mFormat,
-                                             mSize,
-                                             mUsePlaceholder,
-                                             mImage,
-                                             nullptr,
-                                             nullptr,
-                                             getter_AddRefs(stream),
-                                             mEncoder);
+      rv = ImageEncoder::ExtractDataInternal(
+          mType, EmptyString(), mImageBuffer.get(), mFormat, mSize,
+          mUsePlaceholder, mImage, nullptr, nullptr, getter_AddRefs(stream),
+          mEncoder);
     }
     NS_ENSURE_SUCCESS(rv, rv);
 
@@ -208,8 +176,7 @@ public:
     return rv;
   }
 
-  NS_IMETHOD Run() override
-  {
+  NS_IMETHOD Run() override {
     uint64_t imgSize;
     void* imgData = nullptr;
 
@@ -219,8 +186,8 @@ public:
     } else {
       mEncodingCompleteEvent->SetMembers(imgData, imgSize, mType);
     }
-    rv = mEncodingCompleteEvent->GetCreationThreadEventTarget()->
-      Dispatch(mEncodingCompleteEvent, nsIThread::DISPATCH_NORMAL);
+    rv = mEncodingCompleteEvent->GetCreationThreadEventTarget()->Dispatch(
+        mEncodingCompleteEvent, nsIThread::DISPATCH_NORMAL);
     if (NS_FAILED(rv)) {
       // Better to leak than to crash.
       Unused << mEncodingCompleteEvent.forget();
@@ -230,7 +197,7 @@ public:
     return rv;
   }
 
-private:
+ private:
   nsAutoString mType;
   nsAutoString mOptions;
   UniquePtr<uint8_t[]> mImageBuffer;
@@ -246,34 +213,26 @@ private:
 StaticRefPtr<nsIThreadPool> ImageEncoder::sThreadPool;
 
 /* static */
-nsresult
-ImageEncoder::ExtractData(nsAString& aType,
-                          const nsAString& aOptions,
-                          const nsIntSize aSize,
-                          bool aUsePlaceholder,
-                          nsICanvasRenderingContextInternal* aContext,
-                          layers::AsyncCanvasRenderer* aRenderer,
-                          nsIInputStream** aStream)
-{
+nsresult ImageEncoder::ExtractData(nsAString& aType, const nsAString& aOptions,
+                                   const nsIntSize aSize, bool aUsePlaceholder,
+                                   nsICanvasRenderingContextInternal* aContext,
+                                   layers::AsyncCanvasRenderer* aRenderer,
+                                   nsIInputStream** aStream) {
   nsCOMPtr<imgIEncoder> encoder = ImageEncoder::GetImageEncoder(aType);
   if (!encoder) {
     return NS_IMAGELIB_ERROR_NO_ENCODER;
   }
 
   return ExtractDataInternal(aType, aOptions, nullptr, 0, aSize,
-                             aUsePlaceholder, nullptr,
-                             aContext, aRenderer, aStream, encoder);
+                             aUsePlaceholder, nullptr, aContext, aRenderer,
+                             aStream, encoder);
 }
 
 /* static */
-nsresult
-ImageEncoder::ExtractDataFromLayersImageAsync(nsAString& aType,
-                                              const nsAString& aOptions,
-                                              bool aUsingCustomOptions,
-                                              layers::Image* aImage,
-                                              bool aUsePlaceholder,
-                                              EncodeCompleteCallback* aEncodeCallback)
-{
+nsresult ImageEncoder::ExtractDataFromLayersImageAsync(
+    nsAString& aType, const nsAString& aOptions, bool aUsingCustomOptions,
+    layers::Image* aImage, bool aUsePlaceholder,
+    EncodeCompleteCallback* aEncodeCallback) {
   nsCOMPtr<imgIEncoder> encoder = ImageEncoder::GetImageEncoder(aType);
   if (!encoder) {
     return NS_IMAGELIB_ERROR_NO_ENCODER;
@@ -285,33 +244,21 @@ ImageEncoder::ExtractDataFromLayersImageAsync(nsAString& aType,
   }
 
   RefPtr<EncodingCompleteEvent> completeEvent =
-    new EncodingCompleteEvent(aEncodeCallback);
+      new EncodingCompleteEvent(aEncodeCallback);
 
   nsIntSize size(aImage->GetSize().width, aImage->GetSize().height);
-  nsCOMPtr<nsIRunnable> event = new EncodingRunnable(aType,
-                                                     aOptions,
-                                                     nullptr,
-                                                     aImage,
-                                                     encoder,
-                                                     completeEvent,
-                                                     imgIEncoder::INPUT_FORMAT_HOSTARGB,
-                                                     size,
-                                                     aUsePlaceholder,
-                                                     aUsingCustomOptions);
+  nsCOMPtr<nsIRunnable> event =
+      new EncodingRunnable(aType, aOptions, nullptr, aImage, encoder,
+                           completeEvent, imgIEncoder::INPUT_FORMAT_HOSTARGB,
+                           size, aUsePlaceholder, aUsingCustomOptions);
   return sThreadPool->Dispatch(event, NS_DISPATCH_NORMAL);
 }
 
 /* static */
-nsresult
-ImageEncoder::ExtractDataAsync(nsAString& aType,
-                               const nsAString& aOptions,
-                               bool aUsingCustomOptions,
-                               UniquePtr<uint8_t[]> aImageBuffer,
-                               int32_t aFormat,
-                               const nsIntSize aSize,
-                               bool aUsePlaceholder,
-                               EncodeCompleteCallback* aEncodeCallback)
-{
+nsresult ImageEncoder::ExtractDataAsync(
+    nsAString& aType, const nsAString& aOptions, bool aUsingCustomOptions,
+    UniquePtr<uint8_t[]> aImageBuffer, int32_t aFormat, const nsIntSize aSize,
+    bool aUsePlaceholder, EncodeCompleteCallback* aEncodeCallback) {
   nsCOMPtr<imgIEncoder> encoder = ImageEncoder::GetImageEncoder(aType);
   if (!encoder) {
     return NS_IMAGELIB_ERROR_NO_ENCODER;
@@ -323,54 +270,33 @@ ImageEncoder::ExtractDataAsync(nsAString& aType,
   }
 
   RefPtr<EncodingCompleteEvent> completeEvent =
-    new EncodingCompleteEvent(aEncodeCallback);
+      new EncodingCompleteEvent(aEncodeCallback);
 
-  nsCOMPtr<nsIRunnable> event = new EncodingRunnable(aType,
-                                                     aOptions,
-                                                     Move(aImageBuffer),
-                                                     nullptr,
-                                                     encoder,
-                                                     completeEvent,
-                                                     aFormat,
-                                                     aSize,
-                                                     aUsePlaceholder,
-                                                     aUsingCustomOptions);
+  nsCOMPtr<nsIRunnable> event = new EncodingRunnable(
+      aType, aOptions, Move(aImageBuffer), nullptr, encoder, completeEvent,
+      aFormat, aSize, aUsePlaceholder, aUsingCustomOptions);
   return sThreadPool->Dispatch(event, NS_DISPATCH_NORMAL);
 }
 
-/*static*/ nsresult
-ImageEncoder::GetInputStream(int32_t aWidth,
-                             int32_t aHeight,
-                             uint8_t* aImageBuffer,
-                             int32_t aFormat,
-                             imgIEncoder* aEncoder,
-                             const char16_t* aEncoderOptions,
-                             nsIInputStream** aStream)
-{
-  nsresult rv =
-    aEncoder->InitFromData(aImageBuffer,
-                           aWidth * aHeight * 4, aWidth, aHeight, aWidth * 4,
-                           aFormat,
-                           nsDependentString(aEncoderOptions));
+/*static*/ nsresult ImageEncoder::GetInputStream(
+    int32_t aWidth, int32_t aHeight, uint8_t* aImageBuffer, int32_t aFormat,
+    imgIEncoder* aEncoder, const char16_t* aEncoderOptions,
+    nsIInputStream** aStream) {
+  nsresult rv = aEncoder->InitFromData(aImageBuffer, aWidth * aHeight * 4,
+                                       aWidth, aHeight, aWidth * 4, aFormat,
+                                       nsDependentString(aEncoderOptions));
   NS_ENSURE_SUCCESS(rv, rv);
 
   return CallQueryInterface(aEncoder, aStream);
 }
 
 /* static */
-nsresult
-ImageEncoder::ExtractDataInternal(const nsAString& aType,
-                                  const nsAString& aOptions,
-                                  uint8_t* aImageBuffer,
-                                  int32_t aFormat,
-                                  const nsIntSize aSize,
-                                  bool aUsePlaceholder,
-                                  layers::Image* aImage,
-                                  nsICanvasRenderingContextInternal* aContext,
-                                  layers::AsyncCanvasRenderer* aRenderer,
-                                  nsIInputStream** aStream,
-                                  imgIEncoder* aEncoder)
-{
+nsresult ImageEncoder::ExtractDataInternal(
+    const nsAString& aType, const nsAString& aOptions, uint8_t* aImageBuffer,
+    int32_t aFormat, const nsIntSize aSize, bool aUsePlaceholder,
+    layers::Image* aImage, nsICanvasRenderingContextInternal* aContext,
+    layers::AsyncCanvasRenderer* aRenderer, nsIInputStream** aStream,
+    imgIEncoder* aEncoder) {
   if (aSize.IsEmpty()) {
     return NS_ERROR_INVALID_ARG;
   }
@@ -385,13 +311,8 @@ ImageEncoder::ExtractDataInternal(const nsAString& aType,
     }
 
     rv = ImageEncoder::GetInputStream(
-      aSize.width,
-      aSize.height,
-      aImageBuffer,
-      aFormat,
-      aEncoder,
-      nsPromiseFlatString(aOptions).get(),
-      getter_AddRefs(imgStream));
+        aSize.width, aSize.height, aImageBuffer, aFormat, aEncoder,
+        nsPromiseFlatString(aOptions).get(), getter_AddRefs(imgStream));
   } else if (aContext && !aUsePlaceholder) {
     NS_ConvertUTF16toUTF8 encoderType(aType);
     rv = aContext->GetInputStream(encoderType.get(),
@@ -409,7 +330,8 @@ ImageEncoder::ExtractDataInternal(const nsAString& aType,
     // format on main thread.
     if (aImage->GetFormat() == ImageFormat::PLANAR_YCBCR) {
       nsTArray<uint8_t> data;
-      layers::PlanarYCbCrImage* ycbcrImage = static_cast<layers::PlanarYCbCrImage*> (aImage);
+      layers::PlanarYCbCrImage* ycbcrImage =
+          static_cast<layers::PlanarYCbCrImage*>(aImage);
       gfxImageFormat format = SurfaceFormat::A8R8G8B8_UINT32;
       uint32_t stride = GetAlignedStride<16>(aSize.width, 4);
       size_t length = BufferSizeFromStrideAndHeight(stride, aSize.height);
@@ -418,19 +340,13 @@ ImageEncoder::ExtractDataInternal(const nsAString& aType,
       }
       data.SetCapacity(length);
 
-      ConvertYCbCrToRGB(*ycbcrImage->GetData(),
-                        format,
-                        aSize,
-                        data.Elements(),
+      ConvertYCbCrToRGB(*ycbcrImage->GetData(), format, aSize, data.Elements(),
                         stride);
 
       rv = aEncoder->InitFromData(data.Elements(),
-                                  aSize.width * aSize.height * 4,
-                                  aSize.width,
-                                  aSize.height,
-                                  aSize.width * 4,
-                                  imgIEncoder::INPUT_FORMAT_HOSTARGB,
-                                  aOptions);
+                                  aSize.width * aSize.height * 4, aSize.width,
+                                  aSize.height, aSize.width * 4,
+                                  imgIEncoder::INPUT_FORMAT_HOSTARGB, aOptions);
     } else {
       if (BufferSizeFromDimensions(aSize.width, aSize.height, 4) == 0) {
         return NS_ERROR_INVALID_ARG;
@@ -444,13 +360,9 @@ ImageEncoder::ExtractDataInternal(const nsAString& aType,
       if (!dataSurface->Map(gfx::DataSourceSurface::MapType::READ, &map)) {
         return NS_ERROR_INVALID_ARG;
       }
-      rv = aEncoder->InitFromData(map.mData,
-                                  aSize.width * aSize.height * 4,
-                                  aSize.width,
-                                  aSize.height,
-                                  aSize.width * 4,
-                                  imgIEncoder::INPUT_FORMAT_HOSTARGB,
-                                  aOptions);
+      rv = aEncoder->InitFromData(map.mData, aSize.width * aSize.height * 4,
+                                  aSize.width, aSize.height, aSize.width * 4,
+                                  imgIEncoder::INPUT_FORMAT_HOSTARGB, aOptions);
       dataSurface->Unmap();
     }
 
@@ -467,9 +379,9 @@ ImageEncoder::ExtractDataInternal(const nsAString& aType,
     // supposed to just return transparent black pixels of the canvas
     // dimensions.
     RefPtr<DataSourceSurface> emptyCanvas =
-      Factory::CreateDataSourceSurfaceWithStride(IntSize(aSize.width, aSize.height),
-                                                 SurfaceFormat::B8G8R8A8,
-                                                 4 * aSize.width, true);
+        Factory::CreateDataSourceSurfaceWithStride(
+            IntSize(aSize.width, aSize.height), SurfaceFormat::B8G8R8A8,
+            4 * aSize.width, true);
     if (NS_WARN_IF(!emptyCanvas)) {
       return NS_ERROR_INVALID_ARG;
     }
@@ -482,13 +394,9 @@ ImageEncoder::ExtractDataInternal(const nsAString& aType,
       // If placeholder data was requested, return all-white, opaque image data.
       memset(map.mData, 0xFF, 4 * aSize.width * aSize.height);
     }
-    rv = aEncoder->InitFromData(map.mData,
-                                aSize.width * aSize.height * 4,
-                                aSize.width,
-                                aSize.height,
-                                aSize.width * 4,
-                                imgIEncoder::INPUT_FORMAT_HOSTARGB,
-                                aOptions);
+    rv = aEncoder->InitFromData(map.mData, aSize.width * aSize.height * 4,
+                                aSize.width, aSize.height, aSize.width * 4,
+                                imgIEncoder::INPUT_FORMAT_HOSTARGB, aOptions);
     emptyCanvas->Unmap();
     if (NS_SUCCEEDED(rv)) {
       imgStream = do_QueryInterface(aEncoder);
@@ -501,9 +409,7 @@ ImageEncoder::ExtractDataInternal(const nsAString& aType,
 }
 
 /* static */
-already_AddRefed<imgIEncoder>
-ImageEncoder::GetImageEncoder(nsAString& aType)
-{
+already_AddRefed<imgIEncoder> ImageEncoder::GetImageEncoder(nsAString& aType) {
   // Get an image encoder for the media type.
   nsCString encoderCID("@mozilla.org/image/encoder;2?type=");
   NS_ConvertUTF16toUTF8 encoderType(aType);
@@ -521,50 +427,45 @@ ImageEncoder::GetImageEncoder(nsAString& aType)
   return encoder.forget();
 }
 
-class EncoderThreadPoolTerminator final : public nsIObserver
-{
-  public:
-    NS_DECL_ISUPPORTS
+class EncoderThreadPoolTerminator final : public nsIObserver {
+ public:
+  NS_DECL_ISUPPORTS
 
-    NS_IMETHOD Observe(nsISupports *, const char *topic, const char16_t *) override
-    {
-      NS_ASSERTION(!strcmp(topic, "xpcom-shutdown-threads"),
-                   "Unexpected topic");
-      if (ImageEncoder::sThreadPool) {
-        ImageEncoder::sThreadPool->Shutdown();
-        ImageEncoder::sThreadPool = nullptr;
-      }
-      return NS_OK;
+  NS_IMETHOD Observe(nsISupports*, const char* topic,
+                     const char16_t*) override {
+    NS_ASSERTION(!strcmp(topic, "xpcom-shutdown-threads"), "Unexpected topic");
+    if (ImageEncoder::sThreadPool) {
+      ImageEncoder::sThreadPool->Shutdown();
+      ImageEncoder::sThreadPool = nullptr;
     }
-  private:
-    ~EncoderThreadPoolTerminator() {}
+    return NS_OK;
+  }
+
+ private:
+  ~EncoderThreadPoolTerminator() {}
 };
 
 NS_IMPL_ISUPPORTS(EncoderThreadPoolTerminator, nsIObserver)
 
-static void
-RegisterEncoderThreadPoolTerminatorObserver()
-{
+static void RegisterEncoderThreadPoolTerminatorObserver() {
   MOZ_ASSERT(NS_IsMainThread());
   nsCOMPtr<nsIObserverService> os = mozilla::services::GetObserverService();
   NS_ASSERTION(os, "do_GetService failed");
-  os->AddObserver(new EncoderThreadPoolTerminator(),
-                  "xpcom-shutdown-threads",
+  os->AddObserver(new EncoderThreadPoolTerminator(), "xpcom-shutdown-threads",
                   false);
 }
 
 /* static */
-nsresult
-ImageEncoder::EnsureThreadPool()
-{
+nsresult ImageEncoder::EnsureThreadPool() {
   if (!sThreadPool) {
-    nsCOMPtr<nsIThreadPool> threadPool = do_CreateInstance(NS_THREADPOOL_CONTRACTID);
+    nsCOMPtr<nsIThreadPool> threadPool =
+        do_CreateInstance(NS_THREADPOOL_CONTRACTID);
     sThreadPool = threadPool;
 
     if (!NS_IsMainThread()) {
       NS_DispatchToMainThread(NS_NewRunnableFunction(
-        "dom::ImageEncoder::EnsureThreadPool",
-        []() -> void { RegisterEncoderThreadPoolTerminatorObserver(); }));
+          "dom::ImageEncoder::EnsureThreadPool",
+          []() -> void { RegisterEncoderThreadPoolTerminatorObserver(); }));
     } else {
       RegisterEncoderThreadPoolTerminatorObserver();
     }
@@ -597,5 +498,5 @@ ImageEncoder::EnsureThreadPool()
   return NS_OK;
 }
 
-} // namespace dom
-} // namespace mozilla
+}  // namespace dom
+}  // namespace mozilla
