@@ -30,21 +30,17 @@ NS_IMPL_CYCLE_COLLECTION(ResponsiveImageSelector, mOwnerNode)
 NS_IMPL_CYCLE_COLLECTION_ROOT_NATIVE(ResponsiveImageSelector, AddRef)
 NS_IMPL_CYCLE_COLLECTION_UNROOT_NATIVE(ResponsiveImageSelector, Release)
 
-static bool
-ParseInteger(const nsAString& aString, int32_t& aInt)
-{
+static bool ParseInteger(const nsAString& aString, int32_t& aInt) {
   nsContentUtils::ParseHTMLIntegerResultFlags parseResult;
   aInt = nsContentUtils::ParseHTMLInteger(aString, &parseResult);
   return !(parseResult &
-           ( nsContentUtils::eParseHTMLInteger_Error |
-             nsContentUtils::eParseHTMLInteger_DidNotConsumeAllInput |
-             nsContentUtils::eParseHTMLInteger_IsPercent |
-             nsContentUtils::eParseHTMLInteger_NonStandard ));
+           (nsContentUtils::eParseHTMLInteger_Error |
+            nsContentUtils::eParseHTMLInteger_DidNotConsumeAllInput |
+            nsContentUtils::eParseHTMLInteger_IsPercent |
+            nsContentUtils::eParseHTMLInteger_NonStandard));
 }
 
-static bool
-ParseFloat(const nsAString& aString, double& aDouble)
-{
+static bool ParseFloat(const nsAString& aString, double& aDouble) {
   // Check if it is a valid floating-point number first since the result of
   // nsString.ToDouble() is more lenient than the spec,
   // https://html.spec.whatwg.org/#valid-floating-point-number
@@ -61,7 +57,8 @@ ParseFloat(const nsAString& aString, double& aDouble)
   }
 
   if (nsCRT::IsAsciiDigit(*iter)) {
-    for (; iter != end && nsCRT::IsAsciiDigit(*iter) ; ++iter);
+    for (; iter != end && nsCRT::IsAsciiDigit(*iter); ++iter)
+      ;
   } else if (*iter == char16_t('.')) {
     // Do nothing, jumps to fraction part
   } else {
@@ -72,11 +69,13 @@ ParseFloat(const nsAString& aString, double& aDouble)
   if (*iter == char16_t('.')) {
     ++iter;
     if (iter == end || !nsCRT::IsAsciiDigit(*iter)) {
-      // U+002E FULL STOP character (.) must be followed by one or more ASCII digits
+      // U+002E FULL STOP character (.) must be followed by one or more ASCII
+      // digits
       return false;
     }
 
-    for (; iter != end && nsCRT::IsAsciiDigit(*iter) ; ++iter);
+    for (; iter != end && nsCRT::IsAsciiDigit(*iter); ++iter)
+      ;
   }
 
   if (iter != end && (*iter == char16_t('e') || *iter == char16_t('E'))) {
@@ -90,7 +89,8 @@ ParseFloat(const nsAString& aString, double& aDouble)
       return false;
     }
 
-    for (; iter != end && nsCRT::IsAsciiDigit(*iter) ; ++iter);
+    for (; iter != end && nsCRT::IsAsciiDigit(*iter); ++iter)
+      ;
   }
 
   if (iter != end) {
@@ -102,33 +102,23 @@ ParseFloat(const nsAString& aString, double& aDouble)
   return NS_SUCCEEDED(rv);
 }
 
-ResponsiveImageSelector::ResponsiveImageSelector(nsIContent *aContent)
-  : mOwnerNode(aContent),
-    mSelectedCandidateIndex(-1)
-{
-}
+ResponsiveImageSelector::ResponsiveImageSelector(nsIContent* aContent)
+    : mOwnerNode(aContent), mSelectedCandidateIndex(-1) {}
 
-ResponsiveImageSelector::ResponsiveImageSelector(nsIDocument *aDocument)
-  : mOwnerNode(aDocument),
-    mSelectedCandidateIndex(-1)
-{
-}
+ResponsiveImageSelector::ResponsiveImageSelector(nsIDocument* aDocument)
+    : mOwnerNode(aDocument), mSelectedCandidateIndex(-1) {}
 
-ResponsiveImageSelector::~ResponsiveImageSelector()
-{}
+ResponsiveImageSelector::~ResponsiveImageSelector() {}
 
 // http://www.whatwg.org/specs/web-apps/current-work/#processing-the-image-candidates
-bool
-ResponsiveImageSelector::SetCandidatesFromSourceSet(const nsAString & aSrcSet,
-                                                    nsIPrincipal* aTriggeringPrincipal)
-{
+bool ResponsiveImageSelector::SetCandidatesFromSourceSet(
+    const nsAString& aSrcSet, nsIPrincipal* aTriggeringPrincipal) {
   ClearSelectedCandidate();
 
   nsCOMPtr<nsIURI> docBaseURI = mOwnerNode ? mOwnerNode->GetBaseURI() : nullptr;
 
   if (!docBaseURI) {
-    MOZ_ASSERT(false,
-               "Should not be parsing SourceSet without a document");
+    MOZ_ASSERT(false, "Should not be parsing SourceSet without a document");
     return false;
   }
 
@@ -144,8 +134,10 @@ ResponsiveImageSelector::SetCandidatesFromSourceSet(const nsAString & aSrcSet,
 
     // Skip whitespace and commas.
     // Extra commas at this point are a non-fatal syntax error.
-    for (; iter != end && (nsContentUtils::IsHTMLWhitespace(*iter) ||
-                           *iter == char16_t(',')); ++iter);
+    for (; iter != end &&
+           (nsContentUtils::IsHTMLWhitespace(*iter) || *iter == char16_t(','));
+         ++iter)
+      ;
 
     if (iter == end) {
       break;
@@ -154,7 +146,8 @@ ResponsiveImageSelector::SetCandidatesFromSourceSet(const nsAString & aSrcSet,
     url = iter;
 
     // Find end of url
-    for (;iter != end && !nsContentUtils::IsHTMLWhitespace(*iter); ++iter);
+    for (; iter != end && !nsContentUtils::IsHTMLWhitespace(*iter); ++iter)
+      ;
 
     // Omit trailing commas from URL.
     // Multiple commas are a non-fatal error.
@@ -165,15 +158,16 @@ ResponsiveImageSelector::SetCandidatesFromSourceSet(const nsAString & aSrcSet,
       }
     }
 
-    const nsDependentSubstring &urlStr = Substring(url, iter);
+    const nsDependentSubstring& urlStr = Substring(url, iter);
 
     MOZ_ASSERT(url != iter, "Shouldn't have empty URL at this point");
 
     ResponsiveImageCandidate candidate;
     if (candidate.ConsumeDescriptors(iter, end)) {
       candidate.SetURLSpec(urlStr);
-      candidate.SetTriggeringPrincipal(nsContentUtils::GetAttrTriggeringPrincipal(
-          Content(), urlStr, aTriggeringPrincipal));
+      candidate.SetTriggeringPrincipal(
+          nsContentUtils::GetAttrTriggeringPrincipal(Content(), urlStr,
+                                                     aTriggeringPrincipal));
       AppendCandidateIfUnique(candidate);
     }
   }
@@ -186,9 +180,7 @@ ResponsiveImageSelector::SetCandidatesFromSourceSet(const nsAString & aSrcSet,
   return parsedCandidates;
 }
 
-uint32_t
-ResponsiveImageSelector::NumCandidates(bool aIncludeDefault)
-{
+uint32_t ResponsiveImageSelector::NumCandidates(bool aIncludeDefault) {
   uint32_t candidates = mCandidates.Length();
 
   // If present, the default candidate is the last item
@@ -201,22 +193,16 @@ ResponsiveImageSelector::NumCandidates(bool aIncludeDefault)
   return candidates;
 }
 
-nsIContent*
-ResponsiveImageSelector::Content()
-{
+nsIContent* ResponsiveImageSelector::Content() {
   return mOwnerNode->IsContent() ? mOwnerNode->AsContent() : nullptr;
 }
 
-nsIDocument*
-ResponsiveImageSelector::Document()
-{
+nsIDocument* ResponsiveImageSelector::Document() {
   return mOwnerNode->OwnerDoc();
 }
 
-void
-ResponsiveImageSelector::SetDefaultSource(const nsAString& aURLString,
-                                          nsIPrincipal* aPrincipal)
-{
+void ResponsiveImageSelector::SetDefaultSource(const nsAString& aURLString,
+                                               nsIPrincipal* aPrincipal) {
   ClearSelectedCandidate();
 
   // Check if the last element of our candidates is a default
@@ -233,16 +219,12 @@ ResponsiveImageSelector::SetDefaultSource(const nsAString& aURLString,
   MaybeAppendDefaultCandidate();
 }
 
-void
-ResponsiveImageSelector::ClearSelectedCandidate()
-{
+void ResponsiveImageSelector::ClearSelectedCandidate() {
   mSelectedCandidateIndex = -1;
   mSelectedCandidateURL = nullptr;
 }
 
-bool
-ResponsiveImageSelector::SetSizesFromDescriptor(const nsAString & aSizes)
-{
+bool ResponsiveImageSelector::SetSizesFromDescriptor(const nsAString& aSizes) {
   ClearSelectedCandidate();
 
   if (Document()->IsStyledByServo()) {
@@ -257,16 +239,15 @@ ResponsiveImageSelector::SetSizesFromDescriptor(const nsAString & aSizes)
   mSizeQueries.Clear();
   mSizeValues.Clear();
 
-  return cssParser.ParseSourceSizeList(aSizes, nullptr, 0,
-                                       mSizeQueries, mSizeValues);
+  return cssParser.ParseSourceSizeList(aSizes, nullptr, 0, mSizeQueries,
+                                       mSizeValues);
 #else
   MOZ_CRASH("old style system disabled");
 #endif
 }
 
-void
-ResponsiveImageSelector::AppendCandidateIfUnique(const ResponsiveImageCandidate & aCandidate)
-{
+void ResponsiveImageSelector::AppendCandidateIfUnique(
+    const ResponsiveImageCandidate& aCandidate) {
   int numCandidates = mCandidates.Length();
 
   // With the exception of Default, which should not be added until we are done
@@ -285,9 +266,7 @@ ResponsiveImageSelector::AppendCandidateIfUnique(const ResponsiveImageCandidate
   mCandidates.AppendElement(aCandidate);
 }
 
-void
-ResponsiveImageSelector::MaybeAppendDefaultCandidate()
-{
+void ResponsiveImageSelector::MaybeAppendDefaultCandidate() {
   if (mDefaultSourceURL.IsEmpty()) {
     return;
   }
@@ -317,18 +296,14 @@ ResponsiveImageSelector::MaybeAppendDefaultCandidate()
   mCandidates.AppendElement(defaultCandidate);
 }
 
-already_AddRefed<nsIURI>
-ResponsiveImageSelector::GetSelectedImageURL()
-{
+already_AddRefed<nsIURI> ResponsiveImageSelector::GetSelectedImageURL() {
   SelectImage();
 
   nsCOMPtr<nsIURI> url = mSelectedCandidateURL;
   return url.forget();
 }
 
-bool
-ResponsiveImageSelector::GetSelectedImageURLSpec(nsAString& aResult)
-{
+bool ResponsiveImageSelector::GetSelectedImageURLSpec(nsAString& aResult) {
   SelectImage();
 
   if (mSelectedCandidateIndex == -1) {
@@ -339,9 +314,7 @@ ResponsiveImageSelector::GetSelectedImageURLSpec(nsAString& aResult)
   return true;
 }
 
-double
-ResponsiveImageSelector::GetSelectedImageDensity()
-{
+double ResponsiveImageSelector::GetSelectedImageDensity() {
   int bestIndex = GetSelectedCandidateIndex();
   if (bestIndex < 0) {
     return 1.0;
@@ -350,9 +323,7 @@ ResponsiveImageSelector::GetSelectedImageDensity()
   return mCandidates[bestIndex].Density(this);
 }
 
-nsIPrincipal*
-ResponsiveImageSelector::GetSelectedImageTriggeringPrincipal()
-{
+nsIPrincipal* ResponsiveImageSelector::GetSelectedImageTriggeringPrincipal() {
   int bestIndex = GetSelectedCandidateIndex();
   if (bestIndex < 0) {
     return nullptr;
@@ -361,9 +332,7 @@ ResponsiveImageSelector::GetSelectedImageTriggeringPrincipal()
   return mCandidates[bestIndex].TriggeringPrincipal();
 }
 
-bool
-ResponsiveImageSelector::SelectImage(bool aReselect)
-{
+bool ResponsiveImageSelector::SelectImage(bool aReselect) {
   if (!aReselect && mSelectedCandidateIndex != -1) {
     // Already have selection
     return false;
@@ -402,7 +371,7 @@ ResponsiveImageSelector::SelectImage(bool aReselect)
   for (int i = 0; i < numCandidates; i++) {
     if (mCandidates[i].IsComputedFromWidth()) {
       DebugOnly<bool> computeResult =
-        ComputeFinalWidthForCurrentViewport(&computedWidth);
+          ComputeFinalWidthForCurrentViewport(&computedWidth);
       MOZ_ASSERT(computeResult,
                  "Computed candidates not allowed without sizes data");
       break;
@@ -412,15 +381,16 @@ ResponsiveImageSelector::SelectImage(bool aReselect)
   int bestIndex = -1;
   double bestDensity = -1.0;
   for (int i = 0; i < numCandidates; i++) {
-    double candidateDensity = \
-      (computedWidth == -1) ? mCandidates[i].Density(this)
-                            : mCandidates[i].Density(computedWidth);
+    double candidateDensity = (computedWidth == -1)
+                                  ? mCandidates[i].Density(this)
+                                  : mCandidates[i].Density(computedWidth);
     // - If bestIndex is below display density, pick anything larger.
     // - Otherwise, prefer if less dense than bestDensity but still above
     //   displayDensity.
     if (bestIndex == -1 ||
         (bestDensity < displayDensity && candidateDensity > bestDensity) ||
-        (candidateDensity >= displayDensity && candidateDensity < bestDensity)) {
+        (candidateDensity >= displayDensity &&
+         candidateDensity < bestDensity)) {
       bestIndex = i;
       bestDensity = candidateDensity;
     }
@@ -441,17 +411,14 @@ ResponsiveImageSelector::SelectImage(bool aReselect)
   return mSelectedCandidateIndex != oldBest;
 }
 
-int
-ResponsiveImageSelector::GetSelectedCandidateIndex()
-{
+int ResponsiveImageSelector::GetSelectedCandidateIndex() {
   SelectImage();
 
   return mSelectedCandidateIndex;
 }
 
-bool
-ResponsiveImageSelector::ComputeFinalWidthForCurrentViewport(double *aWidth)
-{
+bool ResponsiveImageSelector::ComputeFinalWidthForCurrentViewport(
+    double* aWidth) {
   nsIDocument* doc = Document();
   nsIPresShell* presShell = doc->GetShell();
   nsPresContext* pctx = presShell ? presShell->GetPresContext() : nullptr;
@@ -462,7 +429,7 @@ ResponsiveImageSelector::ComputeFinalWidthForCurrentViewport(double *aWidth)
   nscoord effectiveWidth;
   if (doc->IsStyledByServo()) {
     effectiveWidth = presShell->StyleSet()->AsServo()->EvaluateSourceSizeList(
-      mServoSourceSizeList.get());
+        mServoSourceSizeList.get());
   } else {
 #ifdef MOZ_OLD_STYLE
     unsigned int numSizes = mSizeQueries.Length();
@@ -479,60 +446,50 @@ ResponsiveImageSelector::ComputeFinalWidthForCurrentViewport(double *aWidth)
     if (i == numSizes) {
       // No match defaults to 100% viewport
       nsCSSValue defaultWidth(100.0f, eCSSUnit_ViewportWidth);
-      effectiveWidth = nsRuleNode::CalcLengthWithInitialFont(pctx,
-                                                             defaultWidth);
+      effectiveWidth =
+          nsRuleNode::CalcLengthWithInitialFont(pctx, defaultWidth);
     } else {
-      effectiveWidth = nsRuleNode::CalcLengthWithInitialFont(pctx,
-                                                             mSizeValues[i]);
+      effectiveWidth =
+          nsRuleNode::CalcLengthWithInitialFont(pctx, mSizeValues[i]);
     }
 #else
     MOZ_CRASH("old style system disabled");
 #endif
   }
 
-  *aWidth = nsPresContext::AppUnitsToDoubleCSSPixels(std::max(effectiveWidth, 0));
+  *aWidth =
+      nsPresContext::AppUnitsToDoubleCSSPixels(std::max(effectiveWidth, 0));
   return true;
 }
 
-ResponsiveImageCandidate::ResponsiveImageCandidate()
-{
+ResponsiveImageCandidate::ResponsiveImageCandidate() {
   mType = eCandidateType_Invalid;
   mValue.mDensity = 1.0;
 }
 
-ResponsiveImageCandidate::ResponsiveImageCandidate(const nsAString& aURLString,
-                                                   double aDensity,
-                                                   nsIPrincipal* aTriggeringPrincipal)
-  : mURLString(aURLString)
-  , mTriggeringPrincipal(aTriggeringPrincipal)
-{
+ResponsiveImageCandidate::ResponsiveImageCandidate(
+    const nsAString& aURLString, double aDensity,
+    nsIPrincipal* aTriggeringPrincipal)
+    : mURLString(aURLString), mTriggeringPrincipal(aTriggeringPrincipal) {
   mType = eCandidateType_Density;
   mValue.mDensity = aDensity;
 }
 
-
-void
-ResponsiveImageCandidate::SetURLSpec(const nsAString& aURLString)
-{
+void ResponsiveImageCandidate::SetURLSpec(const nsAString& aURLString) {
   mURLString = aURLString;
 }
 
-void
-ResponsiveImageCandidate::SetTriggeringPrincipal(nsIPrincipal* aPrincipal)
-{
+void ResponsiveImageCandidate::SetTriggeringPrincipal(
+    nsIPrincipal* aPrincipal) {
   mTriggeringPrincipal = aPrincipal;
 }
 
-void
-ResponsiveImageCandidate::SetParameterAsComputedWidth(int32_t aWidth)
-{
+void ResponsiveImageCandidate::SetParameterAsComputedWidth(int32_t aWidth) {
   mType = eCandidateType_ComputedFromWidth;
   mValue.mWidth = aWidth;
 }
 
-void
-ResponsiveImageCandidate::SetParameterDefault()
-{
+void ResponsiveImageCandidate::SetParameterDefault() {
   MOZ_ASSERT(mType == eCandidateType_Invalid, "double setting candidate type");
 
   mType = eCandidateType_Default;
@@ -541,18 +498,14 @@ ResponsiveImageCandidate::SetParameterDefault()
   mValue.mDensity = 1.0;
 }
 
-void
-ResponsiveImageCandidate::SetParameterInvalid()
-{
+void ResponsiveImageCandidate::SetParameterInvalid() {
   mType = eCandidateType_Invalid;
   // mValue shouldn't actually be used for this type, but set it to default
   // anyway
   mValue.mDensity = 1.0;
 }
 
-void
-ResponsiveImageCandidate::SetParameterAsDensity(double aDensity)
-{
+void ResponsiveImageCandidate::SetParameterAsDensity(double aDensity) {
   MOZ_ASSERT(mType == eCandidateType_Invalid, "double setting candidate type");
 
   mType = eCandidateType_Density;
@@ -563,8 +516,7 @@ ResponsiveImageCandidate::SetParameterAsDensity(double aDensity)
 // there is no candidate type that uses all of these. This should generally
 // match the mValue union of ResponsiveImageCandidate.
 struct ResponsiveImageDescriptors {
-  ResponsiveImageDescriptors()
-    : mInvalid(false) {};
+  ResponsiveImageDescriptors() : mInvalid(false){};
 
   Maybe<double> mDensity;
   Maybe<int32_t> mWidth;
@@ -579,16 +531,14 @@ struct ResponsiveImageDescriptors {
   void AddDescriptor(const nsAString& aDescriptor);
   bool Valid();
   // Use the current set of descriptors to configure a candidate
-  void FillCandidate(ResponsiveImageCandidate &aCandidate);
+  void FillCandidate(ResponsiveImageCandidate& aCandidate);
 };
 
 // Try to parse a single descriptor from a string. If value already set or
 // unknown, sets invalid flag.
 // This corresponds to the descriptor "Descriptor parser" step in:
 // https://html.spec.whatwg.org/#parse-a-srcset-attribute
-void
-ResponsiveImageDescriptors::AddDescriptor(const nsAString& aDescriptor)
-{
+void ResponsiveImageDescriptors::AddDescriptor(const nsAString& aDescriptor) {
   if (aDescriptor.IsEmpty()) {
     return;
   }
@@ -635,10 +585,8 @@ ResponsiveImageDescriptors::AddDescriptor(const nsAString& aDescriptor)
     // descriptor, fall through.
     double possibleDensity = 0.0;
     if (ParseFloat(valueStr, possibleDensity)) {
-      if (possibleDensity >= 0.0 &&
-          mWidth.isNothing() &&
-          mDensity.isNothing() &&
-          mFutureCompatHeight.isNothing()) {
+      if (possibleDensity >= 0.0 && mWidth.isNothing() &&
+          mDensity.isNothing() && mFutureCompatHeight.isNothing()) {
         mDensity.emplace(possibleDensity);
       } else {
         // Valid density descriptor, but height or width or density were already
@@ -654,23 +602,20 @@ ResponsiveImageDescriptors::AddDescriptor(const nsAString& aDescriptor)
   mInvalid = true;
 }
 
-bool
-ResponsiveImageDescriptors::Valid()
-{
+bool ResponsiveImageDescriptors::Valid() {
   return !mInvalid && !(mFutureCompatHeight.isSome() && mWidth.isNothing());
 }
 
-void
-ResponsiveImageDescriptors::FillCandidate(ResponsiveImageCandidate &aCandidate)
-{
+void ResponsiveImageDescriptors::FillCandidate(
+    ResponsiveImageCandidate& aCandidate) {
   if (!Valid()) {
     aCandidate.SetParameterInvalid();
   } else if (mWidth.isSome()) {
-    MOZ_ASSERT(mDensity.isNothing()); // Shouldn't be valid
+    MOZ_ASSERT(mDensity.isNothing());  // Shouldn't be valid
 
     aCandidate.SetParameterAsComputedWidth(*mWidth);
   } else if (mDensity.isSome()) {
-    MOZ_ASSERT(mWidth.isNothing()); // Shouldn't be valid
+    MOZ_ASSERT(mWidth.isNothing());  // Shouldn't be valid
 
     aCandidate.SetParameterAsDensity(*mDensity);
   } else {
@@ -680,12 +625,11 @@ ResponsiveImageDescriptors::FillCandidate(ResponsiveImageCandidate &aCandidate)
   }
 }
 
-bool
-ResponsiveImageCandidate::ConsumeDescriptors(nsAString::const_iterator& aIter,
-                                             const nsAString::const_iterator& aIterEnd)
-{
-  nsAString::const_iterator &iter = aIter;
-  const nsAString::const_iterator &end  = aIterEnd;
+bool ResponsiveImageCandidate::ConsumeDescriptors(
+    nsAString::const_iterator& aIter,
+    const nsAString::const_iterator& aIterEnd) {
+  nsAString::const_iterator& iter = aIter;
+  const nsAString::const_iterator& end = aIterEnd;
 
   bool inParens = false;
 
@@ -696,7 +640,8 @@ ResponsiveImageCandidate::ConsumeDescriptors(nsAString::const_iterator& aIter,
   // https://html.spec.whatwg.org/#parse-a-srcset-attribute
 
   // Skip initial whitespace
-  for (; iter != end && nsContentUtils::IsHTMLWhitespace(*iter); ++iter);
+  for (; iter != end && nsContentUtils::IsHTMLWhitespace(*iter); ++iter)
+    ;
 
   nsAString::const_iterator currentDescriptor = iter;
 
@@ -719,12 +664,14 @@ ResponsiveImageCandidate::ConsumeDescriptors(nsAString::const_iterator& aIter,
         // End of current descriptor, consume it, skip spaces
         // ("After descriptor" state in spec) before continuing
         descriptors.AddDescriptor(Substring(currentDescriptor, iter));
-        for (; iter != end && nsContentUtils::IsHTMLWhitespace(*iter); ++iter);
+        for (; iter != end && nsContentUtils::IsHTMLWhitespace(*iter); ++iter)
+          ;
         if (iter == end) {
           break;
         }
         currentDescriptor = iter;
-        // Leave one whitespace so the loop advances to this position next iteration
+        // Leave one whitespace so the loop advances to this position next
+        // iteration
         iter--;
       } else if (*iter == char16_t('(')) {
         inParens = true;
@@ -737,9 +684,8 @@ ResponsiveImageCandidate::ConsumeDescriptors(nsAString::const_iterator& aIter,
   return Type() != eCandidateType_Invalid;
 }
 
-bool
-ResponsiveImageCandidate::HasSameParameter(const ResponsiveImageCandidate & aOther) const
-{
+bool ResponsiveImageCandidate::HasSameParameter(
+    const ResponsiveImageCandidate& aOther) const {
   if (aOther.mType != mType) {
     return false;
   }
@@ -763,21 +709,16 @@ ResponsiveImageCandidate::HasSameParameter(const ResponsiveImageCandidate & aOth
   return false;
 }
 
-const nsAString&
-ResponsiveImageCandidate::URLString() const
-{
+const nsAString& ResponsiveImageCandidate::URLString() const {
   return mURLString;
 }
 
-nsIPrincipal*
-ResponsiveImageCandidate::TriggeringPrincipal() const
-{
+nsIPrincipal* ResponsiveImageCandidate::TriggeringPrincipal() const {
   return mTriggeringPrincipal;
 }
 
-double
-ResponsiveImageCandidate::Density(ResponsiveImageSelector *aSelector) const
-{
+double ResponsiveImageCandidate::Density(
+    ResponsiveImageSelector* aSelector) const {
   if (mType == eCandidateType_ComputedFromWidth) {
     double width;
     if (!aSelector->ComputeFinalWidthForCurrentViewport(&width)) {
@@ -792,9 +733,7 @@ ResponsiveImageCandidate::Density(ResponsiveImageSelector *aSelector) const
   return Density(-1);
 }
 
-double
-ResponsiveImageCandidate::Density(double aMatchingWidth) const
-{
+double ResponsiveImageCandidate::Density(double aMatchingWidth) const {
   if (mType == eCandidateType_Invalid) {
     MOZ_ASSERT(false, "Getting density for uninitialized candidate");
     return 1.0;
@@ -808,7 +747,9 @@ ResponsiveImageCandidate::Density(double aMatchingWidth) const
     return mValue.mDensity;
   } else if (mType == eCandidateType_ComputedFromWidth) {
     if (aMatchingWidth < 0) {
-      MOZ_ASSERT(false, "Don't expect to have a negative matching width at this point");
+      MOZ_ASSERT(
+          false,
+          "Don't expect to have a negative matching width at this point");
       return 1.0;
     }
     double density = double(mValue.mWidth) / aMatchingWidth;
@@ -820,9 +761,7 @@ ResponsiveImageCandidate::Density(double aMatchingWidth) const
   return 1.0;
 }
 
-bool
-ResponsiveImageCandidate::IsComputedFromWidth() const
-{
+bool ResponsiveImageCandidate::IsComputedFromWidth() const {
   if (mType == eCandidateType_ComputedFromWidth) {
     return true;
   }
@@ -832,5 +771,5 @@ ResponsiveImageCandidate::IsComputedFromWidth() const
   return false;
 }
 
-} // namespace dom
-} // namespace mozilla
+}  // namespace dom
+}  // namespace mozilla
