@@ -22,8 +22,7 @@
 using namespace mozilla;
 using namespace mozilla::dom;
 
-NS_IMPL_CYCLE_COLLECTION_INHERITED(ScreenOrientation,
-                                   DOMEventTargetHelper,
+NS_IMPL_CYCLE_COLLECTION_INHERITED(ScreenOrientation, DOMEventTargetHelper,
                                    mScreen);
 
 NS_INTERFACE_MAP_BEGIN_CYCLE_COLLECTION(ScreenOrientation)
@@ -32,43 +31,41 @@ NS_INTERFACE_MAP_END_INHERITING(DOMEventTargetHelper)
 NS_IMPL_ADDREF_INHERITED(ScreenOrientation, DOMEventTargetHelper)
 NS_IMPL_RELEASE_INHERITED(ScreenOrientation, DOMEventTargetHelper)
 
-static OrientationType
-InternalOrientationToType(ScreenOrientationInternal aOrientation)
-{
+static OrientationType InternalOrientationToType(
+    ScreenOrientationInternal aOrientation) {
   switch (aOrientation) {
-  case eScreenOrientation_PortraitPrimary:
-    return OrientationType::Portrait_primary;
-  case eScreenOrientation_PortraitSecondary:
-    return OrientationType::Portrait_secondary;
-  case eScreenOrientation_LandscapePrimary:
-    return OrientationType::Landscape_primary;
-  case eScreenOrientation_LandscapeSecondary:
-    return OrientationType::Landscape_secondary;
-  default:
-    MOZ_CRASH("Bad aOrientation value");
+    case eScreenOrientation_PortraitPrimary:
+      return OrientationType::Portrait_primary;
+    case eScreenOrientation_PortraitSecondary:
+      return OrientationType::Portrait_secondary;
+    case eScreenOrientation_LandscapePrimary:
+      return OrientationType::Landscape_primary;
+    case eScreenOrientation_LandscapeSecondary:
+      return OrientationType::Landscape_secondary;
+    default:
+      MOZ_CRASH("Bad aOrientation value");
   }
 }
 
-static ScreenOrientationInternal
-OrientationTypeToInternal(OrientationType aOrientation)
-{
+static ScreenOrientationInternal OrientationTypeToInternal(
+    OrientationType aOrientation) {
   switch (aOrientation) {
-  case OrientationType::Portrait_primary:
-    return eScreenOrientation_PortraitPrimary;
-  case OrientationType::Portrait_secondary:
-    return eScreenOrientation_PortraitSecondary;
-  case OrientationType::Landscape_primary:
-    return eScreenOrientation_LandscapePrimary;
-  case OrientationType::Landscape_secondary:
-    return eScreenOrientation_LandscapeSecondary;
-  default:
-    MOZ_CRASH("Bad aOrientation value");
+    case OrientationType::Portrait_primary:
+      return eScreenOrientation_PortraitPrimary;
+    case OrientationType::Portrait_secondary:
+      return eScreenOrientation_PortraitSecondary;
+    case OrientationType::Landscape_primary:
+      return eScreenOrientation_LandscapePrimary;
+    case OrientationType::Landscape_secondary:
+      return eScreenOrientation_LandscapeSecondary;
+    default:
+      MOZ_CRASH("Bad aOrientation value");
   }
 }
 
-ScreenOrientation::ScreenOrientation(nsPIDOMWindowInner* aWindow, nsScreen* aScreen)
-  : DOMEventTargetHelper(aWindow), mScreen(aScreen)
-{
+ScreenOrientation::ScreenOrientation(nsPIDOMWindowInner* aWindow,
+                                     nsScreen* aScreen)
+    : DOMEventTargetHelper(aWindow), mScreen(aScreen) {
   MOZ_ASSERT(aWindow);
   MOZ_ASSERT(aScreen);
 
@@ -85,45 +82,45 @@ ScreenOrientation::ScreenOrientation(nsPIDOMWindowInner* aWindow, nsScreen* aScr
   }
 }
 
-ScreenOrientation::~ScreenOrientation()
-{
+ScreenOrientation::~ScreenOrientation() {
   hal::UnregisterScreenConfigurationObserver(this);
   MOZ_ASSERT(!mFullScreenListener);
 }
 
-class ScreenOrientation::FullScreenEventListener final : public nsIDOMEventListener
-{
+class ScreenOrientation::FullScreenEventListener final
+    : public nsIDOMEventListener {
   ~FullScreenEventListener() {}
-public:
+
+ public:
   FullScreenEventListener() {}
 
   NS_DECL_ISUPPORTS
   NS_DECL_NSIDOMEVENTLISTENER
 };
 
-class ScreenOrientation::VisibleEventListener final : public nsIDOMEventListener
-{
+class ScreenOrientation::VisibleEventListener final
+    : public nsIDOMEventListener {
   ~VisibleEventListener() {}
-public:
+
+ public:
   VisibleEventListener() {}
 
   NS_DECL_ISUPPORTS
   NS_DECL_NSIDOMEVENTLISTENER
 };
 
-class ScreenOrientation::LockOrientationTask final : public nsIRunnable
-{
+class ScreenOrientation::LockOrientationTask final : public nsIRunnable {
   ~LockOrientationTask();
-public:
+
+ public:
   NS_DECL_ISUPPORTS
   NS_DECL_NSIRUNNABLE
 
-  LockOrientationTask(ScreenOrientation* aScreenOrientation,
-                      Promise* aPromise,
+  LockOrientationTask(ScreenOrientation* aScreenOrientation, Promise* aPromise,
                       ScreenOrientationInternal aOrientationLock,
-                      nsIDocument* aDocument,
-                      bool aIsFullScreen);
-protected:
+                      nsIDocument* aDocument, bool aIsFullScreen);
+
+ protected:
   bool OrientationLockContains(OrientationType aOrientationType);
 
   RefPtr<ScreenOrientation> mScreenOrientation;
@@ -136,32 +133,28 @@ protected:
 NS_IMPL_ISUPPORTS(ScreenOrientation::LockOrientationTask, nsIRunnable)
 
 ScreenOrientation::LockOrientationTask::LockOrientationTask(
-  ScreenOrientation* aScreenOrientation, Promise* aPromise,
-  ScreenOrientationInternal aOrientationLock,
-  nsIDocument* aDocument, bool aIsFullScreen)
-  : mScreenOrientation(aScreenOrientation), mPromise(aPromise),
-    mOrientationLock(aOrientationLock), mDocument(aDocument),
-    mIsFullScreen(aIsFullScreen)
-{
+    ScreenOrientation* aScreenOrientation, Promise* aPromise,
+    ScreenOrientationInternal aOrientationLock, nsIDocument* aDocument,
+    bool aIsFullScreen)
+    : mScreenOrientation(aScreenOrientation),
+      mPromise(aPromise),
+      mOrientationLock(aOrientationLock),
+      mDocument(aDocument),
+      mIsFullScreen(aIsFullScreen) {
   MOZ_ASSERT(aScreenOrientation);
   MOZ_ASSERT(aPromise);
   MOZ_ASSERT(aDocument);
 }
 
-ScreenOrientation::LockOrientationTask::~LockOrientationTask()
-{
-}
+ScreenOrientation::LockOrientationTask::~LockOrientationTask() {}
 
-bool
-ScreenOrientation::LockOrientationTask::OrientationLockContains(
-  OrientationType aOrientationType)
-{
+bool ScreenOrientation::LockOrientationTask::OrientationLockContains(
+    OrientationType aOrientationType) {
   return mOrientationLock & OrientationTypeToInternal(aOrientationType);
 }
 
 NS_IMETHODIMP
-ScreenOrientation::LockOrientationTask::Run()
-{
+ScreenOrientation::LockOrientationTask::Run() {
   // Step to lock the orientation as defined in the spec.
 
   if (mDocument->GetOrientationPendingPromise() != mPromise) {
@@ -210,53 +203,50 @@ ScreenOrientation::LockOrientationTask::Run()
   return NS_OK;
 }
 
-already_AddRefed<Promise>
-ScreenOrientation::Lock(OrientationLockType aOrientation, ErrorResult& aRv)
-{
+already_AddRefed<Promise> ScreenOrientation::Lock(
+    OrientationLockType aOrientation, ErrorResult& aRv) {
   ScreenOrientationInternal orientation = eScreenOrientation_None;
 
   switch (aOrientation) {
-  case OrientationLockType::Any:
-    orientation = eScreenOrientation_PortraitPrimary |
-                  eScreenOrientation_PortraitSecondary |
-                  eScreenOrientation_LandscapePrimary |
-                  eScreenOrientation_LandscapeSecondary;
-    break;
-  case OrientationLockType::Natural:
-    orientation |= eScreenOrientation_Default;
-    break;
-  case OrientationLockType::Landscape:
-    orientation = eScreenOrientation_LandscapePrimary |
-                  eScreenOrientation_LandscapeSecondary;
-    break;
-  case OrientationLockType::Portrait:
-    orientation = eScreenOrientation_PortraitPrimary |
-                  eScreenOrientation_PortraitSecondary;
-    break;
-  case OrientationLockType::Portrait_primary:
-    orientation = eScreenOrientation_PortraitPrimary;
-    break;
-  case OrientationLockType::Portrait_secondary:
-    orientation = eScreenOrientation_PortraitSecondary;
-    break;
-  case OrientationLockType::Landscape_primary:
-    orientation = eScreenOrientation_LandscapePrimary;
-    break;
-  case OrientationLockType::Landscape_secondary:
-    orientation = eScreenOrientation_LandscapeSecondary;
-    break;
-  default:
-    NS_WARNING("Unexpected orientation type");
-    aRv.Throw(NS_ERROR_UNEXPECTED);
-    return nullptr;
+    case OrientationLockType::Any:
+      orientation = eScreenOrientation_PortraitPrimary |
+                    eScreenOrientation_PortraitSecondary |
+                    eScreenOrientation_LandscapePrimary |
+                    eScreenOrientation_LandscapeSecondary;
+      break;
+    case OrientationLockType::Natural:
+      orientation |= eScreenOrientation_Default;
+      break;
+    case OrientationLockType::Landscape:
+      orientation = eScreenOrientation_LandscapePrimary |
+                    eScreenOrientation_LandscapeSecondary;
+      break;
+    case OrientationLockType::Portrait:
+      orientation = eScreenOrientation_PortraitPrimary |
+                    eScreenOrientation_PortraitSecondary;
+      break;
+    case OrientationLockType::Portrait_primary:
+      orientation = eScreenOrientation_PortraitPrimary;
+      break;
+    case OrientationLockType::Portrait_secondary:
+      orientation = eScreenOrientation_PortraitSecondary;
+      break;
+    case OrientationLockType::Landscape_primary:
+      orientation = eScreenOrientation_LandscapePrimary;
+      break;
+    case OrientationLockType::Landscape_secondary:
+      orientation = eScreenOrientation_LandscapeSecondary;
+      break;
+    default:
+      NS_WARNING("Unexpected orientation type");
+      aRv.Throw(NS_ERROR_UNEXPECTED);
+      return nullptr;
   }
 
   return LockInternal(orientation, aRv);
 }
 
-static inline void
-AbortOrientationPromises(nsIDocShell* aDocShell)
-{
+static inline void AbortOrientationPromises(nsIDocShell* aDocShell) {
   MOZ_ASSERT(aDocShell);
 
   nsIDocument* doc = aDocShell->GetDocument();
@@ -281,9 +271,8 @@ AbortOrientationPromises(nsIDocShell* aDocShell)
   }
 }
 
-already_AddRefed<Promise>
-ScreenOrientation::LockInternal(ScreenOrientationInternal aOrientation, ErrorResult& aRv)
-{
+already_AddRefed<Promise> ScreenOrientation::LockInternal(
+    ScreenOrientationInternal aOrientation, ErrorResult& aRv) {
   // Steps to apply an orientation lock as defined in spec.
 
   nsIDocument* doc = GetResponsibleDocument();
@@ -335,9 +324,8 @@ ScreenOrientation::LockInternal(ScreenOrientationInternal aOrientation, ErrorRes
 
   doc->SetOrientationPendingPromise(p);
 
-  nsCOMPtr<nsIRunnable> lockOrientationTask =
-    new LockOrientationTask(this, p, aOrientation, doc,
-                            perm == FULLSCREEN_LOCK_ALLOWED);
+  nsCOMPtr<nsIRunnable> lockOrientationTask = new LockOrientationTask(
+      this, p, aOrientation, doc, perm == FULLSCREEN_LOCK_ALLOWED);
   aRv = NS_DispatchToMainThread(lockOrientationTask);
   if (NS_WARN_IF(aRv.Failed())) {
     return nullptr;
@@ -347,10 +335,9 @@ ScreenOrientation::LockInternal(ScreenOrientationInternal aOrientation, ErrorRes
 #endif
 }
 
-bool
-ScreenOrientation::LockDeviceOrientation(ScreenOrientationInternal aOrientation,
-                                         bool aIsFullScreen, ErrorResult& aRv)
-{
+bool ScreenOrientation::LockDeviceOrientation(
+    ScreenOrientationInternal aOrientation, bool aIsFullScreen,
+    ErrorResult& aRv) {
   if (!GetOwner()) {
     aRv.Throw(NS_ERROR_UNEXPECTED);
     return false;
@@ -376,7 +363,8 @@ ScreenOrientation::LockDeviceOrientation(ScreenOrientationInternal aOrientation,
     }
 
     aRv = target->AddSystemEventListener(NS_LITERAL_STRING("fullscreenchange"),
-                                         mFullScreenListener, /* useCapture = */ true);
+                                         mFullScreenListener,
+                                         /* useCapture = */ true);
     if (NS_WARN_IF(aRv.Failed())) {
       return false;
     }
@@ -385,15 +373,11 @@ ScreenOrientation::LockDeviceOrientation(ScreenOrientationInternal aOrientation,
   return true;
 }
 
-void
-ScreenOrientation::Unlock(ErrorResult& aRv)
-{
+void ScreenOrientation::Unlock(ErrorResult& aRv) {
   RefPtr<Promise> p = LockInternal(eScreenOrientation_None, aRv);
 }
 
-void
-ScreenOrientation::UnlockDeviceOrientation()
-{
+void ScreenOrientation::UnlockDeviceOrientation() {
   hal::UnlockScreenOrientation();
 
   if (!mFullScreenListener || !GetOwner()) {
@@ -404,32 +388,27 @@ ScreenOrientation::UnlockDeviceOrientation()
   // Remove event listener in case of fullscreen lock.
   nsCOMPtr<EventTarget> target = do_QueryInterface(GetOwner()->GetDoc());
   if (target) {
-    DebugOnly<nsresult> rv =
-      target->RemoveSystemEventListener(NS_LITERAL_STRING("fullscreenchange"),
-                                        mFullScreenListener,
-                                        /* useCapture */ true);
+    DebugOnly<nsresult> rv = target->RemoveSystemEventListener(
+        NS_LITERAL_STRING("fullscreenchange"), mFullScreenListener,
+        /* useCapture */ true);
     NS_WARNING_ASSERTION(NS_SUCCEEDED(rv), "RemoveSystemEventListener failed");
   }
 
   mFullScreenListener = nullptr;
 }
 
-OrientationType
-ScreenOrientation::DeviceType(CallerType aCallerType) const
-{
-  return nsContentUtils::ResistFingerprinting(aCallerType) ?
-    OrientationType::Landscape_primary : mType;
+OrientationType ScreenOrientation::DeviceType(CallerType aCallerType) const {
+  return nsContentUtils::ResistFingerprinting(aCallerType)
+             ? OrientationType::Landscape_primary
+             : mType;
 }
 
-uint16_t
-ScreenOrientation::DeviceAngle(CallerType aCallerType) const
-{
+uint16_t ScreenOrientation::DeviceAngle(CallerType aCallerType) const {
   return nsContentUtils::ResistFingerprinting(aCallerType) ? 0 : mAngle;
 }
 
-OrientationType
-ScreenOrientation::GetType(CallerType aCallerType, ErrorResult& aRv) const
-{
+OrientationType ScreenOrientation::GetType(CallerType aCallerType,
+                                           ErrorResult& aRv) const {
   if (nsContentUtils::ResistFingerprinting(aCallerType)) {
     return OrientationType::Landscape_primary;
   }
@@ -443,9 +422,8 @@ ScreenOrientation::GetType(CallerType aCallerType, ErrorResult& aRv) const
   return doc->CurrentOrientationType();
 }
 
-uint16_t
-ScreenOrientation::GetAngle(CallerType aCallerType, ErrorResult& aRv) const
-{
+uint16_t ScreenOrientation::GetAngle(CallerType aCallerType,
+                                     ErrorResult& aRv) const {
   if (nsContentUtils::ResistFingerprinting(aCallerType)) {
     return 0;
   }
@@ -460,8 +438,7 @@ ScreenOrientation::GetAngle(CallerType aCallerType, ErrorResult& aRv) const
 }
 
 ScreenOrientation::LockPermission
-ScreenOrientation::GetLockOrientationPermission(bool aCheckSandbox) const
-{
+ScreenOrientation::GetLockOrientationPermission(bool aCheckSandbox) const {
   nsCOMPtr<nsPIDOMWindowInner> owner = GetOwner();
   if (!owner) {
     return LOCK_DENIED;
@@ -483,8 +460,8 @@ ScreenOrientation::GetLockOrientationPermission(bool aCheckSandbox) const
     return LOCK_DENIED;
   }
 
-  if (Preferences::GetBool("dom.screenorientation.testing.non_fullscreen_lock_allow",
-                           false)) {
+  if (Preferences::GetBool(
+          "dom.screenorientation.testing.non_fullscreen_lock_allow", false)) {
     return LOCK_ALLOWED;
   }
 
@@ -492,9 +469,7 @@ ScreenOrientation::GetLockOrientationPermission(bool aCheckSandbox) const
   return doc->Fullscreen() ? FULLSCREEN_LOCK_ALLOWED : LOCK_DENIED;
 }
 
-nsIDocument*
-ScreenOrientation::GetResponsibleDocument() const
-{
+nsIDocument* ScreenOrientation::GetResponsibleDocument() const {
   nsCOMPtr<nsPIDOMWindowInner> owner = GetOwner();
   if (!owner) {
     return nullptr;
@@ -503,9 +478,7 @@ ScreenOrientation::GetResponsibleDocument() const
   return owner->GetDoc();
 }
 
-void
-ScreenOrientation::Notify(const hal::ScreenConfiguration& aConfiguration)
-{
+void ScreenOrientation::Notify(const hal::ScreenConfiguration& aConfiguration) {
   if (ShouldResistFingerprinting()) {
     return;
   }
@@ -534,7 +507,8 @@ ScreenOrientation::Notify(const hal::ScreenConfiguration& aConfiguration)
   DebugOnly<nsresult> rv;
   if (mScreen && mType != previousOrientation) {
     // Use of mozorientationchange is deprecated.
-    rv = mScreen->DispatchTrustedEvent(NS_LITERAL_STRING("mozorientationchange"));
+    rv = mScreen->DispatchTrustedEvent(
+        NS_LITERAL_STRING("mozorientationchange"));
     NS_WARNING_ASSERTION(NS_SUCCEEDED(rv), "DispatchTrustedEvent failed");
   }
 
@@ -556,17 +530,15 @@ ScreenOrientation::Notify(const hal::ScreenConfiguration& aConfiguration)
     }
 
     nsCOMPtr<nsIRunnable> runnable =
-      NewRunnableMethod("dom::ScreenOrientation::DispatchChangeEvent",
-                        this,
-                        &ScreenOrientation::DispatchChangeEvent);
+        NewRunnableMethod("dom::ScreenOrientation::DispatchChangeEvent", this,
+                          &ScreenOrientation::DispatchChangeEvent);
     rv = NS_DispatchToMainThread(runnable);
     NS_WARNING_ASSERTION(NS_SUCCEEDED(rv), "NS_DispatchToMainThread failed");
   }
 }
 
-void
-ScreenOrientation::UpdateActiveOrientationLock(ScreenOrientationInternal aOrientation)
-{
+void ScreenOrientation::UpdateActiveOrientationLock(
+    ScreenOrientationInternal aOrientation) {
   if (aOrientation == eScreenOrientation_None) {
     hal::UnlockScreenOrientation();
   } else {
@@ -575,22 +547,17 @@ ScreenOrientation::UpdateActiveOrientationLock(ScreenOrientationInternal aOrient
   }
 }
 
-void
-ScreenOrientation::DispatchChangeEvent()
-{
+void ScreenOrientation::DispatchChangeEvent() {
   DebugOnly<nsresult> rv = DispatchTrustedEvent(NS_LITERAL_STRING("change"));
   NS_WARNING_ASSERTION(NS_SUCCEEDED(rv), "DispatchTrustedEvent failed");
 }
 
-JSObject*
-ScreenOrientation::WrapObject(JSContext* aCx, JS::Handle<JSObject*> aGivenProto)
-{
+JSObject* ScreenOrientation::WrapObject(JSContext* aCx,
+                                        JS::Handle<JSObject*> aGivenProto) {
   return ScreenOrientationBinding::Wrap(aCx, this, aGivenProto);
 }
 
-bool
-ScreenOrientation::ShouldResistFingerprinting() const
-{
+bool ScreenOrientation::ShouldResistFingerprinting() const {
   bool resist = false;
   if (nsCOMPtr<nsPIDOMWindowInner> owner = GetOwner()) {
     resist = nsContentUtils::ShouldResistFingerprinting(owner->GetDocShell());
@@ -601,8 +568,7 @@ ScreenOrientation::ShouldResistFingerprinting() const
 NS_IMPL_ISUPPORTS(ScreenOrientation::VisibleEventListener, nsIDOMEventListener)
 
 NS_IMETHODIMP
-ScreenOrientation::VisibleEventListener::HandleEvent(nsIDOMEvent* aEvent)
-{
+ScreenOrientation::VisibleEventListener::HandleEvent(nsIDOMEvent* aEvent) {
   // Document may have become visible, if the page is visible, run the steps
   // following the "now visible algorithm" as specified.
   nsCOMPtr<EventTarget> target = aEvent->InternalDOMEvent()->GetCurrentTarget();
@@ -634,9 +600,10 @@ ScreenOrientation::VisibleEventListener::HandleEvent(nsIDOMEvent* aEvent)
     return rv.StealNSResult();
   }
 
-  if (doc->CurrentOrientationType() != orientation->DeviceType(CallerType::System)) {
+  if (doc->CurrentOrientationType() !=
+      orientation->DeviceType(CallerType::System)) {
     doc->SetCurrentOrientation(orientation->DeviceType(CallerType::System),
-			       orientation->DeviceAngle(CallerType::System));
+                               orientation->DeviceAngle(CallerType::System));
 
     Promise* pendingPromise = doc->GetOrientationPendingPromise();
     if (pendingPromise) {
@@ -645,9 +612,8 @@ ScreenOrientation::VisibleEventListener::HandleEvent(nsIDOMEvent* aEvent)
     }
 
     nsCOMPtr<nsIRunnable> runnable =
-      NewRunnableMethod("dom::ScreenOrientation::DispatchChangeEvent",
-                        orientation,
-                        &ScreenOrientation::DispatchChangeEvent);
+        NewRunnableMethod("dom::ScreenOrientation::DispatchChangeEvent",
+                          orientation, &ScreenOrientation::DispatchChangeEvent);
     rv = NS_DispatchToMainThread(runnable);
     if (NS_WARN_IF(rv.Failed())) {
       return rv.StealNSResult();
@@ -657,11 +623,11 @@ ScreenOrientation::VisibleEventListener::HandleEvent(nsIDOMEvent* aEvent)
   return NS_OK;
 }
 
-NS_IMPL_ISUPPORTS(ScreenOrientation::FullScreenEventListener, nsIDOMEventListener)
+NS_IMPL_ISUPPORTS(ScreenOrientation::FullScreenEventListener,
+                  nsIDOMEventListener)
 
 NS_IMETHODIMP
-ScreenOrientation::FullScreenEventListener::HandleEvent(nsIDOMEvent* aEvent)
-{
+ScreenOrientation::FullScreenEventListener::HandleEvent(nsIDOMEvent* aEvent) {
 #ifdef DEBUG
   nsAutoString eventType;
   aEvent->GetType(eventType);
@@ -684,8 +650,8 @@ ScreenOrientation::FullScreenEventListener::HandleEvent(nsIDOMEvent* aEvent)
 
   hal::UnlockScreenOrientation();
 
-  nsresult rv = target->RemoveSystemEventListener(NS_LITERAL_STRING("fullscreenchange"),
-                                                  this, true);
+  nsresult rv = target->RemoveSystemEventListener(
+      NS_LITERAL_STRING("fullscreenchange"), this, true);
   NS_ENSURE_SUCCESS(rv, rv);
 
   return NS_OK;
