@@ -62,38 +62,31 @@
 using namespace mozilla::dom;
 using mozilla::IgnoreErrors;
 
-class MOZ_STACK_CLASS DragDataProducer
-{
-public:
-  DragDataProducer(nsPIDOMWindowOuter* aWindow,
-                   nsIContent* aTarget,
-                   nsIContent* aSelectionTargetNode,
-                   bool aIsAltKeyPressed);
-  nsresult Produce(DataTransfer* aDataTransfer,
-                   bool* aCanDrag,
-                   nsISelection** aSelection,
-                   nsIContent** aDragNode,
+class MOZ_STACK_CLASS DragDataProducer {
+ public:
+  DragDataProducer(nsPIDOMWindowOuter* aWindow, nsIContent* aTarget,
+                   nsIContent* aSelectionTargetNode, bool aIsAltKeyPressed);
+  nsresult Produce(DataTransfer* aDataTransfer, bool* aCanDrag,
+                   nsISelection** aSelection, nsIContent** aDragNode,
                    nsACString& aPrincipalURISpec);
 
-private:
-  void AddString(DataTransfer* aDataTransfer,
-                 const nsAString& aFlavor,
-                 const nsAString& aData,
-                 nsIPrincipal* aPrincipal,
-                 bool aHidden=false);
+ private:
+  void AddString(DataTransfer* aDataTransfer, const nsAString& aFlavor,
+                 const nsAString& aData, nsIPrincipal* aPrincipal,
+                 bool aHidden = false);
   nsresult AddStringsToDataTransfer(nsIContent* aDragNode,
                                     DataTransfer* aDataTransfer);
   nsresult GetImageData(imgIContainer* aImage, imgIRequest* aRequest);
   static nsresult GetDraggableSelectionData(nsISelection* inSelection,
                                             nsIContent* inRealTargetNode,
-                                            nsIContent **outImageOrLinkNode,
+                                            nsIContent** outImageOrLinkNode,
                                             bool* outDragSelectedText);
   static already_AddRefed<nsIContent> FindParentLinkNode(nsIContent* inNode);
-  static MOZ_MUST_USE nsresult
-  GetAnchorURL(nsIContent* inNode, nsAString& outURL);
-  static void GetNodeString(nsIContent* inNode, nsAString & outNodeString);
-  static void CreateLinkText(const nsAString& inURL, const nsAString & inText,
-                              nsAString& outLinkText);
+  static MOZ_MUST_USE nsresult GetAnchorURL(nsIContent* inNode,
+                                            nsAString& outURL);
+  static void GetNodeString(nsIContent* inNode, nsAString& outNodeString);
+  static void CreateLinkText(const nsAString& inURL, const nsAString& inText,
+                             nsAString& outLinkText);
 
   nsCOMPtr<nsPIDOMWindowOuter> mWindow;
   nsCOMPtr<nsIContent> mTarget;
@@ -103,7 +96,7 @@ private:
   nsString mUrlString;
   nsString mImageSourceString;
   nsString mImageDestFileName;
-#if defined (XP_MACOSX)
+#if defined(XP_MACOSX)
   nsString mImageRequestMime;
 #endif
   nsString mTitleString;
@@ -116,39 +109,29 @@ private:
   nsCOMPtr<imgIContainer> mImage;
 };
 
-
-nsresult
-nsContentAreaDragDrop::GetDragData(nsPIDOMWindowOuter* aWindow,
-                                   nsIContent* aTarget,
-                                   nsIContent* aSelectionTargetNode,
-                                   bool aIsAltKeyPressed,
-                                   DataTransfer* aDataTransfer,
-                                   bool* aCanDrag,
-                                   nsISelection** aSelection,
-                                   nsIContent** aDragNode,
-                                   nsACString& aPrincipalURISpec)
-{
+nsresult nsContentAreaDragDrop::GetDragData(
+    nsPIDOMWindowOuter* aWindow, nsIContent* aTarget,
+    nsIContent* aSelectionTargetNode, bool aIsAltKeyPressed,
+    DataTransfer* aDataTransfer, bool* aCanDrag, nsISelection** aSelection,
+    nsIContent** aDragNode, nsACString& aPrincipalURISpec) {
   NS_ENSURE_TRUE(aSelectionTargetNode, NS_ERROR_INVALID_ARG);
 
   *aCanDrag = true;
 
-  DragDataProducer
-    provider(aWindow, aTarget, aSelectionTargetNode, aIsAltKeyPressed);
+  DragDataProducer provider(aWindow, aTarget, aSelectionTargetNode,
+                            aIsAltKeyPressed);
   return provider.Produce(aDataTransfer, aCanDrag, aSelection, aDragNode,
                           aPrincipalURISpec);
 }
 
-
 NS_IMPL_ISUPPORTS(nsContentAreaDragDropDataProvider, nsIFlavorDataProvider)
 
 // SaveURIToFile
 // used on platforms where it's possible to drag items (e.g. images)
 // into the file system
-nsresult
-nsContentAreaDragDropDataProvider::SaveURIToFile(nsIURI* inSourceURI,
-                                                 nsIFile* inDestFile,
-                                                 bool isPrivate)
-{
+nsresult nsContentAreaDragDropDataProvider::SaveURIToFile(nsIURI* inSourceURI,
+                                                          nsIFile* inDestFile,
+                                                          bool isPrivate) {
   nsCOMPtr<nsIURL> sourceURL = do_QueryInterface(inSourceURI);
   if (!sourceURL) {
     return NS_ERROR_NO_INTERFACE;
@@ -159,17 +142,16 @@ nsContentAreaDragDropDataProvider::SaveURIToFile(nsIURI* inSourceURI,
 
   // we rely on the fact that the WPB is refcounted by the channel etc,
   // so we don't keep a ref to it. It will die when finished.
-  nsCOMPtr<nsIWebBrowserPersist> persist =
-    do_CreateInstance("@mozilla.org/embedding/browser/nsWebBrowserPersist;1",
-                      &rv);
+  nsCOMPtr<nsIWebBrowserPersist> persist = do_CreateInstance(
+      "@mozilla.org/embedding/browser/nsWebBrowserPersist;1", &rv);
   NS_ENSURE_SUCCESS(rv, rv);
 
-  persist->SetPersistFlags(nsIWebBrowserPersist::PERSIST_FLAGS_AUTODETECT_APPLY_CONVERSION);
+  persist->SetPersistFlags(
+      nsIWebBrowserPersist::PERSIST_FLAGS_AUTODETECT_APPLY_CONVERSION);
 
   // referrer policy can be anything since the referrer is nullptr
   return persist->SavePrivacyAwareURI(inSourceURI, nullptr, nullptr,
-                                      mozilla::net::RP_Unset,
-                                      nullptr, nullptr,
+                                      mozilla::net::RP_Unset, nullptr, nullptr,
                                       inDestFile, isPrivate);
 }
 
@@ -185,12 +167,10 @@ nsContentAreaDragDropDataProvider::SaveURIToFile(nsIURI* inSourceURI,
  *                                   to potentially be used as a replacement
  *                                   for |aExtension|
  */
-nsresult
-CheckAndGetExtensionForMime(const nsCString& aExtension,
-                            const nsCString& aMimeType,
-                            bool* aIsValidExtension,
-                            nsACString* aPrimaryExtension)
-{
+nsresult CheckAndGetExtensionForMime(const nsCString& aExtension,
+                                     const nsCString& aMimeType,
+                                     bool* aIsValidExtension,
+                                     nsACString* aPrimaryExtension) {
   nsresult rv;
 
   nsCOMPtr<nsIMIMEService> mimeService = do_GetService("@mozilla.org/mime;1");
@@ -231,11 +211,10 @@ CheckAndGetExtensionForMime(const nsCString& aExtension,
 //    OS-specific drag information.
 //
 NS_IMETHODIMP
-nsContentAreaDragDropDataProvider::GetFlavorData(nsITransferable *aTransferable,
-                                                 const char *aFlavor,
-                                                 nsISupports **aData,
-                                                 uint32_t *aDataLen)
-{
+nsContentAreaDragDropDataProvider::GetFlavorData(nsITransferable* aTransferable,
+                                                 const char* aFlavor,
+                                                 nsISupports** aData,
+                                                 uint32_t* aDataLen) {
   NS_ENSURE_ARG_POINTER(aData && aDataLen);
   *aData = nullptr;
   *aDataLen = 0;
@@ -247,17 +226,14 @@ nsContentAreaDragDropDataProvider::GetFlavorData(nsITransferable *aTransferable,
     NS_ENSURE_ARG(aTransferable);
     nsCOMPtr<nsISupports> tmp;
     uint32_t dataSize = 0;
-    aTransferable->GetTransferData(kFilePromiseURLMime,
-                                   getter_AddRefs(tmp), &dataSize);
-    nsCOMPtr<nsISupportsString> supportsString =
-      do_QueryInterface(tmp);
-    if (!supportsString)
-      return NS_ERROR_FAILURE;
+    aTransferable->GetTransferData(kFilePromiseURLMime, getter_AddRefs(tmp),
+                                   &dataSize);
+    nsCOMPtr<nsISupportsString> supportsString = do_QueryInterface(tmp);
+    if (!supportsString) return NS_ERROR_FAILURE;
 
     nsAutoString sourceURLString;
     supportsString->GetData(sourceURLString);
-    if (sourceURLString.IsEmpty())
-      return NS_ERROR_FAILURE;
+    if (sourceURLString.IsEmpty()) return NS_ERROR_FAILURE;
 
     nsCOMPtr<nsIURI> sourceURI;
     rv = NS_NewURI(getter_AddRefs(sourceURI), sourceURLString);
@@ -266,13 +242,11 @@ nsContentAreaDragDropDataProvider::GetFlavorData(nsITransferable *aTransferable,
     aTransferable->GetTransferData(kFilePromiseDestFilename,
                                    getter_AddRefs(tmp), &dataSize);
     supportsString = do_QueryInterface(tmp);
-    if (!supportsString)
-      return NS_ERROR_FAILURE;
+    if (!supportsString) return NS_ERROR_FAILURE;
 
     nsAutoString targetFilename;
     supportsString->GetData(targetFilename);
-    if (targetFilename.IsEmpty())
-      return NS_ERROR_FAILURE;
+    if (targetFilename.IsEmpty()) return NS_ERROR_FAILURE;
 
 #if defined(XP_MACOSX)
     // Use the image request's MIME type to ensure the filename's
@@ -282,11 +256,10 @@ nsContentAreaDragDropDataProvider::GetFlavorData(nsITransferable *aTransferable,
     // because sandboxing blocks access to MIME-handler info from
     // content processes.
     if (XRE_IsParentProcess()) {
-      aTransferable->GetTransferData(kImageRequestMime,
-                                     getter_AddRefs(tmp), &dataSize);
+      aTransferable->GetTransferData(kImageRequestMime, getter_AddRefs(tmp),
+                                     &dataSize);
       supportsString = do_QueryInterface(tmp);
-      if (!supportsString)
-        return NS_ERROR_FAILURE;
+      if (!supportsString) return NS_ERROR_FAILURE;
 
       nsAutoString imageRequestMime;
       supportsString->GetData(imageRequestMime);
@@ -304,10 +277,8 @@ nsContentAreaDragDropDataProvider::GetFlavorData(nsITransferable *aTransferable,
         NS_ConvertUTF16toUTF8 mimeCString(imageRequestMime);
         bool isValidExtension;
         nsAutoCString primaryExtension;
-        rv = CheckAndGetExtensionForMime(extension,
-                                         mimeCString,
-                                         &isValidExtension,
-                                         &primaryExtension);
+        rv = CheckAndGetExtensionForMime(extension, mimeCString,
+                                         &isValidExtension, &primaryExtension);
         NS_ENSURE_SUCCESS(rv, rv);
 
         if (!isValidExtension) {
@@ -335,8 +306,7 @@ nsContentAreaDragDropDataProvider::GetFlavorData(nsITransferable *aTransferable,
     aTransferable->GetTransferData(kFilePromiseDirectoryMime,
                                    getter_AddRefs(dirPrimitive), &dataSize);
     nsCOMPtr<nsIFile> destDirectory = do_QueryInterface(dirPrimitive);
-    if (!destDirectory)
-      return NS_ERROR_FAILURE;
+    if (!destDirectory) return NS_ERROR_FAILURE;
 
     nsCOMPtr<nsIFile> file;
     rv = destDirectory->Clone(getter_AddRefs(file));
@@ -362,14 +332,11 @@ DragDataProducer::DragDataProducer(nsPIDOMWindowOuter* aWindow,
                                    nsIContent* aTarget,
                                    nsIContent* aSelectionTargetNode,
                                    bool aIsAltKeyPressed)
-  : mWindow(aWindow),
-    mTarget(aTarget),
-    mSelectionTargetNode(aSelectionTargetNode),
-    mIsAltKeyPressed(aIsAltKeyPressed),
-    mIsAnchor(false)
-{
-}
-
+    : mWindow(aWindow),
+      mTarget(aTarget),
+      mSelectionTargetNode(aSelectionTargetNode),
+      mIsAltKeyPressed(aIsAltKeyPressed),
+      mIsAnchor(false) {}
 
 //
 // FindParentLinkNode
@@ -378,9 +345,8 @@ DragDataProducer::DragDataProducer(nsPIDOMWindowOuter* aWindow,
 // it gets up to the root without finding it, we stop looking and
 // return null.
 //
-already_AddRefed<nsIContent>
-DragDataProducer::FindParentLinkNode(nsIContent* inNode)
-{
+already_AddRefed<nsIContent> DragDataProducer::FindParentLinkNode(
+    nsIContent* inNode) {
   nsIContent* content = inNode;
   if (!content) {
     // That must have been the document node; nothing else to do here;
@@ -397,13 +363,10 @@ DragDataProducer::FindParentLinkNode(nsIContent* inNode)
   return nullptr;
 }
 
-
 //
 // GetAnchorURL
 //
-nsresult
-DragDataProducer::GetAnchorURL(nsIContent* inNode, nsAString& outURL)
-{
+nsresult DragDataProducer::GetAnchorURL(nsIContent* inNode, nsAString& outURL) {
   nsCOMPtr<nsIURI> linkURI;
   if (!inNode || !inNode->IsLink(getter_AddRefs(linkURI))) {
     // Not a link
@@ -418,40 +381,32 @@ DragDataProducer::GetAnchorURL(nsIContent* inNode, nsAString& outURL)
   return NS_OK;
 }
 
-
 //
 // CreateLinkText
 //
 // Creates the html for an anchor in the form
 //  <a href="inURL">inText</a>
 //
-void
-DragDataProducer::CreateLinkText(const nsAString& inURL,
-                                 const nsAString & inText,
-                                 nsAString& outLinkText)
-{
+void DragDataProducer::CreateLinkText(const nsAString& inURL,
+                                      const nsAString& inText,
+                                      nsAString& outLinkText) {
   // use a temp var in case |inText| is the same string as
   // |outLinkText| to avoid overwriting it while building up the
   // string in pieces.
-  nsAutoString linkText(NS_LITERAL_STRING("<a href=\"") +
-                        inURL +
-                        NS_LITERAL_STRING("\">") +
-                        inText +
-                        NS_LITERAL_STRING("</a>") );
+  nsAutoString linkText(NS_LITERAL_STRING("<a href=\"") + inURL +
+                        NS_LITERAL_STRING("\">") + inText +
+                        NS_LITERAL_STRING("</a>"));
 
   outLinkText = linkText;
 }
 
-
 //
 // GetNodeString
 //
 // Gets the text associated with a node
 //
-void
-DragDataProducer::GetNodeString(nsIContent* inNode,
-                                nsAString & outNodeString)
-{
+void DragDataProducer::GetNodeString(nsIContent* inNode,
+                                     nsAString& outNodeString) {
   nsCOMPtr<nsINode> node = inNode;
 
   outNodeString.Truncate();
@@ -465,9 +420,8 @@ DragDataProducer::GetNodeString(nsIContent* inNode,
   }
 }
 
-nsresult
-DragDataProducer::GetImageData(imgIContainer* aImage, imgIRequest* aRequest)
-{
+nsresult DragDataProducer::GetImageData(imgIContainer* aImage,
+                                        imgIRequest* aRequest) {
   nsCOMPtr<nsIURI> imgUri;
   aRequest->GetURI(getter_AddRefs(imgUri));
 
@@ -497,24 +451,23 @@ DragDataProducer::GetImageData(imgIContainer* aImage, imgIRequest* aRequest)
 
     nsCOMPtr<nsIMIMEInfo> mimeInfo;
     mimeService->GetFromTypeAndExtension(mimeType, EmptyCString(),
-					 getter_AddRefs(mimeInfo));
+                                         getter_AddRefs(mimeInfo));
     if (mimeInfo) {
       nsAutoCString extension;
       imgUrl->GetFileExtension(extension);
 
       bool validExtension;
       if (extension.IsEmpty() ||
-          NS_FAILED(mimeInfo->ExtensionExists(extension,
-                                              &validExtension)) ||
+          NS_FAILED(mimeInfo->ExtensionExists(extension, &validExtension)) ||
           !validExtension) {
         // Fix the file extension in the URL
         nsAutoCString primaryExtension;
         mimeInfo->GetPrimaryExtension(primaryExtension);
 
         rv = NS_MutateURI(imgUrl)
-               .Apply(NS_MutatorMethod(&nsIURLMutator::SetFileExtension,
-                                       primaryExtension, nullptr))
-               .Finalize(imgUrl);
+                 .Apply(NS_MutatorMethod(&nsIURLMutator::SetFileExtension,
+                                         primaryExtension, nullptr))
+                 .Finalize(imgUrl);
         NS_ENSURE_SUCCESS(rv, rv);
       }
     }
@@ -539,17 +492,15 @@ DragDataProducer::GetImageData(imgIContainer* aImage, imgIRequest* aRequest)
   return NS_OK;
 }
 
-nsresult
-DragDataProducer::Produce(DataTransfer* aDataTransfer,
-                          bool* aCanDrag,
-                          nsISelection** aSelection,
-                          nsIContent** aDragNode,
-                          nsACString& aPrincipalURISpec)
-{
+nsresult DragDataProducer::Produce(DataTransfer* aDataTransfer, bool* aCanDrag,
+                                   nsISelection** aSelection,
+                                   nsIContent** aDragNode,
+                                   nsACString& aPrincipalURISpec) {
   NS_PRECONDITION(aCanDrag && aSelection && aDataTransfer && aDragNode,
                   "null pointer passed to Produce");
   NS_ASSERTION(mWindow, "window not set");
-  NS_ASSERTION(mSelectionTargetNode, "selection target node should have been set");
+  NS_ASSERTION(mSelectionTargetNode,
+               "selection target node should have been set");
 
   *aDragNode = nullptr;
 
@@ -561,26 +512,26 @@ DragDataProducer::Produce(DataTransfer* aDataTransfer,
   // dragging is in what is selected. If this is an editable textbox, use
   // the textbox's selection, otherwise use the window's selection.
   nsCOMPtr<nsISelection> selection;
-  nsIContent* editingElement = mSelectionTargetNode->IsEditable() ?
-                               mSelectionTargetNode->GetEditingHost() : nullptr;
+  nsIContent* editingElement = mSelectionTargetNode->IsEditable()
+                                   ? mSelectionTargetNode->GetEditingHost()
+                                   : nullptr;
   nsCOMPtr<nsITextControlElement> textControl =
-    nsITextControlElement::GetTextControlElementFromEditingHost(editingElement);
+      nsITextControlElement::GetTextControlElementFromEditingHost(
+          editingElement);
   if (textControl) {
     nsISelectionController* selcon = textControl->GetSelectionController();
     if (selcon) {
-      selcon->GetSelection(nsISelectionController::SELECTION_NORMAL, getter_AddRefs(selection));
+      selcon->GetSelection(nsISelectionController::SELECTION_NORMAL,
+                           getter_AddRefs(selection));
     }
 
-    if (!selection)
-      return NS_OK;
-  }
-  else {
+    if (!selection) return NS_OK;
+  } else {
     selection = mWindow->GetSelection();
-    if (!selection)
-      return NS_OK;
+    if (!selection) return NS_OK;
 
     // Check if the node is inside a form control. Don't set aCanDrag to false
-    //however, as we still want to allow the drag.
+    // however, as we still want to allow the drag.
     nsCOMPtr<nsIContent> findFormNode = mSelectionTargetNode;
     nsIContent* findFormParent = findFormNode->GetParent();
     while (findFormParent) {
@@ -597,7 +548,7 @@ DragDataProducer::Produce(DataTransfer* aDataTransfer,
 
   nsCOMPtr<nsIDocShellTreeItem> dsti = mWindow->GetDocShell();
   const bool isChromeShell =
-    dsti && dsti->ItemType() == nsIDocShellTreeItem::typeChrome;
+      dsti && dsti->ItemType() == nsIDocShellTreeItem::typeChrome;
 
   // In chrome shells, only allow dragging inside editable areas.
   if (isChromeShell && !editingElement) {
@@ -621,12 +572,10 @@ DragDataProducer::Produce(DataTransfer* aDataTransfer,
     bool selectionContainsTarget = false;
     nsCOMPtr<nsIDOMNode> targetNode = do_QueryInterface(mSelectionTargetNode);
     selection->ContainsNode(targetNode, false, &selectionContainsTarget);
-    if (!selectionContainsTarget)
-      return NS_OK;
+    if (!selectionContainsTarget) return NS_OK;
 
     selection.swap(*aSelection);
-  }
-  else {
+  } else {
     // In content shells, a number of checks are made below to determine
     // whether an image or a link is being dragged. If so, add additional
     // data to the data transfer. This is also done for chrome shells, but
@@ -653,7 +602,7 @@ DragDataProducer::Produce(DataTransfer* aDataTransfer,
       draggedNode = mTarget;
     }
 
-    nsCOMPtr<nsIImageLoadingContent>  image;
+    nsCOMPtr<nsIImageLoadingContent> image;
 
     nsCOMPtr<nsIContent> selectedImageOrLinkNode;
     GetDraggableSelectionData(selection, mSelectionTargetNode,
@@ -685,7 +634,8 @@ DragDataProducer::Produce(DataTransfer* aDataTransfer,
       // set for linked images, and links
       nsCOMPtr<nsIContent> linkNode;
 
-      RefPtr<HTMLAreaElement> areaElem = HTMLAreaElement::FromContentOrNull(draggedNode);
+      RefPtr<HTMLAreaElement> areaElem =
+          HTMLAreaElement::FromContentOrNull(draggedNode);
       if (areaElem) {
         // use the alt text (or, if missing, the href) as the title
         areaElem->GetAttribute(NS_LITERAL_STRING("alt"), mTitleString);
@@ -738,9 +688,8 @@ DragDataProducer::Produce(DataTransfer* aDataTransfer,
         nsCOMPtr<imgIRequest> imgRequest;
 
         // grab the image data, and its request.
-        nsCOMPtr<imgIContainer> img =
-          nsContentUtils::GetImageFromContent(image,
-                                              getter_AddRefs(imgRequest));
+        nsCOMPtr<imgIContainer> img = nsContentUtils::GetImageFromContent(
+            image, getter_AddRefs(imgRequest));
         if (imgRequest) {
           rv = GetImageData(img, imgRequest);
           NS_ENSURE_SUCCESS(rv, rv);
@@ -757,7 +706,7 @@ DragDataProducer::Produce(DataTransfer* aDataTransfer,
         dragNode = nodeToSerialize;
       } else if (draggedNode && draggedNode->IsHTMLElement(nsGkAtoms::a)) {
         // set linkNode. The code below will handle this
-        linkNode = do_QueryInterface(draggedNode);    // XXX test this
+        linkNode = do_QueryInterface(draggedNode);  // XXX test this
         GetNodeString(draggedNode, mTitleString);
       } else if (parentLink) {
         // parentLink will always be null if there's selected content
@@ -789,10 +738,9 @@ DragDataProducer::Produce(DataTransfer* aDataTransfer,
     // if we have selected text, use it in preference to the node
     nsCOMPtr<nsITransferable> transferable;
     if (*aSelection) {
-      rv = nsCopySupport::GetTransferableForSelection(*aSelection, doc,
-                                                      getter_AddRefs(transferable));
-    }
-    else {
+      rv = nsCopySupport::GetTransferableForSelection(
+          *aSelection, doc, getter_AddRefs(transferable));
+    } else {
       rv = nsCopySupport::GetTransferableForNode(nodeToSerialize, doc,
                                                  getter_AddRefs(transferable));
     }
@@ -822,7 +770,7 @@ DragDataProducer::Produce(DataTransfer* aDataTransfer,
     rv = transferable->GetTransferData(kUnicodeMime, getter_AddRefs(supports),
                                        &dataSize);
     data = do_QueryInterface(supports);
-    NS_ENSURE_SUCCESS(rv, rv); // require plain text at a minimum
+    NS_ENSURE_SUCCESS(rv, rv);  // require plain text at a minimum
     data->GetData(mTitleString);
   }
 
@@ -838,32 +786,28 @@ DragDataProducer::Produce(DataTransfer* aDataTransfer,
   // if there is no drag node, which will be the case for a selection, just
   // use the selection target node.
   rv = AddStringsToDataTransfer(
-         dragNode ? dragNode : mSelectionTargetNode.get(), aDataTransfer);
+      dragNode ? dragNode : mSelectionTargetNode.get(), aDataTransfer);
   NS_ENSURE_SUCCESS(rv, rv);
 
   NS_IF_ADDREF(*aDragNode = dragNode);
   return NS_OK;
 }
 
-void
-DragDataProducer::AddString(DataTransfer* aDataTransfer,
-                            const nsAString& aFlavor,
-                            const nsAString& aData,
-                            nsIPrincipal* aPrincipal,
-                            bool aHidden)
-{
+void DragDataProducer::AddString(DataTransfer* aDataTransfer,
+                                 const nsAString& aFlavor,
+                                 const nsAString& aData,
+                                 nsIPrincipal* aPrincipal, bool aHidden) {
   RefPtr<nsVariantCC> variant = new nsVariantCC();
   variant->SetAsAString(aData);
   aDataTransfer->SetDataWithPrincipal(aFlavor, variant, 0, aPrincipal, aHidden);
 }
 
-nsresult
-DragDataProducer::AddStringsToDataTransfer(nsIContent* aDragNode,
-                                           DataTransfer* aDataTransfer)
-{
+nsresult DragDataProducer::AddStringsToDataTransfer(
+    nsIContent* aDragNode, DataTransfer* aDataTransfer) {
   NS_ASSERTION(aDragNode, "adding strings for null node");
 
-  // set all of the data to have the principal of the node where the data came from
+  // set all of the data to have the principal of the node where the data came
+  // from
   nsIPrincipal* principal = aDragNode->NodePrincipal();
 
   // add a special flavor if we're an anchor to indicate that we have
@@ -880,22 +824,28 @@ DragDataProducer::AddStringsToDataTransfer(nsIContent* aDragNode,
     dragData += title;
 
     AddString(aDataTransfer, NS_LITERAL_STRING(kURLMime), dragData, principal);
-    AddString(aDataTransfer, NS_LITERAL_STRING(kURLDataMime), mUrlString, principal);
-    AddString(aDataTransfer, NS_LITERAL_STRING(kURLDescriptionMime), mTitleString, principal);
-    AddString(aDataTransfer, NS_LITERAL_STRING("text/uri-list"), mUrlString, principal);
+    AddString(aDataTransfer, NS_LITERAL_STRING(kURLDataMime), mUrlString,
+              principal);
+    AddString(aDataTransfer, NS_LITERAL_STRING(kURLDescriptionMime),
+              mTitleString, principal);
+    AddString(aDataTransfer, NS_LITERAL_STRING("text/uri-list"), mUrlString,
+              principal);
   }
 
   // add a special flavor for the html context data
   if (!mContextString.IsEmpty())
-    AddString(aDataTransfer, NS_LITERAL_STRING(kHTMLContext), mContextString, principal);
+    AddString(aDataTransfer, NS_LITERAL_STRING(kHTMLContext), mContextString,
+              principal);
 
   // add a special flavor if we have html info data
   if (!mInfoString.IsEmpty())
-    AddString(aDataTransfer, NS_LITERAL_STRING(kHTMLInfo), mInfoString, principal);
+    AddString(aDataTransfer, NS_LITERAL_STRING(kHTMLInfo), mInfoString,
+              principal);
 
   // add the full html
   if (!mHtmlString.IsEmpty())
-    AddString(aDataTransfer, NS_LITERAL_STRING(kHTMLMime), mHtmlString, principal);
+    AddString(aDataTransfer, NS_LITERAL_STRING(kHTMLMime), mHtmlString,
+              principal);
 
   // add the plain text. we use the url for text/plain data if an anchor is
   // being dragged, rather than the title text of the link or the alt text for
@@ -918,7 +868,7 @@ DragDataProducer::AddStringsToDataTransfer(nsIContent* aDragNode,
     // GetFlavorData callback to save the image to disk.
 
     nsCOMPtr<nsIFlavorDataProvider> dataProvider =
-      new nsContentAreaDragDropDataProvider();
+        new nsContentAreaDragDropDataProvider();
     if (dataProvider) {
       RefPtr<nsVariantCC> variant = new nsVariantCC();
       variant->SetAsISupports(dataProvider);
@@ -937,8 +887,10 @@ DragDataProducer::AddStringsToDataTransfer(nsIContent* aDragNode,
 
     // if not an anchor, add the image url
     if (!mIsAnchor) {
-      AddString(aDataTransfer, NS_LITERAL_STRING(kURLDataMime), mUrlString, principal);
-      AddString(aDataTransfer, NS_LITERAL_STRING("text/uri-list"), mUrlString, principal);
+      AddString(aDataTransfer, NS_LITERAL_STRING(kURLDataMime), mUrlString,
+                principal);
+      AddString(aDataTransfer, NS_LITERAL_STRING("text/uri-list"), mUrlString,
+                principal);
     }
   }
 
@@ -947,12 +899,9 @@ DragDataProducer::AddStringsToDataTransfer(nsIContent* aDragNode,
 
 // note that this can return NS_OK, but a null out param (by design)
 // static
-nsresult
-DragDataProducer::GetDraggableSelectionData(nsISelection* inSelection,
-                                            nsIContent* inRealTargetNode,
-                                            nsIContent **outImageOrLinkNode,
-                                            bool* outDragSelectedText)
-{
+nsresult DragDataProducer::GetDraggableSelectionData(
+    nsISelection* inSelection, nsIContent* inRealTargetNode,
+    nsIContent** outImageOrLinkNode, bool* outDragSelectedText) {
   NS_ENSURE_ARG(inSelection);
   NS_ENSURE_ARG(inRealTargetNode);
   NS_ENSURE_ARG_POINTER(outImageOrLinkNode);
@@ -966,8 +915,7 @@ DragDataProducer::GetDraggableSelectionData(nsISelection* inSelection,
   inSelection->GetIsCollapsed(&isCollapsed);
   if (!isCollapsed) {
     nsCOMPtr<nsIDOMNode> realTargetNode = do_QueryInterface(inRealTargetNode);
-    inSelection->ContainsNode(realTargetNode, false,
-                              &selectionContainsTarget);
+    inSelection->ContainsNode(realTargetNode, false, &selectionContainsTarget);
 
     if (selectionContainsTarget) {
       // track down the anchor node, if any, for the url
@@ -981,7 +929,8 @@ DragDataProducer::GetDraggableSelectionData(nsISelection* inSelection,
       // in this case, drag the image, rather than a serialization of the HTML
       // XXX generalize this to other draggable element types?
       if (selectionStart == selectionEnd) {
-        nsCOMPtr<nsIContent> selStartContent = do_QueryInterface(selectionStart);
+        nsCOMPtr<nsIContent> selStartContent =
+            do_QueryInterface(selectionStart);
         if (selStartContent && selStartContent->HasChildNodes()) {
           // see if just one node is selected
           int32_t anchorOffset, focusOffset;
@@ -989,9 +938,9 @@ DragDataProducer::GetDraggableSelectionData(nsISelection* inSelection,
           inSelection->GetFocusOffset(&focusOffset);
           if (abs(anchorOffset - focusOffset) == 1) {
             int32_t childOffset =
-              (anchorOffset < focusOffset) ? anchorOffset : focusOffset;
-            nsIContent *childContent =
-              selStartContent->GetChildAt_Deprecated(childOffset);
+                (anchorOffset < focusOffset) ? anchorOffset : focusOffset;
+            nsIContent* childContent =
+                selStartContent->GetChildAt_Deprecated(childOffset);
             // if we find an image, we'll fall into the node-dragging code,
             // rather the the selection-dragging code
             if (nsContentUtils::IsDraggableImage(childContent)) {
