@@ -69,19 +69,18 @@
 using namespace mozilla;
 using namespace mozilla::dom;
 
-nsresult NS_NewDomSelection(nsISelection **aDomSelection);
+nsresult NS_NewDomSelection(nsISelection** aDomSelection);
 
-static NS_DEFINE_CID(kCClipboardCID,           NS_CLIPBOARD_CID);
-static NS_DEFINE_CID(kCTransferableCID,        NS_TRANSFERABLE_CID);
-static NS_DEFINE_CID(kHTMLConverterCID,        NS_HTMLFORMATCONVERTER_CID);
+static NS_DEFINE_CID(kCClipboardCID, NS_CLIPBOARD_CID);
+static NS_DEFINE_CID(kCTransferableCID, NS_TRANSFERABLE_CID);
+static NS_DEFINE_CID(kHTMLConverterCID, NS_HTMLFORMATCONVERTER_CID);
 
 // copy string data onto the transferable
-static nsresult AppendString(nsITransferable *aTransferable,
-                             const nsAString& aString,
-                             const char* aFlavor);
+static nsresult AppendString(nsITransferable* aTransferable,
+                             const nsAString& aString, const char* aFlavor);
 
 // copy HTML node data
-static nsresult AppendDOMNode(nsITransferable *aTransferable,
+static nsresult AppendDOMNode(nsITransferable* aTransferable,
                               nsINode* aDOMNode);
 
 #ifdef XP_WIN
@@ -93,11 +92,10 @@ static nsresult AppendImagePromise(nsITransferable* aTransferable,
 
 // Helper used for HTMLCopy and GetTransferableForSelection since both routines
 // share common code.
-static nsresult
-SelectionCopyHelper(nsISelection *aSel, nsIDocument *aDoc,
-                    bool doPutOnClipboard, int16_t aClipboardID,
-                    uint32_t aFlags, nsITransferable ** aTransferable)
-{
+static nsresult SelectionCopyHelper(nsISelection* aSel, nsIDocument* aDoc,
+                                    bool doPutOnClipboard, int16_t aClipboardID,
+                                    uint32_t aFlags,
+                                    nsITransferable** aTransferable) {
   // Clear the output parameter for the transferable, if provided.
   if (aTransferable) {
     *aTransferable = nullptr;
@@ -109,18 +107,18 @@ SelectionCopyHelper(nsISelection *aSel, nsIDocument *aDoc,
   docEncoder = do_CreateInstance(NS_HTMLCOPY_ENCODER_CONTRACTID);
   NS_ENSURE_TRUE(docEncoder, NS_ERROR_FAILURE);
 
-  // note that we assign text/unicode as mime type, but in fact nsHTMLCopyEncoder
-  // ignore it and use text/html or text/plain depending where the selection
-  // is. if it is a selection into input/textarea element or in a html content
-  // with pre-wrap style : text/plain. Otherwise text/html.
-  // see nsHTMLCopyEncoder::SetSelection
+  // note that we assign text/unicode as mime type, but in fact
+  // nsHTMLCopyEncoder ignore it and use text/html or text/plain depending where
+  // the selection is. if it is a selection into input/textarea element or in a
+  // html content with pre-wrap style : text/plain. Otherwise text/html. see
+  // nsHTMLCopyEncoder::SetSelection
   nsAutoString mimeType;
   mimeType.AssignLiteral(kUnicodeMime);
 
   // Do the first and potentially trial encoding as preformatted and raw.
-  uint32_t flags = aFlags | nsIDocumentEncoder::OutputPreformatted
-                          | nsIDocumentEncoder::OutputRaw
-                          | nsIDocumentEncoder::OutputForPlainTextClipboardCopy;
+  uint32_t flags = aFlags | nsIDocumentEncoder::OutputPreformatted |
+                   nsIDocumentEncoder::OutputRaw |
+                   nsIDocumentEncoder::OutputForPlainTextClipboardCopy;
 
   nsCOMPtr<nsIDOMDocument> domDoc = do_QueryInterface(aDoc);
   NS_ASSERTION(domDoc, "Need a document");
@@ -165,13 +163,12 @@ SelectionCopyHelper(nsISelection *aSel, nsIDocument *aDoc,
     textPlainBuf.Assign(buf);
   } else {
     // Redo the encoding, but this time use pretty printing.
-    flags =
-      nsIDocumentEncoder::OutputSelectionOnly |
-      nsIDocumentEncoder::OutputAbsoluteLinks |
-      nsIDocumentEncoder::SkipInvisibleContent |
-      nsIDocumentEncoder::OutputDropInvisibleBreak |
-      (aFlags & (nsIDocumentEncoder::OutputNoScriptContent |
-                 nsIDocumentEncoder::OutputRubyAnnotation));
+    flags = nsIDocumentEncoder::OutputSelectionOnly |
+            nsIDocumentEncoder::OutputAbsoluteLinks |
+            nsIDocumentEncoder::SkipInvisibleContent |
+            nsIDocumentEncoder::OutputDropInvisibleBreak |
+            (aFlags & (nsIDocumentEncoder::OutputNoScriptContent |
+                       nsIDocumentEncoder::OutputRubyAnnotation));
 
     mimeType.AssignLiteral(kTextMime);
     rv = docEncoder->Init(domDoc, mimeType, flags);
@@ -192,9 +189,9 @@ SelectionCopyHelper(nsISelection *aSel, nsIDocument *aDoc,
     // Redo the encoding, but this time use the passed-in flags.
     // Don't allow wrapping of CJK strings.
     mimeType.AssignLiteral(kHTMLMime);
-    rv = docEncoder->Init(domDoc, mimeType,
-                          aFlags |
-                          nsIDocumentEncoder::OutputDisallowLineBreaking);
+    rv = docEncoder->Init(
+        domDoc, mimeType,
+        aFlags | nsIDocumentEncoder::OutputDisallowLineBreaking);
     NS_ENSURE_SUCCESS(rv, rv);
 
     rv = docEncoder->SetSelection(aSel);
@@ -209,8 +206,7 @@ SelectionCopyHelper(nsISelection *aSel, nsIDocument *aDoc,
   nsCOMPtr<nsIClipboard> clipboard;
   if (doPutOnClipboard) {
     clipboard = do_GetService(kCClipboardCID, &rv);
-    if (NS_FAILED(rv))
-      return rv;
+    if (NS_FAILED(rv)) return rv;
   }
 
   if ((doPutOnClipboard && clipboard) || aTransferable != nullptr) {
@@ -222,7 +218,7 @@ SelectionCopyHelper(nsISelection *aSel, nsIDocument *aDoc,
         // Set up a format converter so that clipboard flavor queries work.
         // This converter isn't really used for conversions.
         nsCOMPtr<nsIFormatConverter> htmlConverter =
-          do_CreateInstance(kHTMLConverterCID);
+            do_CreateInstance(kHTMLConverterCID);
         trans->SetConverter(htmlConverter);
 
         if (!textHTMLBuf.IsEmpty()) {
@@ -246,14 +242,15 @@ SelectionCopyHelper(nsISelection *aSel, nsIDocument *aDoc,
         if (!textPlainBuf.IsEmpty()) {
           // unicode text
           // Add the unicode DataFlavor to the transferable
-          // If we didn't have this, then nsDataObj::GetData matches text/unicode against
-          // the kURLMime flavour which is not desirable (eg. when pasting into Notepad)
+          // If we didn't have this, then nsDataObj::GetData matches
+          // text/unicode against the kURLMime flavour which is not desirable
+          // (eg. when pasting into Notepad)
           rv = AppendString(trans, textPlainBuf, kUnicodeMime);
           NS_ENSURE_SUCCESS(rv, rv);
         }
 
         // Try and get source URI of the items that are being dragged
-        nsIURI *uri = aDoc->GetDocumentURI();
+        nsIURI* uri = aDoc->GetDocumentURI();
         if (uri) {
           nsAutoCString spec;
           nsresult rv = uri->GetSpec(spec);
@@ -262,12 +259,12 @@ SelectionCopyHelper(nsISelection *aSel, nsIDocument *aDoc,
             nsAutoString shortcut;
             AppendUTF8toUTF16(spec, shortcut);
 
-            // Add the URL DataFlavor to the transferable. Don't use kURLMime, as it will
-            // cause an unnecessary UniformResourceLocator to be added which confuses
-            // some apps eg. Outlook 2000 - (See Bug 315370). Don't use
-            // kURLDataMime, as it will cause a bogus 'url ' flavor to
-            // show up on the Mac clipboard, confusing other apps, like
-            // Terminal (see bug 336012).
+            // Add the URL DataFlavor to the transferable. Don't use kURLMime,
+            // as it will cause an unnecessary UniformResourceLocator to be
+            // added which confuses some apps eg. Outlook 2000 - (See Bug
+            // 315370). Don't use kURLDataMime, as it will cause a bogus 'url '
+            // flavor to show up on the Mac clipboard, confusing other apps,
+            // like Terminal (see bug 336012).
             rv = AppendString(trans, shortcut, kURLPrivateMime);
             NS_ENSURE_SUCCESS(rv, rv);
           }
@@ -298,10 +295,9 @@ SelectionCopyHelper(nsISelection *aSel, nsIDocument *aDoc,
   return rv;
 }
 
-nsresult
-nsCopySupport::HTMLCopy(nsISelection* aSel, nsIDocument* aDoc,
-                        int16_t aClipboardID, bool aWithRubyAnnotation)
-{
+nsresult nsCopySupport::HTMLCopy(nsISelection* aSel, nsIDocument* aDoc,
+                                 int16_t aClipboardID,
+                                 bool aWithRubyAnnotation) {
   uint32_t flags = nsIDocumentEncoder::SkipInvisibleContent;
   if (aWithRubyAnnotation) {
     flags |= nsIDocumentEncoder::OutputRubyAnnotation;
@@ -309,30 +305,22 @@ nsCopySupport::HTMLCopy(nsISelection* aSel, nsIDocument* aDoc,
   return SelectionCopyHelper(aSel, aDoc, true, aClipboardID, flags, nullptr);
 }
 
-nsresult
-nsCopySupport::ClearSelectionCache()
-{
+nsresult nsCopySupport::ClearSelectionCache() {
   nsresult rv;
   nsCOMPtr<nsIClipboard> clipboard = do_GetService(kCClipboardCID, &rv);
   clipboard->EmptyClipboard(nsIClipboard::kSelectionCache);
   return rv;
 }
 
-nsresult
-nsCopySupport::GetTransferableForSelection(nsISelection* aSel,
-                                           nsIDocument* aDoc,
-                                           nsITransferable** aTransferable)
-{
+nsresult nsCopySupport::GetTransferableForSelection(
+    nsISelection* aSel, nsIDocument* aDoc, nsITransferable** aTransferable) {
   return SelectionCopyHelper(aSel, aDoc, false, 0,
                              nsIDocumentEncoder::SkipInvisibleContent,
                              aTransferable);
 }
 
-nsresult
-nsCopySupport::GetTransferableForNode(nsINode* aNode,
-                                      nsIDocument* aDoc,
-                                      nsITransferable** aTransferable)
-{
+nsresult nsCopySupport::GetTransferableForNode(
+    nsINode* aNode, nsIDocument* aDoc, nsITransferable** aTransferable) {
   nsCOMPtr<nsISelection> selection;
   // Make a temporary selection with aNode in a single range.
   // XXX We should try to get rid of the Selection object here.
@@ -350,13 +338,11 @@ nsCopySupport::GetTransferableForNode(nsINode* aNode,
   NS_ENSURE_SUCCESS(rv, rv);
   // It's not the primary selection - so don't skip invisible content.
   uint32_t flags = 0;
-  return SelectionCopyHelper(selection, aDoc, false, 0, flags,
-                             aTransferable);
+  return SelectionCopyHelper(selection, aDoc, false, 0, flags, aTransferable);
 }
 
-nsresult nsCopySupport::DoHooks(nsIDocument *aDoc, nsITransferable *aTrans,
-                                bool *aDoPutOnClipboard)
-{
+nsresult nsCopySupport::DoHooks(nsIDocument* aDoc, nsITransferable* aTrans,
+                                bool* aDoPutOnClipboard) {
   NS_ENSURE_ARG(aDoc);
 
   *aDoPutOnClipboard = true;
@@ -376,30 +362,27 @@ nsresult nsCopySupport::DoHooks(nsIDocument *aDoc, nsITransferable *aTrans,
   nsCOMPtr<nsISupports> isupp;
   bool hasMoreHooks = false;
   nsresult rv = NS_OK;
-  while (NS_SUCCEEDED(enumerator->HasMoreElements(&hasMoreHooks))
-         && hasMoreHooks)
-  {
+  while (NS_SUCCEEDED(enumerator->HasMoreElements(&hasMoreHooks)) &&
+         hasMoreHooks) {
     rv = enumerator->GetNext(getter_AddRefs(isupp));
     if (NS_FAILED(rv)) break;
     override = do_QueryInterface(isupp);
-    if (override)
-    {
+    if (override) {
 #ifdef DEBUG
       nsresult hookResult =
 #endif
-      override->OnCopyOrDrag(nullptr, aTrans, aDoPutOnClipboard);
+          override->OnCopyOrDrag(nullptr, aTrans, aDoPutOnClipboard);
       NS_ASSERTION(NS_SUCCEEDED(hookResult), "OnCopyOrDrag hook failed");
-      if (!*aDoPutOnClipboard)
-        break;
+      if (!*aDoPutOnClipboard) break;
     }
   }
 
   return rv;
 }
 
-nsresult
-nsCopySupport::GetContents(const nsACString& aMimeType, uint32_t aFlags, nsISelection *aSel, nsIDocument *aDoc, nsAString& outdata)
-{
+nsresult nsCopySupport::GetContents(const nsACString& aMimeType,
+                                    uint32_t aFlags, nsISelection* aSel,
+                                    nsIDocument* aDoc, nsAString& outdata) {
   nsresult rv = NS_OK;
 
   nsCOMPtr<nsIDocumentEncoder> docEncoder;
@@ -423,8 +406,7 @@ nsCopySupport::GetContents(const nsACString& aMimeType, uint32_t aFlags, nsISele
   rv = docEncoder->Init(domDoc, unicodeMimeType, flags);
   if (NS_FAILED(rv)) return rv;
 
-  if (aSel)
-  {
+  if (aSel) {
     rv = docEncoder->SetSelection(aSel);
     if (NS_FAILED(rv)) return rv;
   }
@@ -433,12 +415,9 @@ nsCopySupport::GetContents(const nsACString& aMimeType, uint32_t aFlags, nsISele
   return docEncoder->EncodeToString(outdata);
 }
 
-
-nsresult
-nsCopySupport::ImageCopy(nsIImageLoadingContent* aImageElement,
-                         nsILoadContext* aLoadContext,
-                         int32_t aCopyFlags)
-{
+nsresult nsCopySupport::ImageCopy(nsIImageLoadingContent* aImageElement,
+                                  nsILoadContext* aLoadContext,
+                                  int32_t aCopyFlags) {
   nsresult rv;
 
   // create a transferable for putting data on the Clipboard
@@ -474,9 +453,8 @@ nsCopySupport::ImageCopy(nsIImageLoadingContent* aImageElement,
   if (aCopyFlags & nsIContentViewerEdit::COPY_IMAGE_DATA) {
     // get the image data and its request from the element
     nsCOMPtr<imgIRequest> imgRequest;
-    nsCOMPtr<imgIContainer> image =
-      nsContentUtils::GetImageFromContent(aImageElement,
-                                          getter_AddRefs(imgRequest));
+    nsCOMPtr<imgIContainer> image = nsContentUtils::GetImageFromContent(
+        aImageElement, getter_AddRefs(imgRequest));
     NS_ENSURE_TRUE(image, NS_ERROR_FAILURE);
 
 #ifdef XP_WIN
@@ -484,16 +462,15 @@ nsCopySupport::ImageCopy(nsIImageLoadingContent* aImageElement,
     NS_ENSURE_SUCCESS(rv, rv);
 #endif
 
-    nsCOMPtr<nsISupportsInterfacePointer>
-      imgPtr(do_CreateInstance(NS_SUPPORTS_INTERFACE_POINTER_CONTRACTID, &rv));
+    nsCOMPtr<nsISupportsInterfacePointer> imgPtr(
+        do_CreateInstance(NS_SUPPORTS_INTERFACE_POINTER_CONTRACTID, &rv));
     NS_ENSURE_SUCCESS(rv, rv);
 
     rv = imgPtr->SetData(image);
     NS_ENSURE_SUCCESS(rv, rv);
 
     // copy the image data onto the transferable
-    rv = trans->SetTransferData(kNativeImageMime, imgPtr,
-                                sizeof(nsISupports*));
+    rv = trans->SetTransferData(kNativeImageMime, imgPtr, sizeof(nsISupports*));
     NS_ENSURE_SUCCESS(rv, rv);
   }
 
@@ -515,14 +492,12 @@ nsCopySupport::ImageCopy(nsIImageLoadingContent* aImageElement,
   return clipboard->SetData(trans, nullptr, nsIClipboard::kGlobalClipboard);
 }
 
-static nsresult AppendString(nsITransferable *aTransferable,
-                             const nsAString& aString,
-                             const char* aFlavor)
-{
+static nsresult AppendString(nsITransferable* aTransferable,
+                             const nsAString& aString, const char* aFlavor) {
   nsresult rv;
 
-  nsCOMPtr<nsISupportsString>
-    data(do_CreateInstance(NS_SUPPORTS_STRING_CONTRACTID, &rv));
+  nsCOMPtr<nsISupportsString> data(
+      do_CreateInstance(NS_SUPPORTS_STRING_CONTRACTID, &rv));
   NS_ENSURE_SUCCESS(rv, rv);
 
   rv = data->SetData(aString);
@@ -535,14 +510,13 @@ static nsresult AppendString(nsITransferable *aTransferable,
                                         aString.Length() * sizeof(char16_t));
 }
 
-static nsresult AppendDOMNode(nsITransferable *aTransferable,
-                              nsINode *aDOMNode)
-{
+static nsresult AppendDOMNode(nsITransferable* aTransferable,
+                              nsINode* aDOMNode) {
   nsresult rv;
 
   // selializer
-  nsCOMPtr<nsIDocumentEncoder>
-    docEncoder(do_CreateInstance(NS_HTMLCOPY_ENCODER_CONTRACTID, &rv));
+  nsCOMPtr<nsIDocumentEncoder> docEncoder(
+      do_CreateInstance(NS_HTMLCOPY_ENCODER_CONTRACTID, &rv));
   NS_ENSURE_SUCCESS(rv, rv);
 
   // get document for the encoder
@@ -552,15 +526,16 @@ static nsresult AppendDOMNode(nsITransferable *aTransferable,
   // properly (all the copy code for non-plaintext assumes using HTML
   // serializers and parsers is OK, and those mess up XHTML).
   DebugOnly<nsCOMPtr<nsIHTMLDocument>> htmlDoc =
-    nsCOMPtr<nsIHTMLDocument>(do_QueryInterface(document, &rv));
+      nsCOMPtr<nsIHTMLDocument>(do_QueryInterface(document, &rv));
   NS_ENSURE_SUCCESS(rv, NS_OK);
 
   NS_ENSURE_TRUE(document->IsHTMLDocument(), NS_OK);
 
   // init encoder with document and node
-  rv = docEncoder->NativeInit(document, NS_LITERAL_STRING(kHTMLMime),
-                              nsIDocumentEncoder::OutputAbsoluteLinks |
-                              nsIDocumentEncoder::OutputEncodeBasicEntities);
+  rv =
+      docEncoder->NativeInit(document, NS_LITERAL_STRING(kHTMLMime),
+                             nsIDocumentEncoder::OutputAbsoluteLinks |
+                                 nsIDocumentEncoder::OutputEncodeBasicEntities);
   NS_ENSURE_SUCCESS(rv, rv);
 
   rv = docEncoder->SetNativeNode(aDOMNode);
@@ -589,8 +564,7 @@ static nsresult AppendDOMNode(nsITransferable *aTransferable,
 #ifdef XP_WIN
 static nsresult AppendImagePromise(nsITransferable* aTransferable,
                                    imgIRequest* aImgRequest,
-                                   nsIImageLoadingContent* aImageElement)
-{
+                                   nsIImageLoadingContent* aImageElement) {
   nsresult rv;
 
   NS_ENSURE_TRUE(aImgRequest, NS_OK);
@@ -615,7 +589,7 @@ static nsresult AppendImagePromise(nsITransferable* aTransferable,
 
   // Fix the file extension in the URL if necessary
   nsCOMPtr<nsIMIMEService> mimeService =
-    do_GetService(NS_MIMESERVICE_CONTRACTID);
+      do_GetService(NS_MIMESERVICE_CONTRACTID);
   NS_ENSURE_TRUE(mimeService, NS_OK);
 
   nsCOMPtr<nsIURI> imgUri;
@@ -648,17 +622,16 @@ static nsresult AppendImagePromise(nsITransferable* aTransferable,
 
   bool validExtension;
   if (extension.IsEmpty() ||
-      NS_FAILED(mimeInfo->ExtensionExists(extension,
-                                          &validExtension)) ||
+      NS_FAILED(mimeInfo->ExtensionExists(extension, &validExtension)) ||
       !validExtension) {
     // Fix the file extension in the URL
     nsAutoCString primaryExtension;
     mimeInfo->GetPrimaryExtension(primaryExtension);
 
     rv = NS_MutateURI(imgUri)
-           .Apply(NS_MutatorMethod(&nsIURLMutator::SetFileExtension,
-                                   primaryExtension, nullptr))
-           .Finalize(imgUrl);
+             .Apply(NS_MutatorMethod(&nsIURLMutator::SetFileExtension,
+                                     primaryExtension, nullptr))
+             .Finalize(imgUrl);
     NS_ENSURE_SUCCESS(rv, rv);
   }
 
@@ -685,21 +658,19 @@ static nsresult AppendImagePromise(nsITransferable* aTransferable,
   // add the dataless file promise flavor
   return aTransferable->AddDataFlavor(kFilePromiseMime);
 }
-#endif // XP_WIN
+#endif  // XP_WIN
 
-nsIContent*
-nsCopySupport::GetSelectionForCopy(nsIDocument* aDocument, nsISelection** aSelection)
-{
+nsIContent* nsCopySupport::GetSelectionForCopy(nsIDocument* aDocument,
+                                               nsISelection** aSelection) {
   *aSelection = nullptr;
 
   nsIPresShell* presShell = aDocument->GetShell();
-  if (!presShell)
-    return nullptr;
+  if (!presShell) return nullptr;
 
   nsCOMPtr<nsIContent> focusedContent;
   nsCOMPtr<nsISelectionController> selectionController =
-    presShell->GetSelectionControllerForFocusedContent(
-      getter_AddRefs(focusedContent));
+      presShell->GetSelectionControllerForFocusedContent(
+          getter_AddRefs(focusedContent));
   if (!selectionController) {
     return nullptr;
   }
@@ -709,11 +680,8 @@ nsCopySupport::GetSelectionForCopy(nsIDocument* aDocument, nsISelection** aSelec
   return focusedContent;
 }
 
-bool
-nsCopySupport::CanCopy(nsIDocument* aDocument)
-{
-  if (!aDocument)
-    return false;
+bool nsCopySupport::CanCopy(nsIDocument* aDocument) {
+  if (!aDocument) return false;
 
   nsCOMPtr<nsISelection> sel;
   GetSelectionForCopy(aDocument, getter_AddRefs(sel));
@@ -724,9 +692,7 @@ nsCopySupport::CanCopy(nsIDocument* aDocument)
   return !isCollapsed;
 }
 
-static bool
-IsInsideRuby(nsINode* aNode)
-{
+static bool IsInsideRuby(nsINode* aNode) {
   for (; aNode; aNode = aNode->GetParent()) {
     if (aNode->IsHTMLElement(nsGkAtoms::ruby)) {
       return true;
@@ -735,9 +701,7 @@ IsInsideRuby(nsINode* aNode)
   return false;
 }
 
-static bool
-IsSelectionInsideRuby(nsISelection* aSelection)
-{
+static bool IsSelectionInsideRuby(nsISelection* aSelection) {
   int32_t rangeCount;
   nsresult rv = aSelection->GetRangeCount(&rangeCount);
   if (NS_FAILED(rv)) {
@@ -756,13 +720,11 @@ IsSelectionInsideRuby(nsISelection* aSelection)
   return true;
 }
 
-bool
-nsCopySupport::FireClipboardEvent(EventMessage aEventMessage,
-                                  int32_t aClipboardType,
-                                  nsIPresShell* aPresShell,
-                                  nsISelection* aSelection,
-                                  bool* aActionTaken)
-{
+bool nsCopySupport::FireClipboardEvent(EventMessage aEventMessage,
+                                       int32_t aClipboardType,
+                                       nsIPresShell* aPresShell,
+                                       nsISelection* aSelection,
+                                       bool* aActionTaken) {
   if (aActionTaken) {
     *aActionTaken = false;
   }
@@ -773,26 +735,22 @@ nsCopySupport::FireClipboardEvent(EventMessage aEventMessage,
   }
 
   NS_ASSERTION(originalEventMessage == eCut || originalEventMessage == eCopy ||
-               originalEventMessage == ePaste,
+                   originalEventMessage == ePaste,
                "Invalid clipboard event type");
 
   nsCOMPtr<nsIPresShell> presShell = aPresShell;
-  if (!presShell)
-    return false;
+  if (!presShell) return false;
 
   nsCOMPtr<nsIDocument> doc = presShell->GetDocument();
-  if (!doc)
-    return false;
+  if (!doc) return false;
 
   nsCOMPtr<nsPIDOMWindowOuter> piWindow = doc->GetWindow();
-  if (!piWindow)
-    return false;
+  if (!piWindow) return false;
 
   // if a selection was not supplied, try to find it
   nsCOMPtr<nsIContent> content;
   nsCOMPtr<nsISelection> sel = aSelection;
-  if (!sel)
-    content = GetSelectionForCopy(doc, getter_AddRefs(sel));
+  if (!sel) content = GetSelectionForCopy(doc, getter_AddRefs(sel));
 
   // retrieve the event target node from the start of the selection
   nsresult rv;
@@ -802,16 +760,14 @@ nsCopySupport::FireClipboardEvent(EventMessage aEventMessage,
     if (NS_SUCCEEDED(rv) && range) {
       nsCOMPtr<nsIDOMNode> startContainer;
       range->GetStartContainer(getter_AddRefs(startContainer));
-      if (startContainer)
-        content = do_QueryInterface(startContainer);
+      if (startContainer) content = do_QueryInterface(startContainer);
     }
   }
 
   // if no content node was set, just get the root
   if (!content) {
     content = doc->GetRootElement();
-    if (!content)
-      return false;
+    if (!content) return false;
   }
 
   // It seems to be unsafe to fire an event handler during reflow (bug 393696)
@@ -822,15 +778,16 @@ nsCopySupport::FireClipboardEvent(EventMessage aEventMessage,
 
   nsCOMPtr<nsIDocShell> docShell = piWindow->GetDocShell();
   const bool chromeShell =
-    docShell && docShell->ItemType() == nsIDocShellTreeItem::typeChrome;
+      docShell && docShell->ItemType() == nsIDocShellTreeItem::typeChrome;
 
   // next, fire the cut, copy or paste event
   bool doDefault = true;
   RefPtr<DataTransfer> clipboardData;
-  if (chromeShell || Preferences::GetBool("dom.event.clipboardevents.enabled", true)) {
+  if (chromeShell ||
+      Preferences::GetBool("dom.event.clipboardevents.enabled", true)) {
     clipboardData =
-      new DataTransfer(doc->GetScopeObject(), aEventMessage,
-                       originalEventMessage == ePaste, aClipboardType);
+        new DataTransfer(doc->GetScopeObject(), aEventMessage,
+                         originalEventMessage == ePaste, aClipboardType);
 
     nsEventStatus status = nsEventStatus_eIgnore;
     InternalClipboardEvent evt(true, originalEventMessage);
@@ -872,11 +829,10 @@ nsCopySupport::FireClipboardEvent(EventMessage aEventMessage,
   // Update the presentation in case the event handler modified the selection,
   // see bug 602231.
   presShell->FlushPendingNotifications(FlushType::Frames);
-  if (presShell->IsDestroying())
-    return false;
+  if (presShell->IsDestroying()) return false;
 
-  // if the event was not cancelled, do the default copy. If the event was cancelled,
-  // use the data added to the data transfer and copy that instead.
+  // if the event was not cancelled, do the default copy. If the event was
+  // cancelled, use the data added to the data transfer and copy that instead.
   uint32_t count = 0;
   if (doDefault) {
     // find the focused node
@@ -922,11 +878,12 @@ nsCopySupport::FireClipboardEvent(EventMessage aEventMessage,
     // check to see if any data was put on the data transfer.
     clipboardData->GetMozItemCount(&count);
     if (count) {
-      nsCOMPtr<nsIClipboard> clipboard(do_GetService("@mozilla.org/widget/clipboard;1"));
+      nsCOMPtr<nsIClipboard> clipboard(
+          do_GetService("@mozilla.org/widget/clipboard;1"));
       NS_ENSURE_TRUE(clipboard, false);
 
       nsCOMPtr<nsITransferable> transferable =
-        clipboardData->GetTransferable(0, doc->GetLoadContext());
+          clipboardData->GetTransferable(0, doc->GetLoadContext());
 
       NS_ENSURE_TRUE(transferable, false);
 
