@@ -31,253 +31,211 @@
 class nsDOMMutationObserver;
 using mozilla::dom::MutationObservingInfo;
 
-class nsDOMMutationRecord final : public nsISupports,
-                                  public nsWrapperCache
-{
+class nsDOMMutationRecord final : public nsISupports, public nsWrapperCache {
   virtual ~nsDOMMutationRecord() {}
 
-public:
+ public:
   typedef nsTArray<RefPtr<mozilla::dom::Animation>> AnimationArray;
 
   nsDOMMutationRecord(nsAtom* aType, nsISupports* aOwner)
-  : mType(aType), mAttrNamespace(VoidString()), mPrevValue(VoidString()), mOwner(aOwner)
-  {
-  }
+      : mType(aType),
+        mAttrNamespace(VoidString()),
+        mPrevValue(VoidString()),
+        mOwner(aOwner) {}
 
-  nsISupports* GetParentObject() const
-  {
-    return mOwner;
-  }
+  nsISupports* GetParentObject() const { return mOwner; }
 
-  virtual JSObject* WrapObject(JSContext* aCx, JS::Handle<JSObject*> aGivenProto) override
-  {
+  virtual JSObject* WrapObject(JSContext* aCx,
+                               JS::Handle<JSObject*> aGivenProto) override {
     return mozilla::dom::MutationRecordBinding::Wrap(aCx, this, aGivenProto);
   }
 
   NS_DECL_CYCLE_COLLECTING_ISUPPORTS
   NS_DECL_CYCLE_COLLECTION_SCRIPT_HOLDER_CLASS(nsDOMMutationRecord)
 
-  void GetType(mozilla::dom::DOMString& aRetVal) const
-  {
+  void GetType(mozilla::dom::DOMString& aRetVal) const {
     aRetVal.SetKnownLiveAtom(mType, mozilla::dom::DOMString::eNullNotExpected);
   }
 
-  nsINode* GetTarget() const
-  {
-    return mTarget;
-  }
+  nsINode* GetTarget() const { return mTarget; }
 
   nsINodeList* AddedNodes();
 
   nsINodeList* RemovedNodes();
 
-  nsINode* GetPreviousSibling() const
-  {
-    return mPreviousSibling;
-  }
+  nsINode* GetPreviousSibling() const { return mPreviousSibling; }
 
-  nsINode* GetNextSibling() const
-  {
-    return mNextSibling;
-  }
+  nsINode* GetNextSibling() const { return mNextSibling; }
 
-  void GetAttributeName(mozilla::dom::DOMString& aRetVal) const
-  {
+  void GetAttributeName(mozilla::dom::DOMString& aRetVal) const {
     aRetVal.SetKnownLiveAtom(mAttrName,
                              mozilla::dom::DOMString::eTreatNullAsNull);
   }
 
-  void GetAttributeNamespace(mozilla::dom::DOMString& aRetVal) const
-  {
+  void GetAttributeNamespace(mozilla::dom::DOMString& aRetVal) const {
     aRetVal.SetKnownLiveString(mAttrNamespace);
   }
 
-  void GetOldValue(mozilla::dom::DOMString& aRetVal) const
-  {
+  void GetOldValue(mozilla::dom::DOMString& aRetVal) const {
     aRetVal.SetKnownLiveString(mPrevValue);
   }
 
-  void GetAddedAnimations(AnimationArray& aRetVal) const
-  {
+  void GetAddedAnimations(AnimationArray& aRetVal) const {
     aRetVal = mAddedAnimations;
   }
 
-  void GetRemovedAnimations(AnimationArray& aRetVal) const
-  {
+  void GetRemovedAnimations(AnimationArray& aRetVal) const {
     aRetVal = mRemovedAnimations;
   }
 
-  void GetChangedAnimations(AnimationArray& aRetVal) const
-  {
+  void GetChangedAnimations(AnimationArray& aRetVal) const {
     aRetVal = mChangedAnimations;
   }
 
-  nsCOMPtr<nsINode>             mTarget;
-  RefPtr<nsAtom>             mType;
-  RefPtr<nsAtom>             mAttrName;
-  nsString                      mAttrNamespace;
-  nsString                      mPrevValue;
+  nsCOMPtr<nsINode> mTarget;
+  RefPtr<nsAtom> mType;
+  RefPtr<nsAtom> mAttrName;
+  nsString mAttrNamespace;
+  nsString mPrevValue;
   RefPtr<nsSimpleContentList> mAddedNodes;
   RefPtr<nsSimpleContentList> mRemovedNodes;
-  nsCOMPtr<nsINode>             mPreviousSibling;
-  nsCOMPtr<nsINode>             mNextSibling;
-  AnimationArray                mAddedAnimations;
-  AnimationArray                mRemovedAnimations;
-  AnimationArray                mChangedAnimations;
+  nsCOMPtr<nsINode> mPreviousSibling;
+  nsCOMPtr<nsINode> mNextSibling;
+  AnimationArray mAddedAnimations;
+  AnimationArray mRemovedAnimations;
+  AnimationArray mChangedAnimations;
 
   RefPtr<nsDOMMutationRecord> mNext;
-  nsCOMPtr<nsISupports>         mOwner;
+  nsCOMPtr<nsISupports> mOwner;
 };
 
 // Base class just prevents direct access to
 // members to make sure we go through getters/setters.
-class nsMutationReceiverBase : public nsStubAnimationObserver
-{
-public:
-  virtual ~nsMutationReceiverBase() { }
+class nsMutationReceiverBase : public nsStubAnimationObserver {
+ public:
+  virtual ~nsMutationReceiverBase() {}
 
   nsDOMMutationObserver* Observer();
   nsINode* Target() { return mParent ? mParent->Target() : mTarget; }
   nsINode* RegisterTarget() { return mRegisterTarget; }
 
   bool Subtree() { return mParent ? mParent->Subtree() : mSubtree; }
-  void SetSubtree(bool aSubtree)
-  {
+  void SetSubtree(bool aSubtree) {
     NS_ASSERTION(!mParent, "Shouldn't have parent");
     mSubtree = aSubtree;
   }
 
   bool ChildList() { return mParent ? mParent->ChildList() : mChildList; }
-  void SetChildList(bool aChildList)
-  {
+  void SetChildList(bool aChildList) {
     NS_ASSERTION(!mParent, "Shouldn't have parent");
     mChildList = aChildList;
   }
 
-  bool CharacterData()
-  {
+  bool CharacterData() {
     return mParent ? mParent->CharacterData() : mCharacterData;
   }
-  void SetCharacterData(bool aCharacterData)
-  {
+  void SetCharacterData(bool aCharacterData) {
     NS_ASSERTION(!mParent, "Shouldn't have parent");
     mCharacterData = aCharacterData;
   }
 
-  bool CharacterDataOldValue()
-  {
+  bool CharacterDataOldValue() {
     return mParent ? mParent->CharacterDataOldValue() : mCharacterDataOldValue;
   }
-  void SetCharacterDataOldValue(bool aOldValue)
-  {
+  void SetCharacterDataOldValue(bool aOldValue) {
     NS_ASSERTION(!mParent, "Shouldn't have parent");
     mCharacterDataOldValue = aOldValue;
   }
 
-  bool NativeAnonymousChildList()
-  {
-    return mParent ? mParent->NativeAnonymousChildList() : mNativeAnonymousChildList;
+  bool NativeAnonymousChildList() {
+    return mParent ? mParent->NativeAnonymousChildList()
+                   : mNativeAnonymousChildList;
   }
-  void SetNativeAnonymousChildList(bool aOldValue)
-  {
+  void SetNativeAnonymousChildList(bool aOldValue) {
     NS_ASSERTION(!mParent, "Shouldn't have parent");
     mNativeAnonymousChildList = aOldValue;
   }
 
   bool Attributes() { return mParent ? mParent->Attributes() : mAttributes; }
-  void SetAttributes(bool aAttributes)
-  {
+  void SetAttributes(bool aAttributes) {
     NS_ASSERTION(!mParent, "Shouldn't have parent");
     mAttributes = aAttributes;
   }
 
-  bool AllAttributes()
-  {
-    return mParent ? mParent->AllAttributes()
-                   : mAllAttributes;
+  bool AllAttributes() {
+    return mParent ? mParent->AllAttributes() : mAllAttributes;
   }
-  void SetAllAttributes(bool aAll)
-  {
+  void SetAllAttributes(bool aAll) {
     NS_ASSERTION(!mParent, "Shouldn't have parent");
     mAllAttributes = aAll;
   }
 
   bool Animations() { return mParent ? mParent->Animations() : mAnimations; }
-  void SetAnimations(bool aAnimations)
-  {
+  void SetAnimations(bool aAnimations) {
     NS_ASSERTION(!mParent, "Shouldn't have parent");
     mAnimations = aAnimations;
   }
 
   bool AttributeOldValue() {
-    return mParent ? mParent->AttributeOldValue()
-                   : mAttributeOldValue;
+    return mParent ? mParent->AttributeOldValue() : mAttributeOldValue;
   }
-  void SetAttributeOldValue(bool aOldValue)
-  {
+  void SetAttributeOldValue(bool aOldValue) {
     NS_ASSERTION(!mParent, "Shouldn't have parent");
     mAttributeOldValue = aOldValue;
   }
 
   nsTArray<RefPtr<nsAtom>>& AttributeFilter() { return mAttributeFilter; }
-  void SetAttributeFilter(nsTArray<RefPtr<nsAtom>>&& aFilter)
-  {
+  void SetAttributeFilter(nsTArray<RefPtr<nsAtom>>&& aFilter) {
     NS_ASSERTION(!mParent, "Shouldn't have parent");
     mAttributeFilter.Clear();
     mAttributeFilter = mozilla::Move(aFilter);
   }
 
-  void AddClone(nsMutationReceiverBase* aClone)
-  {
+  void AddClone(nsMutationReceiverBase* aClone) {
     mTransientReceivers.AppendObject(aClone);
   }
 
-  void RemoveClone(nsMutationReceiverBase* aClone)
-  {
+  void RemoveClone(nsMutationReceiverBase* aClone) {
     mTransientReceivers.RemoveObject(aClone);
   }
 
-protected:
+ protected:
   nsMutationReceiverBase(nsINode* aTarget, nsDOMMutationObserver* aObserver)
-    : mTarget(aTarget)
-    , mObserver(aObserver)
-    , mRegisterTarget(aTarget)
-    , mSubtree(false)
-    , mChildList(false)
-    , mCharacterData(false)
-    , mCharacterDataOldValue(false)
-    , mNativeAnonymousChildList(false)
-    , mAttributes(false)
-    , mAllAttributes(false)
-    , mAttributeOldValue(false)
-    , mAnimations(false)
-  {
-  }
+      : mTarget(aTarget),
+        mObserver(aObserver),
+        mRegisterTarget(aTarget),
+        mSubtree(false),
+        mChildList(false),
+        mCharacterData(false),
+        mCharacterDataOldValue(false),
+        mNativeAnonymousChildList(false),
+        mAttributes(false),
+        mAllAttributes(false),
+        mAttributeOldValue(false),
+        mAnimations(false) {}
 
   nsMutationReceiverBase(nsINode* aRegisterTarget,
                          nsMutationReceiverBase* aParent)
-    : mTarget(nullptr)
-    , mObserver(nullptr)
-    , mParent(aParent)
-    , mRegisterTarget(aRegisterTarget)
-    , mKungFuDeathGrip(aParent->Target())
-    , mSubtree(false)
-    , mChildList(false)
-    , mCharacterData(false)
-    , mCharacterDataOldValue(false)
-    , mNativeAnonymousChildList(false)
-    , mAttributes(false)
-    , mAllAttributes(false)
-    , mAttributeOldValue(false)
-    , mAnimations(false)
-  {
+      : mTarget(nullptr),
+        mObserver(nullptr),
+        mParent(aParent),
+        mRegisterTarget(aRegisterTarget),
+        mKungFuDeathGrip(aParent->Target()),
+        mSubtree(false),
+        mChildList(false),
+        mCharacterData(false),
+        mCharacterDataOldValue(false),
+        mNativeAnonymousChildList(false),
+        mAttributes(false),
+        mAllAttributes(false),
+        mAttributeOldValue(false),
+        mAnimations(false) {
     NS_ASSERTION(mParent->Subtree(), "Should clone a non-subtree observer!");
   }
 
   virtual void AddMutationObserver() = 0;
 
-  void AddObserver()
-  {
+  void AddObserver() {
     AddMutationObserver();
     mRegisterTarget->SetMayHaveDOMMutationObserver();
     mRegisterTarget->OwnerDoc()->SetMayHaveDOMMutationObservers();
@@ -285,17 +243,15 @@ protected:
 
   bool IsObservable(nsIContent* aContent);
 
-  bool ObservesAttr(nsINode* aRegisterTarget,
-                    mozilla::dom::Element* aElement,
-                    int32_t aNameSpaceID,
-                    nsAtom* aAttr)
-  {
+  bool ObservesAttr(nsINode* aRegisterTarget, mozilla::dom::Element* aElement,
+                    int32_t aNameSpaceID, nsAtom* aAttr) {
     if (mParent) {
-      return mParent->ObservesAttr(aRegisterTarget, aElement, aNameSpaceID, aAttr);
+      return mParent->ObservesAttr(aRegisterTarget, aElement, aNameSpaceID,
+                                   aAttr);
     }
-    if (!Attributes() ||
-        (!Subtree() && aElement != Target()) ||
-        (Subtree() && aRegisterTarget->SubtreeRoot() != aElement->SubtreeRoot()) ||
+    if (!Attributes() || (!Subtree() && aElement != Target()) ||
+        (Subtree() &&
+         aRegisterTarget->SubtreeRoot() != aElement->SubtreeRoot()) ||
         !IsObservable(aElement)) {
       return false;
     }
@@ -317,71 +273,64 @@ protected:
   }
 
   // The target for the MutationObserver.observe() method.
-  nsINode*                           mTarget;
-  nsDOMMutationObserver*             mObserver;
-  RefPtr<nsMutationReceiverBase>   mParent; // Cleared after microtask.
+  nsINode* mTarget;
+  nsDOMMutationObserver* mObserver;
+  RefPtr<nsMutationReceiverBase> mParent;  // Cleared after microtask.
   // The node to which Gecko-internal nsIMutationObserver was registered to.
   // This is different than mTarget when dealing with transient observers.
-  nsINode*                           mRegisterTarget;
+  nsINode* mRegisterTarget;
   nsCOMArray<nsMutationReceiverBase> mTransientReceivers;
   // While we have transient receivers, keep the original mutation receiver
   // alive so it doesn't go away and disconnect all its transient receivers.
-  nsCOMPtr<nsINode>                  mKungFuDeathGrip;
+  nsCOMPtr<nsINode> mKungFuDeathGrip;
 
-private:
-  bool                               mSubtree;
-  bool                               mChildList;
-  bool                               mCharacterData;
-  bool                               mCharacterDataOldValue;
-  bool                               mNativeAnonymousChildList;
-  bool                               mAttributes;
-  bool                               mAllAttributes;
-  bool                               mAttributeOldValue;
-  bool                               mAnimations;
-  nsTArray<RefPtr<nsAtom>>          mAttributeFilter;
+ private:
+  bool mSubtree;
+  bool mChildList;
+  bool mCharacterData;
+  bool mCharacterDataOldValue;
+  bool mNativeAnonymousChildList;
+  bool mAttributes;
+  bool mAllAttributes;
+  bool mAttributeOldValue;
+  bool mAnimations;
+  nsTArray<RefPtr<nsAtom>> mAttributeFilter;
 };
 
-
-class nsMutationReceiver : public nsMutationReceiverBase
-{
-protected:
+class nsMutationReceiver : public nsMutationReceiverBase {
+ protected:
   virtual ~nsMutationReceiver() { Disconnect(false); }
 
-public:
+ public:
   static nsMutationReceiver* Create(nsINode* aTarget,
-                                    nsDOMMutationObserver* aObserver)
-  {
+                                    nsDOMMutationObserver* aObserver) {
     nsMutationReceiver* r = new nsMutationReceiver(aTarget, aObserver);
     r->AddObserver();
     return r;
   }
 
   static nsMutationReceiver* Create(nsINode* aRegisterTarget,
-                                    nsMutationReceiverBase* aParent)
-  {
+                                    nsMutationReceiverBase* aParent) {
     nsMutationReceiver* r = new nsMutationReceiver(aRegisterTarget, aParent);
     aParent->AddClone(r);
     r->AddObserver();
     return r;
   }
 
-  nsMutationReceiver* GetParent()
-  {
+  nsMutationReceiver* GetParent() {
     return static_cast<nsMutationReceiver*>(mParent.get());
   }
 
-  void RemoveClones()
-  {
+  void RemoveClones() {
     for (int32_t i = 0; i < mTransientReceivers.Count(); ++i) {
       nsMutationReceiver* r =
-        static_cast<nsMutationReceiver*>(mTransientReceivers[i]);
+          static_cast<nsMutationReceiver*>(mTransientReceivers[i]);
       r->DisconnectTransientReceiver();
     }
     mTransientReceivers.Clear();
   }
 
-  void DisconnectTransientReceiver()
-  {
+  void DisconnectTransientReceiver() {
     if (mRegisterTarget) {
       mRegisterTarget->RemoveMutationObserver(this);
       mRegisterTarget = nullptr;
@@ -406,43 +355,38 @@ public:
 
   virtual void AttributeSetToCurrentValue(mozilla::dom::Element* aElement,
                                           int32_t aNameSpaceID,
-                                          nsAtom* aAttribute) override
-  {
+                                          nsAtom* aAttribute) override {
     // We can reuse AttributeWillChange implementation.
     AttributeWillChange(aElement, aNameSpaceID, aAttribute,
-                        mozilla::dom::MutationEventBinding::MODIFICATION, nullptr);
+                        mozilla::dom::MutationEventBinding::MODIFICATION,
+                        nullptr);
   }
 
-protected:
+ protected:
   nsMutationReceiver(nsINode* aTarget, nsDOMMutationObserver* aObserver);
 
   nsMutationReceiver(nsINode* aRegisterTarget, nsMutationReceiverBase* aParent)
-  : nsMutationReceiverBase(aRegisterTarget, aParent)
-  {
+      : nsMutationReceiverBase(aRegisterTarget, aParent) {
     NS_ASSERTION(!static_cast<nsMutationReceiver*>(aParent)->GetParent(),
                  "Shouldn't create deep observer hierarchies!");
   }
 
-  virtual void AddMutationObserver() override
-  {
+  virtual void AddMutationObserver() override {
     mRegisterTarget->AddMutationObserver(this);
   }
 };
 
-class nsAnimationReceiver : public nsMutationReceiver
-{
-public:
+class nsAnimationReceiver : public nsMutationReceiver {
+ public:
   static nsAnimationReceiver* Create(nsINode* aTarget,
-                                     nsDOMMutationObserver* aObserver)
-  {
+                                     nsDOMMutationObserver* aObserver) {
     nsAnimationReceiver* r = new nsAnimationReceiver(aTarget, aObserver);
     r->AddObserver();
     return r;
   }
 
   static nsAnimationReceiver* Create(nsINode* aRegisterTarget,
-                                     nsMutationReceiverBase* aParent)
-  {
+                                     nsMutationReceiverBase* aParent) {
     nsAnimationReceiver* r = new nsAnimationReceiver(aRegisterTarget, aParent);
     aParent->AddClone(r);
     r->AddObserver();
@@ -455,21 +399,20 @@ public:
   NS_DECL_NSIANIMATIONOBSERVER_ANIMATIONCHANGED
   NS_DECL_NSIANIMATIONOBSERVER_ANIMATIONREMOVED
 
-protected:
+ protected:
   virtual ~nsAnimationReceiver() {}
 
   nsAnimationReceiver(nsINode* aTarget, nsDOMMutationObserver* aObserver)
-    : nsMutationReceiver(aTarget, aObserver) {}
+      : nsMutationReceiver(aTarget, aObserver) {}
 
   nsAnimationReceiver(nsINode* aRegisterTarget, nsMutationReceiverBase* aParent)
-    : nsMutationReceiver(aRegisterTarget, aParent) {}
+      : nsMutationReceiver(aRegisterTarget, aParent) {}
 
-  virtual void AddMutationObserver() override
-  {
+  virtual void AddMutationObserver() override {
     mRegisterTarget->AddAnimationObserver(this);
   }
 
-private:
+ private:
   enum AnimationMutation {
     eAnimationMutation_Added,
     eAnimationMutation_Changed,
@@ -480,45 +423,41 @@ private:
                                AnimationMutation aMutationType);
 };
 
-#define NS_DOM_MUTATION_OBSERVER_IID \
-{ 0x0c3b91f8, 0xcc3b, 0x4b08, \
-  { 0x9e, 0xab, 0x07, 0x47, 0xa9, 0xe4, 0x65, 0xb4 } }
-
-class nsDOMMutationObserver final : public nsISupports,
-                                    public nsWrapperCache
-{
-public:
-  nsDOMMutationObserver(already_AddRefed<nsPIDOMWindowInner>&& aOwner,
-                        mozilla::dom::MutationCallback& aCb,
-                        bool aChrome)
-  : mOwner(aOwner), mLastPendingMutation(nullptr), mPendingMutationCount(0),
-    mCallback(&aCb), mWaitingForRun(false), mIsChrome(aChrome),
-    mMergeAttributeRecords(false), mId(++sCount)
-  {
+#define NS_DOM_MUTATION_OBSERVER_IID                 \
+  {                                                  \
+    0x0c3b91f8, 0xcc3b, 0x4b08, {                    \
+      0x9e, 0xab, 0x07, 0x47, 0xa9, 0xe4, 0x65, 0xb4 \
+    }                                                \
   }
+
+class nsDOMMutationObserver final : public nsISupports, public nsWrapperCache {
+ public:
+  nsDOMMutationObserver(already_AddRefed<nsPIDOMWindowInner>&& aOwner,
+                        mozilla::dom::MutationCallback& aCb, bool aChrome)
+      : mOwner(aOwner),
+        mLastPendingMutation(nullptr),
+        mPendingMutationCount(0),
+        mCallback(&aCb),
+        mWaitingForRun(false),
+        mIsChrome(aChrome),
+        mMergeAttributeRecords(false),
+        mId(++sCount) {}
   NS_DECL_CYCLE_COLLECTING_ISUPPORTS
   NS_DECL_CYCLE_COLLECTION_SCRIPT_HOLDER_CLASS(nsDOMMutationObserver)
   NS_DECLARE_STATIC_IID_ACCESSOR(NS_DOM_MUTATION_OBSERVER_IID)
 
-  static already_AddRefed<nsDOMMutationObserver>
-  Constructor(const mozilla::dom::GlobalObject& aGlobal,
-              mozilla::dom::MutationCallback& aCb,
-              mozilla::ErrorResult& aRv);
+  static already_AddRefed<nsDOMMutationObserver> Constructor(
+      const mozilla::dom::GlobalObject& aGlobal,
+      mozilla::dom::MutationCallback& aCb, mozilla::ErrorResult& aRv);
 
-  virtual JSObject* WrapObject(JSContext* aCx, JS::Handle<JSObject*> aGivenProto) override
-  {
+  virtual JSObject* WrapObject(JSContext* aCx,
+                               JS::Handle<JSObject*> aGivenProto) override {
     return mozilla::dom::MutationObserverBinding::Wrap(aCx, this, aGivenProto);
   }
 
-  nsISupports* GetParentObject() const
-  {
-    return mOwner;
-  }
+  nsISupports* GetParentObject() const { return mOwner; }
 
-  bool IsChrome()
-  {
-    return mIsChrome;
-  }
+  bool IsChrome() { return mIsChrome; }
 
   void Observe(nsINode& aTarget,
                const mozilla::dom::MutationObserverInit& aOptions,
@@ -526,7 +465,7 @@ public:
 
   void Disconnect();
 
-  void TakeRecords(nsTArray<RefPtr<nsDOMMutationRecord> >& aRetVal);
+  void TakeRecords(nsTArray<RefPtr<nsDOMMutationRecord>>& aRetVal);
 
   void HandleMutation();
 
@@ -535,15 +474,9 @@ public:
 
   mozilla::dom::MutationCallback* MutationCallback() { return mCallback; }
 
-  bool MergeAttributeRecords()
-  {
-    return mMergeAttributeRecords;
-  }
+  bool MergeAttributeRecords() { return mMergeAttributeRecords; }
 
-  void SetMergeAttributeRecords(bool aVal)
-  {
-    mMergeAttributeRecords = aVal;
-  }
+  void SetMergeAttributeRecords(bool aVal) { mMergeAttributeRecords = aVal; }
 
   // If both records are for 'attributes' type and for the same target and
   // attribute name and namespace are the same, we can skip the newer record.
@@ -551,8 +484,7 @@ public:
   bool MergeableAttributeRecord(nsDOMMutationRecord* aOldRecord,
                                 nsDOMMutationRecord* aRecord);
 
-  void AppendMutationRecord(already_AddRefed<nsDOMMutationRecord> aRecord)
-  {
+  void AppendMutationRecord(already_AddRefed<nsDOMMutationRecord> aRecord) {
     RefPtr<nsDOMMutationRecord> record = aRecord;
     MOZ_ASSERT(record);
     if (!mLastPendingMutation) {
@@ -567,8 +499,7 @@ public:
     ++mPendingMutationCount;
   }
 
-  void ClearPendingRecords()
-  {
+  void ClearPendingRecords() {
     mFirstPendingMutation = nullptr;
     mLastPendingMutation = nullptr;
     mPendingMutationCount = 0;
@@ -579,8 +510,7 @@ public:
 
   static void HandleMutations(mozilla::AutoSlowOperation& aAso);
 
-  static bool AllScheduledMutationObserversAreSuppressed()
-  {
+  static bool AllScheduledMutationObserversAreSuppressed() {
     if (sScheduledMutationObservers) {
       uint32_t len = sScheduledMutationObservers->Length();
       if (len > 0) {
@@ -599,15 +529,15 @@ public:
   static void LeaveMutationHandling();
 
   static void Shutdown();
-protected:
+
+ protected:
   virtual ~nsDOMMutationObserver();
 
   friend class nsMutationReceiver;
   friend class nsAnimationReceiver;
   friend class nsAutoMutationBatch;
   friend class nsAutoAnimationMutationBatch;
-  nsMutationReceiver* GetReceiverFor(nsINode* aNode,
-                                     bool aMayCreate,
+  nsMutationReceiver* GetReceiverFor(nsINode* aNode, bool aMayCreate,
                                      bool aWantsAnimations);
   void RemoveReceiver(nsMutationReceiver* aReceiver);
 
@@ -621,8 +551,7 @@ protected:
   nsDOMMutationRecord* CurrentRecord(nsAtom* aType);
   bool HasCurrentRecord(const nsAString& aType);
 
-  bool Suppressed()
-  {
+  bool Suppressed() {
     return mOwner && nsGlobalWindowInner::Cast(mOwner)->IsInSyncOperation();
   }
 
@@ -631,56 +560,59 @@ protected:
   static void AddCurrentlyHandlingObserver(nsDOMMutationObserver* aObserver,
                                            uint32_t aMutationLevel);
 
-  nsCOMPtr<nsPIDOMWindowInner>                       mOwner;
+  nsCOMPtr<nsPIDOMWindowInner> mOwner;
 
-  nsCOMArray<nsMutationReceiver>                     mReceivers;
-  nsClassHashtable<nsISupportsHashKey,
-                   nsCOMArray<nsMutationReceiver> >  mTransientReceivers;
+  nsCOMArray<nsMutationReceiver> mReceivers;
+  nsClassHashtable<nsISupportsHashKey, nsCOMArray<nsMutationReceiver>>
+      mTransientReceivers;
   // MutationRecords which are being constructed.
-  AutoTArray<nsDOMMutationRecord*, 4>              mCurrentMutations;
+  AutoTArray<nsDOMMutationRecord*, 4> mCurrentMutations;
   // MutationRecords which will be handed to the callback at the end of
   // the microtask.
-  RefPtr<nsDOMMutationRecord>                      mFirstPendingMutation;
-  nsDOMMutationRecord*                               mLastPendingMutation;
-  uint32_t                                           mPendingMutationCount;
+  RefPtr<nsDOMMutationRecord> mFirstPendingMutation;
+  nsDOMMutationRecord* mLastPendingMutation;
+  uint32_t mPendingMutationCount;
 
-  RefPtr<mozilla::dom::MutationCallback>           mCallback;
+  RefPtr<mozilla::dom::MutationCallback> mCallback;
 
-  bool                                               mWaitingForRun;
-  bool                                               mIsChrome;
-  bool                                               mMergeAttributeRecords;
+  bool mWaitingForRun;
+  bool mIsChrome;
+  bool mMergeAttributeRecords;
 
-  uint64_t                                           mId;
+  uint64_t mId;
 
-  static uint64_t                                    sCount;
-  static AutoTArray<RefPtr<nsDOMMutationObserver>, 4>* sScheduledMutationObservers;
+  static uint64_t sCount;
+  static AutoTArray<RefPtr<nsDOMMutationObserver>, 4>*
+      sScheduledMutationObservers;
 
-  static uint32_t                                    sMutationLevel;
+  static uint32_t sMutationLevel;
   static AutoTArray<AutoTArray<RefPtr<nsDOMMutationObserver>, 4>, 4>*
-                                                     sCurrentlyHandlingObservers;
+      sCurrentlyHandlingObservers;
 };
 
-NS_DEFINE_STATIC_IID_ACCESSOR(nsDOMMutationObserver, NS_DOM_MUTATION_OBSERVER_IID)
+NS_DEFINE_STATIC_IID_ACCESSOR(nsDOMMutationObserver,
+                              NS_DOM_MUTATION_OBSERVER_IID)
 
-class nsAutoMutationBatch
-{
-public:
+class nsAutoMutationBatch {
+ public:
   nsAutoMutationBatch()
-  : mPreviousBatch(nullptr), mBatchTarget(nullptr), mRemovalDone(false),
-    mFromFirstToLast(false), mAllowNestedBatches(false)
-  {
-  }
+      : mPreviousBatch(nullptr),
+        mBatchTarget(nullptr),
+        mRemovalDone(false),
+        mFromFirstToLast(false),
+        mAllowNestedBatches(false) {}
 
   nsAutoMutationBatch(nsINode* aTarget, bool aFromFirstToLast,
                       bool aAllowNestedBatches)
-  : mPreviousBatch(nullptr), mBatchTarget(nullptr), mRemovalDone(false),
-    mFromFirstToLast(false), mAllowNestedBatches(false)
-  {
+      : mPreviousBatch(nullptr),
+        mBatchTarget(nullptr),
+        mRemovalDone(false),
+        mFromFirstToLast(false),
+        mAllowNestedBatches(false) {
     Init(aTarget, aFromFirstToLast, aAllowNestedBatches);
   }
 
-  void Init(nsINode* aTarget, bool aFromFirstToLast, bool aAllowNestedBatches)
-  {
+  void Init(nsINode* aTarget, bool aFromFirstToLast, bool aAllowNestedBatches) {
     if (aTarget && aTarget->OwnerDoc()->MayHaveDOMMutationObservers()) {
       if (sCurrentBatch && !sCurrentBatch->mAllowNestedBatches) {
         return;
@@ -704,19 +636,12 @@ public:
 
   ~nsAutoMutationBatch() { NodesAdded(); }
 
-  static bool IsBatching()
-  {
-    return !!sCurrentBatch;
-  }
+  static bool IsBatching() { return !!sCurrentBatch; }
 
-  static nsAutoMutationBatch* GetCurrentBatch()
-  {
-    return sCurrentBatch;
-  }
+  static nsAutoMutationBatch* GetCurrentBatch() { return sCurrentBatch; }
 
   static void UpdateObserver(nsDOMMutationObserver* aObserver,
-                             bool aWantsChildList)
-  {
+                             bool aWantsChildList) {
     uint32_t l = sCurrentBatch->mObservers.Length();
     for (uint32_t i = 0; i < l; ++i) {
       if (sCurrentBatch->mObservers[i].mObserver == aObserver) {
@@ -731,49 +656,43 @@ public:
     bo->mWantsChildList = aWantsChildList;
   }
 
-
   static nsINode* GetBatchTarget() { return sCurrentBatch->mBatchTarget; }
 
   // Mutation receivers notify the batch about removed child nodes.
-  static void NodeRemoved(nsIContent* aChild)
-  {
+  static void NodeRemoved(nsIContent* aChild) {
     if (IsBatching() && !sCurrentBatch->mRemovalDone) {
       uint32_t len = sCurrentBatch->mRemovedNodes.Length();
-      if (!len ||
-          sCurrentBatch->mRemovedNodes[len - 1] != aChild) {
+      if (!len || sCurrentBatch->mRemovedNodes[len - 1] != aChild) {
         sCurrentBatch->mRemovedNodes.AppendElement(aChild);
       }
     }
   }
 
   // Called after new child nodes have been added to the batch target.
-  void NodesAdded()
-  {
+  void NodesAdded() {
     if (sCurrentBatch != this) {
       return;
     }
 
-    nsIContent* c =
-      mPrevSibling ? mPrevSibling->GetNextSibling() :
-                     mBatchTarget->GetFirstChild();
+    nsIContent* c = mPrevSibling ? mPrevSibling->GetNextSibling()
+                                 : mBatchTarget->GetFirstChild();
     for (; c != mNextSibling; c = c->GetNextSibling()) {
       mAddedNodes.AppendElement(c);
     }
     Done();
   }
 
-private:
-  struct BatchObserver
-  {
+ private:
+  struct BatchObserver {
     nsDOMMutationObserver* mObserver;
-    bool                   mWantsChildList;
+    bool mWantsChildList;
   };
 
   static nsAutoMutationBatch* sCurrentBatch;
   nsAutoMutationBatch* mPreviousBatch;
   AutoTArray<BatchObserver, 2> mObservers;
-  nsTArray<nsCOMPtr<nsIContent> > mRemovedNodes;
-  nsTArray<nsCOMPtr<nsIContent> > mAddedNodes;
+  nsTArray<nsCOMPtr<nsIContent>> mRemovedNodes;
+  nsTArray<nsCOMPtr<nsIContent>> mAddedNodes;
   nsINode* mBatchTarget;
   bool mRemovalDone;
   bool mFromFirstToLast;
@@ -782,20 +701,16 @@ private:
   nsCOMPtr<nsINode> mNextSibling;
 };
 
-class nsAutoAnimationMutationBatch
-{
+class nsAutoAnimationMutationBatch {
   struct Entry;
 
-public:
-  explicit nsAutoAnimationMutationBatch(nsIDocument* aDocument)
-  {
+ public:
+  explicit nsAutoAnimationMutationBatch(nsIDocument* aDocument) {
     Init(aDocument);
   }
 
-  void Init(nsIDocument* aDocument)
-  {
-    if (!aDocument ||
-        !aDocument->MayHaveDOMMutationObservers() ||
+  void Init(nsIDocument* aDocument) {
+    if (!aDocument || !aDocument->MayHaveDOMMutationObservers() ||
         sCurrentBatch) {
       return;
     }
@@ -804,25 +719,17 @@ public:
     nsDOMMutationObserver::EnterMutationHandling();
   }
 
-  ~nsAutoAnimationMutationBatch()
-  {
-    Done();
-  }
+  ~nsAutoAnimationMutationBatch() { Done(); }
 
   void Done();
 
-  static bool IsBatching()
-  {
-    return !!sCurrentBatch;
-  }
+  static bool IsBatching() { return !!sCurrentBatch; }
 
-  static nsAutoAnimationMutationBatch* GetCurrentBatch()
-  {
+  static nsAutoAnimationMutationBatch* GetCurrentBatch() {
     return sCurrentBatch;
   }
 
-  static void AddObserver(nsDOMMutationObserver* aObserver)
-  {
+  static void AddObserver(nsDOMMutationObserver* aObserver) {
     if (sCurrentBatch->mObservers.Contains(aObserver)) {
       return;
     }
@@ -830,8 +737,7 @@ public:
   }
 
   static void AnimationAdded(mozilla::dom::Animation* aAnimation,
-                             nsINode* aTarget)
-  {
+                             nsINode* aTarget) {
     if (!IsBatching()) {
       return;
     }
@@ -846,8 +752,9 @@ public:
           entry->mState = eState_RemainedPresent;
           break;
         default:
-          NS_NOTREACHED("shouldn't have observed an animation being added "
-                        "twice");
+          NS_NOTREACHED(
+              "shouldn't have observed an animation being added "
+              "twice");
       }
     } else {
       entry = sCurrentBatch->AddEntry(aAnimation, aTarget);
@@ -857,12 +764,11 @@ public:
   }
 
   static void AnimationChanged(mozilla::dom::Animation* aAnimation,
-                               nsINode* aTarget)
-  {
+                               nsINode* aTarget) {
     Entry* entry = sCurrentBatch->FindEntry(aAnimation, aTarget);
     if (entry) {
       NS_ASSERTION(entry->mState == eState_RemainedPresent ||
-                   entry->mState == eState_Added,
+                       entry->mState == eState_Added,
                    "shouldn't have observed an animation being changed after "
                    "being removed");
       entry->mChanged = true;
@@ -874,8 +780,7 @@ public:
   }
 
   static void AnimationRemoved(mozilla::dom::Animation* aAnimation,
-                               nsINode* aTarget)
-  {
+                               nsINode* aTarget) {
     Entry* entry = sCurrentBatch->FindEntry(aAnimation, aTarget);
     if (entry) {
       switch (entry->mState) {
@@ -886,8 +791,9 @@ public:
           entry->mState = eState_RemainedAbsent;
           break;
         default:
-          NS_NOTREACHED("shouldn't have observed an animation being removed "
-                        "twice");
+          NS_NOTREACHED(
+              "shouldn't have observed an animation being removed "
+              "twice");
       }
     } else {
       entry = sCurrentBatch->AddEntry(aAnimation, aTarget);
@@ -896,9 +802,8 @@ public:
     }
   }
 
-private:
-  Entry* FindEntry(mozilla::dom::Animation* aAnimation, nsINode* aTarget)
-  {
+ private:
+  Entry* FindEntry(mozilla::dom::Animation* aAnimation, nsINode* aTarget) {
     EntryArray* entries = mEntryTable.Get(aTarget);
     if (!entries) {
       return nullptr;
@@ -912,8 +817,7 @@ private:
     return nullptr;
   }
 
-  Entry* AddEntry(mozilla::dom::Animation* aAnimation, nsINode* aTarget)
-  {
+  Entry* AddEntry(mozilla::dom::Animation* aAnimation, nsINode* aTarget) {
     EntryArray* entries = sCurrentBatch->mEntryTable.LookupOrAdd(aTarget);
     if (entries->IsEmpty()) {
       sCurrentBatch->mBatchTargets.AppendElement(aTarget);
@@ -930,8 +834,7 @@ private:
     eState_Removed
   };
 
-  struct Entry
-  {
+  struct Entry {
     RefPtr<mozilla::dom::Animation> mAnimation;
     State mState;
     bool mChanged;
@@ -947,12 +850,9 @@ private:
   nsTArray<nsINode*> mBatchTargets;
 };
 
-inline
-nsDOMMutationObserver*
-nsMutationReceiverBase::Observer()
-{
-  return mParent ?
-    mParent->Observer() : static_cast<nsDOMMutationObserver*>(mObserver);
+inline nsDOMMutationObserver* nsMutationReceiverBase::Observer() {
+  return mParent ? mParent->Observer()
+                 : static_cast<nsDOMMutationObserver*>(mObserver);
 }
 
 #endif
