@@ -30,7 +30,7 @@ namespace mozilla {
 namespace dom {
 class TabParent;
 }
-}
+}  // namespace mozilla
 
 struct nsDelayedBlurOrFocusEvent;
 
@@ -41,12 +41,10 @@ struct nsDelayedBlurOrFocusEvent;
 
 class nsFocusManager final : public nsIFocusManager,
                              public nsIObserver,
-                             public nsSupportsWeakReference
-{
+                             public nsSupportsWeakReference {
   typedef mozilla::widget::InputContextAction InputContextAction;
 
-public:
-
+ public:
   NS_DECL_CYCLE_COLLECTION_CLASS_AMBIGUOUS(nsFocusManager, nsIFocusManager)
   NS_DECL_CYCLE_COLLECTING_ISUPPORTS
   NS_DECL_NSIOBSERVER
@@ -91,16 +89,14 @@ public:
   /**
    * Called when mouse button event handling is started and finished.
    */
-  already_AddRefed<nsIDocument>
-    SetMouseButtonHandlingDocument(nsIDocument* aDocument)
-  {
+  already_AddRefed<nsIDocument> SetMouseButtonHandlingDocument(
+      nsIDocument* aDocument) {
     nsCOMPtr<nsIDocument> handlingDocument = mMouseButtonEventHandlingDocument;
     mMouseButtonEventHandlingDocument = aDocument;
     return handlingDocument.forget();
   }
 
-  void NeedsFlushBeforeEventHandling(nsIContent* aContent)
-  {
+  void NeedsFlushBeforeEventHandling(nsIContent* aContent) {
     if (mFocusedContent == aContent) {
       mEventHandlingNeedsFlush = true;
     }
@@ -108,8 +104,7 @@ public:
 
   bool CanSkipFocus(nsIContent* aContent);
 
-  void FlushBeforeEventHandlingIfNeeded(nsIContent* aContent)
-  {
+  void FlushBeforeEventHandlingIfNeeded(nsIContent* aContent) {
     if (mEventHandlingNeedsFlush) {
       nsCOMPtr<nsIDocument> doc = aContent->GetComposedDoc();
       if (doc) {
@@ -134,8 +129,7 @@ public:
    *
    * aWindow and aFocusedWindow must both be non-null.
    */
-  enum SearchRange
-  {
+  enum SearchRange {
     // Return focused content in aWindow.  So, aFocusedWindow is always aWindow.
     eOnlyCurrentWindow,
     // Return focused content in aWindow or one of all sub windows.
@@ -167,8 +161,8 @@ public:
   static bool sMouseFocusesFormControl;
 
   static void MarkUncollectableForCCGeneration(uint32_t aGeneration);
-protected:
 
+ protected:
   nsFocusManager();
   ~nsFocusManager();
 
@@ -182,7 +176,8 @@ protected:
    * Iterate over the children of the message broadcaster and notify them
    * of the activation change.
    */
-  void ActivateOrDeactivateChildren(nsIMessageBroadcaster* aManager, bool aActive);
+  void ActivateOrDeactivateChildren(nsIMessageBroadcaster* aManager,
+                                    bool aActive);
 
   /**
    * Activate or deactivate the window and send the activate/deactivate events.
@@ -214,8 +209,8 @@ protected:
    * Returns the window that is the lowest common ancestor of both aWindow1
    * and aWindow2, or null if they share no common ancestor.
    */
-  already_AddRefed<nsPIDOMWindowOuter>
-  GetCommonAncestor(nsPIDOMWindowOuter* aWindow1, nsPIDOMWindowOuter* aWindow2);
+  already_AddRefed<nsPIDOMWindowOuter> GetCommonAncestor(
+      nsPIDOMWindowOuter* aWindow1, nsPIDOMWindowOuter* aWindow2);
 
   /**
    * When aNewWindow is focused, adjust the ancestors of aNewWindow so that they
@@ -275,10 +270,8 @@ protected:
    * If aAdjustWidget is false, don't change the widget focus state.
    */
   bool Blur(nsPIDOMWindowOuter* aWindowToClear,
-            nsPIDOMWindowOuter* aAncestorWindowToFocus,
-            bool aIsLeavingDocument,
-            bool aAdjustWidget,
-            nsIContent* aContentToFocus = nullptr);
+            nsPIDOMWindowOuter* aAncestorWindowToFocus, bool aIsLeavingDocument,
+            bool aAdjustWidget, nsIContent* aContentToFocus = nullptr);
 
   /**
    * Focus an element in the active window and child frame.
@@ -306,14 +299,9 @@ protected:
    *
    * If aAdjustWidget is false, don't change the widget focus state.
    */
-  void Focus(nsPIDOMWindowOuter* aWindow,
-             nsIContent* aContent,
-             uint32_t aFlags,
-             bool aIsNewDocument,
-             bool aFocusChanged,
-             bool aWindowRaised,
-             bool aAdjustWidget,
-             nsIContent* aContentLostFocus = nullptr);
+  void Focus(nsPIDOMWindowOuter* aWindow, nsIContent* aContent, uint32_t aFlags,
+             bool aIsNewDocument, bool aFocusChanged, bool aWindowRaised,
+             bool aAdjustWidget, nsIContent* aContentLostFocus = nullptr);
 
   /**
    * Send a focus or blur event at aTarget. It may be added to the delayed
@@ -324,14 +312,11 @@ protected:
    *
    * aWindowRaised should only be true if called from WindowRaised.
    */
-  void SendFocusOrBlurEvent(mozilla::EventMessage aEventMessage,
-                            nsIPresShell* aPresShell,
-                            nsIDocument* aDocument,
-                            nsISupports* aTarget,
-                            uint32_t aFocusMethod,
-                            bool aWindowRaised,
-                            bool aIsRefocus = false,
-                            mozilla::dom::EventTarget* aRelatedTarget = nullptr);
+  void SendFocusOrBlurEvent(
+      mozilla::EventMessage aEventMessage, nsIPresShell* aPresShell,
+      nsIDocument* aDocument, nsISupports* aTarget, uint32_t aFocusMethod,
+      bool aWindowRaised, bool aIsRefocus = false,
+      mozilla::dom::EventTarget* aRelatedTarget = nullptr);
 
   /**
    * Fire a focus or blur event at aTarget.
@@ -341,12 +326,10 @@ protected:
    *
    * aWindowRaised should only be true if called from WindowRaised.
    */
-  void FireFocusOrBlurEvent(mozilla::EventMessage aEventMessage,
-                            nsIPresShell* aPresShell,
-                            nsISupports* aTarget,
-                            bool aWindowRaised,
-                            bool aIsRefocus = false,
-                            mozilla::dom::EventTarget* aRelatedTarget = nullptr);
+  void FireFocusOrBlurEvent(
+      mozilla::EventMessage aEventMessage, nsIPresShell* aPresShell,
+      nsISupports* aTarget, bool aWindowRaised, bool aIsRefocus = false,
+      mozilla::dom::EventTarget* aRelatedTarget = nullptr);
 
   /**
    *  Fire a focusin or focusout event
@@ -365,18 +348,16 @@ protected:
    *  aRelatedTarget is the content related to the event (the object
    *  losing focus for focusin, the object getting focus for focusout).
    */
-  void FireFocusInOrOutEvent(mozilla::EventMessage aEventMessage,
-                             nsIPresShell* aPresShell,
-                             nsISupports* aTarget,
-                             nsPIDOMWindowOuter* aCurrentFocusedWindow,
-                             nsIContent* aCurrentFocusedContent,
-                             mozilla::dom::EventTarget* aRelatedTarget = nullptr);
+  void FireFocusInOrOutEvent(
+      mozilla::EventMessage aEventMessage, nsIPresShell* aPresShell,
+      nsISupports* aTarget, nsPIDOMWindowOuter* aCurrentFocusedWindow,
+      nsIContent* aCurrentFocusedContent,
+      mozilla::dom::EventTarget* aRelatedTarget = nullptr);
 
   /**
    * Scrolls aContent into view unless the FLAG_NOSCROLL flag is set.
    */
-  void ScrollIntoView(nsIPresShell* aPresShell,
-                      nsIContent* aContent,
+  void ScrollIntoView(nsIPresShell* aPresShell, nsIContent* aContent,
                       uint32_t aFlags);
 
   /**
@@ -392,8 +373,7 @@ protected:
    * aUpdateVisibility should be true to update whether the caret is
    * visible or not.
    */
-  void UpdateCaret(bool aMoveCaretToFocus,
-                   bool aUpdateVisibility,
+  void UpdateCaret(bool aMoveCaretToFocus, bool aUpdateVisibility,
                    nsIContent* aContent);
 
   /**
@@ -404,11 +384,9 @@ protected:
   /**
    * Makes the caret visible or not, depending on aVisible.
    */
-  nsresult SetCaretVisible(nsIPresShell* aPresShell,
-                           bool aVisible,
+  nsresult SetCaretVisible(nsIPresShell* aPresShell, bool aVisible,
                            nsIContent* aContent);
 
-
   // the remaining functions are used for tab key and document-navigation
 
   /**
@@ -417,8 +395,8 @@ protected:
    */
   nsresult GetSelectionLocation(nsIDocument* aDocument,
                                 nsIPresShell* aPresShell,
-                                nsIContent **aStartContent,
-                                nsIContent **aEndContent);
+                                nsIContent** aStartContent,
+                                nsIContent** aEndContent);
 
   /**
    * Helper function for MoveFocus which determines the next element
@@ -433,8 +411,8 @@ protected:
    * beginning (or end) of the starting document.
    */
   nsresult DetermineElementToMoveFocus(nsPIDOMWindowOuter* aWindow,
-                                       nsIContent* aStart,
-                                       int32_t aType, bool aNoParentTraversal,
+                                       nsIContent* aStart, int32_t aType,
+                                       bool aNoParentTraversal,
                                        nsIContent** aNextContent);
 
   /**
@@ -471,12 +449,9 @@ protected:
    *   Consider the method searches downwards in flattened subtree
    *   rooted at aOwner.
    */
-  nsIContent* GetNextTabbableContentInScope(nsIContent* aOwner,
-                                            nsIContent* aStartContent,
-                                            bool aForward,
-                                            int32_t aCurrentTabIndex,
-                                            bool aIgnoreTabIndex,
-                                            bool aSkipOwner);
+  nsIContent* GetNextTabbableContentInScope(
+      nsIContent* aOwner, nsIContent* aStartContent, bool aForward,
+      int32_t aCurrentTabIndex, bool aIgnoreTabIndex, bool aSkipOwner);
 
   /**
    * Retrieve the next tabbable element in scope including aStartContent
@@ -536,15 +511,11 @@ protected:
    * from where the selection is. Similarly, if the starting element isn't
    * focusable, since it doesn't really have a defined tab index.
    */
-  nsresult GetNextTabbableContent(nsIPresShell* aPresShell,
-                                  nsIContent* aRootContent,
-                                  nsIContent* aOriginalStartContent,
-                                  nsIContent* aStartContent,
-                                  bool aForward,
-                                  int32_t aCurrentTabIndex,
-                                  bool aIgnoreTabIndex,
-                                  bool aForDocumentNavigation,
-                                  nsIContent** aResultContent);
+  nsresult GetNextTabbableContent(
+      nsIPresShell* aPresShell, nsIContent* aRootContent,
+      nsIContent* aOriginalStartContent, nsIContent* aStartContent,
+      bool aForward, int32_t aCurrentTabIndex, bool aIgnoreTabIndex,
+      bool aForDocumentNavigation, nsIContent** aResultContent);
 
   /**
    * Get the next tabbable image map area and returns it.
@@ -558,8 +529,7 @@ protected:
    *
    * aStartContent is the current image map area.
    */
-  nsIContent* GetNextTabbableMapArea(bool aForward,
-                                     int32_t aCurrentTabIndex,
+  nsIContent* GetNextTabbableMapArea(bool aForward, int32_t aCurrentTabIndex,
                                      mozilla::dom::Element* aImageContent,
                                      nsIContent* aStartContent);
 
@@ -568,8 +538,7 @@ protected:
    * is true, or the previous tabindex value if aForward is false. aParent is
    * the node from which to start looking for tab indicies.
    */
-  int32_t GetNextTabIndex(nsIContent* aParent,
-                          int32_t aCurrentTabIndex,
+  int32_t GetNextTabIndex(nsIContent* aParent, int32_t aCurrentTabIndex,
                           bool aForward);
 
   /**
@@ -577,7 +546,8 @@ protected:
    * aRootContent. For content documents, this will be aRootContent itself, but
    * for chrome documents, this will locate the next focusable content.
    */
-  nsresult FocusFirst(mozilla::dom::Element* aRootContent, nsIContent** aNextContent);
+  nsresult FocusFirst(mozilla::dom::Element* aRootContent,
+                      nsIContent** aNextContent);
 
   /**
    * Retrieves and returns the root node from aDocument to be focused. Will
@@ -612,7 +582,7 @@ protected:
                            nsIContent* aEndSelection,
                            nsIContent** aFocusedContent);
 
-private:
+ private:
   // Notify that the focus state of aContent has changed.  Note that
   // we need to pass in whether the window should show a focus ring
   // before the SetFocusedNode call on it happened when losing focus
@@ -674,7 +644,6 @@ private:
   static nsFocusManager* sInstance;
 };
 
-nsresult
-NS_NewFocusManager(nsIFocusManager** aResult);
+nsresult NS_NewFocusManager(nsIFocusManager** aResult);
 
 #endif
