@@ -35,25 +35,18 @@ StaticRefPtr<nsWindowMemoryReporter> sWindowReporter;
 const int32_t kTimeBetweenChecks = 45; /* seconds */
 
 nsWindowMemoryReporter::nsWindowMemoryReporter()
-  : mLastCheckForGhostWindows(TimeStamp::NowLoRes()),
-    mCycleCollectorIsRunning(false),
-    mCheckTimerWaitingForCCEnd(false),
-    mGhostWindowCount(0)
-{
-}
+    : mLastCheckForGhostWindows(TimeStamp::NowLoRes()),
+      mCycleCollectorIsRunning(false),
+      mCheckTimerWaitingForCCEnd(false),
+      mGhostWindowCount(0) {}
 
-nsWindowMemoryReporter::~nsWindowMemoryReporter()
-{
-  KillCheckTimer();
-}
+nsWindowMemoryReporter::~nsWindowMemoryReporter() { KillCheckTimer(); }
 
 NS_IMPL_ISUPPORTS(nsWindowMemoryReporter, nsIMemoryReporter, nsIObserver,
                   nsISupportsWeakReference)
 
-static nsresult
-AddNonJSSizeOfWindowAndItsDescendents(nsGlobalWindowOuter* aWindow,
-                                      nsTabSizes* aSizes)
-{
+static nsresult AddNonJSSizeOfWindowAndItsDescendents(
+    nsGlobalWindowOuter* aWindow, nsTabSizes* aSizes) {
   // Measure the window.
   SizeOfState state(moz_malloc_size_of);
   nsWindowSizes windowSizes(state);
@@ -75,37 +68,34 @@ AddNonJSSizeOfWindowAndItsDescendents(nsGlobalWindowOuter* aWindow,
 
   // Measure this window's descendents.
   for (uint32_t i = 0; i < length; i++) {
-      nsCOMPtr<mozIDOMWindowProxy> child;
-      rv = frames->Item(i, getter_AddRefs(child));
-      NS_ENSURE_SUCCESS(rv, rv);
-      NS_ENSURE_STATE(child);
+    nsCOMPtr<mozIDOMWindowProxy> child;
+    rv = frames->Item(i, getter_AddRefs(child));
+    NS_ENSURE_SUCCESS(rv, rv);
+    NS_ENSURE_STATE(child);
 
-      nsGlobalWindowOuter* childWin = nsGlobalWindowOuter::Cast(child);
+    nsGlobalWindowOuter* childWin = nsGlobalWindowOuter::Cast(child);
 
-      rv = AddNonJSSizeOfWindowAndItsDescendents(childWin, aSizes);
-      NS_ENSURE_SUCCESS(rv, rv);
+    rv = AddNonJSSizeOfWindowAndItsDescendents(childWin, aSizes);
+    NS_ENSURE_SUCCESS(rv, rv);
   }
   return NS_OK;
 }
 
-static nsresult
-NonJSSizeOfTab(nsPIDOMWindowOuter* aWindow, size_t* aDomSize, size_t* aStyleSize, size_t* aOtherSize)
-{
+static nsresult NonJSSizeOfTab(nsPIDOMWindowOuter* aWindow, size_t* aDomSize,
+                               size_t* aStyleSize, size_t* aOtherSize) {
   nsGlobalWindowOuter* window = nsGlobalWindowOuter::Cast(aWindow);
 
   nsTabSizes sizes;
   nsresult rv = AddNonJSSizeOfWindowAndItsDescendents(window, &sizes);
   NS_ENSURE_SUCCESS(rv, rv);
 
-  *aDomSize   = sizes.mDom;
+  *aDomSize = sizes.mDom;
   *aStyleSize = sizes.mStyle;
   *aOtherSize = sizes.mOther;
   return NS_OK;
 }
 
-/* static */ void
-nsWindowMemoryReporter::Init()
-{
+/* static */ void nsWindowMemoryReporter::Init() {
   MOZ_ASSERT(!sWindowReporter);
   sWindowReporter = new nsWindowMemoryReporter();
   ClearOnShutdown(&sWindowReporter);
@@ -125,15 +115,11 @@ nsWindowMemoryReporter::Init()
   RegisterGhostWindowsDistinguishedAmount(GhostWindowsDistinguishedAmount);
 }
 
-/* static */ nsWindowMemoryReporter*
-nsWindowMemoryReporter::Get()
-{
+/* static */ nsWindowMemoryReporter* nsWindowMemoryReporter::Get() {
   return sWindowReporter;
 }
 
-static already_AddRefed<nsIURI>
-GetWindowURI(nsGlobalWindowInner* aWindow)
-{
+static already_AddRefed<nsIURI> GetWindowURI(nsGlobalWindowInner* aWindow) {
   NS_ENSURE_TRUE(aWindow, nullptr);
 
   nsCOMPtr<nsIDocument> doc = aWindow->GetExtantDoc();
@@ -145,7 +131,7 @@ GetWindowURI(nsGlobalWindowInner* aWindow)
 
   if (!uri) {
     nsCOMPtr<nsIScriptObjectPrincipal> scriptObjPrincipal =
-      do_QueryObject(aWindow);
+        do_QueryObject(aWindow);
     NS_ENSURE_TRUE(scriptObjPrincipal, nullptr);
 
     // GetPrincipal() will print a warning if the window does not have an outer
@@ -164,16 +150,13 @@ GetWindowURI(nsGlobalWindowInner* aWindow)
 }
 
 // Forward to the inner window if we need to when getting the window's URI.
-static already_AddRefed<nsIURI>
-GetWindowURI(nsGlobalWindowOuter* aWindow)
-{
+static already_AddRefed<nsIURI> GetWindowURI(nsGlobalWindowOuter* aWindow) {
   NS_ENSURE_TRUE(aWindow, nullptr);
   return GetWindowURI(aWindow->GetCurrentInnerWindowInternal());
 }
 
-static void
-AppendWindowURI(nsGlobalWindowInner *aWindow, nsACString& aStr, bool aAnonymize)
-{
+static void AppendWindowURI(nsGlobalWindowInner* aWindow, nsACString& aStr,
+                            bool aAnonymize) {
   nsCOMPtr<nsIURI> uri = GetWindowURI(aWindow);
 
   if (uri) {
@@ -201,13 +184,11 @@ MOZ_DEFINE_MALLOC_SIZE_OF(WindowsMallocSizeOf)
 // The key is the window ID.
 typedef nsDataHashtable<nsUint64HashKey, nsCString> WindowPaths;
 
-static void
-ReportAmount(const nsCString& aBasePath, const char* aPathTail,
-             size_t aAmount, const nsCString& aDescription,
-             uint32_t aKind, uint32_t aUnits,
-             nsIHandleReportCallback* aHandleReport,
-             nsISupports* aData)
-{
+static void ReportAmount(const nsCString& aBasePath, const char* aPathTail,
+                         size_t aAmount, const nsCString& aDescription,
+                         uint32_t aKind, uint32_t aUnits,
+                         nsIHandleReportCallback* aHandleReport,
+                         nsISupports* aData) {
   if (aAmount == 0) {
     return;
   }
@@ -215,48 +196,41 @@ ReportAmount(const nsCString& aBasePath, const char* aPathTail,
   nsAutoCString path(aBasePath);
   path += aPathTail;
 
-  aHandleReport->Callback(
-    EmptyCString(), path, aKind, aUnits, aAmount, aDescription, aData);
+  aHandleReport->Callback(EmptyCString(), path, aKind, aUnits, aAmount,
+                          aDescription, aData);
 }
 
-static void
-ReportSize(const nsCString& aBasePath, const char* aPathTail,
-           size_t aAmount, const nsCString& aDescription,
-           nsIHandleReportCallback* aHandleReport,
-           nsISupports* aData)
-{
+static void ReportSize(const nsCString& aBasePath, const char* aPathTail,
+                       size_t aAmount, const nsCString& aDescription,
+                       nsIHandleReportCallback* aHandleReport,
+                       nsISupports* aData) {
   ReportAmount(aBasePath, aPathTail, aAmount, aDescription,
                nsIMemoryReporter::KIND_HEAP, nsIMemoryReporter::UNITS_BYTES,
                aHandleReport, aData);
 }
 
-static void
-ReportCount(const nsCString& aBasePath, const char* aPathTail,
-            size_t aAmount, const nsCString& aDescription,
-            nsIHandleReportCallback* aHandleReport,
-            nsISupports* aData)
-{
+static void ReportCount(const nsCString& aBasePath, const char* aPathTail,
+                        size_t aAmount, const nsCString& aDescription,
+                        nsIHandleReportCallback* aHandleReport,
+                        nsISupports* aData) {
   ReportAmount(aBasePath, aPathTail, aAmount, aDescription,
                nsIMemoryReporter::KIND_OTHER, nsIMemoryReporter::UNITS_COUNT,
                aHandleReport, aData);
 }
 
-static void
-CollectWindowReports(nsGlobalWindowInner *aWindow,
-                     amIAddonManager *addonManager,
-                     nsWindowSizes *aWindowTotalSizes,
-                     nsTHashtable<nsUint64HashKey> *aGhostWindowIDs,
-                     WindowPaths *aWindowPaths,
-                     WindowPaths *aTopWindowPaths,
-                     nsIHandleReportCallback *aHandleReport,
-                     nsISupports *aData,
-                     bool aAnonymize)
-{
+static void CollectWindowReports(nsGlobalWindowInner* aWindow,
+                                 amIAddonManager* addonManager,
+                                 nsWindowSizes* aWindowTotalSizes,
+                                 nsTHashtable<nsUint64HashKey>* aGhostWindowIDs,
+                                 WindowPaths* aWindowPaths,
+                                 WindowPaths* aTopWindowPaths,
+                                 nsIHandleReportCallback* aHandleReport,
+                                 nsISupports* aData, bool aAnonymize) {
   nsAutoCString windowPath("explicit/");
 
   // Avoid calling aWindow->GetTop() if there's no outer window.  It will work
   // just fine, but will spew a lot of warnings.
-  nsGlobalWindowOuter *top = nullptr;
+  nsGlobalWindowOuter* top = nullptr;
   nsCOMPtr<nsIURI> location;
   if (aWindow->GetOuterWindow()) {
     // Our window should have a null top iff it has a null docshell.
@@ -276,8 +250,8 @@ CollectWindowReports(nsGlobalWindowInner *aWindow,
     if (NS_SUCCEEDED(addonManager->MapURIToAddonID(location, id, &ok)) && ok) {
       // Add-on names are not privacy-sensitive, so we can use them with
       // impunity.
-      windowPath += NS_LITERAL_CSTRING("add-ons/") + id +
-                    NS_LITERAL_CSTRING("/");
+      windowPath +=
+          NS_LITERAL_CSTRING("add-ons/") + id + NS_LITERAL_CSTRING("/");
     }
   }
 
@@ -285,7 +259,8 @@ CollectWindowReports(nsGlobalWindowInner *aWindow,
 
   if (top) {
     windowPath += NS_LITERAL_CSTRING("top(");
-    AppendWindowURI(top->GetCurrentInnerWindowInternal(), windowPath, aAnonymize);
+    AppendWindowURI(top->GetCurrentInnerWindowInternal(), windowPath,
+                    aAnonymize);
     windowPath.AppendPrintf(", id=%" PRIu64 ")", top->WindowID());
 
     aTopWindowPaths->Put(aWindow->WindowID(), windowPath);
@@ -313,20 +288,20 @@ CollectWindowReports(nsGlobalWindowInner *aWindow,
 
 // Report the size from windowSizes and add to the appropriate total in
 // aWindowTotalSizes.
-#define REPORT_SIZE(_pathTail, _field, _desc) \
-  ReportSize(windowPath, _pathTail, windowSizes._field, \
+#define REPORT_SIZE(_pathTail, _field, _desc)                  \
+  ReportSize(windowPath, _pathTail, windowSizes._field,        \
              NS_LITERAL_CSTRING(_desc), aHandleReport, aData); \
   aWindowTotalSizes->_field += windowSizes._field;
 
 // Report the size, which is a sum of other sizes, and so doesn't require
 // updating aWindowTotalSizes.
-#define REPORT_SUM_SIZE(_pathTail, _amount, _desc) \
+#define REPORT_SUM_SIZE(_pathTail, _amount, _desc)                      \
   ReportSize(windowPath, _pathTail, _amount, NS_LITERAL_CSTRING(_desc), \
              aHandleReport, aData);
 
 // Like REPORT_SIZE, but for a count.
-#define REPORT_COUNT(_pathTail, _field, _desc) \
-  ReportCount(censusWindowPath, _pathTail, windowSizes._field, \
+#define REPORT_COUNT(_pathTail, _field, _desc)                  \
+  ReportCount(censusWindowPath, _pathTail, windowSizes._field,  \
               NS_LITERAL_CSTRING(_desc), aHandleReport, aData); \
   aWindowTotalSizes->_field += windowSizes._field;
 
@@ -462,23 +437,23 @@ CollectWindowReports(nsGlobalWindowInner *aWindow,
   // only a few matter. Implement a cutoff so we don't bloat about:memory with
   // many uninteresting entries.
   const size_t STYLE_SUNDRIES_THRESHOLD =
-    js::MemoryReportingSundriesThreshold();
+      js::MemoryReportingSundriesThreshold();
 
   // This is the Gecko style structs, which are in the nsPresArena.
   size_t geckoStyleSundriesSize = 0;
-#define STYLE_STRUCT(name_, cb_) \
-  { \
-    size_t size = \
-      windowSizes.mArenaSizes.mGeckoStyleSizes.NS_STYLE_SIZES_FIELD(name_); \
-    if (size < STYLE_SUNDRIES_THRESHOLD) { \
-      geckoStyleSundriesSize += size; \
-    } else { \
-      REPORT_SUM_SIZE( \
-        "/layout/gecko-style-structs/" # name_, size, \
-        "Memory used by the " #name_ " Gecko style structs within a window."); \
-    } \
-    aWindowTotalSizes->mArenaSizes.mGeckoStyleSizes.NS_STYLE_SIZES_FIELD(name_) += \
-      size; \
+#define STYLE_STRUCT(name_, cb_)                                              \
+  {                                                                           \
+    size_t size =                                                             \
+        windowSizes.mArenaSizes.mGeckoStyleSizes.NS_STYLE_SIZES_FIELD(name_); \
+    if (size < STYLE_SUNDRIES_THRESHOLD) {                                    \
+      geckoStyleSundriesSize += size;                                         \
+    } else {                                                                  \
+      REPORT_SUM_SIZE("/layout/gecko-style-structs/" #name_, size,            \
+                      "Memory used by the " #name_                            \
+                      " Gecko style structs within a window.");               \
+    }                                                                         \
+    aWindowTotalSizes->mArenaSizes.mGeckoStyleSizes.NS_STYLE_SIZES_FIELD(     \
+        name_) += size;                                                       \
   }
 #define STYLE_STRUCT_LIST_IGNORE_VARIABLES
 #include "nsStyleStructList.h"
@@ -486,29 +461,30 @@ CollectWindowReports(nsGlobalWindowInner *aWindow,
 #undef STYLE_STRUCT_LIST_IGNORE_VARIABLES
 
   if (geckoStyleSundriesSize > 0) {
-    REPORT_SUM_SIZE(
-      "/layout/gecko-style-structs/sundries", geckoStyleSundriesSize,
-      "The sum of all memory used by Gecko style structs which were too small "
-      "to be shown individually.");
+    REPORT_SUM_SIZE("/layout/gecko-style-structs/sundries",
+                    geckoStyleSundriesSize,
+                    "The sum of all memory used by Gecko style structs which "
+                    "were too small "
+                    "to be shown individually.");
   }
 
   // There are many different kinds of frames, but it is very likely
   // that only a few matter.  Implement a cutoff so we don't bloat
   // about:memory with many uninteresting entries.
   const size_t FRAME_SUNDRIES_THRESHOLD =
-    js::MemoryReportingSundriesThreshold();
+      js::MemoryReportingSundriesThreshold();
 
   size_t frameSundriesSize = 0;
-#define FRAME_ID(classname, ...) \
-  { \
-    size_t size = windowSizes.mArenaSizes.NS_ARENA_SIZES_FIELD(classname); \
-    if (size < FRAME_SUNDRIES_THRESHOLD) { \
-      frameSundriesSize += size; \
-    } else { \
-      REPORT_SUM_SIZE( \
-        "/layout/frames/" # classname, size, \
-        "Memory used by frames of type " #classname " within a window."); \
-    } \
+#define FRAME_ID(classname, ...)                                            \
+  {                                                                         \
+    size_t size = windowSizes.mArenaSizes.NS_ARENA_SIZES_FIELD(classname);  \
+    if (size < FRAME_SUNDRIES_THRESHOLD) {                                  \
+      frameSundriesSize += size;                                            \
+    } else {                                                                \
+      REPORT_SUM_SIZE("/layout/frames/" #classname, size,                   \
+                      "Memory used by frames of type " #classname           \
+                      " within a window.");                                 \
+    }                                                                       \
     aWindowTotalSizes->mArenaSizes.NS_ARENA_SIZES_FIELD(classname) += size; \
   }
 #define ABSTRACT_FRAME_ID(...)
@@ -518,23 +494,23 @@ CollectWindowReports(nsGlobalWindowInner *aWindow,
 
   if (frameSundriesSize > 0) {
     REPORT_SUM_SIZE(
-      "/layout/frames/sundries", frameSundriesSize,
-      "The sum of all memory used by frames which were too small to be shown "
-      "individually.");
+        "/layout/frames/sundries", frameSundriesSize,
+        "The sum of all memory used by frames which were too small to be shown "
+        "individually.");
   }
 
   // This is the Servo style structs.
   size_t servoStyleSundriesSize = 0;
-#define STYLE_STRUCT(name_, cb_) \
-  { \
-    size_t size = windowSizes.mServoStyleSizes.NS_STYLE_SIZES_FIELD(name_); \
-    if (size < STYLE_SUNDRIES_THRESHOLD) { \
-      servoStyleSundriesSize += size; \
-    } else { \
-      REPORT_SUM_SIZE( \
-        "/layout/servo-style-structs/" # name_, size, \
-        "Memory used by the " #name_ " Servo style structs within a window."); \
-    } \
+#define STYLE_STRUCT(name_, cb_)                                             \
+  {                                                                          \
+    size_t size = windowSizes.mServoStyleSizes.NS_STYLE_SIZES_FIELD(name_);  \
+    if (size < STYLE_SUNDRIES_THRESHOLD) {                                   \
+      servoStyleSundriesSize += size;                                        \
+    } else {                                                                 \
+      REPORT_SUM_SIZE("/layout/servo-style-structs/" #name_, size,           \
+                      "Memory used by the " #name_                           \
+                      " Servo style structs within a window.");              \
+    }                                                                        \
     aWindowTotalSizes->mServoStyleSizes.NS_STYLE_SIZES_FIELD(name_) += size; \
   }
 #define STYLE_STRUCT_LIST_IGNORE_VARIABLES
@@ -544,9 +520,9 @@ CollectWindowReports(nsGlobalWindowInner *aWindow,
 
   if (servoStyleSundriesSize > 0) {
     REPORT_SUM_SIZE(
-      "/layout/servo-style-structs/sundries", servoStyleSundriesSize,
-      "The sum of all memory used by Servo style structs which were too "
-      "small to be shown individually.");
+        "/layout/servo-style-structs/sundries", servoStyleSundriesSize,
+        "The sum of all memory used by Servo style structs which were too "
+        "small to be shown individually.");
   }
 
 #undef REPORT_SIZE
@@ -554,14 +530,13 @@ CollectWindowReports(nsGlobalWindowInner *aWindow,
 #undef REPORT_COUNT
 }
 
-typedef nsTArray< RefPtr<nsGlobalWindowInner> > WindowArray;
+typedef nsTArray<RefPtr<nsGlobalWindowInner>> WindowArray;
 
 NS_IMETHODIMP
 nsWindowMemoryReporter::CollectReports(nsIHandleReportCallback* aHandleReport,
-                                       nsISupports* aData, bool aAnonymize)
-{
+                                       nsISupports* aData, bool aAnonymize) {
   nsGlobalWindowInner::InnerWindowByIdTable* windowsById =
-    nsGlobalWindowInner::GetWindowsTable();
+      nsGlobalWindowInner::GetWindowsTable();
   NS_ENSURE_TRUE(windowsById, NS_OK);
 
   // Hold on to every window in memory so that window objects can't be
@@ -577,7 +552,7 @@ nsWindowMemoryReporter::CollectReports(nsIHandleReportCallback* aHandleReport,
   CheckForGhostWindows(&ghostWindows);
   for (auto iter = ghostWindows.ConstIter(); !iter.Done(); iter.Next()) {
     nsGlobalWindowInner::InnerWindowByIdTable* windowsById =
-      nsGlobalWindowInner::GetWindowsTable();
+        nsGlobalWindowInner::GetWindowsTable();
     if (!windowsById) {
       NS_WARNING("Couldn't get window-by-id hashtable?");
       continue;
@@ -594,15 +569,13 @@ nsWindowMemoryReporter::CollectReports(nsIHandleReportCallback* aHandleReport,
     AppendWindowURI(window, path, aAnonymize);
 
     aHandleReport->Callback(
-      /* process = */ EmptyCString(),
-      path,
-      nsIMemoryReporter::KIND_OTHER,
-      nsIMemoryReporter::UNITS_COUNT,
-      /* amount = */ 1,
-      /* description = */ NS_LITERAL_CSTRING("A ghost window."),
-      aData);
+        /* process = */ EmptyCString(), path, nsIMemoryReporter::KIND_OTHER,
+        nsIMemoryReporter::UNITS_COUNT,
+        /* amount = */ 1,
+        /* description = */ NS_LITERAL_CSTRING("A ghost window."), aData);
   }
 
+  // clang-format off
   MOZ_COLLECT_REPORT(
     "ghost-windows", KIND_OTHER, UNITS_COUNT, ghostWindows.Count(),
 "The number of ghost windows present (the number of nodes underneath "
@@ -613,12 +586,13 @@ nsWindowMemoryReporter::CollectReports(nsIHandleReportCallback* aHandleReport,
 "about:memory's minimize memory usage button.\n\n"
 "Ghost windows can happen legitimately, but they are often indicative of "
 "leaks in the browser or add-ons.");
+  // clang-format on
 
   WindowPaths windowPaths;
   WindowPaths topWindowPaths;
 
   // Collect window memory usage.
-  SizeOfState fakeState(nullptr);   // this won't be used
+  SizeOfState fakeState(nullptr);  // this won't be used
   nsWindowSizes windowTotalSizes(fakeState);
   nsCOMPtr<amIAddonManager> addonManager;
   if (XRE_IsParentProcess()) {
@@ -626,24 +600,23 @@ nsWindowMemoryReporter::CollectReports(nsIHandleReportCallback* aHandleReport,
     addonManager = do_GetService("@mozilla.org/addons/integration;1");
   }
   for (uint32_t i = 0; i < windows.Length(); i++) {
-    CollectWindowReports(windows[i], addonManager,
-                         &windowTotalSizes, &ghostWindows,
-                         &windowPaths, &topWindowPaths, aHandleReport,
-                         aData, aAnonymize);
+    CollectWindowReports(windows[i], addonManager, &windowTotalSizes,
+                         &ghostWindows, &windowPaths, &topWindowPaths,
+                         aHandleReport, aData, aAnonymize);
   }
 
   // Report JS memory usage.  We do this from here because the JS memory
   // reporter needs to be passed |windowPaths|.
-  xpc::JSReporter::CollectReports(&windowPaths, &topWindowPaths,
-                                  aHandleReport, aData, aAnonymize);
+  xpc::JSReporter::CollectReports(&windowPaths, &topWindowPaths, aHandleReport,
+                                  aData, aAnonymize);
 
 #ifdef MOZ_XUL
   nsXULPrototypeCache::CollectMemoryReports(aHandleReport, aData);
 #endif
 
-#define REPORT(_path, _amount, _desc) \
+#define REPORT(_path, _amount, _desc)                                \
   aHandleReport->Callback(EmptyCString(), NS_LITERAL_CSTRING(_path), \
-                          KIND_OTHER, UNITS_BYTES, _amount, \
+                          KIND_OTHER, UNITS_BYTES, _amount,          \
                           NS_LITERAL_CSTRING(_desc), aData);
 
   REPORT("window-objects/dom/element-nodes",
@@ -656,15 +629,17 @@ nsWindowMemoryReporter::CollectReports(nsIHandleReportCallback* aHandleReport,
   REPORT("window-objects/dom/cdata-nodes", windowTotalSizes.mDOMCDATANodesSize,
          "This is the sum of all windows' 'dom/cdata-nodes' numbers.");
 
-  REPORT("window-objects/dom/comment-nodes", windowTotalSizes.mDOMCommentNodesSize,
+  REPORT("window-objects/dom/comment-nodes",
+         windowTotalSizes.mDOMCommentNodesSize,
          "This is the sum of all windows' 'dom/comment-nodes' numbers.");
 
-  REPORT("window-objects/dom/event-targets", windowTotalSizes.mDOMEventTargetsSize,
+  REPORT("window-objects/dom/event-targets",
+         windowTotalSizes.mDOMEventTargetsSize,
          "This is the sum of all windows' 'dom/event-targets' numbers.");
 
   REPORT("window-objects/dom/performance",
          windowTotalSizes.mDOMPerformanceUserEntries +
-         windowTotalSizes.mDOMPerformanceResourceEntries,
+             windowTotalSizes.mDOMPerformanceResourceEntries,
          "This is the sum of all windows' 'dom/performance/' numbers.");
 
   REPORT("window-objects/dom/other", windowTotalSizes.mDOMOtherSize,
@@ -682,21 +657,23 @@ nsWindowMemoryReporter::CollectReports(nsIHandleReportCallback* aHandleReport,
          windowTotalSizes.mLayoutGeckoStyleSets,
          "This is the sum of all windows' 'layout/gecko-style-sets' numbers.");
 
-  REPORT("window-objects/layout/servo-style-sets",
-         windowTotalSizes.mLayoutServoStyleSetsStylistRuleTree +
-         windowTotalSizes.mLayoutServoStyleSetsStylistElementAndPseudosMaps +
-         windowTotalSizes.mLayoutServoStyleSetsStylistInvalidationMap +
-         windowTotalSizes.mLayoutServoStyleSetsStylistRevalidationSelectors +
-         windowTotalSizes.mLayoutServoStyleSetsStylistOther +
-         windowTotalSizes.mLayoutServoStyleSetsOther,
-         "This is the sum of all windows' 'layout/servo-style-sets/' numbers.");
+  REPORT(
+      "window-objects/layout/servo-style-sets",
+      windowTotalSizes.mLayoutServoStyleSetsStylistRuleTree +
+          windowTotalSizes.mLayoutServoStyleSetsStylistElementAndPseudosMaps +
+          windowTotalSizes.mLayoutServoStyleSetsStylistInvalidationMap +
+          windowTotalSizes.mLayoutServoStyleSetsStylistRevalidationSelectors +
+          windowTotalSizes.mLayoutServoStyleSetsStylistOther +
+          windowTotalSizes.mLayoutServoStyleSetsOther,
+      "This is the sum of all windows' 'layout/servo-style-sets/' numbers.");
 
   REPORT("window-objects/layout/servo-element-data-objects",
          windowTotalSizes.mLayoutServoElementDataObjects,
          "This is the sum of all windows' 'layout/servo-element-data-objects' "
          "numbers.");
 
-  REPORT("window-objects/layout/text-runs", windowTotalSizes.mLayoutTextRunsSize,
+  REPORT("window-objects/layout/text-runs",
+         windowTotalSizes.mLayoutTextRunsSize,
          "This is the sum of all windows' 'layout/text-runs' numbers.");
 
   REPORT("window-objects/layout/pres-contexts",
@@ -709,12 +686,11 @@ nsWindowMemoryReporter::CollectReports(nsIHandleReportCallback* aHandleReport,
 
   REPORT("window-objects/layout/computed-values",
          windowTotalSizes.mLayoutComputedValuesDom +
-         windowTotalSizes.mLayoutComputedValuesNonDom +
-         windowTotalSizes.mLayoutComputedValuesVisited,
+             windowTotalSizes.mLayoutComputedValuesNonDom +
+             windowTotalSizes.mLayoutComputedValuesVisited,
          "This is the sum of all windows' 'layout/computed-values/' numbers.");
 
-  REPORT("window-objects/property-tables",
-         windowTotalSizes.mPropertyTablesSize,
+  REPORT("window-objects/property-tables", windowTotalSizes.mPropertyTablesSize,
          "This is the sum of all windows' 'property-tables' numbers.");
 
   REPORT("window-objects/layout/line-boxes",
@@ -730,9 +706,10 @@ nsWindowMemoryReporter::CollectReports(nsIHandleReportCallback* aHandleReport,
          "This is the sum of all windows' 'layout/style-contexts' numbers.");
 
   size_t geckoStyleTotal = 0;
-#define STYLE_STRUCT(name_, cb_) \
-  geckoStyleTotal += \
-    windowTotalSizes.mArenaSizes.mGeckoStyleSizes.NS_STYLE_SIZES_FIELD(name_);
+#define STYLE_STRUCT(name_, cb_)                                          \
+  geckoStyleTotal +=                                                      \
+      windowTotalSizes.mArenaSizes.mGeckoStyleSizes.NS_STYLE_SIZES_FIELD( \
+          name_);
 #define STYLE_STRUCT_LIST_IGNORE_VARIABLES
 #include "nsStyleStructList.h"
 #undef STYLE_STRUCT
@@ -756,8 +733,8 @@ nsWindowMemoryReporter::CollectReports(nsIHandleReportCallback* aHandleReport,
 
   size_t servoStyleTotal = 0;
 #define STYLE_STRUCT(name_, cb_) \
-  servoStyleTotal += \
-    windowTotalSizes.mServoStyleSizes.NS_STYLE_SIZES_FIELD(name_);
+  servoStyleTotal +=             \
+      windowTotalSizes.mServoStyleSizes.NS_STYLE_SIZES_FIELD(name_);
 #define STYLE_STRUCT_LIST_IGNORE_VARIABLES
 #include "nsStyleStructList.h"
 #undef STYLE_STRUCT
@@ -772,16 +749,13 @@ nsWindowMemoryReporter::CollectReports(nsIHandleReportCallback* aHandleReport,
   return NS_OK;
 }
 
-uint32_t
-nsWindowMemoryReporter::GetGhostTimeout()
-{
+uint32_t nsWindowMemoryReporter::GetGhostTimeout() {
   return Preferences::GetUint("memory.ghost_window_timeout_seconds", 60);
 }
 
 NS_IMETHODIMP
-nsWindowMemoryReporter::Observe(nsISupports *aSubject, const char *aTopic,
-                                const char16_t *aData)
-{
+nsWindowMemoryReporter::Observe(nsISupports* aSubject, const char* aTopic,
+                                const char16_t* aData) {
   if (!strcmp(aTopic, "after-minimize-memory-usage")) {
     ObserveAfterMinimizeMemoryUsage();
   } else if (!strcmp(aTopic, "cycle-collector-begin")) {
@@ -803,10 +777,10 @@ nsWindowMemoryReporter::Observe(nsISupports *aSubject, const char *aTopic,
   return NS_OK;
 }
 
-void
-nsWindowMemoryReporter::ObserveDOMWindowDetached(nsGlobalWindowInner* aWindow)
-{
-  nsWeakPtr weakWindow = do_GetWeakReference(static_cast<nsIDOMEventTarget*>(aWindow));
+void nsWindowMemoryReporter::ObserveDOMWindowDetached(
+    nsGlobalWindowInner* aWindow) {
+  nsWeakPtr weakWindow =
+      do_GetWeakReference(static_cast<nsIDOMEventTarget*>(aWindow));
   if (!weakWindow) {
     NS_WARNING("Couldn't take weak reference to a window?");
     return;
@@ -818,18 +792,14 @@ nsWindowMemoryReporter::ObserveDOMWindowDetached(nsGlobalWindowInner* aWindow)
 }
 
 // static
-void
-nsWindowMemoryReporter::CheckTimerFired(nsITimer* aTimer, void* aData)
-{
+void nsWindowMemoryReporter::CheckTimerFired(nsITimer* aTimer, void* aData) {
   if (sWindowReporter) {
     MOZ_ASSERT(!sWindowReporter->mCycleCollectorIsRunning);
     sWindowReporter->CheckForGhostWindows();
   }
 }
 
-void
-nsWindowMemoryReporter::AsyncCheckForGhostWindows()
-{
+void nsWindowMemoryReporter::AsyncCheckForGhostWindows() {
   if (mCheckTimer) {
     return;
   }
@@ -844,26 +814,27 @@ nsWindowMemoryReporter::AsyncCheckForGhostWindows()
   // since the last check.  Reducing the delay by the time since the last check
   // prevents the timer from being completely starved if it is repeatedly killed
   // and restarted.
-  int32_t timeSinceLastCheck = (TimeStamp::NowLoRes() - mLastCheckForGhostWindows).ToSeconds();
-  int32_t timerDelay = (kTimeBetweenChecks - std::min(timeSinceLastCheck, kTimeBetweenChecks)) * PR_MSEC_PER_SEC;
+  int32_t timeSinceLastCheck =
+      (TimeStamp::NowLoRes() - mLastCheckForGhostWindows).ToSeconds();
+  int32_t timerDelay =
+      (kTimeBetweenChecks - std::min(timeSinceLastCheck, kTimeBetweenChecks)) *
+      PR_MSEC_PER_SEC;
 
-  NS_NewTimerWithFuncCallback(getter_AddRefs(mCheckTimer),
-                              CheckTimerFired, nullptr,
-                              timerDelay, nsITimer::TYPE_ONE_SHOT,
-                              "nsWindowMemoryReporter::AsyncCheckForGhostWindows_timer");
+  NS_NewTimerWithFuncCallback(
+      getter_AddRefs(mCheckTimer), CheckTimerFired, nullptr, timerDelay,
+      nsITimer::TYPE_ONE_SHOT,
+      "nsWindowMemoryReporter::AsyncCheckForGhostWindows_timer");
 }
 
-void
-nsWindowMemoryReporter::ObserveAfterMinimizeMemoryUsage()
-{
+void nsWindowMemoryReporter::ObserveAfterMinimizeMemoryUsage() {
   // Someone claims they've done enough GC/CCs so that all eligible windows
   // have been free'd.  So we deem that any windows which satisfy ghost
   // criteria (1) and (2) now satisfy criterion (3) as well.
   //
   // To effect this change, we'll backdate some of our timestamps.
 
-  TimeStamp minTimeStamp = TimeStamp::Now() -
-                           TimeDuration::FromSeconds(GetGhostTimeout());
+  TimeStamp minTimeStamp =
+      TimeStamp::Now() - TimeDuration::FromSeconds(GetGhostTimeout());
 
   for (auto iter = mDetachedWindows.Iter(); !iter.Done(); iter.Next()) {
     TimeStamp& timeStamp = iter.Data();
@@ -890,12 +861,10 @@ nsWindowMemoryReporter::ObserveAfterMinimizeMemoryUsage()
  * Additionally, if aOutGhostIDs is not null, fill it with the window IDs of
  * all ghost windows we found.
  */
-void
-nsWindowMemoryReporter::CheckForGhostWindows(
-  nsTHashtable<nsUint64HashKey> *aOutGhostIDs /* = nullptr */)
-{
-  nsGlobalWindowInner::InnerWindowByIdTable *windowsById =
-    nsGlobalWindowInner::GetWindowsTable();
+void nsWindowMemoryReporter::CheckForGhostWindows(
+    nsTHashtable<nsUint64HashKey>* aOutGhostIDs /* = nullptr */) {
+  nsGlobalWindowInner::InnerWindowByIdTable* windowsById =
+      nsGlobalWindowInner::GetWindowsTable();
   if (!windowsById) {
     NS_WARNING("GetWindowsTable returned null");
     return;
@@ -974,15 +943,11 @@ nsWindowMemoryReporter::CheckForGhostWindows(
   }
 }
 
-/* static */ int64_t
-nsWindowMemoryReporter::GhostWindowsDistinguishedAmount()
-{
+/* static */ int64_t nsWindowMemoryReporter::GhostWindowsDistinguishedAmount() {
   return sWindowReporter->mGhostWindowCount;
 }
 
-void
-nsWindowMemoryReporter::KillCheckTimer()
-{
+void nsWindowMemoryReporter::KillCheckTimer() {
   if (mCheckTimer) {
     mCheckTimer->Cancel();
     mCheckTimer = nullptr;
@@ -990,15 +955,13 @@ nsWindowMemoryReporter::KillCheckTimer()
 }
 
 #ifdef DEBUG
-/* static */ void
-nsWindowMemoryReporter::UnlinkGhostWindows()
-{
+/* static */ void nsWindowMemoryReporter::UnlinkGhostWindows() {
   if (!sWindowReporter) {
     return;
   }
 
   nsGlobalWindowInner::InnerWindowByIdTable* windowsById =
-    nsGlobalWindowInner::GetWindowsTable();
+      nsGlobalWindowInner::GetWindowsTable();
   if (!windowsById) {
     return;
   }
@@ -1015,7 +978,7 @@ nsWindowMemoryReporter::UnlinkGhostWindows()
   sWindowReporter->CheckForGhostWindows(&ghostWindows);
   for (auto iter = ghostWindows.ConstIter(); !iter.Done(); iter.Next()) {
     nsGlobalWindowInner::InnerWindowByIdTable* windowsById =
-      nsGlobalWindowInner::GetWindowsTable();
+        nsGlobalWindowInner::GetWindowsTable();
     if (!windowsById) {
       continue;
     }
