@@ -36,13 +36,15 @@
 namespace mozilla {
 namespace dom {
 
-#define DOM_CALLBACKOBJECT_IID \
-{ 0xbe74c190, 0x6d76, 0x4991, \
- { 0x84, 0xb9, 0x65, 0x06, 0x99, 0xe6, 0x93, 0x2b } }
+#define DOM_CALLBACKOBJECT_IID                       \
+  {                                                  \
+    0xbe74c190, 0x6d76, 0x4991, {                    \
+      0x84, 0xb9, 0x65, 0x06, 0x99, 0xe6, 0x93, 0x2b \
+    }                                                \
+  }
 
-class CallbackObject : public nsISupports
-{
-public:
+class CallbackObject : public nsISupports {
+ public:
   NS_DECLARE_STATIC_IID_ACCESSOR(DOM_CALLBACKOBJECT_IID)
 
   NS_DECL_CYCLE_COLLECTING_ISUPPORTS
@@ -56,8 +58,7 @@ public:
   // is invoked.  aCx can be nullptr, in which case no stack is
   // captured.
   explicit CallbackObject(JSContext* aCx, JS::Handle<JSObject*> aCallback,
-                          nsIGlobalObject* aIncumbentGlobal)
-  {
+                          nsIGlobalObject* aIncumbentGlobal) {
     if (aCx && JS::ContextOptionsRef(aCx).asyncStack()) {
       JS::RootedObject stack(aCx);
       if (!JS::CaptureCurrentStack(aCx, &stack)) {
@@ -74,8 +75,7 @@ public:
   // for that purpose.
   explicit CallbackObject(JS::Handle<JSObject*> aCallback,
                           JS::Handle<JSObject*> aAsyncStack,
-                          nsIGlobalObject* aIncumbentGlobal)
-  {
+                          nsIGlobalObject* aIncumbentGlobal) {
     Init(aCallback, aAsyncStack, aIncumbentGlobal);
   }
 
@@ -87,8 +87,7 @@ public:
   // This means that any native callee which receives a CallbackObject as an
   // argument can safely rely on the callback being non-null so long as it
   // doesn't trigger any scripts before it accesses it.
-  JS::Handle<JSObject*> CallbackOrNull() const
-  {
+  JS::Handle<JSObject*> CallbackOrNull() const {
     mCallback.exposeToActiveJS();
     return CallbackPreserveColor();
   }
@@ -97,13 +96,9 @@ public:
   // caller's compartment if the callback is null.
   JSObject* Callback(JSContext* aCx);
 
-  JSObject* GetCreationStack() const
-  {
-    return mCreationStack;
-  }
+  JSObject* GetCreationStack() const { return mCreationStack; }
 
-  void MarkForCC()
-  {
+  void MarkForCC() {
     mCallback.exposeToActiveJS();
     mCreationStack.exposeToActiveJS();
   }
@@ -116,8 +111,7 @@ public:
    * be passed into a JS API function and that it won't be stored without being
    * rooted (or otherwise signaling the stored value to the CC).
    */
-  JS::Handle<JSObject*> CallbackPreserveColor() const
-  {
+  JS::Handle<JSObject*> CallbackPreserveColor() const {
     // Calling fromMarkedLocation() is safe because we trace our mCallback, and
     // because the value of mCallback cannot change after if has been set.
     return JS::Handle<JSObject*>::fromMarkedLocation(mCallback.address());
@@ -128,16 +122,12 @@ public:
    * used instead of CallbackOrNull() to avoid the overhead of
    * ExposeObjectToActiveJS().
    */
-  JS::Handle<JSObject*> CallbackKnownNotGray() const
-  {
+  JS::Handle<JSObject*> CallbackKnownNotGray() const {
     MOZ_ASSERT(JS::ObjectIsNotGray(mCallback));
     return CallbackPreserveColor();
   }
 
-  nsIGlobalObject* IncumbentGlobalOrNull() const
-  {
-    return mIncumbentGlobal;
-  }
+  nsIGlobalObject* IncumbentGlobalOrNull() const { return mIncumbentGlobal; }
 
   enum ExceptionHandling {
     // Report any exception and don't throw it to the caller code.
@@ -153,25 +143,19 @@ public:
     eRethrowExceptions
   };
 
-  size_t SizeOfIncludingThis(mozilla::MallocSizeOf aMallocSizeOf) const
-  {
+  size_t SizeOfIncludingThis(mozilla::MallocSizeOf aMallocSizeOf) const {
     return aMallocSizeOf(this);
   }
 
-protected:
-  virtual ~CallbackObject()
-  {
-    mozilla::DropJSObjects(this);
-  }
+ protected:
+  virtual ~CallbackObject() { mozilla::DropJSObjects(this); }
 
-  explicit CallbackObject(CallbackObject* aCallbackObject)
-  {
+  explicit CallbackObject(CallbackObject* aCallbackObject) {
     Init(aCallbackObject->mCallback, aCallbackObject->mCreationStack,
          aCallbackObject->mIncumbentGlobal);
   }
 
-  bool operator==(const CallbackObject& aOther) const
-  {
+  bool operator==(const CallbackObject& aOther) const {
     JSObject* wrappedThis = CallbackPreserveColor();
     JSObject* wrappedOther = aOther.CallbackPreserveColor();
     if (!wrappedThis || !wrappedOther) {
@@ -183,26 +167,19 @@ protected:
     return thisObj == otherObj;
   }
 
-  class JSObjectsDropper final
-  {
-  public:
-    explicit JSObjectsDropper(CallbackObject* aHolder)
-      : mHolder(aHolder)
-    {}
+  class JSObjectsDropper final {
+   public:
+    explicit JSObjectsDropper(CallbackObject* aHolder) : mHolder(aHolder) {}
 
-    ~JSObjectsDropper()
-    {
-      mHolder->ClearJSObjects();
-    }
+    ~JSObjectsDropper() { mHolder->ClearJSObjects(); }
 
-  private:
+   private:
     RefPtr<CallbackObject> mHolder;
   };
 
-private:
+ private:
   inline void InitNoHold(JSObject* aCallback, JSObject* aCreationStack,
-                         nsIGlobalObject* aIncumbentGlobal)
-  {
+                         nsIGlobalObject* aIncumbentGlobal) {
     MOZ_ASSERT(aCallback && !mCallback);
     // Set script objects before we hold, on the off chance that a GC could
     // somehow happen in there... (which would be pretty odd, granted).
@@ -215,25 +192,22 @@ private:
   }
 
   inline void Init(JSObject* aCallback, JSObject* aCreationStack,
-                   nsIGlobalObject* aIncumbentGlobal)
-  {
+                   nsIGlobalObject* aIncumbentGlobal) {
     InitNoHold(aCallback, aCreationStack, aIncumbentGlobal);
     mozilla::HoldJSObjects(this);
   }
 
-  inline void ClearJSReferences()
-  {
+  inline void ClearJSReferences() {
     mCallback = nullptr;
     mCreationStack = nullptr;
     mIncumbentJSGlobal = nullptr;
   }
 
   CallbackObject(const CallbackObject&) = delete;
-  CallbackObject& operator =(const CallbackObject&) = delete;
+  CallbackObject& operator=(const CallbackObject&) = delete;
 
-protected:
-  void ClearJSObjects()
-  {
+ protected:
+  void ClearJSObjects() {
     MOZ_ASSERT_IF(mIncumbentJSGlobal, mCallback);
     if (mCallback) {
       ClearJSReferences();
@@ -255,8 +229,7 @@ protected:
   //
   // Places that use this need to ensure that the callback is traced (e.g. via a
   // Rooted) until the HoldJSObjects call happens.
-  struct FastCallbackConstructor {
-  };
+  struct FastCallbackConstructor {};
 
   // Just like the public version without the FastCallbackConstructor argument,
   // except for not calling HoldJSObjects and not capturing async stacks (on the
@@ -264,8 +237,7 @@ protected:
   // HoldJSObjects; see FinishSlowJSInitIfMoreThanOneOwner).  If you use this,
   // you MUST ensure that the object is traced until the HoldJSObjects happens!
   CallbackObject(JS::Handle<JSObject*> aCallback,
-                 const FastCallbackConstructor&)
-  {
+                 const FastCallbackConstructor&) {
     InitNoHold(aCallback, nullptr, nullptr);
   }
 
@@ -286,15 +258,14 @@ protected:
   nsCOMPtr<nsIGlobalObject> mIncumbentGlobal;
   JS::TenuredHeap<JSObject*> mIncumbentJSGlobal;
 
-  class MOZ_STACK_CLASS CallSetup
-  {
+  class MOZ_STACK_CLASS CallSetup {
     /**
      * A class that performs whatever setup we need to safely make a
      * call while this class is on the stack, After the constructor
      * returns, the call is safe to make if GetContext() returns
      * non-null.
      */
-  public:
+   public:
     // If aExceptionHandling == eRethrowContentExceptions then aCompartment
     // needs to be set to the compartment in which exceptions will be rethrown.
     //
@@ -309,12 +280,9 @@ protected:
               bool aIsJSImplementedWebIDL = false);
     ~CallSetup();
 
-    JSContext* GetContext() const
-    {
-      return mCx;
-    }
+    JSContext* GetContext() const { return mCx; }
 
-  private:
+   private:
     // We better not get copy-constructed
     CallSetup(const CallSetup&) = delete;
 
@@ -331,7 +299,7 @@ protected:
     Maybe<AutoEntryScript> mAutoEntryScript;
     Maybe<AutoIncumbentScript> mAutoIncumbentScript;
 
-    Maybe<JS::Rooted<JSObject*> > mRootedCallable;
+    Maybe<JS::Rooted<JSObject*>> mRootedCallable;
 
     // Members which are used to set the async stack.
     Maybe<JS::Rooted<JSObject*>> mAsyncStack;
@@ -351,23 +319,21 @@ protected:
   };
 };
 
-template<class WebIDLCallbackT, class XPCOMCallbackT>
+template <class WebIDLCallbackT, class XPCOMCallbackT>
 class CallbackObjectHolder;
 
-template<class T, class U>
+template <class T, class U>
 void ImplCycleCollectionUnlink(CallbackObjectHolder<T, U>& aField);
 
-class CallbackObjectHolderBase
-{
-protected:
+class CallbackObjectHolderBase {
+ protected:
   // Returns null on all failures
   already_AddRefed<nsISupports> ToXPCOMCallback(CallbackObject* aCallback,
                                                 const nsIID& aIID) const;
 };
 
-template<class WebIDLCallbackT, class XPCOMCallbackT>
-class CallbackObjectHolder : CallbackObjectHolderBase
-{
+template <class WebIDLCallbackT, class XPCOMCallbackT>
+class CallbackObjectHolder : CallbackObjectHolderBase {
   /**
    * A class which stores either a WebIDLCallbackT* or an XPCOMCallbackT*.  Both
    * types must inherit from nsISupports.  The pointer that's stored can be
@@ -377,22 +343,19 @@ class CallbackObjectHolder : CallbackObjectHolderBase
    * When storing an XPCOMCallbackT*, mPtrBits is the pointer value with low bit
    * set.
    */
-public:
+ public:
   explicit CallbackObjectHolder(WebIDLCallbackT* aCallback)
-    : mPtrBits(reinterpret_cast<uintptr_t>(aCallback))
-  {
+      : mPtrBits(reinterpret_cast<uintptr_t>(aCallback)) {
     NS_IF_ADDREF(aCallback);
   }
 
   explicit CallbackObjectHolder(XPCOMCallbackT* aCallback)
-    : mPtrBits(reinterpret_cast<uintptr_t>(aCallback) | XPCOMCallbackFlag)
-  {
+      : mPtrBits(reinterpret_cast<uintptr_t>(aCallback) | XPCOMCallbackFlag) {
     NS_IF_ADDREF(aCallback);
   }
 
   CallbackObjectHolder(CallbackObjectHolder&& aOther)
-    : mPtrBits(aOther.mPtrBits)
-  {
+      : mPtrBits(aOther.mPtrBits) {
     aOther.mPtrBits = 0;
     static_assert(sizeof(CallbackObjectHolder) == sizeof(void*),
                   "This object is expected to be as small as a pointer, and it "
@@ -402,31 +365,23 @@ public:
 
   CallbackObjectHolder(const CallbackObjectHolder& aOther) = delete;
 
-  CallbackObjectHolder()
-    : mPtrBits(0)
-  {}
+  CallbackObjectHolder() : mPtrBits(0) {}
 
-  ~CallbackObjectHolder()
-  {
-    UnlinkSelf();
-  }
+  ~CallbackObjectHolder() { UnlinkSelf(); }
 
-  void operator=(WebIDLCallbackT* aCallback)
-  {
+  void operator=(WebIDLCallbackT* aCallback) {
     UnlinkSelf();
     mPtrBits = reinterpret_cast<uintptr_t>(aCallback);
     NS_IF_ADDREF(aCallback);
   }
 
-  void operator=(XPCOMCallbackT* aCallback)
-  {
+  void operator=(XPCOMCallbackT* aCallback) {
     UnlinkSelf();
     mPtrBits = reinterpret_cast<uintptr_t>(aCallback) | XPCOMCallbackFlag;
     NS_IF_ADDREF(aCallback);
   }
 
-  void operator=(CallbackObjectHolder&& aOther)
-  {
+  void operator=(CallbackObjectHolder&& aOther) {
     UnlinkSelf();
     mPtrBits = aOther.mPtrBits;
     aOther.mPtrBits = 0;
@@ -434,19 +389,14 @@ public:
 
   void operator=(const CallbackObjectHolder& aOther) = delete;
 
-  nsISupports* GetISupports() const
-  {
+  nsISupports* GetISupports() const {
     return reinterpret_cast<nsISupports*>(mPtrBits & ~XPCOMCallbackFlag);
   }
 
   // Boolean conversion operator so people can use this in boolean tests
-  explicit operator bool() const
-  {
-    return GetISupports();
-  }
+  explicit operator bool() const { return GetISupports(); }
 
-  CallbackObjectHolder Clone() const
-  {
+  CallbackObjectHolder Clone() const {
     CallbackObjectHolder result;
     result.mPtrBits = mPtrBits;
     NS_IF_ADDREF(GetISupports());
@@ -455,25 +405,19 @@ public:
 
   // Even if HasWebIDLCallback returns true, GetWebIDLCallback() might still
   // return null.
-  bool HasWebIDLCallback() const
-  {
-    return !(mPtrBits & XPCOMCallbackFlag);
-  }
+  bool HasWebIDLCallback() const { return !(mPtrBits & XPCOMCallbackFlag); }
 
-  WebIDLCallbackT* GetWebIDLCallback() const
-  {
+  WebIDLCallbackT* GetWebIDLCallback() const {
     MOZ_ASSERT(HasWebIDLCallback());
     return reinterpret_cast<WebIDLCallbackT*>(mPtrBits);
   }
 
-  XPCOMCallbackT* GetXPCOMCallback() const
-  {
+  XPCOMCallbackT* GetXPCOMCallback() const {
     MOZ_ASSERT(!HasWebIDLCallback());
     return reinterpret_cast<XPCOMCallbackT*>(mPtrBits & ~XPCOMCallbackFlag);
   }
 
-  bool operator==(WebIDLCallbackT* aOtherCallback) const
-  {
+  bool operator==(WebIDLCallbackT* aOtherCallback) const {
     if (!aOtherCallback) {
       // If other is null, then we must be null to be equal.
       return !GetISupports();
@@ -488,14 +432,12 @@ public:
     return *GetWebIDLCallback() == *aOtherCallback;
   }
 
-  bool operator==(XPCOMCallbackT* aOtherCallback) const
-  {
+  bool operator==(XPCOMCallbackT* aOtherCallback) const {
     return (!aOtherCallback && !GetISupports()) ||
-      (!HasWebIDLCallback() && GetXPCOMCallback() == aOtherCallback);
+           (!HasWebIDLCallback() && GetXPCOMCallback() == aOtherCallback);
   }
 
-  bool operator==(const CallbackObjectHolder& aOtherCallback) const
-  {
+  bool operator==(const CallbackObjectHolder& aOtherCallback) const {
     if (aOtherCallback.HasWebIDLCallback()) {
       return *this == aOtherCallback.GetWebIDLCallback();
     }
@@ -504,16 +446,14 @@ public:
   }
 
   // Try to return an XPCOMCallbackT version of this object.
-  already_AddRefed<XPCOMCallbackT> ToXPCOMCallback() const
-  {
+  already_AddRefed<XPCOMCallbackT> ToXPCOMCallback() const {
     if (!HasWebIDLCallback()) {
       RefPtr<XPCOMCallbackT> callback = GetXPCOMCallback();
       return callback.forget();
     }
 
-    nsCOMPtr<nsISupports> supp =
-      CallbackObjectHolderBase::ToXPCOMCallback(GetWebIDLCallback(),
-                                                NS_GET_TEMPLATE_IID(XPCOMCallbackT));
+    nsCOMPtr<nsISupports> supp = CallbackObjectHolderBase::ToXPCOMCallback(
+        GetWebIDLCallback(), NS_GET_TEMPLATE_IID(XPCOMCallbackT));
     if (supp) {
       // ToXPCOMCallback already did the right QI for us.
       return supp.forget().downcast<XPCOMCallbackT>();
@@ -522,8 +462,7 @@ public:
   }
 
   // Try to return a WebIDLCallbackT version of this object.
-  already_AddRefed<WebIDLCallbackT> ToWebIDLCallback() const
-  {
+  already_AddRefed<WebIDLCallbackT> ToWebIDLCallback() const {
     if (HasWebIDLCallback()) {
       RefPtr<WebIDLCallbackT> callback = GetWebIDLCallback();
       return callback.forget();
@@ -531,19 +470,18 @@ public:
     return nullptr;
   }
 
-private:
+ private:
   static const uintptr_t XPCOMCallbackFlag = 1u;
 
-  friend void
-  ImplCycleCollectionUnlink<WebIDLCallbackT,
-                            XPCOMCallbackT>(CallbackObjectHolder& aField);
+  friend void ImplCycleCollectionUnlink<WebIDLCallbackT, XPCOMCallbackT>(
+      CallbackObjectHolder& aField);
 
-  void UnlinkSelf()
-  {
+  void UnlinkSelf() {
     // NS_IF_RELEASE because we might have been unlinked before
     nsISupports* ptr = GetISupports();
-    NS_IF_RELEASE(ptr);
+    // Clear mPtrBits before the release to prevent reentrance.
     mPtrBits = 0;
+    NS_IF_RELEASE(ptr);
   }
 
   uintptr_t mPtrBits;
@@ -551,22 +489,18 @@ private:
 
 NS_DEFINE_STATIC_IID_ACCESSOR(CallbackObject, DOM_CALLBACKOBJECT_IID)
 
-template<class T, class U>
-inline void
-ImplCycleCollectionTraverse(nsCycleCollectionTraversalCallback& aCallback,
-                            CallbackObjectHolder<T, U>& aField,
-                            const char* aName,
-                            uint32_t aFlags = 0)
-{
+template <class T, class U>
+inline void ImplCycleCollectionTraverse(
+    nsCycleCollectionTraversalCallback& aCallback,
+    CallbackObjectHolder<T, U>& aField, const char* aName,
+    uint32_t aFlags = 0) {
   if (aField) {
     CycleCollectionNoteChild(aCallback, aField.GetISupports(), aName, aFlags);
   }
 }
 
-template<class T, class U>
-void
-ImplCycleCollectionUnlink(CallbackObjectHolder<T, U>& aField)
-{
+template <class T, class U>
+void ImplCycleCollectionUnlink(CallbackObjectHolder<T, U>& aField) {
   aField.UnlinkSelf();
 }
 
@@ -574,43 +508,32 @@ ImplCycleCollectionUnlink(CallbackObjectHolder<T, U>& aField)
 // subclass.  This class is used in bindings to safely handle Fast* callbacks;
 // it ensures that the callback is traced, and that if something is holding onto
 // the callback when we're done with it HoldJSObjects is called.
-template<typename T>
-class MOZ_RAII RootedCallback : public JS::Rooted<T>
-{
-public:
-  explicit RootedCallback(JSContext* cx)
-    : JS::Rooted<T>(cx)
-    , mCx(cx)
-  {}
+template <typename T>
+class MOZ_RAII RootedCallback : public JS::Rooted<T> {
+ public:
+  explicit RootedCallback(JSContext* cx) : JS::Rooted<T>(cx), mCx(cx) {}
 
   // We need a way to make assignment from pointers (how we're normally used)
   // work.
-  template<typename S>
-  void operator=(S* arg)
-  {
+  template <typename S>
+  void operator=(S* arg) {
     this->get().operator=(arg);
   }
 
   // But nullptr can't use the above template, because it doesn't know which S
   // to select.  So we need a special overload for nullptr.
-  void operator=(decltype(nullptr) arg)
-  {
-    this->get().operator=(arg);
-  }
+  void operator=(decltype(nullptr) arg) { this->get().operator=(arg); }
 
   // Codegen relies on being able to do CallbackOrNull() and Callback() on us.
-  JS::Handle<JSObject*> CallbackOrNull() const
-  {
+  JS::Handle<JSObject*> CallbackOrNull() const {
     return this->get()->CallbackOrNull();
   }
 
-  JSObject* Callback(JSContext* aCx) const
-  {
+  JSObject* Callback(JSContext* aCx) const {
     return this->get()->Callback(aCx);
   }
 
-  ~RootedCallback()
-  {
+  ~RootedCallback() {
     // Ensure that our callback starts holding on to its own JS objects as
     // needed.  We really do need to check that things are initialized even when
     // T is OwningNonNull, because we might be running before the OwningNonNull
@@ -620,26 +543,24 @@ public:
     }
   }
 
-private:
-  template<typename U>
-  static bool IsInitialized(U& aArg); // Not implemented
+ private:
+  template <typename U>
+  static bool IsInitialized(U& aArg);  // Not implemented
 
-  template<typename U>
-  static bool IsInitialized(RefPtr<U>& aRefPtr)
-  {
+  template <typename U>
+  static bool IsInitialized(RefPtr<U>& aRefPtr) {
     return aRefPtr;
   }
 
-  template<typename U>
-  static bool IsInitialized(OwningNonNull<U>& aOwningNonNull)
-  {
+  template <typename U>
+  static bool IsInitialized(OwningNonNull<U>& aOwningNonNull) {
     return aOwningNonNull.isInitialized();
   }
 
   JSContext* mCx;
 };
 
-} // namespace dom
-} // namespace mozilla
+}  // namespace dom
+}  // namespace mozilla
 
-#endif // mozilla_dom_CallbackObject_h
+#endif  // mozilla_dom_CallbackObject_h
