@@ -39,18 +39,12 @@ namespace {
 // XXX This will be tweaked to something more meaningful in Bug 1383656.
 const int64_t kRoundUpNumber = 20480;
 
-enum BodyFileType
-{
-  BODY_FILE_FINAL,
-  BODY_FILE_TMP
-};
+enum BodyFileType { BODY_FILE_FINAL, BODY_FILE_TMP };
 
-nsresult
-BodyIdToFile(nsIFile* aBaseDir, const nsID& aId, BodyFileType aType,
-             nsIFile** aBodyFileOut);
+nsresult BodyIdToFile(nsIFile* aBaseDir, const nsID& aId, BodyFileType aType,
+                      nsIFile** aBodyFileOut);
 
-int64_t
-RoundUp(const int64_t aX, const int64_t aY);
+int64_t RoundUp(const int64_t aX, const int64_t aY);
 
 // The alogrithm for generating padding refers to the mitigation approach in
 // https://github.com/whatwg/storage/issues/31.
@@ -58,71 +52,82 @@ RoundUp(const int64_t aX, const int64_t aY);
 // Next, round up the sum of random number and response size to the nearest
 // 20kB.
 // Finally, the virtual padding size will be the result minus the response size.
-int64_t
-BodyGeneratePadding(const int64_t aBodyFileSize, const uint32_t aPaddingInfo);
+int64_t BodyGeneratePadding(const int64_t aBodyFileSize,
+                            const uint32_t aPaddingInfo);
 
-nsresult
-LockedDirectoryPaddingWrite(nsIFile* aBaseDir, DirPaddingFile aPaddingFileType,
-                            int64_t aPaddingSize);
+nsresult LockedDirectoryPaddingWrite(nsIFile* aBaseDir,
+                                     DirPaddingFile aPaddingFileType,
+                                     int64_t aPaddingSize);
 
-} // namespace
+}  // namespace
 
 // static
-nsresult
-BodyCreateDir(nsIFile* aBaseDir)
-{
+nsresult BodyCreateDir(nsIFile* aBaseDir) {
   MOZ_DIAGNOSTIC_ASSERT(aBaseDir);
 
   nsCOMPtr<nsIFile> aBodyDir;
   nsresult rv = aBaseDir->Clone(getter_AddRefs(aBodyDir));
-  if (NS_WARN_IF(NS_FAILED(rv))) { return rv; }
+  if (NS_WARN_IF(NS_FAILED(rv))) {
+    return rv;
+  }
 
   rv = aBodyDir->Append(NS_LITERAL_STRING("morgue"));
-  if (NS_WARN_IF(NS_FAILED(rv))) { return rv; }
+  if (NS_WARN_IF(NS_FAILED(rv))) {
+    return rv;
+  }
 
   rv = aBodyDir->Create(nsIFile::DIRECTORY_TYPE, 0755);
   if (rv == NS_ERROR_FILE_ALREADY_EXISTS) {
     return NS_OK;
   }
-  if (NS_WARN_IF(NS_FAILED(rv))) { return rv; }
+  if (NS_WARN_IF(NS_FAILED(rv))) {
+    return rv;
+  }
 
   return rv;
 }
 
 // static
-nsresult
-BodyDeleteDir(const QuotaInfo& aQuotaInfo, nsIFile* aBaseDir)
-{
+nsresult BodyDeleteDir(const QuotaInfo& aQuotaInfo, nsIFile* aBaseDir) {
   MOZ_DIAGNOSTIC_ASSERT(aBaseDir);
 
   nsCOMPtr<nsIFile> aBodyDir;
   nsresult rv = aBaseDir->Clone(getter_AddRefs(aBodyDir));
-  if (NS_WARN_IF(NS_FAILED(rv))) { return rv; }
+  if (NS_WARN_IF(NS_FAILED(rv))) {
+    return rv;
+  }
 
   rv = aBodyDir->Append(NS_LITERAL_STRING("morgue"));
-  if (NS_WARN_IF(NS_FAILED(rv))) { return rv; }
+  if (NS_WARN_IF(NS_FAILED(rv))) {
+    return rv;
+  }
 
   rv = RemoveNsIFileRecursively(aQuotaInfo, aBodyDir);
-  if (NS_WARN_IF(NS_FAILED(rv))) { return rv; }
+  if (NS_WARN_IF(NS_FAILED(rv))) {
+    return rv;
+  }
 
   return rv;
 }
 
 // static
-nsresult
-BodyGetCacheDir(nsIFile* aBaseDir, const nsID& aId, nsIFile** aCacheDirOut)
-{
+nsresult BodyGetCacheDir(nsIFile* aBaseDir, const nsID& aId,
+                         nsIFile** aCacheDirOut) {
   MOZ_DIAGNOSTIC_ASSERT(aBaseDir);
   MOZ_DIAGNOSTIC_ASSERT(aCacheDirOut);
 
   *aCacheDirOut = nullptr;
 
   nsresult rv = aBaseDir->Clone(aCacheDirOut);
-  if (NS_WARN_IF(NS_FAILED(rv))) { return rv; }
+  if (NS_WARN_IF(NS_FAILED(rv))) {
+    return rv;
+  }
   MOZ_DIAGNOSTIC_ASSERT(*aCacheDirOut);
 
   rv = (*aCacheDirOut)->Append(NS_LITERAL_STRING("morgue"));
-  if (NS_WARN_IF(NS_FAILED(rv))) { return rv; }
+  if (NS_WARN_IF(NS_FAILED(rv))) {
+    return rv;
+  }
 
   // Some file systems have poor performance when there are too many files
   // in a single directory.  Mitigate this issue by spreading the body
@@ -131,25 +136,26 @@ BodyGetCacheDir(nsIFile* aBaseDir, const nsID& aId, nsIFile** aCacheDirOut)
   nsAutoString subDirName;
   subDirName.AppendInt(aId.m3[7]);
   rv = (*aCacheDirOut)->Append(subDirName);
-  if (NS_WARN_IF(NS_FAILED(rv))) { return rv; }
+  if (NS_WARN_IF(NS_FAILED(rv))) {
+    return rv;
+  }
 
   rv = (*aCacheDirOut)->Create(nsIFile::DIRECTORY_TYPE, 0755);
   if (rv == NS_ERROR_FILE_ALREADY_EXISTS) {
     return NS_OK;
   }
-  if (NS_WARN_IF(NS_FAILED(rv))) { return rv; }
+  if (NS_WARN_IF(NS_FAILED(rv))) {
+    return rv;
+  }
 
   return rv;
 }
 
 // static
-nsresult
-BodyStartWriteStream(const QuotaInfo& aQuotaInfo,
-                     nsIFile* aBaseDir, nsIInputStream* aSource,
-                     void* aClosure,
-                     nsAsyncCopyCallbackFun aCallback, nsID* aIdOut,
-                     nsISupports** aCopyContextOut)
-{
+nsresult BodyStartWriteStream(const QuotaInfo& aQuotaInfo, nsIFile* aBaseDir,
+                              nsIInputStream* aSource, void* aClosure,
+                              nsAsyncCopyCallbackFun aCallback, nsID* aIdOut,
+                              nsISupports** aCopyContextOut) {
   MOZ_DIAGNOSTIC_ASSERT(aBaseDir);
   MOZ_DIAGNOSTIC_ASSERT(aSource);
   MOZ_DIAGNOSTIC_ASSERT(aClosure);
@@ -159,54 +165,71 @@ BodyStartWriteStream(const QuotaInfo& aQuotaInfo,
 
   nsresult rv;
   nsCOMPtr<nsIUUIDGenerator> idGen =
-    do_GetService("@mozilla.org/uuid-generator;1", &rv);
-  if (NS_WARN_IF(NS_FAILED(rv))) { return rv; }
+      do_GetService("@mozilla.org/uuid-generator;1", &rv);
+  if (NS_WARN_IF(NS_FAILED(rv))) {
+    return rv;
+  }
 
   rv = idGen->GenerateUUIDInPlace(aIdOut);
-  if (NS_WARN_IF(NS_FAILED(rv))) { return rv; }
+  if (NS_WARN_IF(NS_FAILED(rv))) {
+    return rv;
+  }
 
   nsCOMPtr<nsIFile> finalFile;
   rv = BodyIdToFile(aBaseDir, *aIdOut, BODY_FILE_FINAL,
                     getter_AddRefs(finalFile));
-  if (NS_WARN_IF(NS_FAILED(rv))) { return rv; }
+  if (NS_WARN_IF(NS_FAILED(rv))) {
+    return rv;
+  }
 
   bool exists;
   rv = finalFile->Exists(&exists);
-  if (NS_WARN_IF(NS_FAILED(rv))) { return rv; }
-  if (NS_WARN_IF(exists)) { return NS_ERROR_FILE_ALREADY_EXISTS; }
+  if (NS_WARN_IF(NS_FAILED(rv))) {
+    return rv;
+  }
+  if (NS_WARN_IF(exists)) {
+    return NS_ERROR_FILE_ALREADY_EXISTS;
+  }
 
   nsCOMPtr<nsIFile> tmpFile;
   rv = BodyIdToFile(aBaseDir, *aIdOut, BODY_FILE_TMP, getter_AddRefs(tmpFile));
-  if (NS_WARN_IF(NS_FAILED(rv))) { return rv; }
+  if (NS_WARN_IF(NS_FAILED(rv))) {
+    return rv;
+  }
 
   rv = tmpFile->Exists(&exists);
-  if (NS_WARN_IF(NS_FAILED(rv))) { return rv; }
-  if (NS_WARN_IF(exists)) { return NS_ERROR_FILE_ALREADY_EXISTS; }
+  if (NS_WARN_IF(NS_FAILED(rv))) {
+    return rv;
+  }
+  if (NS_WARN_IF(exists)) {
+    return NS_ERROR_FILE_ALREADY_EXISTS;
+  }
 
-  nsCOMPtr<nsIOutputStream> fileStream =
-    FileOutputStream::Create(PERSISTENCE_TYPE_DEFAULT, aQuotaInfo.mGroup,
-                             aQuotaInfo.mOrigin, tmpFile);
-  if (NS_WARN_IF(!fileStream)) { return NS_ERROR_UNEXPECTED; }
+  nsCOMPtr<nsIOutputStream> fileStream = FileOutputStream::Create(
+      PERSISTENCE_TYPE_DEFAULT, aQuotaInfo.mGroup, aQuotaInfo.mOrigin, tmpFile);
+  if (NS_WARN_IF(!fileStream)) {
+    return NS_ERROR_UNEXPECTED;
+  }
 
   RefPtr<SnappyCompressOutputStream> compressed =
-    new SnappyCompressOutputStream(fileStream);
+      new SnappyCompressOutputStream(fileStream);
 
   nsCOMPtr<nsIEventTarget> target =
-    do_GetService(NS_STREAMTRANSPORTSERVICE_CONTRACTID);
+      do_GetService(NS_STREAMTRANSPORTSERVICE_CONTRACTID);
 
   rv = NS_AsyncCopy(aSource, compressed, target, NS_ASYNCCOPY_VIA_WRITESEGMENTS,
-                    compressed->BlockSize(), aCallback, aClosure,
-                    true, true, // close streams
+                    compressed->BlockSize(), aCallback, aClosure, true,
+                    true,  // close streams
                     aCopyContextOut);
-  if (NS_WARN_IF(NS_FAILED(rv))) { return rv; }
+  if (NS_WARN_IF(NS_FAILED(rv))) {
+    return rv;
+  }
 
   return rv;
 }
 
 // static
-void
-BodyCancelWrite(nsIFile* aBaseDir, nsISupports* aCopyContext)
-{
+void BodyCancelWrite(nsIFile* aBaseDir, nsISupports* aCopyContext) {
   MOZ_DIAGNOSTIC_ASSERT(aBaseDir);
   MOZ_DIAGNOSTIC_ASSERT(aCopyContext);
 
@@ -218,54 +241,67 @@ BodyCancelWrite(nsIFile* aBaseDir, nsISupports* aCopyContext)
 }
 
 // static
-nsresult
-BodyFinalizeWrite(nsIFile* aBaseDir, const nsID& aId)
-{
+nsresult BodyFinalizeWrite(nsIFile* aBaseDir, const nsID& aId) {
   MOZ_DIAGNOSTIC_ASSERT(aBaseDir);
 
   nsCOMPtr<nsIFile> tmpFile;
-  nsresult rv = BodyIdToFile(aBaseDir, aId, BODY_FILE_TMP, getter_AddRefs(tmpFile));
-  if (NS_WARN_IF(NS_FAILED(rv))) { return rv; }
+  nsresult rv =
+      BodyIdToFile(aBaseDir, aId, BODY_FILE_TMP, getter_AddRefs(tmpFile));
+  if (NS_WARN_IF(NS_FAILED(rv))) {
+    return rv;
+  }
 
   nsCOMPtr<nsIFile> finalFile;
   rv = BodyIdToFile(aBaseDir, aId, BODY_FILE_FINAL, getter_AddRefs(finalFile));
-  if (NS_WARN_IF(NS_FAILED(rv))) { return rv; }
+  if (NS_WARN_IF(NS_FAILED(rv))) {
+    return rv;
+  }
 
   nsAutoString finalFileName;
   rv = finalFile->GetLeafName(finalFileName);
-  if (NS_WARN_IF(NS_FAILED(rv))) { return rv; }
+  if (NS_WARN_IF(NS_FAILED(rv))) {
+    return rv;
+  }
 
   // It's fine to not notify the QuotaManager that the path has been changed,
   // because its path will be updated and its size will be recalculated when
   // opening file next time.
   rv = tmpFile->RenameTo(nullptr, finalFileName);
-  if (NS_WARN_IF(NS_FAILED(rv))) { return rv; }
+  if (NS_WARN_IF(NS_FAILED(rv))) {
+    return rv;
+  }
 
   return rv;
 }
 
 // static
-nsresult
-BodyOpen(const QuotaInfo& aQuotaInfo, nsIFile* aBaseDir, const nsID& aId,
-         nsIInputStream** aStreamOut)
-{
+nsresult BodyOpen(const QuotaInfo& aQuotaInfo, nsIFile* aBaseDir,
+                  const nsID& aId, nsIInputStream** aStreamOut) {
   MOZ_DIAGNOSTIC_ASSERT(aBaseDir);
   MOZ_DIAGNOSTIC_ASSERT(aStreamOut);
 
   nsCOMPtr<nsIFile> finalFile;
-  nsresult rv = BodyIdToFile(aBaseDir, aId, BODY_FILE_FINAL,
-                             getter_AddRefs(finalFile));
-  if (NS_WARN_IF(NS_FAILED(rv))) { return rv; }
+  nsresult rv =
+      BodyIdToFile(aBaseDir, aId, BODY_FILE_FINAL, getter_AddRefs(finalFile));
+  if (NS_WARN_IF(NS_FAILED(rv))) {
+    return rv;
+  }
 
   bool exists;
   rv = finalFile->Exists(&exists);
-  if (NS_WARN_IF(NS_FAILED(rv))) { return rv; }
-  if (NS_WARN_IF(!exists)) { return NS_ERROR_FILE_NOT_FOUND; }
+  if (NS_WARN_IF(NS_FAILED(rv))) {
+    return rv;
+  }
+  if (NS_WARN_IF(!exists)) {
+    return NS_ERROR_FILE_NOT_FOUND;
+  }
 
   nsCOMPtr<nsIInputStream> fileStream =
-    FileInputStream::Create(PERSISTENCE_TYPE_DEFAULT, aQuotaInfo.mGroup,
-                            aQuotaInfo.mOrigin, finalFile);
-  if (NS_WARN_IF(!fileStream)) { return NS_ERROR_UNEXPECTED; }
+      FileInputStream::Create(PERSISTENCE_TYPE_DEFAULT, aQuotaInfo.mGroup,
+                              aQuotaInfo.mOrigin, finalFile);
+  if (NS_WARN_IF(!fileStream)) {
+    return NS_ERROR_UNEXPECTED;
+  }
 
   fileStream.forget(aStreamOut);
 
@@ -273,18 +309,19 @@ BodyOpen(const QuotaInfo& aQuotaInfo, nsIFile* aBaseDir, const nsID& aId,
 }
 
 // static
-nsresult
-BodyMaybeUpdatePaddingSize(const QuotaInfo& aQuotaInfo, nsIFile* aBaseDir,
-                           const nsID& aId, const uint32_t aPaddingInfo,
-                           int64_t* aPaddingSizeOut)
-{
+nsresult BodyMaybeUpdatePaddingSize(const QuotaInfo& aQuotaInfo,
+                                    nsIFile* aBaseDir, const nsID& aId,
+                                    const uint32_t aPaddingInfo,
+                                    int64_t* aPaddingSizeOut) {
   MOZ_DIAGNOSTIC_ASSERT(aBaseDir);
   MOZ_DIAGNOSTIC_ASSERT(aPaddingSizeOut);
 
   nsCOMPtr<nsIFile> bodyFile;
   nsresult rv =
-    BodyIdToFile(aBaseDir, aId, BODY_FILE_TMP, getter_AddRefs(bodyFile));
-  if (NS_WARN_IF(NS_FAILED(rv))) { return rv; }
+      BodyIdToFile(aBaseDir, aId, BODY_FILE_TMP, getter_AddRefs(bodyFile));
+  if (NS_WARN_IF(NS_FAILED(rv))) {
+    return rv;
+  }
 
   MOZ_DIAGNOSTIC_ASSERT(bodyFile);
 
@@ -293,12 +330,14 @@ BodyMaybeUpdatePaddingSize(const QuotaInfo& aQuotaInfo, nsIFile* aBaseDir,
 
   int64_t fileSize = 0;
   RefPtr<QuotaObject> quotaObject =
-    quotaManager->GetQuotaObject(PERSISTENCE_TYPE_DEFAULT, aQuotaInfo.mGroup,
-                                 aQuotaInfo.mOrigin, bodyFile, &fileSize);
+      quotaManager->GetQuotaObject(PERSISTENCE_TYPE_DEFAULT, aQuotaInfo.mGroup,
+                                   aQuotaInfo.mOrigin, bodyFile, &fileSize);
   MOZ_DIAGNOSTIC_ASSERT(quotaObject);
   MOZ_DIAGNOSTIC_ASSERT(fileSize >= 0);
   // XXXtt: bug: https://bugzilla.mozilla.org/show_bug.cgi?id=1422815
-  if (!quotaObject) { return NS_ERROR_UNEXPECTED; }
+  if (!quotaObject) {
+    return NS_ERROR_UNEXPECTED;
+  }
 
   if (*aPaddingSizeOut == InternalResponse::UNKNOWN_PADDING_SIZE) {
     *aPaddingSizeOut = BodyGeneratePadding(fileSize, aPaddingInfo);
@@ -314,17 +353,17 @@ BodyMaybeUpdatePaddingSize(const QuotaInfo& aQuotaInfo, nsIFile* aBaseDir,
 }
 
 // static
-nsresult
-BodyDeleteFiles(const QuotaInfo& aQuotaInfo, nsIFile* aBaseDir,
-                const nsTArray<nsID>& aIdList)
-{
+nsresult BodyDeleteFiles(const QuotaInfo& aQuotaInfo, nsIFile* aBaseDir,
+                         const nsTArray<nsID>& aIdList) {
   nsresult rv = NS_OK;
 
   for (uint32_t i = 0; i < aIdList.Length(); ++i) {
     nsCOMPtr<nsIFile> tmpFile;
     rv = BodyIdToFile(aBaseDir, aIdList[i], BODY_FILE_TMP,
                       getter_AddRefs(tmpFile));
-    if (NS_WARN_IF(NS_FAILED(rv))) { return rv; }
+    if (NS_WARN_IF(NS_FAILED(rv))) {
+      return rv;
+    }
 
     rv = RemoveNsIFile(aQuotaInfo, tmpFile);
     // Only treat file deletion as a hard failure in DEBUG builds.  Users
@@ -335,7 +374,9 @@ BodyDeleteFiles(const QuotaInfo& aQuotaInfo, nsIFile* aBaseDir,
     nsCOMPtr<nsIFile> finalFile;
     rv = BodyIdToFile(aBaseDir, aIdList[i], BODY_FILE_FINAL,
                       getter_AddRefs(finalFile));
-    if (NS_WARN_IF(NS_FAILED(rv))) { return rv; }
+    if (NS_WARN_IF(NS_FAILED(rv))) {
+      return rv;
+    }
 
     rv = RemoveNsIFile(aQuotaInfo, finalFile);
     // Again, only treat removal as hard failure in debug build.
@@ -347,17 +388,17 @@ BodyDeleteFiles(const QuotaInfo& aQuotaInfo, nsIFile* aBaseDir,
 
 namespace {
 
-nsresult
-BodyIdToFile(nsIFile* aBaseDir, const nsID& aId, BodyFileType aType,
-             nsIFile** aBodyFileOut)
-{
+nsresult BodyIdToFile(nsIFile* aBaseDir, const nsID& aId, BodyFileType aType,
+                      nsIFile** aBodyFileOut) {
   MOZ_DIAGNOSTIC_ASSERT(aBaseDir);
   MOZ_DIAGNOSTIC_ASSERT(aBodyFileOut);
 
   *aBodyFileOut = nullptr;
 
   nsresult rv = BodyGetCacheDir(aBaseDir, aId, aBodyFileOut);
-  if (NS_WARN_IF(NS_FAILED(rv))) { return rv; }
+  if (NS_WARN_IF(NS_FAILED(rv))) {
+    return rv;
+  }
   MOZ_DIAGNOSTIC_ASSERT(*aBodyFileOut);
 
   char idString[NSID_LENGTH];
@@ -372,14 +413,14 @@ BodyIdToFile(nsIFile* aBaseDir, const nsID& aId, BodyFileType aType,
   }
 
   rv = (*aBodyFileOut)->Append(fileName);
-  if (NS_WARN_IF(NS_FAILED(rv))) { return rv; }
+  if (NS_WARN_IF(NS_FAILED(rv))) {
+    return rv;
+  }
 
   return rv;
 }
 
-int64_t
-RoundUp(const int64_t aX, const int64_t aY)
-{
+int64_t RoundUp(const int64_t aX, const int64_t aY) {
   MOZ_DIAGNOSTIC_ASSERT(aX >= 0);
   MOZ_DIAGNOSTIC_ASSERT(aY > 0);
 
@@ -387,9 +428,8 @@ RoundUp(const int64_t aX, const int64_t aY)
   return aY + ((aX - 1) / aY) * aY;
 }
 
-int64_t
-BodyGeneratePadding(const int64_t aBodyFileSize, const uint32_t aPaddingInfo)
-{
+int64_t BodyGeneratePadding(const int64_t aBodyFileSize,
+                            const uint32_t aPaddingInfo) {
   // Generate padding
   int64_t randomSize = static_cast<int64_t>(aPaddingInfo);
   MOZ_DIAGNOSTIC_ASSERT(INT64_MAX - aBodyFileSize >= randomSize);
@@ -398,43 +438,48 @@ BodyGeneratePadding(const int64_t aBodyFileSize, const uint32_t aPaddingInfo)
   return RoundUp(randomSize, kRoundUpNumber) - aBodyFileSize;
 }
 
-nsresult
-LockedDirectoryPaddingWrite(nsIFile* aBaseDir, DirPaddingFile aPaddingFileType,
-                            int64_t aPaddingSize)
-{
+nsresult LockedDirectoryPaddingWrite(nsIFile* aBaseDir,
+                                     DirPaddingFile aPaddingFileType,
+                                     int64_t aPaddingSize) {
   MOZ_DIAGNOSTIC_ASSERT(aBaseDir);
   MOZ_DIAGNOSTIC_ASSERT(aPaddingSize >= 0);
 
   nsCOMPtr<nsIFile> file;
   nsresult rv = aBaseDir->Clone(getter_AddRefs(file));
-  if (NS_WARN_IF(NS_FAILED(rv))) { return rv; }
+  if (NS_WARN_IF(NS_FAILED(rv))) {
+    return rv;
+  }
 
   if (aPaddingFileType == DirPaddingFile::TMP_FILE) {
     rv = file->Append(NS_LITERAL_STRING(PADDING_TMP_FILE_NAME));
   } else {
     rv = file->Append(NS_LITERAL_STRING(PADDING_FILE_NAME));
   }
-  if (NS_WARN_IF(NS_FAILED(rv))) { return rv; }
+  if (NS_WARN_IF(NS_FAILED(rv))) {
+    return rv;
+  }
 
   nsCOMPtr<nsIOutputStream> outputStream;
   rv = NS_NewLocalFileOutputStream(getter_AddRefs(outputStream), file);
-  if (NS_WARN_IF(NS_FAILED(rv))) { return rv; }
+  if (NS_WARN_IF(NS_FAILED(rv))) {
+    return rv;
+  }
 
   nsCOMPtr<nsIObjectOutputStream> objectStream =
-    NS_NewObjectOutputStream(outputStream);
+      NS_NewObjectOutputStream(outputStream);
 
   rv = objectStream->Write64(aPaddingSize);
-  if (NS_WARN_IF(NS_FAILED(rv))) { return rv; }
+  if (NS_WARN_IF(NS_FAILED(rv))) {
+    return rv;
+  }
 
   return rv;
 }
 
-} // namespace
+}  // namespace
 
-nsresult
-BodyDeleteOrphanedFiles(const QuotaInfo& aQuotaInfo, nsIFile* aBaseDir,
-                        nsTArray<nsID>& aKnownBodyIdList)
-{
+nsresult BodyDeleteOrphanedFiles(const QuotaInfo& aQuotaInfo, nsIFile* aBaseDir,
+                                 nsTArray<nsID>& aKnownBodyIdList) {
   MOZ_DIAGNOSTIC_ASSERT(aBaseDir);
 
   // body files are stored in a directory structure like:
@@ -444,28 +489,38 @@ BodyDeleteOrphanedFiles(const QuotaInfo& aQuotaInfo, nsIFile* aBaseDir,
 
   nsCOMPtr<nsIFile> dir;
   nsresult rv = aBaseDir->Clone(getter_AddRefs(dir));
-  if (NS_WARN_IF(NS_FAILED(rv))) { return rv; }
+  if (NS_WARN_IF(NS_FAILED(rv))) {
+    return rv;
+  }
 
   // Add the root morgue directory
   rv = dir->Append(NS_LITERAL_STRING("morgue"));
-  if (NS_WARN_IF(NS_FAILED(rv))) { return rv; }
+  if (NS_WARN_IF(NS_FAILED(rv))) {
+    return rv;
+  }
 
   nsCOMPtr<nsISimpleEnumerator> entries;
   rv = dir->GetDirectoryEntries(getter_AddRefs(entries));
-  if (NS_WARN_IF(NS_FAILED(rv))) { return rv; }
+  if (NS_WARN_IF(NS_FAILED(rv))) {
+    return rv;
+  }
 
   // Iterate over all the intermediate morgue subdirs
   bool hasMore = false;
   while (NS_SUCCEEDED(rv = entries->HasMoreElements(&hasMore)) && hasMore) {
     nsCOMPtr<nsISupports> entry;
     rv = entries->GetNext(getter_AddRefs(entry));
-    if (NS_WARN_IF(NS_FAILED(rv))) { return rv; }
+    if (NS_WARN_IF(NS_FAILED(rv))) {
+      return rv;
+    }
 
     nsCOMPtr<nsIFile> subdir = do_QueryInterface(entry);
 
     bool isDir = false;
     rv = subdir->IsDirectory(&isDir);
-    if (NS_WARN_IF(NS_FAILED(rv))) { return rv; }
+    if (NS_WARN_IF(NS_FAILED(rv))) {
+      return rv;
+    }
 
     // If a file got in here somehow, try to remove it and move on
     if (NS_WARN_IF(!isDir)) {
@@ -476,21 +531,27 @@ BodyDeleteOrphanedFiles(const QuotaInfo& aQuotaInfo, nsIFile* aBaseDir,
 
     nsCOMPtr<nsISimpleEnumerator> subEntries;
     rv = subdir->GetDirectoryEntries(getter_AddRefs(subEntries));
-    if (NS_WARN_IF(NS_FAILED(rv))) { return rv; }
+    if (NS_WARN_IF(NS_FAILED(rv))) {
+      return rv;
+    }
 
     // Now iterate over all the files in the subdir
     bool subHasMore = false;
-    while(NS_SUCCEEDED(rv = subEntries->HasMoreElements(&subHasMore)) &&
-          subHasMore) {
+    while (NS_SUCCEEDED(rv = subEntries->HasMoreElements(&subHasMore)) &&
+           subHasMore) {
       nsCOMPtr<nsISupports> subEntry;
       rv = subEntries->GetNext(getter_AddRefs(subEntry));
-      if (NS_WARN_IF(NS_FAILED(rv))) { return rv; }
+      if (NS_WARN_IF(NS_FAILED(rv))) {
+        return rv;
+      }
 
       nsCOMPtr<nsIFile> file = do_QueryInterface(subEntry);
 
       nsAutoCString leafName;
       rv = file->GetNativeLeafName(leafName);
-      if (NS_WARN_IF(NS_FAILED(rv))) { return rv; }
+      if (NS_WARN_IF(NS_FAILED(rv))) {
+        return rv;
+      }
 
       // Delete all tmp files regardless of known bodies.  These are
       // all considered orphans.
@@ -530,34 +591,38 @@ BodyDeleteOrphanedFiles(const QuotaInfo& aQuotaInfo, nsIFile* aBaseDir,
 
 namespace {
 
-nsresult
-GetMarkerFileHandle(const QuotaInfo& aQuotaInfo, nsIFile** aFileOut)
-{
+nsresult GetMarkerFileHandle(const QuotaInfo& aQuotaInfo, nsIFile** aFileOut) {
   MOZ_DIAGNOSTIC_ASSERT(aFileOut);
 
   nsCOMPtr<nsIFile> marker;
   nsresult rv = aQuotaInfo.mDir->Clone(getter_AddRefs(marker));
-  if (NS_WARN_IF(NS_FAILED(rv))) { return rv; }
+  if (NS_WARN_IF(NS_FAILED(rv))) {
+    return rv;
+  }
 
   rv = marker->Append(NS_LITERAL_STRING("cache"));
-  if (NS_WARN_IF(NS_FAILED(rv))) { return rv; }
+  if (NS_WARN_IF(NS_FAILED(rv))) {
+    return rv;
+  }
 
   rv = marker->Append(NS_LITERAL_STRING("context_open.marker"));
-  if (NS_WARN_IF(NS_FAILED(rv))) { return rv; }
+  if (NS_WARN_IF(NS_FAILED(rv))) {
+    return rv;
+  }
 
   marker.forget(aFileOut);
 
   return rv;
 }
 
-} // namespace
+}  // namespace
 
-nsresult
-CreateMarkerFile(const QuotaInfo& aQuotaInfo)
-{
+nsresult CreateMarkerFile(const QuotaInfo& aQuotaInfo) {
   nsCOMPtr<nsIFile> marker;
   nsresult rv = GetMarkerFileHandle(aQuotaInfo, getter_AddRefs(marker));
-  if (NS_WARN_IF(NS_FAILED(rv))) { return rv; }
+  if (NS_WARN_IF(NS_FAILED(rv))) {
+    return rv;
+  }
 
   rv = marker->Create(nsIFile::NORMAL_FILE_TYPE, 0644);
   if (rv == NS_ERROR_FILE_ALREADY_EXISTS) {
@@ -573,12 +638,12 @@ CreateMarkerFile(const QuotaInfo& aQuotaInfo)
   return rv;
 }
 
-nsresult
-DeleteMarkerFile(const QuotaInfo& aQuotaInfo)
-{
+nsresult DeleteMarkerFile(const QuotaInfo& aQuotaInfo) {
   nsCOMPtr<nsIFile> marker;
   nsresult rv = GetMarkerFileHandle(aQuotaInfo, getter_AddRefs(marker));
-  if (NS_WARN_IF(NS_FAILED(rv))) { return rv; }
+  if (NS_WARN_IF(NS_FAILED(rv))) {
+    return rv;
+  }
 
   rv = RemoveNsIFile(aQuotaInfo, marker);
   MOZ_ASSERT(NS_SUCCEEDED(rv));
@@ -591,24 +656,24 @@ DeleteMarkerFile(const QuotaInfo& aQuotaInfo)
   return NS_OK;
 }
 
-bool
-MarkerFileExists(const QuotaInfo& aQuotaInfo)
-{
+bool MarkerFileExists(const QuotaInfo& aQuotaInfo) {
   nsCOMPtr<nsIFile> marker;
   nsresult rv = GetMarkerFileHandle(aQuotaInfo, getter_AddRefs(marker));
-  if (NS_WARN_IF(NS_FAILED(rv))) { return false; }
+  if (NS_WARN_IF(NS_FAILED(rv))) {
+    return false;
+  }
 
   bool exists = false;
   rv = marker->Exists(&exists);
-  if (NS_WARN_IF(NS_FAILED(rv))) { return false; }
+  if (NS_WARN_IF(NS_FAILED(rv))) {
+    return false;
+  }
 
   return exists;
 }
 
 // static
-nsresult
-RemoveNsIFileRecursively(const QuotaInfo& aQuotaInfo, nsIFile* aFile)
-{
+nsresult RemoveNsIFileRecursively(const QuotaInfo& aQuotaInfo, nsIFile* aFile) {
   MOZ_DIAGNOSTIC_ASSERT(aFile);
 
   bool isDirectory = false;
@@ -617,7 +682,9 @@ RemoveNsIFileRecursively(const QuotaInfo& aQuotaInfo, nsIFile* aFile)
       rv == NS_ERROR_FILE_TARGET_DOES_NOT_EXIST) {
     return NS_OK;
   }
-  if (NS_WARN_IF(NS_FAILED(rv))) { return rv; }
+  if (NS_WARN_IF(NS_FAILED(rv))) {
+    return rv;
+  }
 
   if (!isDirectory) {
     return RemoveNsIFile(aQuotaInfo, aFile);
@@ -627,33 +694,41 @@ RemoveNsIFileRecursively(const QuotaInfo& aQuotaInfo, nsIFile* aFile)
   // one to update their usages to the QuotaManager.
   nsCOMPtr<nsISimpleEnumerator> entries;
   rv = aFile->GetDirectoryEntries(getter_AddRefs(entries));
-  if (NS_WARN_IF(NS_FAILED(rv))) { return rv; }
+  if (NS_WARN_IF(NS_FAILED(rv))) {
+    return rv;
+  }
 
   bool hasMore = false;
   while (NS_SUCCEEDED((rv = entries->HasMoreElements(&hasMore))) && hasMore) {
     nsCOMPtr<nsISupports> entry;
     rv = entries->GetNext(getter_AddRefs(entry));
-    if (NS_WARN_IF(NS_FAILED(rv))) { return rv; }
+    if (NS_WARN_IF(NS_FAILED(rv))) {
+      return rv;
+    }
 
     nsCOMPtr<nsIFile> file = do_QueryInterface(entry);
     MOZ_ASSERT(file);
 
     rv = RemoveNsIFileRecursively(aQuotaInfo, file);
-    if (NS_WARN_IF(NS_FAILED(rv))) { return rv; }
+    if (NS_WARN_IF(NS_FAILED(rv))) {
+      return rv;
+    }
+  }
+  if (NS_WARN_IF(NS_FAILED(rv))) {
+    return rv;
   }
-  if (NS_WARN_IF(NS_FAILED(rv))) { return rv; }
 
   // In the end, remove the folder
   rv = aFile->Remove(/* recursive */ false);
-  if (NS_WARN_IF(NS_FAILED(rv))) { return rv; }
+  if (NS_WARN_IF(NS_FAILED(rv))) {
+    return rv;
+  }
 
   return rv;
 }
 
 // static
-nsresult
-RemoveNsIFile(const QuotaInfo& aQuotaInfo, nsIFile* aFile)
-{
+nsresult RemoveNsIFile(const QuotaInfo& aQuotaInfo, nsIFile* aFile) {
   MOZ_DIAGNOSTIC_ASSERT(aFile);
 
   int64_t fileSize = 0;
@@ -662,10 +737,14 @@ RemoveNsIFile(const QuotaInfo& aQuotaInfo, nsIFile* aFile)
       rv == NS_ERROR_FILE_TARGET_DOES_NOT_EXIST) {
     return NS_OK;
   }
-  if (NS_WARN_IF(NS_FAILED(rv))) { return rv; }
+  if (NS_WARN_IF(NS_FAILED(rv))) {
+    return rv;
+  }
 
-  rv = aFile->Remove( /* recursive */ false);
-  if (NS_WARN_IF(NS_FAILED(rv))) { return rv; }
+  rv = aFile->Remove(/* recursive */ false);
+  if (NS_WARN_IF(NS_FAILED(rv))) {
+    return rv;
+  }
 
   if (fileSize > 0) {
     DecreaseUsageForQuotaInfo(aQuotaInfo, fileSize);
@@ -675,10 +754,8 @@ RemoveNsIFile(const QuotaInfo& aQuotaInfo, nsIFile* aFile)
 }
 
 // static
-void
-DecreaseUsageForQuotaInfo(const QuotaInfo& aQuotaInfo,
-                          const int64_t& aUpdatingSize)
-{
+void DecreaseUsageForQuotaInfo(const QuotaInfo& aQuotaInfo,
+                               const int64_t& aUpdatingSize) {
   MOZ_DIAGNOSTIC_ASSERT(aUpdatingSize > 0);
 
   QuotaManager* quotaManager = QuotaManager::Get();
@@ -690,14 +767,15 @@ DecreaseUsageForQuotaInfo(const QuotaInfo& aQuotaInfo,
 }
 
 // static
-bool
-DirectoryPaddingFileExists(nsIFile* aBaseDir, DirPaddingFile aPaddingFileType)
-{
+bool DirectoryPaddingFileExists(nsIFile* aBaseDir,
+                                DirPaddingFile aPaddingFileType) {
   MOZ_DIAGNOSTIC_ASSERT(aBaseDir);
 
   nsCOMPtr<nsIFile> file;
   nsresult rv = aBaseDir->Clone(getter_AddRefs(file));
-  if (NS_WARN_IF(NS_FAILED(rv))) { return false; }
+  if (NS_WARN_IF(NS_FAILED(rv))) {
+    return false;
+  }
 
   nsString fileName;
   if (aPaddingFileType == DirPaddingFile::TMP_FILE) {
@@ -707,46 +785,59 @@ DirectoryPaddingFileExists(nsIFile* aBaseDir, DirPaddingFile aPaddingFileType)
   }
 
   rv = file->Append(fileName);
-  if (NS_WARN_IF(NS_FAILED(rv))) { return false; }
+  if (NS_WARN_IF(NS_FAILED(rv))) {
+    return false;
+  }
 
   bool exists = false;
   rv = file->Exists(&exists);
-  if (NS_WARN_IF(NS_FAILED(rv))) { return false; }
+  if (NS_WARN_IF(NS_FAILED(rv))) {
+    return false;
+  }
 
   return exists;
 }
 
 // static
-nsresult
-LockedDirectoryPaddingGet(nsIFile* aBaseDir, int64_t* aPaddingSizeOut)
-{
+nsresult LockedDirectoryPaddingGet(nsIFile* aBaseDir,
+                                   int64_t* aPaddingSizeOut) {
   MOZ_DIAGNOSTIC_ASSERT(aBaseDir);
   MOZ_DIAGNOSTIC_ASSERT(aPaddingSizeOut);
-  MOZ_DIAGNOSTIC_ASSERT(!DirectoryPaddingFileExists(aBaseDir,
-                                                    DirPaddingFile::TMP_FILE));
+  MOZ_DIAGNOSTIC_ASSERT(
+      !DirectoryPaddingFileExists(aBaseDir, DirPaddingFile::TMP_FILE));
 
   nsCOMPtr<nsIFile> file;
   nsresult rv = aBaseDir->Clone(getter_AddRefs(file));
-  if (NS_WARN_IF(NS_FAILED(rv))) { return rv; }
+  if (NS_WARN_IF(NS_FAILED(rv))) {
+    return rv;
+  }
 
   rv = file->Append(NS_LITERAL_STRING(PADDING_FILE_NAME));
-  if (NS_WARN_IF(NS_FAILED(rv))) { return rv; }
+  if (NS_WARN_IF(NS_FAILED(rv))) {
+    return rv;
+  }
 
   nsCOMPtr<nsIInputStream> stream;
   rv = NS_NewLocalFileInputStream(getter_AddRefs(stream), file);
-  if (NS_WARN_IF(NS_FAILED(rv))) { return rv; }
+  if (NS_WARN_IF(NS_FAILED(rv))) {
+    return rv;
+  }
 
   nsCOMPtr<nsIInputStream> bufferedStream;
-  rv = NS_NewBufferedInputStream(getter_AddRefs(bufferedStream), stream.forget(),
-                                 512);
-  if (NS_WARN_IF(NS_FAILED(rv))) { return rv; }
+  rv = NS_NewBufferedInputStream(getter_AddRefs(bufferedStream),
+                                 stream.forget(), 512);
+  if (NS_WARN_IF(NS_FAILED(rv))) {
+    return rv;
+  }
 
   nsCOMPtr<nsIObjectInputStream> objectStream =
-    NS_NewObjectInputStream(bufferedStream);
+      NS_NewObjectInputStream(bufferedStream);
 
   uint64_t paddingSize = 0;
   rv = objectStream->Read64(&paddingSize);
-  if (NS_WARN_IF(NS_FAILED(rv))) { return rv; }
+  if (NS_WARN_IF(NS_FAILED(rv))) {
+    return rv;
+  }
 
   *aPaddingSizeOut = paddingSize;
 
@@ -754,9 +845,7 @@ LockedDirectoryPaddingGet(nsIFile* aBaseDir, int64_t* aPaddingSizeOut)
 }
 
 // static
-nsresult
-LockedDirectoryPaddingInit(nsIFile* aBaseDir)
-{
+nsresult LockedDirectoryPaddingInit(nsIFile* aBaseDir) {
   MOZ_DIAGNOSTIC_ASSERT(aBaseDir);
 
   nsresult rv = LockedDirectoryPaddingWrite(aBaseDir, DirPaddingFile::FILE, 0);
@@ -766,13 +855,11 @@ LockedDirectoryPaddingInit(nsIFile* aBaseDir)
 }
 
 // static
-nsresult
-LockedUpdateDirectoryPaddingFile(nsIFile* aBaseDir,
-                                 mozIStorageConnection* aConn,
-                                 const int64_t aIncreaseSize,
-                                 const int64_t aDecreaseSize,
-                                 const bool aTemporaryFileExist)
-{
+nsresult LockedUpdateDirectoryPaddingFile(nsIFile* aBaseDir,
+                                          mozIStorageConnection* aConn,
+                                          const int64_t aIncreaseSize,
+                                          const int64_t aDecreaseSize,
+                                          const bool aTemporaryFileExist) {
   MOZ_DIAGNOSTIC_ASSERT(aBaseDir);
   MOZ_DIAGNOSTIC_ASSERT(aConn);
   MOZ_DIAGNOSTIC_ASSERT(aIncreaseSize >= 0);
@@ -781,21 +868,25 @@ LockedUpdateDirectoryPaddingFile(nsIFile* aBaseDir,
   int64_t currentPaddingSize = 0;
   nsresult rv = NS_OK;
   if (aTemporaryFileExist ||
-      NS_WARN_IF(NS_FAILED(rv =
-        LockedDirectoryPaddingGet(aBaseDir, &currentPaddingSize)))) {
+      NS_WARN_IF(NS_FAILED(
+          rv = LockedDirectoryPaddingGet(aBaseDir, &currentPaddingSize)))) {
     // Fail to read padding size from the dir padding file, so try to restore.
     if (rv != NS_ERROR_FILE_NOT_FOUND &&
         rv != NS_ERROR_FILE_TARGET_DOES_NOT_EXIST) {
       // Not delete the temporary padding file here, because we're going to
       // overwrite it below anyway.
       rv = LockedDirectoryPaddingDeleteFile(aBaseDir, DirPaddingFile::FILE);
-      if (NS_WARN_IF(NS_FAILED(rv))) { return rv; }
+      if (NS_WARN_IF(NS_FAILED(rv))) {
+        return rv;
+      }
     }
 
     // We don't need to add the aIncreaseSize or aDecreaseSize here, because
     // it's already encompassed within the database.
     rv = db::FindOverallPaddingSize(aConn, &currentPaddingSize);
-    if (NS_WARN_IF(NS_FAILED(rv))) { return rv; }
+    if (NS_WARN_IF(NS_FAILED(rv))) {
+      return rv;
+    }
   } else {
     bool shouldRevise = false;
     if (aIncreaseSize > 0) {
@@ -809,7 +900,7 @@ LockedUpdateDirectoryPaddingFile(nsIFile* aBaseDir,
     if (aDecreaseSize > 0) {
       if (currentPaddingSize < aDecreaseSize) {
         shouldRevise = true;
-      } else if(!shouldRevise) {
+      } else if (!shouldRevise) {
         currentPaddingSize -= aDecreaseSize;
       }
     }
@@ -820,11 +911,15 @@ LockedUpdateDirectoryPaddingFile(nsIFile* aBaseDir,
       // Delete padding file to indicate the padding size is incorrect for
       // avoiding error happening in the following lines.
       rv = LockedDirectoryPaddingDeleteFile(aBaseDir, DirPaddingFile::FILE);
-      if (NS_WARN_IF(NS_FAILED(rv))) { return rv; }
+      if (NS_WARN_IF(NS_FAILED(rv))) {
+        return rv;
+      }
 
       int64_t paddingSizeFromDB = 0;
       rv = db::FindOverallPaddingSize(aConn, &paddingSizeFromDB);
-      if (NS_WARN_IF(NS_FAILED(rv))) { return rv; }
+      if (NS_WARN_IF(NS_FAILED(rv))) {
+        return rv;
+      }
       currentPaddingSize = paddingSizeFromDB;
 
       // XXXtt: we should have an easy way to update (increase or recalulate)
@@ -838,72 +933,85 @@ LockedUpdateDirectoryPaddingFile(nsIFile* aBaseDir,
 #ifdef DEBUG
     int64_t paddingSizeFromDB = 0;
     rv = db::FindOverallPaddingSize(aConn, &paddingSizeFromDB);
-    if (NS_WARN_IF(NS_FAILED(rv))) { return rv; }
+    if (NS_WARN_IF(NS_FAILED(rv))) {
+      return rv;
+    }
 
     MOZ_DIAGNOSTIC_ASSERT(paddingSizeFromDB == currentPaddingSize);
-#endif // DEBUG
+#endif  // DEBUG
   }
 
   MOZ_DIAGNOSTIC_ASSERT(currentPaddingSize >= 0);
 
   rv = LockedDirectoryPaddingTemporaryWrite(aBaseDir, currentPaddingSize);
-  if (NS_WARN_IF(NS_FAILED(rv))) { return rv; }
+  if (NS_WARN_IF(NS_FAILED(rv))) {
+    return rv;
+  }
 
   return rv;
 }
 
 // static
-nsresult
-LockedDirectoryPaddingTemporaryWrite(nsIFile* aBaseDir, int64_t aPaddingSize)
-{
+nsresult LockedDirectoryPaddingTemporaryWrite(nsIFile* aBaseDir,
+                                              int64_t aPaddingSize) {
   MOZ_DIAGNOSTIC_ASSERT(aBaseDir);
   MOZ_DIAGNOSTIC_ASSERT(aPaddingSize >= 0);
 
   nsresult rv = LockedDirectoryPaddingWrite(aBaseDir, DirPaddingFile::TMP_FILE,
                                             aPaddingSize);
-  if (NS_WARN_IF(NS_FAILED(rv))) { return rv; }
+  if (NS_WARN_IF(NS_FAILED(rv))) {
+    return rv;
+  }
 
   return rv;
 }
 
 // static
-nsresult
-LockedDirectoryPaddingFinalizeWrite(nsIFile* aBaseDir)
-{
+nsresult LockedDirectoryPaddingFinalizeWrite(nsIFile* aBaseDir) {
   MOZ_DIAGNOSTIC_ASSERT(aBaseDir);
-  MOZ_DIAGNOSTIC_ASSERT(DirectoryPaddingFileExists(aBaseDir,
-                                                   DirPaddingFile::TMP_FILE));
+  MOZ_DIAGNOSTIC_ASSERT(
+      DirectoryPaddingFileExists(aBaseDir, DirPaddingFile::TMP_FILE));
 
   nsCOMPtr<nsIFile> file;
   nsresult rv = aBaseDir->Clone(getter_AddRefs(file));
-  if (NS_WARN_IF(NS_FAILED(rv))) { return rv; }
+  if (NS_WARN_IF(NS_FAILED(rv))) {
+    return rv;
+  }
 
   rv = file->Append(NS_LITERAL_STRING(PADDING_TMP_FILE_NAME));
-  if (NS_WARN_IF(NS_FAILED(rv))) { return rv; }
+  if (NS_WARN_IF(NS_FAILED(rv))) {
+    return rv;
+  }
 
   rv = file->RenameTo(nullptr, NS_LITERAL_STRING(PADDING_FILE_NAME));
-  if (NS_WARN_IF(NS_FAILED(rv))) { return rv; }
+  if (NS_WARN_IF(NS_FAILED(rv))) {
+    return rv;
+  }
 
   return rv;
 }
 
 // static
-nsresult
-LockedDirectoryPaddingRestore(nsIFile* aBaseDir, mozIStorageConnection* aConn,
-                              bool aMustRestore, int64_t* aPaddingSizeOut)
-{
+nsresult LockedDirectoryPaddingRestore(nsIFile* aBaseDir,
+                                       mozIStorageConnection* aConn,
+                                       bool aMustRestore,
+                                       int64_t* aPaddingSizeOut) {
   MOZ_DIAGNOSTIC_ASSERT(aBaseDir);
   MOZ_DIAGNOSTIC_ASSERT(aConn);
   MOZ_DIAGNOSTIC_ASSERT(aPaddingSizeOut);
 
   // The content of padding file is untrusted, so remove it here.
-  nsresult rv = LockedDirectoryPaddingDeleteFile(aBaseDir,
-                                                 DirPaddingFile::FILE);
-  if (NS_WARN_IF(NS_FAILED(rv))) { return rv; }
+  nsresult rv =
+      LockedDirectoryPaddingDeleteFile(aBaseDir, DirPaddingFile::FILE);
+  if (NS_WARN_IF(NS_FAILED(rv))) {
+    return rv;
+  }
 
   int64_t paddingSize = 0;
   rv = db::FindOverallPaddingSize(aConn, &paddingSize);
-  if (NS_WARN_IF(NS_FAILED(rv))) { return rv; }
+  if (NS_WARN_IF(NS_FAILED(rv))) {
+    return rv;
+  }
 
   MOZ_DIAGNOSTIC_ASSERT(paddingSize >= 0);
   *aPaddingSizeOut = paddingSize;
@@ -923,32 +1031,36 @@ LockedDirectoryPaddingRestore(nsIFile* aBaseDir, mozIStorageConnection* aConn,
 }
 
 // static
-nsresult
-LockedDirectoryPaddingDeleteFile(nsIFile* aBaseDir,
-                                 DirPaddingFile aPaddingFileType)
-{
+nsresult LockedDirectoryPaddingDeleteFile(nsIFile* aBaseDir,
+                                          DirPaddingFile aPaddingFileType) {
   MOZ_DIAGNOSTIC_ASSERT(aBaseDir);
 
   nsCOMPtr<nsIFile> file;
   nsresult rv = aBaseDir->Clone(getter_AddRefs(file));
-  if (NS_WARN_IF(NS_FAILED(rv))) { return rv; }
+  if (NS_WARN_IF(NS_FAILED(rv))) {
+    return rv;
+  }
 
   if (aPaddingFileType == DirPaddingFile::TMP_FILE) {
     rv = file->Append(NS_LITERAL_STRING(PADDING_TMP_FILE_NAME));
   } else {
     rv = file->Append(NS_LITERAL_STRING(PADDING_FILE_NAME));
   }
-  if (NS_WARN_IF(NS_FAILED(rv))) { return rv; }
+  if (NS_WARN_IF(NS_FAILED(rv))) {
+    return rv;
+  }
 
-  rv = file->Remove( /* recursive */ false);
+  rv = file->Remove(/* recursive */ false);
   if (rv == NS_ERROR_FILE_NOT_FOUND ||
       rv == NS_ERROR_FILE_TARGET_DOES_NOT_EXIST) {
     return NS_OK;
   }
-  if (NS_WARN_IF(NS_FAILED(rv))) { return rv; }
+  if (NS_WARN_IF(NS_FAILED(rv))) {
+    return rv;
+  }
 
   return rv;
 }
-} // namespace cache
-} // namespace dom
-} // namespace mozilla
+}  // namespace cache
+}  // namespace dom
+}  // namespace mozilla
