@@ -11,13 +11,11 @@
 namespace mozilla {
 namespace dom {
 
-CommandEvent::CommandEvent(EventTarget* aOwner,
-                           nsPresContext* aPresContext,
+CommandEvent::CommandEvent(EventTarget* aOwner, nsPresContext* aPresContext,
                            WidgetCommandEvent* aEvent)
-  : Event(aOwner, aPresContext,
-          aEvent ? aEvent :
-                   new WidgetCommandEvent(false, nullptr, nullptr, nullptr))
-{
+    : Event(aOwner, aPresContext,
+            aEvent ? aEvent
+                   : new WidgetCommandEvent(false, nullptr, nullptr, nullptr)) {
   mEvent->mTime = PR_Now();
   if (aEvent) {
     mEventIsInternal = false;
@@ -26,9 +24,7 @@ CommandEvent::CommandEvent(EventTarget* aOwner,
   }
 }
 
-void
-CommandEvent::GetCommand(nsAString& aCommand)
-{
+void CommandEvent::GetCommand(nsAString& aCommand) {
   nsAtom* command = mEvent->AsCommandEvent()->mCommand;
   if (command) {
     command->ToString(aCommand);
@@ -37,18 +33,15 @@ CommandEvent::GetCommand(nsAString& aCommand)
   }
 }
 
-} // namespace dom
-} // namespace mozilla
+}  // namespace dom
+}  // namespace mozilla
 
 using namespace mozilla;
 using namespace mozilla::dom;
 
-already_AddRefed<CommandEvent>
-NS_NewDOMCommandEvent(EventTarget* aOwner,
-                      nsPresContext* aPresContext,
-                      WidgetCommandEvent* aEvent)
-{
-  RefPtr<CommandEvent> it =
-    new CommandEvent(aOwner, aPresContext, aEvent);
+already_AddRefed<CommandEvent> NS_NewDOMCommandEvent(
+    EventTarget* aOwner, nsPresContext* aPresContext,
+    WidgetCommandEvent* aEvent) {
+  RefPtr<CommandEvent> it = new CommandEvent(aOwner, aPresContext, aEvent);
   return it.forget();
 }
