@@ -38,28 +38,22 @@
 namespace mozilla {
 namespace dom {
 
-static char *sPopupAllowedEvents;
+static char* sPopupAllowedEvents;
 
 static bool sReturnHighResTimeStamp = false;
 static bool sReturnHighResTimeStampIsSet = false;
 
-Event::Event(EventTarget* aOwner,
-             nsPresContext* aPresContext,
-             WidgetEvent* aEvent)
-{
+Event::Event(EventTarget* aOwner, nsPresContext* aPresContext,
+             WidgetEvent* aEvent) {
   ConstructorInit(aOwner, aPresContext, aEvent);
 }
 
-Event::Event(nsPIDOMWindowInner* aParent)
-{
+Event::Event(nsPIDOMWindowInner* aParent) {
   ConstructorInit(nsGlobalWindowInner::Cast(aParent), nullptr, nullptr);
 }
 
-void
-Event::ConstructorInit(EventTarget* aOwner,
-                       nsPresContext* aPresContext,
-                       WidgetEvent* aEvent)
-{
+void Event::ConstructorInit(EventTarget* aOwner, nsPresContext* aPresContext,
+                            WidgetEvent* aEvent) {
   SetOwner(aOwner);
   mIsMainThreadEvent = NS_IsMainThread();
 
@@ -76,8 +70,7 @@ Event::ConstructorInit(EventTarget* aOwner,
   if (aEvent) {
     mEvent = aEvent;
     mEventIsInternal = false;
-  }
-  else {
+  } else {
     mEventIsInternal = true;
     /*
       A derived class might want to allocate its own type of aEvent
@@ -110,9 +103,7 @@ Event::ConstructorInit(EventTarget* aOwner,
   InitPresContextData(aPresContext);
 }
 
-void
-Event::InitPresContextData(nsPresContext* aPresContext)
-{
+void Event::InitPresContextData(nsPresContext* aPresContext) {
   mPresContext = aPresContext;
   // Get the explicit original target (if it's anonymous make it null)
   {
@@ -124,8 +115,7 @@ Event::InitPresContextData(nsPresContext* aPresContext)
   }
 }
 
-Event::~Event()
-{
+Event::~Event() {
   NS_ASSERT_OWNINGTHREAD(Event);
 
   if (mEventIsInternal && mEvent) {
@@ -208,23 +198,18 @@ NS_IMPL_CYCLE_COLLECTION_TRAVERSE_BEGIN(Event)
   NS_IMPL_CYCLE_COLLECTION_TRAVERSE(mOwner)
 NS_IMPL_CYCLE_COLLECTION_TRAVERSE_END
 
-
-JSObject*
-Event::WrapObject(JSContext* aCx, JS::Handle<JSObject*> aGivenProto)
-{
+JSObject* Event::WrapObject(JSContext* aCx, JS::Handle<JSObject*> aGivenProto) {
   return WrapObjectInternal(aCx, aGivenProto);
 }
 
-JSObject*
-Event::WrapObjectInternal(JSContext* aCx, JS::Handle<JSObject*> aGivenProto)
-{
+JSObject* Event::WrapObjectInternal(JSContext* aCx,
+                                    JS::Handle<JSObject*> aGivenProto) {
   return EventBinding::Wrap(aCx, this, aGivenProto);
 }
 
 // nsIDOMEventInterface
 NS_IMETHODIMP
-Event::GetType(nsAString& aType)
-{
+Event::GetType(nsAString& aType) {
   if (!mIsMainThreadEvent) {
     aType = mEvent->mSpecifiedEventTypeString;
     return NS_OK;
@@ -233,23 +218,17 @@ Event::GetType(nsAString& aType)
   return NS_OK;
 }
 
-EventTarget*
-Event::GetTarget() const
-{
-  return mEvent->GetDOMEventTarget();
-}
+EventTarget* Event::GetTarget() const { return mEvent->GetDOMEventTarget(); }
 
 NS_IMETHODIMP
-Event::GetTarget(nsIDOMEventTarget** aTarget)
-{
+Event::GetTarget(nsIDOMEventTarget** aTarget) {
   NS_IF_ADDREF(*aTarget = GetTarget());
   return NS_OK;
 }
 
-bool
-Event::IsSrcElementEnabled(JSContext* /* unused */, JSObject* /* unused */)
-{
-  // Not a pref, because that's a pain on workers.
+bool Event::IsSrcElementEnabled(JSContext* /* unused */,
+                                JSObject* /* unused */) {
+// Not a pref, because that's a pain on workers.
 #ifdef NIGHTLY_BUILD
   return true;
 #else
@@ -257,21 +236,16 @@ Event::IsSrcElementEnabled(JSContext* /* unused */, JSObject* /* unused */)
 #endif
 }
 
-EventTarget*
-Event::GetCurrentTarget() const
-{
+EventTarget* Event::GetCurrentTarget() const {
   return mEvent->GetCurrentDOMEventTarget();
 }
 
-void
-Event::ComposedPath(nsTArray<RefPtr<EventTarget>>& aPath)
-{
+void Event::ComposedPath(nsTArray<RefPtr<EventTarget>>& aPath) {
   EventDispatcher::GetComposedPathFor(mEvent, aPath);
 }
 
 NS_IMETHODIMP
-Event::GetCurrentTarget(nsIDOMEventTarget** aCurrentTarget)
-{
+Event::GetCurrentTarget(nsIDOMEventTarget** aCurrentTarget) {
   NS_IF_ADDREF(*aCurrentTarget = GetCurrentTarget());
   return NS_OK;
 }
@@ -279,14 +253,16 @@ Event::GetCurrentTarget(nsIDOMEventTarget** aCurrentTarget)
 //
 // Get the actual event target node (may have been retargeted for mouse events)
 //
-already_AddRefed<nsIContent>
-Event::GetTargetFromFrame()
-{
-  if (!mPresContext) { return nullptr; }
+already_AddRefed<nsIContent> Event::GetTargetFromFrame() {
+  if (!mPresContext) {
+    return nullptr;
+  }
 
   // Get the mTarget frame (have to get the ESM first)
   nsIFrame* targetFrame = mPresContext->EventStateManager()->GetEventTarget();
-  if (!targetFrame) { return nullptr; }
+  if (!targetFrame) {
+    return nullptr;
+  }
 
   // get the real content
   nsCOMPtr<nsIContent> realEventContent;
@@ -294,9 +270,7 @@ Event::GetTargetFromFrame()
   return realEventContent.forget();
 }
 
-EventTarget*
-Event::GetExplicitOriginalTarget() const
-{
+EventTarget* Event::GetExplicitOriginalTarget() const {
   if (mExplicitOriginalTarget) {
     return mExplicitOriginalTarget;
   }
@@ -304,48 +278,36 @@ Event::GetExplicitOriginalTarget() const
 }
 
 NS_IMETHODIMP
-Event::GetExplicitOriginalTarget(nsIDOMEventTarget** aRealEventTarget)
-{
+Event::GetExplicitOriginalTarget(nsIDOMEventTarget** aRealEventTarget) {
   NS_IF_ADDREF(*aRealEventTarget = GetExplicitOriginalTarget());
   return NS_OK;
 }
 
-EventTarget*
-Event::GetOriginalTarget() const
-{
+EventTarget* Event::GetOriginalTarget() const {
   return mEvent->GetOriginalDOMEventTarget();
 }
 
 NS_IMETHODIMP
-Event::GetOriginalTarget(nsIDOMEventTarget** aOriginalTarget)
-{
+Event::GetOriginalTarget(nsIDOMEventTarget** aOriginalTarget) {
   NS_IF_ADDREF(*aOriginalTarget = GetOriginalTarget());
   return NS_OK;
 }
 
-EventTarget*
-Event::GetComposedTarget() const
-{
+EventTarget* Event::GetComposedTarget() const {
   EventTarget* et = GetOriginalTarget();
   nsCOMPtr<nsIContent> content = do_QueryInterface(et);
   if (!content) {
     return et;
   }
   nsIContent* nonChrome = content->FindFirstNonChromeOnlyAccessContent();
-  return nonChrome ?
-    static_cast<EventTarget*>(nonChrome) :
-    static_cast<EventTarget*>(content->GetComposedDoc());
+  return nonChrome ? static_cast<EventTarget*>(nonChrome)
+                   : static_cast<EventTarget*>(content->GetComposedDoc());
 }
 
 NS_IMETHODIMP_(void)
-Event::SetTrusted(bool aTrusted)
-{
-  mEvent->mFlags.mIsTrusted = aTrusted;
-}
+Event::SetTrusted(bool aTrusted) { mEvent->mFlags.mIsTrusted = aTrusted; }
 
-bool
-Event::Init(mozilla::dom::EventTarget* aGlobal)
-{
+bool Event::Init(mozilla::dom::EventTarget* aGlobal) {
   if (!mIsMainThreadEvent) {
     return IsCurrentThreadRunningChromeWorker();
   }
@@ -365,22 +327,19 @@ Event::Init(mozilla::dom::EventTarget* aGlobal)
 }
 
 // static
-already_AddRefed<Event>
-Event::Constructor(const GlobalObject& aGlobal,
-                   const nsAString& aType,
-                   const EventInit& aParam,
-                   ErrorResult& aRv)
-{
-  nsCOMPtr<mozilla::dom::EventTarget> t = do_QueryInterface(aGlobal.GetAsSupports());
+already_AddRefed<Event> Event::Constructor(const GlobalObject& aGlobal,
+                                           const nsAString& aType,
+                                           const EventInit& aParam,
+                                           ErrorResult& aRv) {
+  nsCOMPtr<mozilla::dom::EventTarget> t =
+      do_QueryInterface(aGlobal.GetAsSupports());
   return Constructor(t, aType, aParam);
 }
 
 // static
-already_AddRefed<Event>
-Event::Constructor(EventTarget* aEventTarget,
-                   const nsAString& aType,
-                   const EventInit& aParam)
-{
+already_AddRefed<Event> Event::Constructor(EventTarget* aEventTarget,
+                                           const nsAString& aType,
+                                           const EventInit& aParam) {
   RefPtr<Event> e = new Event(aEventTarget, nullptr, nullptr);
   bool trusted = e->Init(aEventTarget);
   e->InitEvent(aType, aParam.mBubbles, aParam.mCancelable);
@@ -389,14 +348,11 @@ Event::Constructor(EventTarget* aEventTarget,
   return e.forget();
 }
 
-uint16_t
-Event::EventPhase() const
-{
+uint16_t Event::EventPhase() const {
   // Note, remember to check that this works also
   // if or when Bug 235441 is fixed.
-  if ((mEvent->mCurrentTarget &&
-       mEvent->mCurrentTarget == mEvent->mTarget) ||
-       mEvent->mFlags.InTargetPhase()) {
+  if ((mEvent->mCurrentTarget && mEvent->mCurrentTarget == mEvent->mTarget) ||
+      mEvent->mFlags.InTargetPhase()) {
     return nsIDOMEvent::AT_TARGET;
   }
   if (mEvent->mFlags.mInCapturePhase) {
@@ -409,87 +365,74 @@ Event::EventPhase() const
 }
 
 NS_IMETHODIMP
-Event::GetEventPhase(uint16_t* aEventPhase)
-{
+Event::GetEventPhase(uint16_t* aEventPhase) {
   *aEventPhase = EventPhase();
   return NS_OK;
 }
 
 NS_IMETHODIMP
-Event::GetBubbles(bool* aBubbles)
-{
+Event::GetBubbles(bool* aBubbles) {
   *aBubbles = Bubbles();
   return NS_OK;
 }
 
 NS_IMETHODIMP
-Event::GetCancelable(bool* aCancelable)
-{
+Event::GetCancelable(bool* aCancelable) {
   *aCancelable = Cancelable();
   return NS_OK;
 }
 
 NS_IMETHODIMP
-Event::GetTimeStamp(uint64_t* aTimeStamp)
-{
+Event::GetTimeStamp(uint64_t* aTimeStamp) {
   *aTimeStamp = mEvent->mTime;
   return NS_OK;
 }
 
 NS_IMETHODIMP
-Event::StopPropagation()
-{
+Event::StopPropagation() {
   mEvent->StopPropagation();
   return NS_OK;
 }
 
 NS_IMETHODIMP
-Event::StopImmediatePropagation()
-{
+Event::StopImmediatePropagation() {
   mEvent->StopImmediatePropagation();
   return NS_OK;
 }
 
 NS_IMETHODIMP
-Event::StopCrossProcessForwarding()
-{
+Event::StopCrossProcessForwarding() {
   mEvent->StopCrossProcessForwarding();
   return NS_OK;
 }
 
 NS_IMETHODIMP
-Event::GetIsTrusted(bool* aIsTrusted)
-{
+Event::GetIsTrusted(bool* aIsTrusted) {
   *aIsTrusted = IsTrusted();
   return NS_OK;
 }
 
 NS_IMETHODIMP
-Event::PreventDefault()
-{
+Event::PreventDefault() {
   // This method is called only from C++ code which must handle default action
   // of this event.  So, pass true always.
   PreventDefaultInternal(true);
   return NS_OK;
 }
 
-void
-Event::PreventDefault(JSContext* aCx, CallerType aCallerType)
-{
+void Event::PreventDefault(JSContext* aCx, CallerType aCallerType) {
   // Note that at handling default action, another event may be dispatched.
   // Then, JS in content mey be call preventDefault()
   // even in the event is in system event group.  Therefore, don't refer
   // mInSystemGroup here.
-  nsIPrincipal* principal = mIsMainThreadEvent ?
-                              nsContentUtils::SubjectPrincipal(aCx) : nullptr;
+  nsIPrincipal* principal =
+      mIsMainThreadEvent ? nsContentUtils::SubjectPrincipal(aCx) : nullptr;
 
   PreventDefaultInternal(aCallerType == CallerType::System, principal);
 }
 
-void
-Event::PreventDefaultInternal(bool aCalledByDefaultHandler,
-                              nsIPrincipal* aPrincipal)
-{
+void Event::PreventDefaultInternal(bool aCalledByDefaultHandler,
+                                   nsIPrincipal* aPrincipal) {
   if (!mEvent->mFlags.mCancelable) {
     return;
   }
@@ -499,9 +442,9 @@ Event::PreventDefaultInternal(bool aCalledByDefaultHandler,
       if (nsIDocument* doc = win->GetExtantDoc()) {
         nsString type;
         GetType(type);
-        const char16_t* params[] = { type.get() };
+        const char16_t* params[] = {type.get()};
         doc->WarnOnceAbout(nsIDocument::ePreventDefaultFromPassiveListener,
-          false, params, ArrayLength(params));
+                           false, params, ArrayLength(params));
       }
     }
     return;
@@ -521,7 +464,7 @@ Event::PreventDefaultInternal(bool aCalledByDefaultHandler,
   nsCOMPtr<nsINode> node = do_QueryInterface(mEvent->mCurrentTarget);
   if (!node) {
     nsCOMPtr<nsPIDOMWindowOuter> win =
-      do_QueryInterface(mEvent->mCurrentTarget);
+        do_QueryInterface(mEvent->mCurrentTarget);
     if (!win) {
       return;
     }
@@ -532,14 +475,11 @@ Event::PreventDefaultInternal(bool aCalledByDefaultHandler,
   }
 }
 
-void
-Event::SetEventType(const nsAString& aEventTypeArg)
-{
+void Event::SetEventType(const nsAString& aEventTypeArg) {
   if (mIsMainThreadEvent) {
     mEvent->mSpecifiedEventTypeString.Truncate();
-    mEvent->mSpecifiedEventType =
-      nsContentUtils::GetEventMessageAndAtom(aEventTypeArg, mEvent->mClass,
-                                             &(mEvent->mMessage));
+    mEvent->mSpecifiedEventType = nsContentUtils::GetEventMessageAndAtom(
+        aEventTypeArg, mEvent->mClass, &(mEvent->mMessage));
     mEvent->SetDefaultComposed();
   } else {
     mEvent->mSpecifiedEventType = nullptr;
@@ -550,9 +490,8 @@ Event::SetEventType(const nsAString& aEventTypeArg)
   mEvent->SetDefaultComposedInNativeAnonymousContent();
 }
 
-already_AddRefed<EventTarget>
-Event::EnsureWebAccessibleRelatedTarget(EventTarget* aRelatedTarget)
-{
+already_AddRefed<EventTarget> Event::EnsureWebAccessibleRelatedTarget(
+    EventTarget* aRelatedTarget) {
   nsCOMPtr<EventTarget> relatedTarget = aRelatedTarget;
   if (relatedTarget) {
     nsCOMPtr<nsIContent> content = do_QueryInterface(relatedTarget);
@@ -570,11 +509,8 @@ Event::EnsureWebAccessibleRelatedTarget(EventTarget* aRelatedTarget)
   return relatedTarget.forget();
 }
 
-void
-Event::InitEvent(const nsAString& aEventTypeArg,
-                 bool aCanBubbleArg,
-                 bool aCancelableArg)
-{
+void Event::InitEvent(const nsAString& aEventTypeArg, bool aCanBubbleArg,
+                      bool aCancelableArg) {
   // Make sure this event isn't already being dispatched.
   NS_ENSURE_TRUE_VOID(!mEvent->mFlags.mIsBeingDispatched);
 
@@ -603,8 +539,7 @@ Event::InitEvent(const nsAString& aEventTypeArg,
 }
 
 NS_IMETHODIMP
-Event::DuplicatePrivateData()
-{
+Event::DuplicatePrivateData() {
   NS_ASSERTION(mEvent, "No WidgetEvent for Event duplication!");
   if (mEventIsInternal) {
     return NS_OK;
@@ -619,35 +554,23 @@ Event::DuplicatePrivateData()
 }
 
 NS_IMETHODIMP
-Event::SetTarget(nsIDOMEventTarget* aTarget)
-{
+Event::SetTarget(nsIDOMEventTarget* aTarget) {
   mEvent->mTarget = do_QueryInterface(aTarget);
   return NS_OK;
 }
 
 NS_IMETHODIMP_(bool)
-Event::IsDispatchStopped()
-{
-  return mEvent->PropagationStopped();
-}
+Event::IsDispatchStopped() { return mEvent->PropagationStopped(); }
 
 NS_IMETHODIMP_(WidgetEvent*)
-Event::WidgetEventPtr()
-{
-  return mEvent;
-}
+Event::WidgetEventPtr() { return mEvent; }
 
 NS_IMETHODIMP_(Event*)
-Event::InternalDOMEvent()
-{
-  return this;
-}
+Event::InternalDOMEvent() { return this; }
 
 // return true if eventName is contained within events, delimited by
 // spaces
-static bool
-PopupAllowedForEvent(const char *eventName)
-{
+static bool PopupAllowedForEvent(const char* eventName) {
   if (!sPopupAllowedEvents) {
     Event::PopupAllowedEventsChanged();
 
@@ -684,9 +607,8 @@ PopupAllowedForEvent(const char *eventName)
 }
 
 // static
-PopupControlState
-Event::GetEventPopupControlState(WidgetEvent* aEvent, nsIDOMEvent* aDOMEvent)
-{
+PopupControlState Event::GetEventPopupControlState(WidgetEvent* aEvent,
+                                                   nsIDOMEvent* aDOMEvent) {
   // generally if an event handler is running, new windows are disallowed.
   // check for exceptions:
   PopupControlState abuse = openAbused;
@@ -699,202 +621,200 @@ Event::GetEventPopupControlState(WidgetEvent* aEvent, nsIDOMEvent* aDOMEvent)
     }
   }
 
-  switch(aEvent->mClass) {
-  case eBasicEventClass:
-    // For these following events only allow popups if they're
-    // triggered while handling user input. See
-    // nsPresShell::HandleEventInternal() for details.
-    if (EventStateManager::IsHandlingUserInput()) {
-      abuse = openBlocked;
-      switch(aEvent->mMessage) {
-      case eFormSelect:
-        if (PopupAllowedForEvent("select")) {
-          abuse = openControlled;
+  switch (aEvent->mClass) {
+    case eBasicEventClass:
+      // For these following events only allow popups if they're
+      // triggered while handling user input. See
+      // nsPresShell::HandleEventInternal() for details.
+      if (EventStateManager::IsHandlingUserInput()) {
+        abuse = openBlocked;
+        switch (aEvent->mMessage) {
+          case eFormSelect:
+            if (PopupAllowedForEvent("select")) {
+              abuse = openControlled;
+            }
+            break;
+          case eFormChange:
+            if (PopupAllowedForEvent("change")) {
+              abuse = openControlled;
+            }
+            break;
+          default:
+            break;
         }
-        break;
-      case eFormChange:
-        if (PopupAllowedForEvent("change")) {
-          abuse = openControlled;
-        }
-        break;
-      default:
-        break;
       }
-    }
-    break;
-  case eEditorInputEventClass:
-    // For this following event only allow popups if it's triggered
-    // while handling user input. See
-    // nsPresShell::HandleEventInternal() for details.
-    if (EventStateManager::IsHandlingUserInput()) {
-      abuse = openBlocked;
-      switch(aEvent->mMessage) {
-      case eEditorInput:
-        if (PopupAllowedForEvent("input")) {
-          abuse = openControlled;
+      break;
+    case eEditorInputEventClass:
+      // For this following event only allow popups if it's triggered
+      // while handling user input. See
+      // nsPresShell::HandleEventInternal() for details.
+      if (EventStateManager::IsHandlingUserInput()) {
+        abuse = openBlocked;
+        switch (aEvent->mMessage) {
+          case eEditorInput:
+            if (PopupAllowedForEvent("input")) {
+              abuse = openControlled;
+            }
+            break;
+          default:
+            break;
         }
-        break;
-      default:
-        break;
       }
-    }
-    break;
-  case eInputEventClass:
-    // For this following event only allow popups if it's triggered
-    // while handling user input. See
-    // nsPresShell::HandleEventInternal() for details.
-    if (EventStateManager::IsHandlingUserInput()) {
-      abuse = openBlocked;
-      switch(aEvent->mMessage) {
-      case eFormChange:
-        if (PopupAllowedForEvent("change")) {
-          abuse = openControlled;
+      break;
+    case eInputEventClass:
+      // For this following event only allow popups if it's triggered
+      // while handling user input. See
+      // nsPresShell::HandleEventInternal() for details.
+      if (EventStateManager::IsHandlingUserInput()) {
+        abuse = openBlocked;
+        switch (aEvent->mMessage) {
+          case eFormChange:
+            if (PopupAllowedForEvent("change")) {
+              abuse = openControlled;
+            }
+            break;
+          case eXULCommand:
+            abuse = openControlled;
+            break;
+          default:
+            break;
         }
-        break;
-      case eXULCommand:
-        abuse = openControlled;
-        break;
-      default:
-        break;
       }
-    }
-    break;
-  case eKeyboardEventClass:
-    if (aEvent->IsTrusted()) {
-      abuse = openBlocked;
-      uint32_t key = aEvent->AsKeyboardEvent()->mKeyCode;
-      switch(aEvent->mMessage) {
-      case eKeyPress:
-        // return key on focused button. see note at eMouseClick.
-        if (key == NS_VK_RETURN) {
-          abuse = openAllowed;
-        } else if (PopupAllowedForEvent("keypress")) {
-          abuse = openControlled;
+      break;
+    case eKeyboardEventClass:
+      if (aEvent->IsTrusted()) {
+        abuse = openBlocked;
+        uint32_t key = aEvent->AsKeyboardEvent()->mKeyCode;
+        switch (aEvent->mMessage) {
+          case eKeyPress:
+            // return key on focused button. see note at eMouseClick.
+            if (key == NS_VK_RETURN) {
+              abuse = openAllowed;
+            } else if (PopupAllowedForEvent("keypress")) {
+              abuse = openControlled;
+            }
+            break;
+          case eKeyUp:
+            // space key on focused button. see note at eMouseClick.
+            if (key == NS_VK_SPACE) {
+              abuse = openAllowed;
+            } else if (PopupAllowedForEvent("keyup")) {
+              abuse = openControlled;
+            }
+            break;
+          case eKeyDown:
+            if (PopupAllowedForEvent("keydown")) {
+              abuse = openControlled;
+            }
+            break;
+          default:
+            break;
         }
-        break;
-      case eKeyUp:
-        // space key on focused button. see note at eMouseClick.
-        if (key == NS_VK_SPACE) {
-          abuse = openAllowed;
-        } else if (PopupAllowedForEvent("keyup")) {
-          abuse = openControlled;
-        }
-        break;
-      case eKeyDown:
-        if (PopupAllowedForEvent("keydown")) {
-          abuse = openControlled;
-        }
-        break;
-      default:
-        break;
       }
-    }
-    break;
-  case eTouchEventClass:
-    if (aEvent->IsTrusted()) {
-      abuse = openBlocked;
-      switch (aEvent->mMessage) {
-      case eTouchStart:
-        if (PopupAllowedForEvent("touchstart")) {
-          abuse = openControlled;
+      break;
+    case eTouchEventClass:
+      if (aEvent->IsTrusted()) {
+        abuse = openBlocked;
+        switch (aEvent->mMessage) {
+          case eTouchStart:
+            if (PopupAllowedForEvent("touchstart")) {
+              abuse = openControlled;
+            }
+            break;
+          case eTouchEnd:
+            if (PopupAllowedForEvent("touchend")) {
+              abuse = openControlled;
+            }
+            break;
+          default:
+            break;
         }
-        break;
-      case eTouchEnd:
-        if (PopupAllowedForEvent("touchend")) {
-          abuse = openControlled;
-        }
-        break;
-      default:
-        break;
       }
-    }
-    break;
-  case eMouseEventClass:
-    if (aEvent->IsTrusted() &&
-        aEvent->AsMouseEvent()->button == WidgetMouseEvent::eLeftButton) {
-      abuse = openBlocked;
-      switch(aEvent->mMessage) {
-      case eMouseUp:
-        if (PopupAllowedForEvent("mouseup")) {
-          abuse = openControlled;
+      break;
+    case eMouseEventClass:
+      if (aEvent->IsTrusted() &&
+          aEvent->AsMouseEvent()->button == WidgetMouseEvent::eLeftButton) {
+        abuse = openBlocked;
+        switch (aEvent->mMessage) {
+          case eMouseUp:
+            if (PopupAllowedForEvent("mouseup")) {
+              abuse = openControlled;
+            }
+            break;
+          case eMouseDown:
+            if (PopupAllowedForEvent("mousedown")) {
+              abuse = openControlled;
+            }
+            break;
+          case eMouseClick:
+            /* Click events get special treatment because of their
+               historical status as a more legitimate event handler. If
+               click popups are enabled in the prefs, clear the popup
+               status completely. */
+            if (PopupAllowedForEvent("click")) {
+              abuse = openAllowed;
+            }
+            break;
+          case eMouseDoubleClick:
+            if (PopupAllowedForEvent("dblclick")) {
+              abuse = openControlled;
+            }
+            break;
+          default:
+            break;
         }
-        break;
-      case eMouseDown:
-        if (PopupAllowedForEvent("mousedown")) {
-          abuse = openControlled;
-        }
-        break;
-      case eMouseClick:
-        /* Click events get special treatment because of their
-           historical status as a more legitimate event handler. If
-           click popups are enabled in the prefs, clear the popup
-           status completely. */
-        if (PopupAllowedForEvent("click")) {
-          abuse = openAllowed;
-        }
-        break;
-      case eMouseDoubleClick:
-        if (PopupAllowedForEvent("dblclick")) {
-          abuse = openControlled;
-        }
-        break;
-      default:
-        break;
       }
-    }
-    break;
-  case ePointerEventClass:
-    if (aEvent->IsTrusted() &&
-        aEvent->AsPointerEvent()->button == WidgetMouseEvent::eLeftButton) {
-      switch(aEvent->mMessage) {
-      case ePointerUp:
-        if (PopupAllowedForEvent("pointerup")) {
-          abuse = openControlled;
+      break;
+    case ePointerEventClass:
+      if (aEvent->IsTrusted() &&
+          aEvent->AsPointerEvent()->button == WidgetMouseEvent::eLeftButton) {
+        switch (aEvent->mMessage) {
+          case ePointerUp:
+            if (PopupAllowedForEvent("pointerup")) {
+              abuse = openControlled;
+            }
+            break;
+          case ePointerDown:
+            if (PopupAllowedForEvent("pointerdown")) {
+              abuse = openControlled;
+            }
+            break;
+          default:
+            break;
         }
-        break;
-      case ePointerDown:
-        if (PopupAllowedForEvent("pointerdown")) {
-          abuse = openControlled;
-        }
-        break;
-      default:
-        break;
       }
-    }
-    break;
-  case eFormEventClass:
-    // For these following events only allow popups if they're
-    // triggered while handling user input. See
-    // nsPresShell::HandleEventInternal() for details.
-    if (EventStateManager::IsHandlingUserInput()) {
-      abuse = openBlocked;
-      switch(aEvent->mMessage) {
-      case eFormSubmit:
-        if (PopupAllowedForEvent("submit")) {
-          abuse = openControlled;
+      break;
+    case eFormEventClass:
+      // For these following events only allow popups if they're
+      // triggered while handling user input. See
+      // nsPresShell::HandleEventInternal() for details.
+      if (EventStateManager::IsHandlingUserInput()) {
+        abuse = openBlocked;
+        switch (aEvent->mMessage) {
+          case eFormSubmit:
+            if (PopupAllowedForEvent("submit")) {
+              abuse = openControlled;
+            }
+            break;
+          case eFormReset:
+            if (PopupAllowedForEvent("reset")) {
+              abuse = openControlled;
+            }
+            break;
+          default:
+            break;
         }
-        break;
-      case eFormReset:
-        if (PopupAllowedForEvent("reset")) {
-          abuse = openControlled;
-        }
-        break;
-      default:
-        break;
       }
-    }
-    break;
-  default:
-    break;
+      break;
+    default:
+      break;
   }
 
   return abuse;
 }
 
 // static
-void
-Event::PopupAllowedEventsChanged()
-{
+void Event::PopupAllowedEventsChanged() {
   if (sPopupAllowedEvents) {
     free(sPopupAllowedEvents);
   }
@@ -908,32 +828,27 @@ Event::PopupAllowedEventsChanged()
 }
 
 // static
-void
-Event::Shutdown()
-{
+void Event::Shutdown() {
   if (sPopupAllowedEvents) {
     free(sPopupAllowedEvents);
   }
 }
 
 // static
-CSSIntPoint
-Event::GetScreenCoords(nsPresContext* aPresContext,
-                       WidgetEvent* aEvent,
-                       LayoutDeviceIntPoint aPoint)
-{
+CSSIntPoint Event::GetScreenCoords(nsPresContext* aPresContext,
+                                   WidgetEvent* aEvent,
+                                   LayoutDeviceIntPoint aPoint) {
   if (EventStateManager::sIsPointerLocked) {
     return EventStateManager::sLastScreenPoint;
   }
 
-  if (!aEvent ||
-       (aEvent->mClass != eMouseEventClass &&
-        aEvent->mClass != eMouseScrollEventClass &&
-        aEvent->mClass != eWheelEventClass &&
-        aEvent->mClass != ePointerEventClass &&
-        aEvent->mClass != eTouchEventClass &&
-        aEvent->mClass != eDragEventClass &&
-        aEvent->mClass != eSimpleGestureEventClass)) {
+  if (!aEvent || (aEvent->mClass != eMouseEventClass &&
+                  aEvent->mClass != eMouseScrollEventClass &&
+                  aEvent->mClass != eWheelEventClass &&
+                  aEvent->mClass != ePointerEventClass &&
+                  aEvent->mClass != eTouchEventClass &&
+                  aEvent->mClass != eDragEventClass &&
+                  aEvent->mClass != eSimpleGestureEventClass)) {
     return CSSIntPoint(0, 0);
   }
 
@@ -944,35 +859,36 @@ Event::GetScreenCoords(nsPresContext* aPresContext,
     return CSSIntPoint(aPoint.x, aPoint.y);
   }
 
-  nsPoint pt =
-    LayoutDevicePixel::ToAppUnits(aPoint, aPresContext->DeviceContext()->AppUnitsPerDevPixelAtUnitFullZoom());
+  nsPoint pt = LayoutDevicePixel::ToAppUnits(
+      aPoint,
+      aPresContext->DeviceContext()->AppUnitsPerDevPixelAtUnitFullZoom());
 
   if (nsIPresShell* ps = aPresContext->GetPresShell()) {
     pt = pt.RemoveResolution(nsLayoutUtils::GetCurrentAPZResolutionScale(ps));
   }
 
-  pt += LayoutDevicePixel::ToAppUnits(guiEvent->mWidget->WidgetToScreenOffset(),
-                                      aPresContext->DeviceContext()->AppUnitsPerDevPixelAtUnitFullZoom());
+  pt += LayoutDevicePixel::ToAppUnits(
+      guiEvent->mWidget->WidgetToScreenOffset(),
+      aPresContext->DeviceContext()->AppUnitsPerDevPixelAtUnitFullZoom());
 
   return CSSPixel::FromAppUnitsRounded(pt);
 }
 
 // static
-CSSIntPoint
-Event::GetPageCoords(nsPresContext* aPresContext,
-                     WidgetEvent* aEvent,
-                     LayoutDeviceIntPoint aPoint,
-                     CSSIntPoint aDefaultPoint)
-{
+CSSIntPoint Event::GetPageCoords(nsPresContext* aPresContext,
+                                 WidgetEvent* aEvent,
+                                 LayoutDeviceIntPoint aPoint,
+                                 CSSIntPoint aDefaultPoint) {
   CSSIntPoint pagePoint =
-    Event::GetClientCoords(aPresContext, aEvent, aPoint, aDefaultPoint);
+      Event::GetClientCoords(aPresContext, aEvent, aPoint, aDefaultPoint);
 
   // If there is some scrolling, add scroll info to client point.
   if (aPresContext && aPresContext->GetPresShell()) {
     nsIPresShell* shell = aPresContext->GetPresShell();
     nsIScrollableFrame* scrollframe = shell->GetRootScrollFrameAsScrollable();
     if (scrollframe) {
-      pagePoint += CSSIntPoint::FromAppUnitsRounded(scrollframe->GetScrollPosition());
+      pagePoint +=
+          CSSIntPoint::FromAppUnitsRounded(scrollframe->GetScrollPosition());
     }
   }
 
@@ -980,12 +896,10 @@ Event::GetPageCoords(nsPresContext* aPresContext,
 }
 
 // static
-CSSIntPoint
-Event::GetClientCoords(nsPresContext* aPresContext,
-                       WidgetEvent* aEvent,
-                       LayoutDeviceIntPoint aPoint,
-                       CSSIntPoint aDefaultPoint)
-{
+CSSIntPoint Event::GetClientCoords(nsPresContext* aPresContext,
+                                   WidgetEvent* aEvent,
+                                   LayoutDeviceIntPoint aPoint,
+                                   CSSIntPoint aDefaultPoint) {
   if (EventStateManager::sIsPointerLocked) {
     return EventStateManager::sLastClientPoint;
   }
@@ -998,8 +912,7 @@ Event::GetClientCoords(nsPresContext* aPresContext,
        aEvent->mClass != eDragEventClass &&
        aEvent->mClass != ePointerEventClass &&
        aEvent->mClass != eSimpleGestureEventClass) ||
-      !aPresContext ||
-      !aEvent->AsGUIEvent()->mWidget) {
+      !aPresContext || !aEvent->AsGUIEvent()->mWidget) {
     return aDefaultPoint;
   }
 
@@ -1012,18 +925,16 @@ Event::GetClientCoords(nsPresContext* aPresContext,
     return CSSIntPoint(0, 0);
   }
   nsPoint pt =
-    nsLayoutUtils::GetEventCoordinatesRelativeTo(aEvent, aPoint, rootFrame);
+      nsLayoutUtils::GetEventCoordinatesRelativeTo(aEvent, aPoint, rootFrame);
 
   return CSSIntPoint::FromAppUnitsRounded(pt);
 }
 
 // static
-CSSIntPoint
-Event::GetOffsetCoords(nsPresContext* aPresContext,
-                       WidgetEvent* aEvent,
-                       LayoutDeviceIntPoint aPoint,
-                       CSSIntPoint aDefaultPoint)
-{
+CSSIntPoint Event::GetOffsetCoords(nsPresContext* aPresContext,
+                                   WidgetEvent* aEvent,
+                                   LayoutDeviceIntPoint aPoint,
+                                   CSSIntPoint aDefaultPoint) {
   if (!aEvent->mTarget) {
     return GetPageCoords(aPresContext, aEvent, aPoint, aDefaultPoint);
   }
@@ -1045,7 +956,7 @@ Event::GetOffsetCoords(nsPresContext* aPresContext,
     return CSSIntPoint(0, 0);
   }
   CSSIntPoint clientCoords =
-    GetClientCoords(aPresContext, aEvent, aPoint, aDefaultPoint);
+      GetClientCoords(aPresContext, aEvent, aPoint, aDefaultPoint);
   nsPoint pt = CSSPixel::ToAppUnits(clientCoords);
   if (nsLayoutUtils::TransformPoint(rootFrame, frame, pt) ==
       nsLayoutUtils::TRANSFORM_SUCCEEDED) {
@@ -1058,16 +969,15 @@ Event::GetOffsetCoords(nsPresContext* aPresContext,
 // To be called ONLY by Event::GetType (which has the additional
 // logic for handling user-defined events).
 // static
-const char*
-Event::GetEventName(EventMessage aEventType)
-{
-  switch(aEventType) {
+const char* Event::GetEventName(EventMessage aEventType) {
+  switch (aEventType) {
 #define MESSAGE_TO_EVENT(name_, _message, _type, _struct) \
-  case _message: return #name_;
+  case _message:                                          \
+    return #name_;
 #include "mozilla/EventNameList.h"
 #undef MESSAGE_TO_EVENT
-  default:
-    break;
+    default:
+      break;
   }
   // XXXldb We can hit this case for WidgetEvent objects that we didn't
   // create and that are not user defined events since this function and
@@ -1077,9 +987,7 @@ Event::GetEventName(EventMessage aEventType)
   return nullptr;
 }
 
-bool
-Event::DefaultPrevented(CallerType aCallerType) const
-{
+bool Event::DefaultPrevented(CallerType aCallerType) const {
   NS_ENSURE_TRUE(mEvent, false);
 
   // If preventDefault() has never been called, just return false.
@@ -1094,9 +1002,7 @@ Event::DefaultPrevented(CallerType aCallerType) const
          aCallerType == CallerType::System;
 }
 
-double
-Event::TimeStamp()
-{
+double Event::TimeStamp() {
   if (!sReturnHighResTimeStamp) {
     // In the situation where you have set a very old, not-very-supported
     // non-default preference, we will always reduce the precision,
@@ -1125,29 +1031,28 @@ Event::TimeStamp()
       return 0.0;
     }
 
-    double ret = perf->GetDOMTiming()->TimeStampToDOMHighRes(mEvent->mTimeStamp);
+    double ret =
+        perf->GetDOMTiming()->TimeStampToDOMHighRes(mEvent->mTimeStamp);
     MOZ_ASSERT(mOwner->PrincipalOrNull());
     if (nsContentUtils::IsSystemPrincipal(mOwner->PrincipalOrNull()))
       return ret;
 
-    return nsRFPService::ReduceTimePrecisionAsMSecs(ret,
-      perf->GetRandomTimelineSeed());
+    return nsRFPService::ReduceTimePrecisionAsMSecs(
+        ret, perf->GetRandomTimelineSeed());
   }
 
   WorkerPrivate* workerPrivate = GetCurrentThreadWorkerPrivate();
   MOZ_ASSERT(workerPrivate);
 
   double ret = workerPrivate->TimeStampToDOMHighRes(mEvent->mTimeStamp);
-  if (workerPrivate->UsesSystemPrincipal())
-    return ret;
+  if (workerPrivate->UsesSystemPrincipal()) return ret;
 
-  return nsRFPService::ReduceTimePrecisionAsMSecs(ret,
-    workerPrivate->GetRandomTimelineSeed());
+  return nsRFPService::ReduceTimePrecisionAsMSecs(
+      ret, workerPrivate->GetRandomTimelineSeed());
 }
 
 NS_IMETHODIMP
-Event::GetDefaultPrevented(bool* aReturn)
-{
+Event::GetDefaultPrevented(bool* aReturn) {
   NS_ENSURE_ARG_POINTER(aReturn);
   // This method must be called by only event handlers implemented by C++.
   // Then, the handlers must handle default action.  So, this method don't need
@@ -1157,8 +1062,7 @@ Event::GetDefaultPrevented(bool* aReturn)
 }
 
 NS_IMETHODIMP_(void)
-Event::Serialize(IPC::Message* aMsg, bool aSerializeInterfaceType)
-{
+Event::Serialize(IPC::Message* aMsg, bool aSerializeInterfaceType) {
   if (aSerializeInterfaceType) {
     IPC::WriteParam(aMsg, NS_LITERAL_STRING("event"));
   }
@@ -1176,8 +1080,7 @@ Event::Serialize(IPC::Message* aMsg, bool aSerializeInterfaceType)
 }
 
 NS_IMETHODIMP_(bool)
-Event::Deserialize(const IPC::Message* aMsg, PickleIterator* aIter)
-{
+Event::Deserialize(const IPC::Message* aMsg, PickleIterator* aIter) {
   nsString type;
   NS_ENSURE_TRUE(IPC::ReadParam(aMsg, aIter, &type), false);
 
@@ -1201,8 +1104,7 @@ Event::Deserialize(const IPC::Message* aMsg, PickleIterator* aIter)
 }
 
 NS_IMETHODIMP_(void)
-Event::SetOwner(EventTarget* aOwner)
-{
+Event::SetOwner(EventTarget* aOwner) {
   mOwner = nullptr;
 
   if (!aOwner) {
@@ -1233,9 +1135,7 @@ Event::SetOwner(EventTarget* aOwner)
 #endif
 }
 
-void
-Event::GetWidgetEventType(WidgetEvent* aEvent, nsAString& aType)
-{
+void Event::GetWidgetEventType(WidgetEvent* aEvent, nsAString& aType) {
   if (!aEvent->mSpecifiedEventTypeString.IsEmpty()) {
     aType = aEvent->mSpecifiedEventTypeString;
     return;
@@ -1258,33 +1158,29 @@ Event::GetWidgetEventType(WidgetEvent* aEvent, nsAString& aType)
 }
 
 NS_IMETHODIMP
-Event::GetCancelBubble(bool* aCancelBubble)
-{
+Event::GetCancelBubble(bool* aCancelBubble) {
   NS_ENSURE_ARG_POINTER(aCancelBubble);
   *aCancelBubble = CancelBubble();
   return NS_OK;
 }
 
 NS_IMETHODIMP
-Event::SetCancelBubble(bool aCancelBubble)
-{
+Event::SetCancelBubble(bool aCancelBubble) {
   if (aCancelBubble) {
     mEvent->StopPropagation();
   }
   return NS_OK;
 }
 
-} // namespace dom
-} // namespace mozilla
+}  // namespace dom
+}  // namespace mozilla
 
 using namespace mozilla;
 using namespace mozilla::dom;
 
-already_AddRefed<Event>
-NS_NewDOMEvent(EventTarget* aOwner,
-               nsPresContext* aPresContext,
-               WidgetEvent* aEvent)
-{
+already_AddRefed<Event> NS_NewDOMEvent(EventTarget* aOwner,
+                                       nsPresContext* aPresContext,
+                                       WidgetEvent* aEvent) {
   RefPtr<Event> it = new Event(aOwner, aPresContext, aEvent);
   return it.forget();
 }
