@@ -55,8 +55,7 @@ NS_IMPL_CYCLE_COLLECTION_UNLINK_BEGIN_INHERITED(FileReader,
   NS_IMPL_CYCLE_COLLECTION_UNLINK(mError)
 NS_IMPL_CYCLE_COLLECTION_UNLINK_END
 
-NS_IMPL_CYCLE_COLLECTION_TRACE_BEGIN_INHERITED(FileReader,
-                                               DOMEventTargetHelper)
+NS_IMPL_CYCLE_COLLECTION_TRACE_BEGIN_INHERITED(FileReader, DOMEventTargetHelper)
   NS_IMPL_CYCLE_COLLECTION_TRACE_JS_MEMBER_CALLBACK(mResultArrayBuffer)
 NS_IMPL_CYCLE_COLLECTION_TRACE_END
 
@@ -70,44 +69,34 @@ NS_INTERFACE_MAP_END_INHERITING(DOMEventTargetHelper)
 NS_IMPL_ADDREF_INHERITED(FileReader, DOMEventTargetHelper)
 NS_IMPL_RELEASE_INHERITED(FileReader, DOMEventTargetHelper)
 
-class MOZ_RAII FileReaderDecreaseBusyCounter
-{
+class MOZ_RAII FileReaderDecreaseBusyCounter {
   RefPtr<FileReader> mFileReader;
-public:
-  explicit FileReaderDecreaseBusyCounter(FileReader* aFileReader)
-    : mFileReader(aFileReader)
-  {}
 
-  ~FileReaderDecreaseBusyCounter()
-  {
-    mFileReader->DecreaseBusyCounter();
-  }
+ public:
+  explicit FileReaderDecreaseBusyCounter(FileReader* aFileReader)
+      : mFileReader(aFileReader) {}
+
+  ~FileReaderDecreaseBusyCounter() { mFileReader->DecreaseBusyCounter(); }
 };
 
-void
-FileReader::RootResultArrayBuffer()
-{
-  mozilla::HoldJSObjects(this);
-}
+void FileReader::RootResultArrayBuffer() { mozilla::HoldJSObjects(this); }
 
-//FileReader constructors/initializers
+// FileReader constructors/initializers
 
-FileReader::FileReader(nsIGlobalObject* aGlobal,
-                       WorkerPrivate* aWorkerPrivate)
-  : DOMEventTargetHelper(aGlobal)
-  , WorkerHolder("FileReader")
-  , mFileData(nullptr)
-  , mDataLen(0)
-  , mDataFormat(FILE_AS_BINARY)
-  , mResultArrayBuffer(nullptr)
-  , mProgressEventWasDelayed(false)
-  , mTimerIsActive(false)
-  , mReadyState(EMPTY)
-  , mTotal(0)
-  , mTransferred(0)
-  , mBusyCount(0)
-  , mWorkerPrivate(aWorkerPrivate)
-{
+FileReader::FileReader(nsIGlobalObject* aGlobal, WorkerPrivate* aWorkerPrivate)
+    : DOMEventTargetHelper(aGlobal),
+      WorkerHolder("FileReader"),
+      mFileData(nullptr),
+      mDataLen(0),
+      mDataFormat(FILE_AS_BINARY),
+      mResultArrayBuffer(nullptr),
+      mProgressEventWasDelayed(false),
+      mTimerIsActive(false),
+      mReadyState(EMPTY),
+      mTotal(0),
+      mTransferred(0),
+      mBusyCount(0),
+      mWorkerPrivate(aWorkerPrivate) {
   MOZ_ASSERT(aGlobal);
   MOZ_ASSERT(NS_IsMainThread() == !mWorkerPrivate);
 
@@ -120,15 +109,13 @@ FileReader::FileReader(nsIGlobalObject* aGlobal,
   SetDOMStringToNull(mResult);
 }
 
-FileReader::~FileReader()
-{
+FileReader::~FileReader() {
   Shutdown();
   DropJSObjects(this);
 }
 
-/* static */ already_AddRefed<FileReader>
-FileReader::Constructor(const GlobalObject& aGlobal, ErrorResult& aRv)
-{
+/* static */ already_AddRefed<FileReader> FileReader::Constructor(
+    const GlobalObject& aGlobal, ErrorResult& aRv) {
   nsCOMPtr<nsIGlobalObject> global = do_QueryInterface(aGlobal.GetAsSupports());
   WorkerPrivate* workerPrivate = nullptr;
 
@@ -146,16 +133,12 @@ FileReader::Constructor(const GlobalObject& aGlobal, ErrorResult& aRv)
 // nsIInterfaceRequestor
 
 NS_IMETHODIMP
-FileReader::GetInterface(const nsIID & aIID, void **aResult)
-{
+FileReader::GetInterface(const nsIID& aIID, void** aResult) {
   return QueryInterface(aIID, aResult);
 }
 
-void
-FileReader::GetResult(JSContext* aCx,
-                      JS::MutableHandle<JS::Value> aResult,
-                      ErrorResult& aRv)
-{
+void FileReader::GetResult(JSContext* aCx, JS::MutableHandle<JS::Value> aResult,
+                           ErrorResult& aRv) {
   JS::Rooted<JS::Value> result(aCx);
 
   if (mDataFormat == FILE_AS_ARRAYBUFFER) {
@@ -181,9 +164,7 @@ FileReader::GetResult(JSContext* aCx,
   }
 }
 
-void
-FileReader::OnLoadEndArrayBuffer()
-{
+void FileReader::OnLoadEndArrayBuffer() {
   AutoJSAPI jsapi;
   if (!jsapi.Init(GetParentObject())) {
     FreeDataAndDispatchError(NS_ERROR_FAILURE);
@@ -196,7 +177,7 @@ FileReader::OnLoadEndArrayBuffer()
 
   mResultArrayBuffer = JS_NewArrayBufferWithContents(cx, mDataLen, mFileData);
   if (mResultArrayBuffer) {
-    mFileData = nullptr; // Transfer ownership
+    mFileData = nullptr;  // Transfer ownership
     FreeDataAndDispatchSuccess();
     return;
   }
@@ -230,16 +211,13 @@ FileReader::OnLoadEndArrayBuffer()
   nsAutoCString errorMsg(er->message().c_str());
   nsAutoCString errorNameC = NS_LossyConvertUTF16toASCII(errorName);
   // XXX Code selected arbitrarily
-  mError =
-    new DOMException(NS_ERROR_DOM_INVALID_STATE_ERR, errorMsg,
-                     errorNameC, DOMException::INVALID_STATE_ERR);
+  mError = new DOMException(NS_ERROR_DOM_INVALID_STATE_ERR, errorMsg,
+                            errorNameC, DOMException::INVALID_STATE_ERR);
 
   FreeDataAndDispatchError();
 }
 
-nsresult
-FileReader::DoAsyncWait()
-{
+nsresult FileReader::DoAsyncWait() {
   nsresult rv = IncreaseBusyCounter();
   if (NS_WARN_IF(NS_FAILED(rv))) {
     return rv;
@@ -247,8 +225,7 @@ FileReader::DoAsyncWait()
 
   rv = mAsyncStream->AsyncWait(this,
                                /* aFlags*/ 0,
-                               /* aRequestedCount */ 0,
-                               mTarget);
+                               /* aRequestedCount */ 0, mTarget);
   if (NS_WARN_IF(NS_FAILED(rv))) {
     DecreaseBusyCounter();
     return rv;
@@ -259,10 +236,8 @@ FileReader::DoAsyncWait()
 
 namespace {
 
-void
-PopulateBufferForBinaryString(char16_t* aDest, const char* aSource,
-                              uint32_t aCount)
-{
+void PopulateBufferForBinaryString(char16_t* aDest, const char* aSource,
+                                   uint32_t aCount) {
   const unsigned char* source = (const unsigned char*)aSource;
   char16_t* end = aDest + aCount;
   while (aDest != end) {
@@ -272,37 +247,28 @@ PopulateBufferForBinaryString(char16_t* aDest, const char* aSource,
   }
 }
 
-nsresult
-ReadFuncBinaryString(nsIInputStream* aInputStream,
-                     void* aClosure,
-                     const char* aFromRawSegment,
-                     uint32_t aToOffset,
-                     uint32_t aCount,
-                     uint32_t* aWriteCount)
-{
+nsresult ReadFuncBinaryString(nsIInputStream* aInputStream, void* aClosure,
+                              const char* aFromRawSegment, uint32_t aToOffset,
+                              uint32_t aCount, uint32_t* aWriteCount) {
   char16_t* dest = static_cast<char16_t*>(aClosure) + aToOffset;
   PopulateBufferForBinaryString(dest, aFromRawSegment, aCount);
   *aWriteCount = aCount;
   return NS_OK;
 }
 
-} // anonymous
+}  // namespace
 
-nsresult
-FileReader::DoReadData(uint64_t aCount)
-{
+nsresult FileReader::DoReadData(uint64_t aCount) {
   MOZ_ASSERT(mAsyncStream);
 
   uint32_t bytesRead = 0;
 
   if (mDataFormat == FILE_AS_BINARY) {
-    //Continuously update our binary string as data comes in
+    // Continuously update our binary string as data comes in
     CheckedInt<uint64_t> size = mResult.Length();
     size += aCount;
 
-    if (!size.isValid() ||
-        size.value() > UINT32_MAX ||
-        size.value() > mTotal) {
+    if (!size.isValid() || size.value() > UINT32_MAX || size.value() > mTotal) {
       return NS_ERROR_OUT_OF_MEMORY;
     }
 
@@ -323,7 +289,7 @@ FileReader::DoReadData(uint64_t aCount)
       while (aCount > 0) {
         char tmpBuffer[4096];
         uint32_t minCount =
-          XPCOM_MIN(aCount, static_cast<uint64_t>(sizeof(tmpBuffer)));
+            XPCOM_MIN(aCount, static_cast<uint64_t>(sizeof(tmpBuffer)));
         uint32_t read;
 
         nsresult rv = mAsyncStream->Read(tmpBuffer, minCount, &read);
@@ -348,18 +314,16 @@ FileReader::DoReadData(uint64_t aCount)
 
     MOZ_ASSERT(size.value() == oldLen + bytesRead);
     mResult.Truncate(size.value());
-  }
-  else {
+  } else {
     CheckedInt<uint64_t> size = mDataLen;
     size += aCount;
 
-    //Update memory buffer to reflect the contents of the file
+    // Update memory buffer to reflect the contents of the file
     if (!size.isValid() ||
         // PR_Realloc doesn't support over 4GB memory size even if 64-bit OS
         // XXX: it's likely that this check is unnecessary and the comment is
         // wrong because we no longer use PR_Realloc outside of NSPR and NSS.
-        size.value() > UINT32_MAX ||
-        size.value() > mTotal) {
+        size.value() > UINT32_MAX || size.value() > mTotal) {
       return NS_ERROR_OUT_OF_MEMORY;
     }
 
@@ -378,12 +342,8 @@ FileReader::DoReadData(uint64_t aCount)
 
 // Helper methods
 
-void
-FileReader::ReadFileContent(Blob& aBlob,
-                            const nsAString &aCharset,
-                            eDataFormat aDataFormat,
-                            ErrorResult& aRv)
-{
+void FileReader::ReadFileContent(Blob& aBlob, const nsAString& aCharset,
+                                 eDataFormat aDataFormat, ErrorResult& aRv) {
   if (mReadyState == LOADING) {
     aRv.Throw(NS_ERROR_DOM_INVALID_STATE_ERR);
     return;
@@ -432,7 +392,7 @@ FileReader::ReadFileContent(Blob& aBlob,
     if (mDataFormat == FILE_AS_ARRAYBUFFER) {
       mFileData = js_pod_malloc<char>(mTotal);
     } else {
-      mFileData = (char *) malloc(mTotal);
+      mFileData = (char*)malloc(mTotal);
     }
 
     if (!mFileData) {
@@ -448,18 +408,14 @@ FileReader::ReadFileContent(Blob& aBlob,
     return;
   }
 
-  //FileReader should be in loading state here
+  // FileReader should be in loading state here
   mReadyState = LOADING;
   DispatchProgressEvent(NS_LITERAL_STRING(LOADSTART_STR));
 }
 
-nsresult
-FileReader::GetAsText(Blob *aBlob,
-                      const nsACString &aCharset,
-                      const char *aFileData,
-                      uint32_t aDataLen,
-                      nsAString& aResult)
-{
+nsresult FileReader::GetAsText(Blob* aBlob, const nsACString& aCharset,
+                               const char* aFileData, uint32_t aDataLen,
+                               nsAString& aResult) {
   // Try the API argument.
   const Encoding* encoding = Encoding::ForLabel(aCharset);
   if (!encoding) {
@@ -470,11 +426,8 @@ FileReader::GetAsText(Blob *aBlob,
     nsAutoCString specifiedCharset;
     bool haveCharset;
     int32_t charsetStart, charsetEnd;
-    NS_ExtractCharsetFromContentType(type,
-                                     specifiedCharset,
-                                     &haveCharset,
-                                     &charsetStart,
-                                     &charsetEnd);
+    NS_ExtractCharsetFromContentType(type, specifiedCharset, &haveCharset,
+                                     &charsetStart, &charsetEnd);
     encoding = Encoding::ForLabel(specifiedCharset);
     if (!encoding) {
       // Type property failed. Use UTF-8.
@@ -482,19 +435,14 @@ FileReader::GetAsText(Blob *aBlob,
     }
   }
 
-  auto data = MakeSpan(reinterpret_cast<const uint8_t*>(aFileData),
-                       aDataLen);
+  auto data = MakeSpan(reinterpret_cast<const uint8_t*>(aFileData), aDataLen);
   nsresult rv;
   Tie(rv, encoding) = encoding->Decode(data, aResult);
   return NS_FAILED(rv) ? rv : NS_OK;
 }
 
-nsresult
-FileReader::GetAsDataURL(Blob *aBlob,
-                         const char *aFileData,
-                         uint32_t aDataLen,
-                         nsAString& aResult)
-{
+nsresult FileReader::GetAsDataURL(Blob* aBlob, const char* aFileData,
+                                  uint32_t aDataLen, nsAString& aResult) {
   aResult.AssignLiteral("data:");
 
   nsAutoString contentType;
@@ -517,15 +465,12 @@ FileReader::GetAsDataURL(Blob *aBlob,
   return NS_OK;
 }
 
-/* virtual */ JSObject*
-FileReader::WrapObject(JSContext* aCx, JS::Handle<JSObject*> aGivenProto)
-{
+/* virtual */ JSObject* FileReader::WrapObject(
+    JSContext* aCx, JS::Handle<JSObject*> aGivenProto) {
   return FileReaderBinding::Wrap(aCx, this, aGivenProto);
 }
 
-void
-FileReader::StartProgressEventTimer()
-{
+void FileReader::StartProgressEventTimer() {
   if (!mProgressNotifier) {
     mProgressNotifier = NS_NewTimer();
   }
@@ -540,9 +485,7 @@ FileReader::StartProgressEventTimer()
   }
 }
 
-void
-FileReader::ClearProgressEventTimer()
-{
+void FileReader::ClearProgressEventTimer() {
   mProgressEventWasDelayed = false;
   mTimerIsActive = false;
   if (mProgressNotifier) {
@@ -550,9 +493,7 @@ FileReader::ClearProgressEventTimer()
   }
 }
 
-void
-FileReader::FreeDataAndDispatchSuccess()
-{
+void FileReader::FreeDataAndDispatchSuccess() {
   FreeFileData();
   mResult.SetIsVoid(false);
   mAsyncStream = nullptr;
@@ -563,9 +504,7 @@ FileReader::FreeDataAndDispatchSuccess()
   DispatchProgressEvent(NS_LITERAL_STRING(LOADEND_STR));
 }
 
-void
-FileReader::FreeDataAndDispatchError()
-{
+void FileReader::FreeDataAndDispatchError() {
   MOZ_ASSERT(mError);
 
   FreeFileData();
@@ -578,28 +517,24 @@ FileReader::FreeDataAndDispatchError()
   DispatchProgressEvent(NS_LITERAL_STRING(LOADEND_STR));
 }
 
-void
-FileReader::FreeDataAndDispatchError(nsresult aRv)
-{
+void FileReader::FreeDataAndDispatchError(nsresult aRv) {
   // Set the status attribute, and dispatch the error event
   switch (aRv) {
-  case NS_ERROR_FILE_NOT_FOUND:
-    mError = DOMException::Create(NS_ERROR_DOM_NOT_FOUND_ERR);
-    break;
-  case NS_ERROR_FILE_ACCESS_DENIED:
-    mError = DOMException::Create(NS_ERROR_DOM_SECURITY_ERR);
-    break;
-  default:
-    mError = DOMException::Create(NS_ERROR_DOM_FILE_NOT_READABLE_ERR);
-    break;
+    case NS_ERROR_FILE_NOT_FOUND:
+      mError = DOMException::Create(NS_ERROR_DOM_NOT_FOUND_ERR);
+      break;
+    case NS_ERROR_FILE_ACCESS_DENIED:
+      mError = DOMException::Create(NS_ERROR_DOM_SECURITY_ERR);
+      break;
+    default:
+      mError = DOMException::Create(NS_ERROR_DOM_FILE_NOT_READABLE_ERR);
+      break;
   }
 
   FreeDataAndDispatchError();
 }
 
-nsresult
-FileReader::DispatchProgressEvent(const nsAString& aType)
-{
+nsresult FileReader::DispatchProgressEvent(const nsAString& aType) {
   ProgressEventInit init;
   init.mBubbles = false;
   init.mCancelable = false;
@@ -612,8 +547,7 @@ FileReader::DispatchProgressEvent(const nsAString& aType)
     init.mLengthComputable = false;
     init.mTotal = 0;
   }
-  RefPtr<ProgressEvent> event =
-    ProgressEvent::Constructor(this, aType, init);
+  RefPtr<ProgressEvent> event = ProgressEvent::Constructor(this, aType, init);
   event->SetTrusted(true);
 
   bool dummy;
@@ -622,8 +556,7 @@ FileReader::DispatchProgressEvent(const nsAString& aType)
 
 // nsITimerCallback
 NS_IMETHODIMP
-FileReader::Notify(nsITimer* aTimer)
-{
+FileReader::Notify(nsITimer* aTimer) {
   nsresult rv;
   mTimerIsActive = false;
 
@@ -639,8 +572,7 @@ FileReader::Notify(nsITimer* aTimer)
 
 // InputStreamCallback
 NS_IMETHODIMP
-FileReader::OnInputStreamReady(nsIAsyncInputStream* aStream)
-{
+FileReader::OnInputStreamReady(nsIAsyncInputStream* aStream) {
   if (mReadyState != LOADING || aStream != mAsyncStream) {
     return NS_OK;
   }
@@ -670,7 +602,7 @@ FileReader::OnInputStreamReady(nsIAsyncInputStream* aStream)
 
   mTransferred += count;
 
-  //Notify the timer is the appropriate timeframe has passed
+  // Notify the timer is the appropriate timeframe has passed
   if (mTimerIsActive) {
     mProgressEventWasDelayed = true;
   } else {
@@ -685,15 +617,12 @@ FileReader::OnInputStreamReady(nsIAsyncInputStream* aStream)
 
 // nsINamed
 NS_IMETHODIMP
-FileReader::GetName(nsACString& aName)
-{
+FileReader::GetName(nsACString& aName) {
   aName.AssignLiteral("FileReader");
   return NS_OK;
 }
 
-nsresult
-FileReader::OnLoadEnd(nsresult aStatus)
-{
+nsresult FileReader::OnLoadEnd(nsresult aStatus) {
   // Cancel the progress event timer
   ClearProgressEventTimer();
 
@@ -744,9 +673,7 @@ FileReader::OnLoadEnd(nsresult aStatus)
   return NS_OK;
 }
 
-void
-FileReader::Abort()
-{
+void FileReader::Abort() {
   if (mReadyState == EMPTY || mReadyState == DONE) {
     return;
   }
@@ -767,7 +694,7 @@ FileReader::Abort()
   mAsyncStream = nullptr;
   mBlob = nullptr;
 
-  //Clean up memory buffer
+  // Clean up memory buffer
   FreeFileData();
 
   // Dispatch the events
@@ -775,9 +702,7 @@ FileReader::Abort()
   DispatchProgressEvent(NS_LITERAL_STRING(LOADEND_STR));
 }
 
-nsresult
-FileReader::IncreaseBusyCounter()
-{
+nsresult FileReader::IncreaseBusyCounter() {
   if (mWorkerPrivate && mBusyCount++ == 0 &&
       !HoldWorker(mWorkerPrivate, Closing)) {
     return NS_ERROR_FAILURE;
@@ -786,18 +711,14 @@ FileReader::IncreaseBusyCounter()
   return NS_OK;
 }
 
-void
-FileReader::DecreaseBusyCounter()
-{
+void FileReader::DecreaseBusyCounter() {
   MOZ_ASSERT_IF(mWorkerPrivate, mBusyCount);
   if (mWorkerPrivate && --mBusyCount == 0) {
     ReleaseWorker();
   }
 }
 
-bool
-FileReader::Notify(WorkerStatus aStatus)
-{
+bool FileReader::Notify(WorkerStatus aStatus) {
   MOZ_ASSERT(mWorkerPrivate);
   mWorkerPrivate->AssertIsOnWorkerThread();
 
@@ -808,9 +729,7 @@ FileReader::Notify(WorkerStatus aStatus)
   return true;
 }
 
-void
-FileReader::Shutdown()
-{
+void FileReader::Shutdown() {
   mReadyState = DONE;
 
   if (mAsyncStream) {
@@ -828,5 +747,5 @@ FileReader::Shutdown()
   }
 }
 
-} // dom namespace
-} // mozilla namespace
+}  // dom namespace
+}  // namespace mozilla
