@@ -22,20 +22,17 @@ namespace dom {
 
 namespace {
 
-class InputStreamCallbackRunnable final : public CancelableRunnable
-{
-public:
+class InputStreamCallbackRunnable final : public CancelableRunnable {
+ public:
   // Note that the execution can be synchronous in case the event target is
   // null.
-  static void
-  Execute(nsIInputStreamCallback* aCallback,
-          nsIEventTarget* aEventTarget,
-          IPCBlobInputStream* aStream)
-  {
+  static void Execute(nsIInputStreamCallback* aCallback,
+                      nsIEventTarget* aEventTarget,
+                      IPCBlobInputStream* aStream) {
     MOZ_ASSERT(aCallback);
 
     RefPtr<InputStreamCallbackRunnable> runnable =
-      new InputStreamCallbackRunnable(aCallback, aStream);
+        new InputStreamCallbackRunnable(aCallback, aStream);
 
     nsCOMPtr<nsIEventTarget> target = aEventTarget;
     if (aEventTarget) {
@@ -46,21 +43,19 @@ public:
   }
 
   NS_IMETHOD
-  Run() override
-  {
+  Run() override {
     mCallback->OnInputStreamReady(mStream);
     mCallback = nullptr;
     mStream = nullptr;
     return NS_OK;
   }
 
-private:
+ private:
   InputStreamCallbackRunnable(nsIInputStreamCallback* aCallback,
                               IPCBlobInputStream* aStream)
-    : CancelableRunnable("dom::InputStreamCallbackRunnable")
-    , mCallback(aCallback)
-    , mStream(aStream)
-  {
+      : CancelableRunnable("dom::InputStreamCallbackRunnable"),
+        mCallback(aCallback),
+        mStream(aStream) {
     MOZ_ASSERT(mCallback);
     MOZ_ASSERT(mStream);
   }
@@ -69,40 +64,35 @@ private:
   RefPtr<IPCBlobInputStream> mStream;
 };
 
-class FileMetadataCallbackRunnable final : public CancelableRunnable
-{
-public:
-  static void
-  Execute(nsIFileMetadataCallback* aCallback,
-          nsIEventTarget* aEventTarget,
-          IPCBlobInputStream* aStream)
-  {
+class FileMetadataCallbackRunnable final : public CancelableRunnable {
+ public:
+  static void Execute(nsIFileMetadataCallback* aCallback,
+                      nsIEventTarget* aEventTarget,
+                      IPCBlobInputStream* aStream) {
     MOZ_ASSERT(aCallback);
     MOZ_ASSERT(aEventTarget);
 
     RefPtr<FileMetadataCallbackRunnable> runnable =
-      new FileMetadataCallbackRunnable(aCallback, aStream);
+        new FileMetadataCallbackRunnable(aCallback, aStream);
 
     nsCOMPtr<nsIEventTarget> target = aEventTarget;
     target->Dispatch(runnable, NS_DISPATCH_NORMAL);
   }
 
   NS_IMETHOD
-  Run() override
-  {
+  Run() override {
     mCallback->OnFileMetadataReady(mStream);
     mCallback = nullptr;
     mStream = nullptr;
     return NS_OK;
   }
 
-private:
+ private:
   FileMetadataCallbackRunnable(nsIFileMetadataCallback* aCallback,
                                IPCBlobInputStream* aStream)
-    : CancelableRunnable("dom::FileMetadataCallbackRunnable")
-    , mCallback(aCallback)
-    , mStream(aStream)
-  {
+      : CancelableRunnable("dom::FileMetadataCallbackRunnable"),
+        mCallback(aCallback),
+        mStream(aStream) {
     MOZ_ASSERT(mCallback);
     MOZ_ASSERT(mStream);
   }
@@ -111,7 +101,7 @@ private:
   RefPtr<IPCBlobInputStream> mStream;
 };
 
-} // anonymous
+}  // namespace
 
 NS_IMPL_ADDREF(IPCBlobInputStream);
 NS_IMPL_RELEASE(IPCBlobInputStream);
@@ -129,19 +119,14 @@ NS_INTERFACE_MAP_BEGIN(IPCBlobInputStream)
 NS_INTERFACE_MAP_END
 
 IPCBlobInputStream::IPCBlobInputStream(IPCBlobInputStreamChild* aActor)
-  : mActor(aActor)
-  , mState(eInit)
-  , mStart(0)
-  , mLength(0)
-{
+    : mActor(aActor), mState(eInit), mStart(0), mLength(0) {
   MOZ_ASSERT(aActor);
 
   mLength = aActor->Size();
 
   if (XRE_IsParentProcess()) {
     nsCOMPtr<nsIInputStream> stream;
-    IPCBlobInputStreamStorage::Get()->GetStream(mActor->ID(),
-                                                0, mLength,
+    IPCBlobInputStreamStorage::Get()->GetStream(mActor->ID(), 0, mLength,
                                                 getter_AddRefs(stream));
     if (stream) {
       mState = eRunning;
@@ -150,16 +135,12 @@ IPCBlobInputStream::IPCBlobInputStream(IPCBlobInputStreamChild* aActor)
   }
 }
 
-IPCBlobInputStream::~IPCBlobInputStream()
-{
-  Close();
-}
+IPCBlobInputStream::~IPCBlobInputStream() { Close(); }
 
 // nsIInputStream interface
 
 NS_IMETHODIMP
-IPCBlobInputStream::Available(uint64_t* aLength)
-{
+IPCBlobInputStream::Available(uint64_t* aLength) {
   // We don't have a remoteStream yet: let's return 0.
   if (mState == eInit || mState == ePending) {
     *aLength = 0;
@@ -183,8 +164,7 @@ IPCBlobInputStream::Available(uint64_t* aLength)
 }
 
 NS_IMETHODIMP
-IPCBlobInputStream::Read(char* aBuffer, uint32_t aCount, uint32_t* aReadCount)
-{
+IPCBlobInputStream::Read(char* aBuffer, uint32_t aCount, uint32_t* aReadCount) {
   // Read is not available is we don't have a remoteStream.
   if (mState == eInit || mState == ePending) {
     return NS_BASE_STREAM_WOULD_BLOCK;
@@ -208,8 +188,7 @@ IPCBlobInputStream::Read(char* aBuffer, uint32_t aCount, uint32_t* aReadCount)
 
 NS_IMETHODIMP
 IPCBlobInputStream::ReadSegments(nsWriteSegmentFun aWriter, void* aClosure,
-                                 uint32_t aCount, uint32_t *aResult)
-{
+                                 uint32_t aCount, uint32_t* aResult) {
   // ReadSegments is not available is we don't have a remoteStream.
   if (mState == eInit || mState == ePending) {
     return NS_BASE_STREAM_WOULD_BLOCK;
@@ -232,15 +211,13 @@ IPCBlobInputStream::ReadSegments(nsWriteSegmentFun aWriter, void* aClosure,
 }
 
 NS_IMETHODIMP
-IPCBlobInputStream::IsNonBlocking(bool* aNonBlocking)
-{
+IPCBlobInputStream::IsNonBlocking(bool* aNonBlocking) {
   *aNonBlocking = true;
   return NS_OK;
 }
 
 NS_IMETHODIMP
-IPCBlobInputStream::Close()
-{
+IPCBlobInputStream::Close() {
   if (mActor) {
     mActor->ForgetStream(this);
     mActor = nullptr;
@@ -269,15 +246,13 @@ IPCBlobInputStream::Close()
 // nsICloneableInputStream interface
 
 NS_IMETHODIMP
-IPCBlobInputStream::GetCloneable(bool* aCloneable)
-{
+IPCBlobInputStream::GetCloneable(bool* aCloneable) {
   *aCloneable = mState != eClosed;
   return NS_OK;
 }
 
 NS_IMETHODIMP
-IPCBlobInputStream::Clone(nsIInputStream** aResult)
-{
+IPCBlobInputStream::Clone(nsIInputStream** aResult) {
   if (mState == eClosed) {
     return NS_BASE_STREAM_CLOSED;
   }
@@ -299,8 +274,7 @@ IPCBlobInputStream::Clone(nsIInputStream** aResult)
 
 NS_IMETHODIMP
 IPCBlobInputStream::CloneWithRange(uint64_t aStart, uint64_t aLength,
-                                   nsIInputStream** aResult)
-{
+                                   nsIInputStream** aResult) {
   if (mState == eClosed) {
     return NS_BASE_STREAM_CLOSED;
   }
@@ -336,54 +310,50 @@ IPCBlobInputStream::CloneWithRange(uint64_t aStart, uint64_t aLength,
 // nsIAsyncInputStream interface
 
 NS_IMETHODIMP
-IPCBlobInputStream::CloseWithStatus(nsresult aStatus)
-{
-  return Close();
-}
+IPCBlobInputStream::CloseWithStatus(nsresult aStatus) { return Close(); }
 
 NS_IMETHODIMP
 IPCBlobInputStream::AsyncWait(nsIInputStreamCallback* aCallback,
                               uint32_t aFlags, uint32_t aRequestedCount,
-                              nsIEventTarget* aEventTarget)
-{
+                              nsIEventTarget* aEventTarget) {
   // See IPCBlobInputStream.h for more information about this state machine.
 
   switch (mState) {
-  // First call, we need to retrieve the stream from the parent actor.
-  case eInit:
-    MOZ_ASSERT(mActor);
+    // First call, we need to retrieve the stream from the parent actor.
+    case eInit:
+      MOZ_ASSERT(mActor);
 
-    mInputStreamCallback = aCallback;
-    mInputStreamCallbackEventTarget = aEventTarget;
-    mState = ePending;
+      mInputStreamCallback = aCallback;
+      mInputStreamCallbackEventTarget = aEventTarget;
+      mState = ePending;
 
-    mActor->StreamNeeded(this, aEventTarget);
-    return NS_OK;
+      mActor->StreamNeeded(this, aEventTarget);
+      return NS_OK;
 
-  // We are still waiting for the remote inputStream
-  case ePending:
-    if (mInputStreamCallback && aCallback) {
-      return NS_ERROR_FAILURE;
-    }
+    // We are still waiting for the remote inputStream
+    case ePending:
+      if (mInputStreamCallback && aCallback) {
+        return NS_ERROR_FAILURE;
+      }
 
-    mInputStreamCallback = aCallback;
-    mInputStreamCallbackEventTarget = aEventTarget;
-    return NS_OK;
+      mInputStreamCallback = aCallback;
+      mInputStreamCallbackEventTarget = aEventTarget;
+      return NS_OK;
 
-  // We have the remote inputStream, let's check if we can execute the callback.
-  case eRunning:
-    return MaybeExecuteInputStreamCallback(aCallback, aEventTarget);
+    // We have the remote inputStream, let's check if we can execute the
+    // callback.
+    case eRunning:
+      return MaybeExecuteInputStreamCallback(aCallback, aEventTarget);
 
-  // Stream is closed.
-  default:
-    MOZ_ASSERT(mState == eClosed);
-    return NS_BASE_STREAM_CLOSED;
+    // Stream is closed.
+    default:
+      MOZ_ASSERT(mState == eClosed);
+      return NS_BASE_STREAM_CLOSED;
   }
 }
 
-void
-IPCBlobInputStream::StreamReady(already_AddRefed<nsIInputStream> aInputStream)
-{
+void IPCBlobInputStream::StreamReady(
+    already_AddRefed<nsIInputStream> aInputStream) {
   nsCOMPtr<nsIInputStream> inputStream = Move(aInputStream);
 
   // We have been closed in the meantime.
@@ -404,8 +374,7 @@ IPCBlobInputStream::StreamReady(already_AddRefed<nsIInputStream> aInputStream)
 
   // Now it's the right time to apply a slice if needed.
   if (mStart > 0 || mLength < mActor->Size()) {
-    inputStream =
-      new SlicedInputStream(inputStream.forget(), mStart, mLength);
+    inputStream = new SlicedInputStream(inputStream.forget(), mStart, mLength);
   }
 
   mRemoteStream = inputStream;
@@ -420,9 +389,8 @@ IPCBlobInputStream::StreamReady(already_AddRefed<nsIInputStream> aInputStream)
   fileMetadataCallbackEventTarget.swap(mFileMetadataCallbackEventTarget);
 
   if (fileMetadataCallback) {
-    FileMetadataCallbackRunnable::Execute(fileMetadataCallback,
-                                          fileMetadataCallbackEventTarget,
-                                          this);
+    FileMetadataCallbackRunnable::Execute(
+        fileMetadataCallback, fileMetadataCallbackEventTarget, this);
   }
 
   nsCOMPtr<nsIInputStreamCallback> inputStreamCallback;
@@ -437,10 +405,8 @@ IPCBlobInputStream::StreamReady(already_AddRefed<nsIInputStream> aInputStream)
   }
 }
 
-nsresult
-IPCBlobInputStream::MaybeExecuteInputStreamCallback(nsIInputStreamCallback* aCallback,
-                                                    nsIEventTarget* aCallbackEventTarget)
-{
+nsresult IPCBlobInputStream::MaybeExecuteInputStreamCallback(
+    nsIInputStreamCallback* aCallback, nsIEventTarget* aCallbackEventTarget) {
   MOZ_ASSERT(mState == eRunning);
   MOZ_ASSERT(mRemoteStream || mAsyncRemoteStream);
 
@@ -466,9 +432,8 @@ IPCBlobInputStream::MaybeExecuteInputStreamCallback(nsIInputStreamCallback* aCal
   return mAsyncRemoteStream->AsyncWait(this, 0, 0, aCallbackEventTarget);
 }
 
-void
-IPCBlobInputStream::InitWithExistingRange(uint64_t aStart, uint64_t aLength)
-{
+void IPCBlobInputStream::InitWithExistingRange(uint64_t aStart,
+                                               uint64_t aLength) {
   MOZ_ASSERT(mActor->Size() >= aStart + aLength);
   mStart = aStart;
   mLength = aLength;
@@ -480,15 +445,14 @@ IPCBlobInputStream::InitWithExistingRange(uint64_t aStart, uint64_t aLength)
   if (mState == eRunning && mRemoteStream && XRE_IsParentProcess() &&
       (mStart > 0 || mLength < mActor->Size())) {
     mRemoteStream =
-      new SlicedInputStream(mRemoteStream.forget(), mStart, mLength);
+        new SlicedInputStream(mRemoteStream.forget(), mStart, mLength);
   }
 }
 
 // nsIInputStreamCallback
 
 NS_IMETHODIMP
-IPCBlobInputStream::OnInputStreamReady(nsIAsyncInputStream* aStream)
-{
+IPCBlobInputStream::OnInputStreamReady(nsIAsyncInputStream* aStream) {
   // We have been closed in the meantime.
   if (mState == eClosed) {
     return NS_OK;
@@ -516,10 +480,8 @@ IPCBlobInputStream::OnInputStreamReady(nsIAsyncInputStream* aStream)
 
 // nsIIPCSerializableInputStream
 
-void
-IPCBlobInputStream::Serialize(mozilla::ipc::InputStreamParams& aParams,
-                              FileDescriptorArray& aFileDescriptors)
-{
+void IPCBlobInputStream::Serialize(mozilla::ipc::InputStreamParams& aParams,
+                                   FileDescriptorArray& aFileDescriptors) {
   mozilla::ipc::IPCBlobInputStreamParams params;
   params.id() = mActor->ID();
   params.start() = mStart;
@@ -528,17 +490,14 @@ IPCBlobInputStream::Serialize(mozilla::ipc::InputStreamParams& aParams,
   aParams = params;
 }
 
-bool
-IPCBlobInputStream::Deserialize(const mozilla::ipc::InputStreamParams& aParams,
-                                const FileDescriptorArray& aFileDescriptors)
-{
+bool IPCBlobInputStream::Deserialize(
+    const mozilla::ipc::InputStreamParams& aParams,
+    const FileDescriptorArray& aFileDescriptors) {
   MOZ_CRASH("This should never be called.");
   return false;
 }
 
-mozilla::Maybe<uint64_t>
-IPCBlobInputStream::ExpectedSerializedLength()
-{
+mozilla::Maybe<uint64_t> IPCBlobInputStream::ExpectedSerializedLength() {
   return mozilla::Nothing();
 }
 
@@ -546,8 +505,7 @@ IPCBlobInputStream::ExpectedSerializedLength()
 
 NS_IMETHODIMP
 IPCBlobInputStream::AsyncWait(nsIFileMetadataCallback* aCallback,
-                              nsIEventTarget* aEventTarget)
-{
+                              nsIEventTarget* aEventTarget) {
   MOZ_ASSERT(!!aCallback == !!aEventTarget);
 
   // If we have the callback, we must have the event target.
@@ -558,44 +516,44 @@ IPCBlobInputStream::AsyncWait(nsIFileMetadataCallback* aCallback,
   // See IPCBlobInputStream.h for more information about this state machine.
 
   switch (mState) {
-  // First call, we need to retrieve the stream from the parent actor.
-  case eInit:
-    MOZ_ASSERT(mActor);
+    // First call, we need to retrieve the stream from the parent actor.
+    case eInit:
+      MOZ_ASSERT(mActor);
 
-    mFileMetadataCallback = aCallback;
-    mFileMetadataCallbackEventTarget = aEventTarget;
-    mState = ePending;
+      mFileMetadataCallback = aCallback;
+      mFileMetadataCallbackEventTarget = aEventTarget;
+      mState = ePending;
 
-    mActor->StreamNeeded(this, aEventTarget);
-    return NS_OK;
+      mActor->StreamNeeded(this, aEventTarget);
+      return NS_OK;
 
-  // We are still waiting for the remote inputStream
-  case ePending:
-    if (mFileMetadataCallback && aCallback) {
-      return NS_ERROR_FAILURE;
-    }
+    // We are still waiting for the remote inputStream
+    case ePending:
+      if (mFileMetadataCallback && aCallback) {
+        return NS_ERROR_FAILURE;
+      }
 
-    mFileMetadataCallback = aCallback;
-    mFileMetadataCallbackEventTarget = aEventTarget;
-    return NS_OK;
+      mFileMetadataCallback = aCallback;
+      mFileMetadataCallbackEventTarget = aEventTarget;
+      return NS_OK;
 
-  // We have the remote inputStream, let's check if we can execute the callback.
-  case eRunning:
-    FileMetadataCallbackRunnable::Execute(aCallback, aEventTarget, this);
-    return NS_OK;
+    // We have the remote inputStream, let's check if we can execute the
+    // callback.
+    case eRunning:
+      FileMetadataCallbackRunnable::Execute(aCallback, aEventTarget, this);
+      return NS_OK;
 
-  // Stream is closed.
-  default:
-    MOZ_ASSERT(mState == eClosed);
-    return NS_BASE_STREAM_CLOSED;
+    // Stream is closed.
+    default:
+      MOZ_ASSERT(mState == eClosed);
+      return NS_BASE_STREAM_CLOSED;
   }
 }
 
 // nsIFileMetadata
 
 NS_IMETHODIMP
-IPCBlobInputStream::GetSize(int64_t* aRetval)
-{
+IPCBlobInputStream::GetSize(int64_t* aRetval) {
   nsCOMPtr<nsIFileMetadata> fileMetadata = do_QueryInterface(mRemoteStream);
   if (!fileMetadata) {
     return mState == eClosed ? NS_BASE_STREAM_CLOSED : NS_ERROR_FAILURE;
@@ -605,8 +563,7 @@ IPCBlobInputStream::GetSize(int64_t* aRetval)
 }
 
 NS_IMETHODIMP
-IPCBlobInputStream::GetLastModified(int64_t* aRetval)
-{
+IPCBlobInputStream::GetLastModified(int64_t* aRetval) {
   nsCOMPtr<nsIFileMetadata> fileMetadata = do_QueryInterface(mRemoteStream);
   if (!fileMetadata) {
     return mState == eClosed ? NS_BASE_STREAM_CLOSED : NS_ERROR_FAILURE;
@@ -616,8 +573,7 @@ IPCBlobInputStream::GetLastModified(int64_t* aRetval)
 }
 
 NS_IMETHODIMP
-IPCBlobInputStream::GetFileDescriptor(PRFileDesc** aRetval)
-{
+IPCBlobInputStream::GetFileDescriptor(PRFileDesc** aRetval) {
   nsCOMPtr<nsIFileMetadata> fileMetadata = do_QueryInterface(mRemoteStream);
   if (!fileMetadata) {
     return mState == eClosed ? NS_BASE_STREAM_CLOSED : NS_ERROR_FAILURE;
@@ -626,9 +582,7 @@ IPCBlobInputStream::GetFileDescriptor(PRFileDesc** aRetval)
   return fileMetadata->GetFileDescriptor(aRetval);
 }
 
-nsresult
-IPCBlobInputStream::EnsureAsyncRemoteStream()
-{
+nsresult IPCBlobInputStream::EnsureAsyncRemoteStream() {
   // We already have an async remote stream.
   if (mAsyncRemoteStream) {
     return NS_OK;
@@ -662,15 +616,14 @@ IPCBlobInputStream::EnsureAsyncRemoteStream()
     // Let's make the stream async using the DOMFile thread.
     nsCOMPtr<nsIAsyncInputStream> pipeIn;
     nsCOMPtr<nsIAsyncOutputStream> pipeOut;
-    rv = NS_NewPipe2(getter_AddRefs(pipeIn),
-                     getter_AddRefs(pipeOut),
-                     true, true);
+    rv = NS_NewPipe2(getter_AddRefs(pipeIn), getter_AddRefs(pipeOut), true,
+                     true);
     if (NS_WARN_IF(NS_FAILED(rv))) {
       return rv;
     }
 
     RefPtr<IPCBlobInputStreamThread> thread =
-      IPCBlobInputStreamThread::GetOrCreate();
+        IPCBlobInputStreamThread::GetOrCreate();
     if (NS_WARN_IF(!thread)) {
       return NS_ERROR_FAILURE;
     }
@@ -691,5 +644,5 @@ IPCBlobInputStream::EnsureAsyncRemoteStream()
   return NS_OK;
 }
 
-} // namespace dom
-} // namespace mozilla
+}  // namespace dom
+}  // namespace mozilla
