@@ -17,17 +17,14 @@ NS_IMPL_NS_NEW_HTML_ELEMENT(Span)
 namespace mozilla {
 namespace dom {
 
-HTMLSpanElement::~HTMLSpanElement()
-{
-}
+HTMLSpanElement::~HTMLSpanElement() {}
 
 NS_IMPL_ELEMENT_CLONE(HTMLSpanElement)
 
-JSObject*
-HTMLSpanElement::WrapNode(JSContext *aCx, JS::Handle<JSObject*> aGivenProto)
-{
+JSObject* HTMLSpanElement::WrapNode(JSContext* aCx,
+                                    JS::Handle<JSObject*> aGivenProto) {
   return HTMLSpanElementBinding::Wrap(aCx, this, aGivenProto);
 }
 
-} // namespace dom
-} // namespace mozilla
+}  // namespace dom
+}  // namespace mozilla
