@@ -35,20 +35,18 @@ namespace dom {
 using namespace mozilla::dom::indexedDB;
 using namespace mozilla::ipc;
 
-class IDBTransaction::WorkerHolder final : public mozilla::dom::WorkerHolder
-{
+class IDBTransaction::WorkerHolder final : public mozilla::dom::WorkerHolder {
   WorkerPrivate* mWorkerPrivate;
 
   // The IDBTransaction owns this object so we only need a weak reference back
   // to it.
   IDBTransaction* mTransaction;
 
-public:
+ public:
   WorkerHolder(WorkerPrivate* aWorkerPrivate, IDBTransaction* aTransaction)
-    : mozilla::dom::WorkerHolder("IDBTransaction::WorkerHolder")
-    , mWorkerPrivate(aWorkerPrivate)
-    , mTransaction(aTransaction)
-  {
+      : mozilla::dom::WorkerHolder("IDBTransaction::WorkerHolder"),
+        mWorkerPrivate(aWorkerPrivate),
+        mTransaction(aTransaction) {
     MOZ_ASSERT(aWorkerPrivate);
     MOZ_ASSERT(aTransaction);
     aWorkerPrivate->AssertIsOnWorkerThread();
@@ -57,40 +55,39 @@ public:
     MOZ_COUNT_CTOR(IDBTransaction::WorkerHolder);
   }
 
-  ~WorkerHolder()
-  {
+  ~WorkerHolder() {
     mWorkerPrivate->AssertIsOnWorkerThread();
 
     MOZ_COUNT_DTOR(IDBTransaction::WorkerHolder);
   }
 
-private:
-  virtual bool
-  Notify(WorkerStatus aStatus) override;
+ private:
+  virtual bool Notify(WorkerStatus aStatus) override;
 };
 
 IDBTransaction::IDBTransaction(IDBDatabase* aDatabase,
                                const nsTArray<nsString>& aObjectStoreNames,
                                Mode aMode)
-  : IDBWrapperCache(aDatabase)
-  , mDatabase(aDatabase)
-  , mObjectStoreNames(aObjectStoreNames)
-  , mLoggingSerialNumber(0)
-  , mNextObjectStoreId(0)
-  , mNextIndexId(0)
-  , mAbortCode(NS_OK)
-  , mPendingRequestCount(0)
-  , mLineNo(0)
-  , mColumn(0)
-  , mReadyState(IDBTransaction::INITIAL)
-  , mMode(aMode)
-  , mCreating(false)
-  , mRegistered(false)
-  , mAbortedByScript(false)
-  , mNotedActiveTransaction(false)
+    : IDBWrapperCache(aDatabase),
+      mDatabase(aDatabase),
+      mObjectStoreNames(aObjectStoreNames),
+      mLoggingSerialNumber(0),
+      mNextObjectStoreId(0),
+      mNextIndexId(0),
+      mAbortCode(NS_OK),
+      mPendingRequestCount(0),
+      mLineNo(0),
+      mColumn(0),
+      mReadyState(IDBTransaction::INITIAL),
+      mMode(aMode),
+      mCreating(false),
+      mRegistered(false),
+      mAbortedByScript(false),
+      mNotedActiveTransaction(false)
 #ifdef DEBUG
-  , mSentCommitOrAbort(false)
-  , mFiredCompleteOrAbort(false)
+      ,
+      mSentCommitOrAbort(false),
+      mFiredCompleteOrAbort(false)
 #endif
 {
   MOZ_ASSERT(aDatabase);
@@ -99,14 +96,14 @@ IDBTransaction::IDBTransaction(IDBDatabase* aDatabase,
   mBackgroundActor.mNormalBackgroundActor = nullptr;
 
   BackgroundChildImpl::ThreadLocal* threadLocal =
-    BackgroundChildImpl::GetThreadLocalForCurrentThread();
+      BackgroundChildImpl::GetThreadLocalForCurrentThread();
   MOZ_ASSERT(threadLocal);
 
   ThreadLocal* idbThreadLocal = threadLocal->mIndexedDBThreadLocal;
   MOZ_ASSERT(idbThreadLocal);
 
   const_cast<int64_t&>(mLoggingSerialNumber) =
-    idbThreadLocal->NextTransactionSN(aMode);
+      idbThreadLocal->NextTransactionSN(aMode);
 
 #ifdef DEBUG
   if (!aObjectStoreNames.IsEmpty()) {
@@ -129,19 +126,18 @@ IDBTransaction::IDBTransaction(IDBDatabase* aDatabase,
 #endif
 }
 
-IDBTransaction::~IDBTransaction()
-{
+IDBTransaction::~IDBTransaction() {
   AssertIsOnOwningThread();
   MOZ_ASSERT(!mPendingRequestCount);
   MOZ_ASSERT(!mCreating);
   MOZ_ASSERT(!mNotedActiveTransaction);
   MOZ_ASSERT(mSentCommitOrAbort);
-  MOZ_ASSERT_IF(mMode == VERSION_CHANGE &&
-                  mBackgroundActor.mVersionChangeBackgroundActor,
-                mFiredCompleteOrAbort);
-  MOZ_ASSERT_IF(mMode != VERSION_CHANGE &&
-                  mBackgroundActor.mNormalBackgroundActor,
-                mFiredCompleteOrAbort);
+  MOZ_ASSERT_IF(
+      mMode == VERSION_CHANGE && mBackgroundActor.mVersionChangeBackgroundActor,
+      mFiredCompleteOrAbort);
+  MOZ_ASSERT_IF(
+      mMode != VERSION_CHANGE && mBackgroundActor.mNormalBackgroundActor,
+      mFiredCompleteOrAbort);
 
   if (mRegistered) {
     mDatabase->UnregisterTransaction(this);
@@ -166,14 +162,10 @@ IDBTransaction::~IDBTransaction()
 }
 
 // static
-already_AddRefed<IDBTransaction>
-IDBTransaction::CreateVersionChange(
-                                IDBDatabase* aDatabase,
-                                BackgroundVersionChangeTransactionChild* aActor,
-                                IDBOpenDBRequest* aOpenRequest,
-                                int64_t aNextObjectStoreId,
-                                int64_t aNextIndexId)
-{
+already_AddRefed<IDBTransaction> IDBTransaction::CreateVersionChange(
+    IDBDatabase* aDatabase, BackgroundVersionChangeTransactionChild* aActor,
+    IDBOpenDBRequest* aOpenRequest, int64_t aNextObjectStoreId,
+    int64_t aNextIndexId) {
   MOZ_ASSERT(aDatabase);
   aDatabase->AssertIsOnOwningThread();
   MOZ_ASSERT(aActor);
@@ -184,11 +176,9 @@ IDBTransaction::CreateVersionChange(
   nsTArray<nsString> emptyObjectStoreNames;
 
   RefPtr<IDBTransaction> transaction =
-    new IDBTransaction(aDatabase,
-                       emptyObjectStoreNames,
-                       VERSION_CHANGE);
-  aOpenRequest->GetCallerLocation(transaction->mFilename,
-                                  &transaction->mLineNo, &transaction->mColumn);
+      new IDBTransaction(aDatabase, emptyObjectStoreNames, VERSION_CHANGE);
+  aOpenRequest->GetCallerLocation(transaction->mFilename, &transaction->mLineNo,
+                                  &transaction->mColumn);
 
   transaction->SetScriptOwner(aDatabase->GetScriptOwner());
 
@@ -205,21 +195,17 @@ IDBTransaction::CreateVersionChange(
 }
 
 // static
-already_AddRefed<IDBTransaction>
-IDBTransaction::Create(JSContext* aCx, IDBDatabase* aDatabase,
-                       const nsTArray<nsString>& aObjectStoreNames,
-                       Mode aMode)
-{
+already_AddRefed<IDBTransaction> IDBTransaction::Create(
+    JSContext* aCx, IDBDatabase* aDatabase,
+    const nsTArray<nsString>& aObjectStoreNames, Mode aMode) {
   MOZ_ASSERT(aDatabase);
   aDatabase->AssertIsOnOwningThread();
   MOZ_ASSERT(!aObjectStoreNames.IsEmpty());
-  MOZ_ASSERT(aMode == READ_ONLY ||
-             aMode == READ_WRITE ||
-             aMode == READ_WRITE_FLUSH ||
-             aMode == CLEANUP);
+  MOZ_ASSERT(aMode == READ_ONLY || aMode == READ_WRITE ||
+             aMode == READ_WRITE_FLUSH || aMode == CLEANUP);
 
   RefPtr<IDBTransaction> transaction =
-    new IDBTransaction(aDatabase, aObjectStoreNames, aMode);
+      new IDBTransaction(aDatabase, aObjectStoreNames, aMode);
   IDBRequest::CaptureCaller(aCx, transaction->mFilename, &transaction->mLineNo,
                             &transaction->mColumn);
 
@@ -232,9 +218,9 @@ IDBTransaction::Create(JSContext* aCx, IDBDatabase* aDatabase,
     workerPrivate->AssertIsOnWorkerThread();
 
     nsAutoPtr<WorkerHolder> workerHolder(
-      new WorkerHolder(workerPrivate, transaction));
+        new WorkerHolder(workerPrivate, transaction));
     if (NS_WARN_IF(!workerHolder->HoldWorker(workerPrivate, Canceling))) {
-      // Silence the destructor assertion if we never made this object live.
+    // Silence the destructor assertion if we never made this object live.
 #ifdef DEBUG
       MOZ_ASSERT(!transaction->mSentCommitOrAbort);
       transaction->mSentCommitOrAbort = true;
@@ -257,15 +243,13 @@ IDBTransaction::Create(JSContext* aCx, IDBDatabase* aDatabase,
 }
 
 // static
-IDBTransaction*
-IDBTransaction::GetCurrent()
-{
+IDBTransaction* IDBTransaction::GetCurrent() {
   using namespace mozilla::ipc;
 
   MOZ_ASSERT(BackgroundChild::GetForCurrentThread());
 
   BackgroundChildImpl::ThreadLocal* threadLocal =
-    BackgroundChildImpl::GetThreadLocalForCurrentThread();
+      BackgroundChildImpl::GetThreadLocalForCurrentThread();
   MOZ_ASSERT(threadLocal);
 
   ThreadLocal* idbThreadLocal = threadLocal->mIndexedDBThreadLocal;
@@ -276,18 +260,15 @@ IDBTransaction::GetCurrent()
 
 #ifdef DEBUG
 
-void
-IDBTransaction::AssertIsOnOwningThread() const
-{
+void IDBTransaction::AssertIsOnOwningThread() const {
   MOZ_ASSERT(mDatabase);
   mDatabase->AssertIsOnOwningThread();
 }
 
-#endif // DEBUG
+#endif  // DEBUG
 
-void
-IDBTransaction::SetBackgroundActor(indexedDB::BackgroundTransactionChild* aBackgroundActor)
-{
+void IDBTransaction::SetBackgroundActor(
+    indexedDB::BackgroundTransactionChild* aBackgroundActor) {
   AssertIsOnOwningThread();
   MOZ_ASSERT(aBackgroundActor);
   MOZ_ASSERT(!mBackgroundActor.mNormalBackgroundActor);
@@ -298,9 +279,8 @@ IDBTransaction::SetBackgroundActor(indexedDB::BackgroundTransactionChild* aBackg
   mBackgroundActor.mNormalBackgroundActor = aBackgroundActor;
 }
 
-BackgroundRequestChild*
-IDBTransaction::StartRequest(IDBRequest* aRequest, const RequestParams& aParams)
-{
+BackgroundRequestChild* IDBTransaction::StartRequest(
+    IDBRequest* aRequest, const RequestParams& aParams) {
   AssertIsOnOwningThread();
   MOZ_ASSERT(aRequest);
   MOZ_ASSERT(aParams.type() != RequestParams::T__None);
@@ -310,17 +290,17 @@ IDBTransaction::StartRequest(IDBRequest* aRequest, const RequestParams& aParams)
   if (mMode == VERSION_CHANGE) {
     MOZ_ASSERT(mBackgroundActor.mVersionChangeBackgroundActor);
 
-    mBackgroundActor.mVersionChangeBackgroundActor->
-      SendPBackgroundIDBRequestConstructor(actor, aParams);
+    mBackgroundActor.mVersionChangeBackgroundActor
+        ->SendPBackgroundIDBRequestConstructor(actor, aParams);
   } else {
     MOZ_ASSERT(mBackgroundActor.mNormalBackgroundActor);
 
-    mBackgroundActor.mNormalBackgroundActor->
-      SendPBackgroundIDBRequestConstructor(actor, aParams);
+    mBackgroundActor.mNormalBackgroundActor
+        ->SendPBackgroundIDBRequestConstructor(actor, aParams);
   }
 
   MOZ_ASSERT(actor->GetActorEventTarget(),
-    "The event target shall be inherited from its manager actor.");
+             "The event target shall be inherited from its manager actor.");
 
   // Balanced in BackgroundRequestChild::Recv__delete__().
   OnNewRequest();
@@ -328,10 +308,8 @@ IDBTransaction::StartRequest(IDBRequest* aRequest, const RequestParams& aParams)
   return actor;
 }
 
-void
-IDBTransaction::OpenCursor(BackgroundCursorChild* aBackgroundActor,
-                           const OpenCursorParams& aParams)
-{
+void IDBTransaction::OpenCursor(BackgroundCursorChild* aBackgroundActor,
+                                const OpenCursorParams& aParams) {
   AssertIsOnOwningThread();
   MOZ_ASSERT(aBackgroundActor);
   MOZ_ASSERT(aParams.type() != OpenCursorParams::T__None);
@@ -339,43 +317,37 @@ IDBTransaction::OpenCursor(BackgroundCursorChild* aBackgroundActor,
   if (mMode == VERSION_CHANGE) {
     MOZ_ASSERT(mBackgroundActor.mVersionChangeBackgroundActor);
 
-    mBackgroundActor.mVersionChangeBackgroundActor->
-      SendPBackgroundIDBCursorConstructor(aBackgroundActor, aParams);
+    mBackgroundActor.mVersionChangeBackgroundActor
+        ->SendPBackgroundIDBCursorConstructor(aBackgroundActor, aParams);
   } else {
     MOZ_ASSERT(mBackgroundActor.mNormalBackgroundActor);
 
-    mBackgroundActor.mNormalBackgroundActor->
-      SendPBackgroundIDBCursorConstructor(aBackgroundActor, aParams);
+    mBackgroundActor.mNormalBackgroundActor
+        ->SendPBackgroundIDBCursorConstructor(aBackgroundActor, aParams);
   }
 
   MOZ_ASSERT(aBackgroundActor->GetActorEventTarget(),
-    "The event target shall be inherited from its manager actor.");
+             "The event target shall be inherited from its manager actor.");
 
   // Balanced in BackgroundCursorChild::RecvResponse().
   OnNewRequest();
 }
 
-void
-IDBTransaction::RefreshSpec(bool aMayDelete)
-{
+void IDBTransaction::RefreshSpec(bool aMayDelete) {
   AssertIsOnOwningThread();
 
-  for (uint32_t count = mObjectStores.Length(), index = 0;
-       index < count;
+  for (uint32_t count = mObjectStores.Length(), index = 0; index < count;
        index++) {
     mObjectStores[index]->RefreshSpec(aMayDelete);
   }
 
-  for (uint32_t count = mDeletedObjectStores.Length(), index = 0;
-       index < count;
+  for (uint32_t count = mDeletedObjectStores.Length(), index = 0; index < count;
        index++) {
     mDeletedObjectStores[index]->RefreshSpec(false);
   }
 }
 
-void
-IDBTransaction::OnNewRequest()
-{
+void IDBTransaction::OnNewRequest() {
   AssertIsOnOwningThread();
 
   if (!mPendingRequestCount) {
@@ -386,9 +358,7 @@ IDBTransaction::OnNewRequest()
   ++mPendingRequestCount;
 }
 
-void
-IDBTransaction::OnRequestFinished(bool aActorDestroyedNormally)
-{
+void IDBTransaction::OnRequestFinished(bool aActorDestroyedNormally) {
   AssertIsOnOwningThread();
   MOZ_ASSERT(mPendingRequestCount);
 
@@ -404,24 +374,22 @@ IDBTransaction::OnRequestFinished(bool aActorDestroyedNormally)
         SendAbort(mAbortCode);
       }
     } else {
-      // Don't try to send any more messages to the parent if the request actor
-      // was killed.
+    // Don't try to send any more messages to the parent if the request actor
+    // was killed.
 #ifdef DEBUG
       MOZ_ASSERT(!mSentCommitOrAbort);
       mSentCommitOrAbort = true;
 #endif
-      IDB_LOG_MARK("IndexedDB %s: Child  Transaction[%lld]: "
-                     "Request actor was killed, transaction will be aborted",
-                   "IndexedDB %s: C T[%lld]: IDBTransaction abort",
-                   IDB_LOG_ID_STRING(),
-                   LoggingSerialNumber());
+      IDB_LOG_MARK(
+          "IndexedDB %s: Child  Transaction[%lld]: "
+          "Request actor was killed, transaction will be aborted",
+          "IndexedDB %s: C T[%lld]: IDBTransaction abort", IDB_LOG_ID_STRING(),
+          LoggingSerialNumber());
     }
   }
 }
 
-void
-IDBTransaction::SendCommit()
-{
+void IDBTransaction::SendCommit() {
   AssertIsOnOwningThread();
   MOZ_ASSERT(NS_SUCCEEDED(mAbortCode));
   MOZ_ASSERT(IsCommittingOrDone());
@@ -432,12 +400,11 @@ IDBTransaction::SendCommit()
   // number to keep in sync with the parent.
   const uint64_t requestSerialNumber = IDBRequest::NextSerialNumber();
 
-  IDB_LOG_MARK("IndexedDB %s: Child  Transaction[%lld] Request[%llu]: "
-                 "All requests complete, committing transaction",
-               "IndexedDB %s: C T[%lld] R[%llu]: IDBTransaction commit",
-               IDB_LOG_ID_STRING(),
-               LoggingSerialNumber(),
-               requestSerialNumber);
+  IDB_LOG_MARK(
+      "IndexedDB %s: Child  Transaction[%lld] Request[%llu]: "
+      "All requests complete, committing transaction",
+      "IndexedDB %s: C T[%lld] R[%llu]: IDBTransaction commit",
+      IDB_LOG_ID_STRING(), LoggingSerialNumber(), requestSerialNumber);
 
   if (mMode == VERSION_CHANGE) {
     MOZ_ASSERT(mBackgroundActor.mVersionChangeBackgroundActor);
@@ -452,9 +419,7 @@ IDBTransaction::SendCommit()
 #endif
 }
 
-void
-IDBTransaction::SendAbort(nsresult aResultCode)
-{
+void IDBTransaction::SendAbort(nsresult aResultCode) {
   AssertIsOnOwningThread();
   MOZ_ASSERT(NS_FAILED(aResultCode));
   MOZ_ASSERT(IsCommittingOrDone());
@@ -464,13 +429,12 @@ IDBTransaction::SendAbort(nsresult aResultCode)
   // number to keep in sync with the parent.
   const uint64_t requestSerialNumber = IDBRequest::NextSerialNumber();
 
-  IDB_LOG_MARK("IndexedDB %s: Child  Transaction[%lld] Request[%llu]: "
-                 "Aborting transaction with result 0x%x",
-               "IndexedDB %s: C T[%lld] R[%llu]: IDBTransaction abort (0x%x)",
-               IDB_LOG_ID_STRING(),
-               LoggingSerialNumber(),
-               requestSerialNumber,
-               aResultCode);
+  IDB_LOG_MARK(
+      "IndexedDB %s: Child  Transaction[%lld] Request[%llu]: "
+      "Aborting transaction with result 0x%x",
+      "IndexedDB %s: C T[%lld] R[%llu]: IDBTransaction abort (0x%x)",
+      IDB_LOG_ID_STRING(), LoggingSerialNumber(), requestSerialNumber,
+      aResultCode);
 
   if (mMode == VERSION_CHANGE) {
     MOZ_ASSERT(mBackgroundActor.mVersionChangeBackgroundActor);
@@ -485,9 +449,7 @@ IDBTransaction::SendAbort(nsresult aResultCode)
 #endif
 }
 
-void
-IDBTransaction::NoteActiveTransaction()
-{
+void IDBTransaction::NoteActiveTransaction() {
   AssertIsOnOwningThread();
   MOZ_ASSERT(!mNotedActiveTransaction);
 
@@ -495,9 +457,7 @@ IDBTransaction::NoteActiveTransaction()
   mNotedActiveTransaction = true;
 }
 
-void
-IDBTransaction::MaybeNoteInactiveTransaction()
-{
+void IDBTransaction::MaybeNoteInactiveTransaction() {
   AssertIsOnOwningThread();
 
   if (mNotedActiveTransaction) {
@@ -506,9 +466,7 @@ IDBTransaction::MaybeNoteInactiveTransaction()
   }
 }
 
-bool
-IDBTransaction::IsOpen() const
-{
+bool IDBTransaction::IsOpen() const {
   AssertIsOnOwningThread();
 
   // If we haven't started anything then we're open.
@@ -529,10 +487,8 @@ IDBTransaction::IsOpen() const
   return false;
 }
 
-void
-IDBTransaction::GetCallerLocation(nsAString& aFilename, uint32_t* aLineNo,
-                                  uint32_t* aColumn) const
-{
+void IDBTransaction::GetCallerLocation(nsAString& aFilename, uint32_t* aLineNo,
+                                       uint32_t* aColumn) const {
   AssertIsOnOwningThread();
   MOZ_ASSERT(aLineNo);
   MOZ_ASSERT(aColumn);
@@ -542,9 +498,8 @@ IDBTransaction::GetCallerLocation(nsAString& aFilename, uint32_t* aLineNo,
   *aColumn = mColumn;
 }
 
-already_AddRefed<IDBObjectStore>
-IDBTransaction::CreateObjectStore(const ObjectStoreSpec& aSpec)
-{
+already_AddRefed<IDBObjectStore> IDBTransaction::CreateObjectStore(
+    const ObjectStoreSpec& aSpec) {
   AssertIsOnOwningThread();
   MOZ_ASSERT(aSpec.metadata().id());
   MOZ_ASSERT(VERSION_CHANGE == mMode);
@@ -555,16 +510,16 @@ IDBTransaction::CreateObjectStore(const ObjectStoreSpec& aSpec)
   {
     const nsString& name = aSpec.metadata().name();
 
-    for (uint32_t count = mObjectStores.Length(), index = 0;
-         index < count;
+    for (uint32_t count = mObjectStores.Length(), index = 0; index < count;
          index++) {
       MOZ_ASSERT(mObjectStores[index]->Name() != name);
     }
   }
 #endif
 
-  MOZ_ALWAYS_TRUE(mBackgroundActor.mVersionChangeBackgroundActor->
-                    SendCreateObjectStore(aSpec.metadata()));
+  MOZ_ALWAYS_TRUE(
+      mBackgroundActor.mVersionChangeBackgroundActor->SendCreateObjectStore(
+          aSpec.metadata()));
 
   RefPtr<IDBObjectStore> objectStore = IDBObjectStore::Create(this, aSpec);
   MOZ_ASSERT(objectStore);
@@ -574,20 +529,18 @@ IDBTransaction::CreateObjectStore(const ObjectStoreSpec& aSpec)
   return objectStore.forget();
 }
 
-void
-IDBTransaction::DeleteObjectStore(int64_t aObjectStoreId)
-{
+void IDBTransaction::DeleteObjectStore(int64_t aObjectStoreId) {
   AssertIsOnOwningThread();
   MOZ_ASSERT(aObjectStoreId);
   MOZ_ASSERT(VERSION_CHANGE == mMode);
   MOZ_ASSERT(mBackgroundActor.mVersionChangeBackgroundActor);
   MOZ_ASSERT(IsOpen());
 
-  MOZ_ALWAYS_TRUE(mBackgroundActor.mVersionChangeBackgroundActor->
-                    SendDeleteObjectStore(aObjectStoreId));
+  MOZ_ALWAYS_TRUE(
+      mBackgroundActor.mVersionChangeBackgroundActor->SendDeleteObjectStore(
+          aObjectStoreId));
 
-  for (uint32_t count = mObjectStores.Length(), index = 0;
-       index < count;
+  for (uint32_t count = mObjectStores.Length(), index = 0; index < count;
        index++) {
     RefPtr<IDBObjectStore>& objectStore = mObjectStores[index];
 
@@ -595,7 +548,7 @@ IDBTransaction::DeleteObjectStore(int64_t aObjectStoreId)
       objectStore->NoteDeletion();
 
       RefPtr<IDBObjectStore>* deletedObjectStore =
-        mDeletedObjectStores.AppendElement();
+          mDeletedObjectStores.AppendElement();
       deletedObjectStore->swap(mObjectStores[index]);
 
       mObjectStores.RemoveElementAt(index);
@@ -604,24 +557,21 @@ IDBTransaction::DeleteObjectStore(int64_t aObjectStoreId)
   }
 }
 
-void
-IDBTransaction::RenameObjectStore(int64_t aObjectStoreId,
-                                  const nsAString& aName)
-{
+void IDBTransaction::RenameObjectStore(int64_t aObjectStoreId,
+                                       const nsAString& aName) {
   AssertIsOnOwningThread();
   MOZ_ASSERT(aObjectStoreId);
   MOZ_ASSERT(VERSION_CHANGE == mMode);
   MOZ_ASSERT(mBackgroundActor.mVersionChangeBackgroundActor);
   MOZ_ASSERT(IsOpen());
 
-  MOZ_ALWAYS_TRUE(mBackgroundActor.mVersionChangeBackgroundActor->
-                    SendRenameObjectStore(aObjectStoreId, nsString(aName)));
+  MOZ_ALWAYS_TRUE(
+      mBackgroundActor.mVersionChangeBackgroundActor->SendRenameObjectStore(
+          aObjectStoreId, nsString(aName)));
 }
 
-void
-IDBTransaction::CreateIndex(IDBObjectStore* aObjectStore,
-                            const indexedDB::IndexMetadata& aMetadata)
-{
+void IDBTransaction::CreateIndex(IDBObjectStore* aObjectStore,
+                                 const indexedDB::IndexMetadata& aMetadata) {
   AssertIsOnOwningThread();
   MOZ_ASSERT(aObjectStore);
   MOZ_ASSERT(aMetadata.id());
@@ -629,14 +579,13 @@ IDBTransaction::CreateIndex(IDBObjectStore* aObjectStore,
   MOZ_ASSERT(mBackgroundActor.mVersionChangeBackgroundActor);
   MOZ_ASSERT(IsOpen());
 
-  MOZ_ALWAYS_TRUE(mBackgroundActor.mVersionChangeBackgroundActor->
-                    SendCreateIndex(aObjectStore->Id(), aMetadata));
+  MOZ_ALWAYS_TRUE(
+      mBackgroundActor.mVersionChangeBackgroundActor->SendCreateIndex(
+          aObjectStore->Id(), aMetadata));
 }
 
-void
-IDBTransaction::DeleteIndex(IDBObjectStore* aObjectStore,
-                            int64_t aIndexId)
-{
+void IDBTransaction::DeleteIndex(IDBObjectStore* aObjectStore,
+                                 int64_t aIndexId) {
   AssertIsOnOwningThread();
   MOZ_ASSERT(aObjectStore);
   MOZ_ASSERT(aIndexId);
@@ -644,15 +593,13 @@ IDBTransaction::DeleteIndex(IDBObjectStore* aObjectStore,
   MOZ_ASSERT(mBackgroundActor.mVersionChangeBackgroundActor);
   MOZ_ASSERT(IsOpen());
 
-  MOZ_ALWAYS_TRUE(mBackgroundActor.mVersionChangeBackgroundActor->
-                    SendDeleteIndex(aObjectStore->Id(), aIndexId));
+  MOZ_ALWAYS_TRUE(
+      mBackgroundActor.mVersionChangeBackgroundActor->SendDeleteIndex(
+          aObjectStore->Id(), aIndexId));
 }
 
-void
-IDBTransaction::RenameIndex(IDBObjectStore* aObjectStore,
-                            int64_t aIndexId,
-                            const nsAString& aName)
-{
+void IDBTransaction::RenameIndex(IDBObjectStore* aObjectStore, int64_t aIndexId,
+                                 const nsAString& aName) {
   AssertIsOnOwningThread();
   MOZ_ASSERT(aObjectStore);
   MOZ_ASSERT(aIndexId);
@@ -660,16 +607,13 @@ IDBTransaction::RenameIndex(IDBObjectStore* aObjectStore,
   MOZ_ASSERT(mBackgroundActor.mVersionChangeBackgroundActor);
   MOZ_ASSERT(IsOpen());
 
-  MOZ_ALWAYS_TRUE(mBackgroundActor.mVersionChangeBackgroundActor->
-                    SendRenameIndex(aObjectStore->Id(),
-                                    aIndexId,
-                                    nsString(aName)));
+  MOZ_ALWAYS_TRUE(
+      mBackgroundActor.mVersionChangeBackgroundActor->SendRenameIndex(
+          aObjectStore->Id(), aIndexId, nsString(aName)));
 }
 
-void
-IDBTransaction::AbortInternal(nsresult aAbortCode,
-                              already_AddRefed<DOMException> aError)
-{
+void IDBTransaction::AbortInternal(nsresult aAbortCode,
+                                   already_AddRefed<DOMException> aError) {
   AssertIsOnOwningThread();
   MOZ_ASSERT(NS_FAILED(aAbortCode));
   MOZ_ASSERT(!IsCommittingOrDone());
@@ -699,7 +643,7 @@ IDBTransaction::AbortInternal(nsresult aAbortCode,
     // which all the executions are returned earlier by !transaction->IsOpen().
 
     const nsTArray<ObjectStoreSpec>& specArray =
-      mDatabase->Spec()->objectStores();
+        mDatabase->Spec()->objectStores();
 
     if (specArray.IsEmpty()) {
       mObjectStores.Clear();
@@ -708,8 +652,7 @@ IDBTransaction::AbortInternal(nsresult aAbortCode,
       nsTHashtable<nsUint64HashKey> validIds(specArray.Length());
 
       for (uint32_t specCount = specArray.Length(), specIndex = 0;
-           specIndex < specCount;
-           specIndex++) {
+           specIndex < specCount; specIndex++) {
         const int64_t objectStoreId = specArray[specIndex].metadata().id();
         MOZ_ASSERT(objectStoreId);
 
@@ -717,8 +660,8 @@ IDBTransaction::AbortInternal(nsresult aAbortCode,
       }
 
       for (uint32_t objCount = mObjectStores.Length(), objIndex = 0;
-            objIndex < objCount;
-            /* incremented conditionally */) {
+           objIndex < objCount;
+           /* incremented conditionally */) {
         const int64_t objectStoreId = mObjectStores[objIndex]->Id();
         MOZ_ASSERT(objectStoreId);
 
@@ -732,14 +675,12 @@ IDBTransaction::AbortInternal(nsresult aAbortCode,
 
       if (!mDeletedObjectStores.IsEmpty()) {
         for (uint32_t objCount = mDeletedObjectStores.Length(), objIndex = 0;
-              objIndex < objCount;
-              objIndex++) {
+             objIndex < objCount; objIndex++) {
           const int64_t objectStoreId = mDeletedObjectStores[objIndex]->Id();
           MOZ_ASSERT(objectStoreId);
 
           if (validIds.Contains(uint64_t(objectStoreId))) {
-            RefPtr<IDBObjectStore>* objectStore =
-              mObjectStores.AppendElement();
+            RefPtr<IDBObjectStore>* objectStore = mObjectStores.AppendElement();
             objectStore->swap(mDeletedObjectStores[objIndex]);
           }
         }
@@ -759,9 +700,7 @@ IDBTransaction::AbortInternal(nsresult aAbortCode,
   }
 }
 
-void
-IDBTransaction::Abort(IDBRequest* aRequest)
-{
+void IDBTransaction::Abort(IDBRequest* aRequest) {
   AssertIsOnOwningThread();
   MOZ_ASSERT(aRequest);
 
@@ -777,9 +716,7 @@ IDBTransaction::Abort(IDBRequest* aRequest)
   AbortInternal(aRequest->GetErrorCode(), error.forget());
 }
 
-void
-IDBTransaction::Abort(nsresult aErrorCode)
-{
+void IDBTransaction::Abort(nsresult aErrorCode) {
   AssertIsOnOwningThread();
 
   if (IsCommittingOrDone()) {
@@ -792,9 +729,7 @@ IDBTransaction::Abort(nsresult aErrorCode)
   AbortInternal(aErrorCode, error.forget());
 }
 
-void
-IDBTransaction::Abort(ErrorResult& aRv)
-{
+void IDBTransaction::Abort(ErrorResult& aRv) {
   AssertIsOnOwningThread();
 
   if (IsCommittingOrDone()) {
@@ -808,9 +743,7 @@ IDBTransaction::Abort(ErrorResult& aRv)
   mAbortedByScript = true;
 }
 
-void
-IDBTransaction::FireCompleteOrAbortEvents(nsresult aResult)
-{
+void IDBTransaction::FireCompleteOrAbortEvents(nsresult aResult) {
   AssertIsOnOwningThread();
   MOZ_ASSERT(!mFiredCompleteOrAbort);
 
@@ -825,10 +758,8 @@ IDBTransaction::FireCompleteOrAbortEvents(nsresult aResult)
 
   nsCOMPtr<nsIDOMEvent> event;
   if (NS_SUCCEEDED(aResult)) {
-    event = CreateGenericEvent(this,
-                               nsDependentString(kCompleteEventType),
-                               eDoesNotBubble,
-                               eNotCancelable);
+    event = CreateGenericEvent(this, nsDependentString(kCompleteEventType),
+                               eDoesNotBubble, eNotCancelable);
     MOZ_ASSERT(event);
   } else {
     if (aResult == NS_ERROR_DOM_INDEXEDDB_QUOTA_ERR) {
@@ -839,26 +770,23 @@ IDBTransaction::FireCompleteOrAbortEvents(nsresult aResult)
       mError = DOMException::Create(aResult);
     }
 
-    event = CreateGenericEvent(this,
-                               nsDependentString(kAbortEventType),
-                               eDoesBubble,
-                               eNotCancelable);
+    event = CreateGenericEvent(this, nsDependentString(kAbortEventType),
+                               eDoesBubble, eNotCancelable);
     MOZ_ASSERT(event);
   }
 
   if (NS_SUCCEEDED(mAbortCode)) {
-    IDB_LOG_MARK("IndexedDB %s: Child  Transaction[%lld]: "
-                   "Firing 'complete' event",
-                 "IndexedDB %s: C T[%lld]: IDBTransaction 'complete' event",
-                 IDB_LOG_ID_STRING(),
-                 mLoggingSerialNumber);
+    IDB_LOG_MARK(
+        "IndexedDB %s: Child  Transaction[%lld]: "
+        "Firing 'complete' event",
+        "IndexedDB %s: C T[%lld]: IDBTransaction 'complete' event",
+        IDB_LOG_ID_STRING(), mLoggingSerialNumber);
   } else {
-    IDB_LOG_MARK("IndexedDB %s: Child  Transaction[%lld]: "
-                   "Firing 'abort' event with error 0x%x",
-                 "IndexedDB %s: C T[%lld]: IDBTransaction 'abort' event (0x%x)",
-                 IDB_LOG_ID_STRING(),
-                 mLoggingSerialNumber,
-                 mAbortCode);
+    IDB_LOG_MARK(
+        "IndexedDB %s: Child  Transaction[%lld]: "
+        "Firing 'abort' event with error 0x%x",
+        "IndexedDB %s: C T[%lld]: IDBTransaction 'abort' event (0x%x)",
+        IDB_LOG_ID_STRING(), mLoggingSerialNumber, mAbortCode);
   }
 
   bool dummy;
@@ -877,35 +805,27 @@ IDBTransaction::FireCompleteOrAbortEvents(nsresult aResult)
   MaybeNoteInactiveTransaction();
 }
 
-int64_t
-IDBTransaction::NextObjectStoreId()
-{
+int64_t IDBTransaction::NextObjectStoreId() {
   AssertIsOnOwningThread();
   MOZ_ASSERT(VERSION_CHANGE == mMode);
 
   return mNextObjectStoreId++;
 }
 
-int64_t
-IDBTransaction::NextIndexId()
-{
+int64_t IDBTransaction::NextIndexId() {
   AssertIsOnOwningThread();
   MOZ_ASSERT(VERSION_CHANGE == mMode);
 
   return mNextIndexId++;
 }
 
-nsPIDOMWindowInner*
-IDBTransaction::GetParentObject() const
-{
+nsPIDOMWindowInner* IDBTransaction::GetParentObject() const {
   AssertIsOnOwningThread();
 
   return mDatabase->GetParentObject();
 }
 
-IDBTransactionMode
-IDBTransaction::GetMode(ErrorResult& aRv) const
-{
+IDBTransactionMode IDBTransaction::GetMode(ErrorResult& aRv) const {
   AssertIsOnOwningThread();
 
   switch (mMode) {
@@ -930,17 +850,13 @@ IDBTransaction::GetMode(ErrorResult& aRv) const
   }
 }
 
-DOMException*
-IDBTransaction::GetError() const
-{
+DOMException* IDBTransaction::GetError() const {
   AssertIsOnOwningThread();
 
   return mError;
 }
 
-already_AddRefed<DOMStringList>
-IDBTransaction::ObjectStoreNames() const
-{
+already_AddRefed<DOMStringList> IDBTransaction::ObjectStoreNames() const {
   AssertIsOnOwningThread();
 
   if (mMode == IDBTransaction::VERSION_CHANGE) {
@@ -952,9 +868,8 @@ IDBTransaction::ObjectStoreNames() const
   return list.forget();
 }
 
-already_AddRefed<IDBObjectStore>
-IDBTransaction::ObjectStore(const nsAString& aName, ErrorResult& aRv)
-{
+already_AddRefed<IDBObjectStore> IDBTransaction::ObjectStore(
+    const nsAString& aName, ErrorResult& aRv) {
   AssertIsOnOwningThread();
 
   if (IsCommittingOrDone()) {
@@ -967,10 +882,9 @@ IDBTransaction::ObjectStore(const nsAString& aName, ErrorResult& aRv)
   if (IDBTransaction::VERSION_CHANGE == mMode ||
       mObjectStoreNames.Contains(aName)) {
     const nsTArray<ObjectStoreSpec>& objectStores =
-      mDatabase->Spec()->objectStores();
+        mDatabase->Spec()->objectStores();
 
-    for (uint32_t count = objectStores.Length(), index = 0;
-         index < count;
+    for (uint32_t count = objectStores.Length(), index = 0; index < count;
          index++) {
       const ObjectStoreSpec& objectStore = objectStores[index];
       if (objectStore.metadata().name() == aName) {
@@ -989,8 +903,7 @@ IDBTransaction::ObjectStore(const nsAString& aName, ErrorResult& aRv)
 
   RefPtr<IDBObjectStore> objectStore;
 
-  for (uint32_t count = mObjectStores.Length(), index = 0;
-       index < count;
+  for (uint32_t count = mObjectStores.Length(), index = 0; index < count;
        index++) {
     RefPtr<IDBObjectStore>& existingObjectStore = mObjectStores[index];
 
@@ -1034,17 +947,14 @@ NS_IMPL_CYCLE_COLLECTION_UNLINK_BEGIN_INHERITED(IDBTransaction, IDBWrapperCache)
   NS_IMPL_CYCLE_COLLECTION_UNLINK(mDeletedObjectStores)
 NS_IMPL_CYCLE_COLLECTION_UNLINK_END
 
-JSObject*
-IDBTransaction::WrapObject(JSContext* aCx, JS::Handle<JSObject*> aGivenProto)
-{
+JSObject* IDBTransaction::WrapObject(JSContext* aCx,
+                                     JS::Handle<JSObject*> aGivenProto) {
   AssertIsOnOwningThread();
 
   return IDBTransactionBinding::Wrap(aCx, this, aGivenProto);
 }
 
-nsresult
-IDBTransaction::GetEventTargetParent(EventChainPreVisitor& aVisitor)
-{
+nsresult IDBTransaction::GetEventTargetParent(EventChainPreVisitor& aVisitor) {
   AssertIsOnOwningThread();
 
   aVisitor.mCanHandle = true;
@@ -1053,8 +963,7 @@ IDBTransaction::GetEventTargetParent(EventChainPreVisitor& aVisitor)
 }
 
 NS_IMETHODIMP
-IDBTransaction::Run()
-{
+IDBTransaction::Run() {
   AssertIsOnOwningThread();
 
   // We're back at the event loop, no longer newborn.
@@ -1070,10 +979,7 @@ IDBTransaction::Run()
   return NS_OK;
 }
 
-bool
-IDBTransaction::
-WorkerHolder::Notify(WorkerStatus aStatus)
-{
+bool IDBTransaction::WorkerHolder::Notify(WorkerStatus aStatus) {
   MOZ_ASSERT(mWorkerPrivate);
   mWorkerPrivate->AssertIsOnWorkerThread();
   MOZ_ASSERT(aStatus > Running);
@@ -1092,5 +998,5 @@ WorkerHolder::Notify(WorkerStatus aStatus)
   return true;
 }
 
-} // namespace dom
-} // namespace mozilla
+}  // namespace dom
+}  // namespace mozilla
