@@ -4,12 +4,11 @@
  * License, v. 2.0. If a copy of the MPL was not distributed with this
  * file, You can obtain one at http://mozilla.org/MPL/2.0/. */
 
-
 #include "nsMathMLElement.h"
 #include "base/compiler_specific.h"
 #include "mozilla/ArrayUtils.h"
 #include "nsGkAtoms.h"
-#include "nsITableCellLayout.h" // for MAX_COLSPAN / MAX_ROWSPAN
+#include "nsITableCellLayout.h"  // for MAX_COLSPAN / MAX_ROWSPAN
 #include "nsCRT.h"
 #include "nsLayoutStylesheetCache.h"
 #ifdef MOZ_OLD_STYLE
@@ -38,71 +37,55 @@ using namespace mozilla::dom;
 //----------------------------------------------------------------------
 // nsISupports methods:
 
-NS_IMPL_ISUPPORTS_INHERITED(nsMathMLElement, nsMathMLElementBase,
-                            nsIDOMElement, nsIDOMNode, Link)
+NS_IMPL_ISUPPORTS_INHERITED(nsMathMLElement, nsMathMLElementBase, nsIDOMElement,
+                            nsIDOMNode, Link)
 
-static nsresult
-WarnDeprecated(const char16_t* aDeprecatedAttribute,
-               const char16_t* aFavoredAttribute, nsIDocument* aDocument)
-{
-  const char16_t *argv[] =
-    { aDeprecatedAttribute, aFavoredAttribute };
-  return nsContentUtils::
-          ReportToConsole(nsIScriptError::warningFlag,
-                          NS_LITERAL_CSTRING("MathML"), aDocument,
-                          nsContentUtils::eMATHML_PROPERTIES,
-                          "DeprecatedSupersededBy", argv, 2);
+static nsresult WarnDeprecated(const char16_t* aDeprecatedAttribute,
+                               const char16_t* aFavoredAttribute,
+                               nsIDocument* aDocument) {
+  const char16_t* argv[] = {aDeprecatedAttribute, aFavoredAttribute};
+  return nsContentUtils::ReportToConsole(
+      nsIScriptError::warningFlag, NS_LITERAL_CSTRING("MathML"), aDocument,
+      nsContentUtils::eMATHML_PROPERTIES, "DeprecatedSupersededBy", argv, 2);
 }
 
-static nsresult
-ReportLengthParseError(const nsString& aValue, nsIDocument* aDocument)
-{
-  const char16_t *arg = aValue.get();
-  return nsContentUtils::
-         ReportToConsole(nsIScriptError::errorFlag,
-                         NS_LITERAL_CSTRING("MathML"), aDocument,
-                         nsContentUtils::eMATHML_PROPERTIES,
-                         "LengthParsingError", &arg, 1);
+static nsresult ReportLengthParseError(const nsString& aValue,
+                                       nsIDocument* aDocument) {
+  const char16_t* arg = aValue.get();
+  return nsContentUtils::ReportToConsole(
+      nsIScriptError::errorFlag, NS_LITERAL_CSTRING("MathML"), aDocument,
+      nsContentUtils::eMATHML_PROPERTIES, "LengthParsingError", &arg, 1);
 }
 
-static nsresult
-ReportParseErrorNoTag(const nsString& aValue,
-                      nsAtom*        aAtom,
-                      nsIDocument*    aDocument)
-{
-  const char16_t *argv[] =
-    { aValue.get(), aAtom->GetUTF16String() };
-  return nsContentUtils::
-         ReportToConsole(nsIScriptError::errorFlag,
-                         NS_LITERAL_CSTRING("MathML"), aDocument,
-                         nsContentUtils::eMATHML_PROPERTIES,
-                         "AttributeParsingErrorNoTag", argv, 2);
+static nsresult ReportParseErrorNoTag(const nsString& aValue, nsAtom* aAtom,
+                                      nsIDocument* aDocument) {
+  const char16_t* argv[] = {aValue.get(), aAtom->GetUTF16String()};
+  return nsContentUtils::ReportToConsole(
+      nsIScriptError::errorFlag, NS_LITERAL_CSTRING("MathML"), aDocument,
+      nsContentUtils::eMATHML_PROPERTIES, "AttributeParsingErrorNoTag", argv,
+      2);
 }
 
-nsMathMLElement::nsMathMLElement(already_AddRefed<mozilla::dom::NodeInfo>& aNodeInfo)
-: nsMathMLElementBase(aNodeInfo),
-  ALLOW_THIS_IN_INITIALIZER_LIST(Link(this)),
-  mIncrementScriptLevel(false)
-{
-}
+nsMathMLElement::nsMathMLElement(
+    already_AddRefed<mozilla::dom::NodeInfo>& aNodeInfo)
+    : nsMathMLElementBase(aNodeInfo),
+      ALLOW_THIS_IN_INITIALIZER_LIST(Link(this)),
+      mIncrementScriptLevel(false) {}
 
-nsMathMLElement::nsMathMLElement(already_AddRefed<mozilla::dom::NodeInfo>&& aNodeInfo)
-: nsMathMLElementBase(aNodeInfo),
-  ALLOW_THIS_IN_INITIALIZER_LIST(Link(this)),
-  mIncrementScriptLevel(false)
-{
-}
+nsMathMLElement::nsMathMLElement(
+    already_AddRefed<mozilla::dom::NodeInfo>&& aNodeInfo)
+    : nsMathMLElementBase(aNodeInfo),
+      ALLOW_THIS_IN_INITIALIZER_LIST(Link(this)),
+      mIncrementScriptLevel(false) {}
 
-nsresult
-nsMathMLElement::BindToTree(nsIDocument* aDocument, nsIContent* aParent,
-                            nsIContent* aBindingParent,
-                            bool aCompileEventHandlers)
-{
+nsresult nsMathMLElement::BindToTree(nsIDocument* aDocument,
+                                     nsIContent* aParent,
+                                     nsIContent* aBindingParent,
+                                     bool aCompileEventHandlers) {
   Link::ResetLinkState(false, Link::ElementHasHref());
 
-  nsresult rv = nsMathMLElementBase::BindToTree(aDocument, aParent,
-                                                aBindingParent,
-                                                aCompileEventHandlers);
+  nsresult rv = nsMathMLElementBase::BindToTree(
+      aDocument, aParent, aBindingParent, aCompileEventHandlers);
   NS_ENSURE_SUCCESS(rv, rv);
 
   if (aDocument) {
@@ -124,8 +107,8 @@ nsMathMLElement::BindToTree(nsIDocument* aDocument, nsIContent* aParent,
       // (See nsRuleNode::CheckSpecifiedProperties.)
       RefPtr<nsPresContext> presContext = doc->GetPresContext();
       if (presContext) {
-        presContext->
-          PostRebuildAllStyleDataEvent(nsChangeHint(0), eRestyle_Subtree);
+        presContext->PostRebuildAllStyleDataEvent(nsChangeHint(0),
+                                                  eRestyle_Subtree);
       }
     }
   }
@@ -133,9 +116,7 @@ nsMathMLElement::BindToTree(nsIDocument* aDocument, nsIContent* aParent,
   return rv;
 }
 
-void
-nsMathMLElement::UnbindFromTree(bool aDeep, bool aNullParent)
-{
+void nsMathMLElement::UnbindFromTree(bool aDeep, bool aNullParent) {
   // If this link is ever reinserted into a document, it might
   // be under a different xml:base, so forget the cached state now.
   Link::ResetLinkState(false, Link::ElementHasHref());
@@ -143,13 +124,10 @@ nsMathMLElement::UnbindFromTree(bool aDeep, bool aNullParent)
   nsMathMLElementBase::UnbindFromTree(aDeep, aNullParent);
 }
 
-bool
-nsMathMLElement::ParseAttribute(int32_t aNamespaceID,
-                                nsAtom* aAttribute,
-                                const nsAString& aValue,
-                                nsIPrincipal* aMaybeScriptedPrincipal,
-                                nsAttrValue& aResult)
-{
+bool nsMathMLElement::ParseAttribute(int32_t aNamespaceID, nsAtom* aAttribute,
+                                     const nsAString& aValue,
+                                     nsIPrincipal* aMaybeScriptedPrincipal,
+                                     nsAttrValue& aResult) {
   MOZ_ASSERT(IsMathMLElement());
 
   if (aNamespaceID == kNameSpaceID_None) {
@@ -161,8 +139,7 @@ nsMathMLElement::ParseAttribute(int32_t aNamespaceID,
       WarnDeprecated(nsGkAtoms::color->GetUTF16String(),
                      nsGkAtoms::mathcolor_->GetUTF16String(), OwnerDoc());
     }
-    if (aAttribute == nsGkAtoms::color ||
-        aAttribute == nsGkAtoms::mathcolor_ ||
+    if (aAttribute == nsGkAtoms::color || aAttribute == nsGkAtoms::mathcolor_ ||
         aAttribute == nsGkAtoms::background ||
         aAttribute == nsGkAtoms::mathbackground_) {
       return aResult.ParseColor(aValue);
@@ -179,74 +156,45 @@ nsMathMLElement::ParseAttribute(int32_t aNamespaceID,
     }
   }
 
-  return nsMathMLElementBase::ParseAttribute(aNamespaceID, aAttribute,
-                                             aValue,
-                                             aMaybeScriptedPrincipal,
-                                             aResult);
+  return nsMathMLElementBase::ParseAttribute(aNamespaceID, aAttribute, aValue,
+                                             aMaybeScriptedPrincipal, aResult);
 }
 
-static Element::MappedAttributeEntry sMtableStyles[] = {
-  { &nsGkAtoms::width },
-  { nullptr }
-};
+static Element::MappedAttributeEntry sMtableStyles[] = {{&nsGkAtoms::width},
+                                                        {nullptr}};
 
 static Element::MappedAttributeEntry sTokenStyles[] = {
-  { &nsGkAtoms::mathsize_ },
-  { &nsGkAtoms::fontsize_ },
-  { &nsGkAtoms::color },
-  { &nsGkAtoms::fontfamily_ },
-  { &nsGkAtoms::fontstyle_ },
-  { &nsGkAtoms::fontweight_ },
-  { &nsGkAtoms::mathvariant_},
-  { nullptr }
-};
+    {&nsGkAtoms::mathsize_},    {&nsGkAtoms::fontsize_},
+    {&nsGkAtoms::color},        {&nsGkAtoms::fontfamily_},
+    {&nsGkAtoms::fontstyle_},   {&nsGkAtoms::fontweight_},
+    {&nsGkAtoms::mathvariant_}, {nullptr}};
 
 static Element::MappedAttributeEntry sEnvironmentStyles[] = {
-  { &nsGkAtoms::scriptlevel_ },
-  { &nsGkAtoms::scriptminsize_ },
-  { &nsGkAtoms::scriptsizemultiplier_ },
-  { &nsGkAtoms::background },
-  { nullptr }
-};
+    {&nsGkAtoms::scriptlevel_},
+    {&nsGkAtoms::scriptminsize_},
+    {&nsGkAtoms::scriptsizemultiplier_},
+    {&nsGkAtoms::background},
+    {nullptr}};
 
 static Element::MappedAttributeEntry sCommonPresStyles[] = {
-  { &nsGkAtoms::mathcolor_ },
-  { &nsGkAtoms::mathbackground_ },
-  { nullptr }
-};
+    {&nsGkAtoms::mathcolor_}, {&nsGkAtoms::mathbackground_}, {nullptr}};
 
-static Element::MappedAttributeEntry sDirStyles[] = {
-  { &nsGkAtoms::dir },
-  { nullptr }
-};
+static Element::MappedAttributeEntry sDirStyles[] = {{&nsGkAtoms::dir},
+                                                     {nullptr}};
 
-bool
-nsMathMLElement::IsAttributeMapped(const nsAtom* aAttribute) const
-{
+bool nsMathMLElement::IsAttributeMapped(const nsAtom* aAttribute) const {
   MOZ_ASSERT(IsMathMLElement());
 
-  static const MappedAttributeEntry* const mtableMap[] = {
-    sMtableStyles,
-    sCommonPresStyles
-  };
+  static const MappedAttributeEntry* const mtableMap[] = {sMtableStyles,
+                                                          sCommonPresStyles};
   static const MappedAttributeEntry* const tokenMap[] = {
-    sTokenStyles,
-    sCommonPresStyles,
-    sDirStyles
-  };
+      sTokenStyles, sCommonPresStyles, sDirStyles};
   static const MappedAttributeEntry* const mstyleMap[] = {
-    sTokenStyles,
-    sEnvironmentStyles,
-    sCommonPresStyles,
-    sDirStyles
-  };
+      sTokenStyles, sEnvironmentStyles, sCommonPresStyles, sDirStyles};
   static const MappedAttributeEntry* const commonPresMap[] = {
-    sCommonPresStyles
-  };
-  static const MappedAttributeEntry* const mrowMap[] = {
-    sCommonPresStyles,
-    sDirStyles
-  };
+      sCommonPresStyles};
+  static const MappedAttributeEntry* const mrowMap[] = {sCommonPresStyles,
+                                                        sDirStyles};
 
   // We don't support mglyph (yet).
   if (IsAnyOfMathMLElements(nsGkAtoms::ms_, nsGkAtoms::mi_, nsGkAtoms::mn_,
@@ -262,86 +210,69 @@ nsMathMLElement::IsAttributeMapped(const nsAtom* aAttribute) const
   if (mNodeInfo->Equals(nsGkAtoms::mrow_))
     return FindAttributeDependence(aAttribute, mrowMap);
 
-  if (IsAnyOfMathMLElements(nsGkAtoms::maction_,
-                            nsGkAtoms::maligngroup_,
-                            nsGkAtoms::malignmark_,
-                            nsGkAtoms::menclose_,
-                            nsGkAtoms::merror_,
-                            nsGkAtoms::mfenced_,
-                            nsGkAtoms::mfrac_,
-                            nsGkAtoms::mover_,
-                            nsGkAtoms::mpadded_,
-                            nsGkAtoms::mphantom_,
-                            nsGkAtoms::mprescripts_,
-                            nsGkAtoms::mroot_,
-                            nsGkAtoms::msqrt_,
-                            nsGkAtoms::msub_,
-                            nsGkAtoms::msubsup_,
-                            nsGkAtoms::msup_,
-                            nsGkAtoms::mtd_,
-                            nsGkAtoms::mtr_,
-                            nsGkAtoms::munder_,
-                            nsGkAtoms::munderover_,
-                            nsGkAtoms::none)) {
+  if (IsAnyOfMathMLElements(
+          nsGkAtoms::maction_, nsGkAtoms::maligngroup_, nsGkAtoms::malignmark_,
+          nsGkAtoms::menclose_, nsGkAtoms::merror_, nsGkAtoms::mfenced_,
+          nsGkAtoms::mfrac_, nsGkAtoms::mover_, nsGkAtoms::mpadded_,
+          nsGkAtoms::mphantom_, nsGkAtoms::mprescripts_, nsGkAtoms::mroot_,
+          nsGkAtoms::msqrt_, nsGkAtoms::msub_, nsGkAtoms::msubsup_,
+          nsGkAtoms::msup_, nsGkAtoms::mtd_, nsGkAtoms::mtr_,
+          nsGkAtoms::munder_, nsGkAtoms::munderover_, nsGkAtoms::none)) {
     return FindAttributeDependence(aAttribute, commonPresMap);
   }
 
   return false;
 }
 
-nsMapRuleToAttributesFunc
-nsMathMLElement::GetAttributeMappingFunction() const
-{
+nsMapRuleToAttributesFunc nsMathMLElement::GetAttributeMappingFunction() const {
   // It doesn't really matter what our tag is here, because only attributes
   // that satisfy IsAttributeMapped will be stored in the mapped attributes
   // list and available to the mapping function
   return &MapMathMLAttributesInto;
 }
 
-/* static */ bool
-nsMathMLElement::ParseNamedSpaceValue(const nsString& aString,
-                                      nsCSSValue&     aCSSValue,
-                                      uint32_t        aFlags)
-{
-   int32_t i = 0;
-   // See if it is one of the 'namedspace' (ranging -7/18em, -6/18, ... 7/18em)
-   if (aString.EqualsLiteral("veryverythinmathspace")) {
-     i = 1;
-   } else if (aString.EqualsLiteral("verythinmathspace")) {
-     i = 2;
-   } else if (aString.EqualsLiteral("thinmathspace")) {
-     i = 3;
-   } else if (aString.EqualsLiteral("mediummathspace")) {
-     i = 4;
-   } else if (aString.EqualsLiteral("thickmathspace")) {
-     i = 5;
-   } else if (aString.EqualsLiteral("verythickmathspace")) {
-     i = 6;
-   } else if (aString.EqualsLiteral("veryverythickmathspace")) {
-     i = 7;
-   } else if (aFlags & PARSE_ALLOW_NEGATIVE) {
-     if (aString.EqualsLiteral("negativeveryverythinmathspace")) {
-       i = -1;
-     } else if (aString.EqualsLiteral("negativeverythinmathspace")) {
-       i = -2;
-     } else if (aString.EqualsLiteral("negativethinmathspace")) {
-       i = -3;
-     } else if (aString.EqualsLiteral("negativemediummathspace")) {
-       i = -4;
-     } else if (aString.EqualsLiteral("negativethickmathspace")) {
-       i = -5;
-     } else if (aString.EqualsLiteral("negativeverythickmathspace")) {
-       i = -6;
-     } else if (aString.EqualsLiteral("negativeveryverythickmathspace")) {
-       i = -7;
-     }
-   }
-   if (0 != i) {
-     aCSSValue.SetFloatValue(float(i)/float(18), eCSSUnit_EM);
-     return true;
-   }
+/* static */ bool nsMathMLElement::ParseNamedSpaceValue(const nsString& aString,
+                                                        nsCSSValue& aCSSValue,
+                                                        uint32_t aFlags) {
+  int32_t i = 0;
+  // See if it is one of the 'namedspace' (ranging -7/18em, -6/18, ... 7/18em)
+  if (aString.EqualsLiteral("veryverythinmathspace")) {
+    i = 1;
+  } else if (aString.EqualsLiteral("verythinmathspace")) {
+    i = 2;
+  } else if (aString.EqualsLiteral("thinmathspace")) {
+    i = 3;
+  } else if (aString.EqualsLiteral("mediummathspace")) {
+    i = 4;
+  } else if (aString.EqualsLiteral("thickmathspace")) {
+    i = 5;
+  } else if (aString.EqualsLiteral("verythickmathspace")) {
+    i = 6;
+  } else if (aString.EqualsLiteral("veryverythickmathspace")) {
+    i = 7;
+  } else if (aFlags & PARSE_ALLOW_NEGATIVE) {
+    if (aString.EqualsLiteral("negativeveryverythinmathspace")) {
+      i = -1;
+    } else if (aString.EqualsLiteral("negativeverythinmathspace")) {
+      i = -2;
+    } else if (aString.EqualsLiteral("negativethinmathspace")) {
+      i = -3;
+    } else if (aString.EqualsLiteral("negativemediummathspace")) {
+      i = -4;
+    } else if (aString.EqualsLiteral("negativethickmathspace")) {
+      i = -5;
+    } else if (aString.EqualsLiteral("negativeverythickmathspace")) {
+      i = -6;
+    } else if (aString.EqualsLiteral("negativeveryverythickmathspace")) {
+      i = -7;
+    }
+  }
+  if (0 != i) {
+    aCSSValue.SetFloatValue(float(i) / float(18), eCSSUnit_EM);
+    return true;
+  }
 
-   return false;
+  return false;
 }
 
 // The REC says:
@@ -380,14 +311,12 @@ nsMathMLElement::ParseNamedSpaceValue(const nsString& aString,
 //   number, representing a terminating decimal number (a type of rational
 //   number)"
 //
-/* static */ bool
-nsMathMLElement::ParseNumericValue(const nsString& aString,
-                                   nsCSSValue&     aCSSValue,
-                                   uint32_t        aFlags,
-                                   nsIDocument*    aDocument)
-{
+/* static */ bool nsMathMLElement::ParseNumericValue(const nsString& aString,
+                                                     nsCSSValue& aCSSValue,
+                                                     uint32_t aFlags,
+                                                     nsIDocument* aDocument) {
   nsAutoString str(aString);
-  str.CompressWhitespace(); // aString is const in this code...
+  str.CompressWhitespace();  // aString is const in this code...
 
   int32_t stringLength = str.Length();
   if (!stringLength) {
@@ -413,15 +342,14 @@ nsMathMLElement::ParseNumericValue(const nsString& aString,
 
   // Gather up characters that make up the number
   bool gotDot = false;
-  for ( ; i < stringLength; i++) {
+  for (; i < stringLength; i++) {
     c = str[i];
     if (gotDot && c == '.') {
       if (!(aFlags & PARSE_SUPPRESS_WARNINGS)) {
         ReportLengthParseError(aString, aDocument);
       }
       return false;  // two dots encountered
-    }
-    else if (c == '.')
+    } else if (c == '.')
       gotDot = true;
     else if (!nsCRT::IsAsciiDigit(c)) {
       str.Right(unit, stringLength - i);
@@ -461,8 +389,7 @@ nsMathMLElement::ParseNumericValue(const nsString& aString,
       if (aFlags & CONVERT_UNITLESS_TO_PERCENT) {
         aCSSValue.SetPercentValue(floatValue);
         return true;
-      }
-      else
+      } else
         cssUnit = eCSSUnit_Number;
     } else {
       // We are supposed to have a unit, but there isn't one.
@@ -476,21 +403,28 @@ nsMathMLElement::ParseNumericValue(const nsString& aString,
       }
       cssUnit = eCSSUnit_Pixel;
     }
-  }
-  else if (unit.EqualsLiteral("%")) {
+  } else if (unit.EqualsLiteral("%")) {
     aCSSValue.SetPercentValue(floatValue / 100.0f);
     return true;
-  }
-  else if (unit.EqualsLiteral("em")) cssUnit = eCSSUnit_EM;
-  else if (unit.EqualsLiteral("ex")) cssUnit = eCSSUnit_XHeight;
-  else if (unit.EqualsLiteral("px")) cssUnit = eCSSUnit_Pixel;
-  else if (unit.EqualsLiteral("in")) cssUnit = eCSSUnit_Inch;
-  else if (unit.EqualsLiteral("cm")) cssUnit = eCSSUnit_Centimeter;
-  else if (unit.EqualsLiteral("mm")) cssUnit = eCSSUnit_Millimeter;
-  else if (unit.EqualsLiteral("pt")) cssUnit = eCSSUnit_Point;
-  else if (unit.EqualsLiteral("pc")) cssUnit = eCSSUnit_Pica;
-  else if (unit.EqualsLiteral("q")) cssUnit = eCSSUnit_Quarter;
-  else { // unexpected unit
+  } else if (unit.EqualsLiteral("em"))
+    cssUnit = eCSSUnit_EM;
+  else if (unit.EqualsLiteral("ex"))
+    cssUnit = eCSSUnit_XHeight;
+  else if (unit.EqualsLiteral("px"))
+    cssUnit = eCSSUnit_Pixel;
+  else if (unit.EqualsLiteral("in"))
+    cssUnit = eCSSUnit_Inch;
+  else if (unit.EqualsLiteral("cm"))
+    cssUnit = eCSSUnit_Centimeter;
+  else if (unit.EqualsLiteral("mm"))
+    cssUnit = eCSSUnit_Millimeter;
+  else if (unit.EqualsLiteral("pt"))
+    cssUnit = eCSSUnit_Point;
+  else if (unit.EqualsLiteral("pc"))
+    cssUnit = eCSSUnit_Pica;
+  else if (unit.EqualsLiteral("q"))
+    cssUnit = eCSSUnit_Quarter;
+  else {  // unexpected unit
     if (!(aFlags & PARSE_SUPPRESS_WARNINGS)) {
       ReportLengthParseError(aString, aDocument);
     }
@@ -501,10 +435,8 @@ nsMathMLElement::ParseNumericValue(const nsString& aString,
   return true;
 }
 
-void
-nsMathMLElement::MapMathMLAttributesInto(const nsMappedAttributes* aAttributes,
-                                         GenericSpecifiedValues* aData)
-{
+void nsMathMLElement::MapMathMLAttributesInto(
+    const nsMappedAttributes* aAttributes, GenericSpecifiedValues* aData) {
   if (aData->mSIDs & NS_STYLE_INHERIT_BIT(Font)) {
     // scriptsizemultiplier
     //
@@ -515,7 +447,7 @@ nsMathMLElement::MapMathMLAttributesInto(const nsMappedAttributes* aAttributes,
     // default: 0.71
     //
     const nsAttrValue* value =
-      aAttributes->GetAttr(nsGkAtoms::scriptsizemultiplier_);
+        aAttributes->GetAttr(nsGkAtoms::scriptsizemultiplier_);
     if (value && value->Type() == nsAttrValue::eString &&
         !aData->PropertyIsSet(eCSSProperty__moz_script_size_multiplier)) {
       nsAutoString str(value->GetStringValue());
@@ -526,10 +458,10 @@ nsMathMLElement::MapMathMLAttributesInto(const nsMappedAttributes* aAttributes,
         float floatValue = str.ToFloat(&errorCode);
         // Negative scriptsizemultipliers are not parsed
         if (NS_SUCCEEDED(errorCode) && floatValue >= 0.0f) {
-          aData->SetNumberValue(eCSSProperty__moz_script_size_multiplier, floatValue);
+          aData->SetNumberValue(eCSSProperty__moz_script_size_multiplier,
+                                floatValue);
         } else {
-          ReportParseErrorNoTag(str,
-                                nsGkAtoms::scriptsizemultiplier_,
+          ReportParseErrorNoTag(str, nsGkAtoms::scriptsizemultiplier_,
                                 aData->Document());
         }
       }
@@ -556,7 +488,7 @@ nsMathMLElement::MapMathMLAttributesInto(const nsMappedAttributes* aAttributes,
 
       if (scriptMinSize.GetUnit() == eCSSUnit_Percent) {
         scriptMinSize.SetFloatValue(8.0 * scriptMinSize.GetPercentValue(),
-                                     eCSSUnit_Point);
+                                    eCSSUnit_Point);
       }
       if (scriptMinSize.GetUnit() != eCSSUnit_Null) {
         aData->SetLengthValue(eCSSProperty__moz_script_min_size, scriptMinSize);
@@ -594,8 +526,7 @@ nsMathMLElement::MapMathMLAttributesInto(const nsMappedAttributes* aAttributes,
             aData->SetNumberValue(eCSSProperty__moz_script_level, intValue);
           }
         } else {
-          ReportParseErrorNoTag(str,
-                                nsGkAtoms::scriptlevel_,
+          ReportParseErrorNoTag(str, nsGkAtoms::scriptlevel_,
                                 aData->Document());
         }
       }
@@ -637,15 +568,15 @@ nsMathMLElement::MapMathMLAttributesInto(const nsMappedAttributes* aAttributes,
         !aData->PropertyIsSet(eCSSProperty_font_size)) {
       nsAutoString str(value->GetStringValue());
       nsCSSValue fontSize;
-      if (!ParseNumericValue(str, fontSize, PARSE_SUPPRESS_WARNINGS |
-                             PARSE_ALLOW_UNITLESS | CONVERT_UNITLESS_TO_PERCENT,
-                             nullptr)
-          && parseSizeKeywords) {
-        static const char sizes[3][7] = { "small", "normal", "big" };
+      if (!ParseNumericValue(str, fontSize,
+                             PARSE_SUPPRESS_WARNINGS | PARSE_ALLOW_UNITLESS |
+                                 CONVERT_UNITLESS_TO_PERCENT,
+                             nullptr) &&
+          parseSizeKeywords) {
+        static const char sizes[3][7] = {"small", "normal", "big"};
         static const int32_t values[MOZ_ARRAY_LENGTH(sizes)] = {
-          NS_STYLE_FONT_SIZE_SMALL, NS_STYLE_FONT_SIZE_MEDIUM,
-          NS_STYLE_FONT_SIZE_LARGE
-        };
+            NS_STYLE_FONT_SIZE_SMALL, NS_STYLE_FONT_SIZE_MEDIUM,
+            NS_STYLE_FONT_SIZE_LARGE};
         str.CompressWhitespace();
         for (uint32_t i = 0; i < ArrayLength(sizes); ++i) {
           if (str.EqualsASCII(sizes[i])) {
@@ -693,8 +624,8 @@ nsMathMLElement::MapMathMLAttributesInto(const nsMappedAttributes* aAttributes,
     value = aAttributes->GetAttr(nsGkAtoms::fontstyle_);
     if (value) {
       WarnDeprecated(nsGkAtoms::fontstyle_->GetUTF16String(),
-                       nsGkAtoms::mathvariant_->GetUTF16String(),
-                       aData->Document());
+                     nsGkAtoms::mathvariant_->GetUTF16String(),
+                     aData->Document());
       if (value->Type() == nsAttrValue::eString &&
           !aData->PropertyIsSet(eCSSProperty_font_style)) {
         nsAutoString str(value->GetStringValue());
@@ -722,8 +653,8 @@ nsMathMLElement::MapMathMLAttributesInto(const nsMappedAttributes* aAttributes,
     value = aAttributes->GetAttr(nsGkAtoms::fontweight_);
     if (value) {
       WarnDeprecated(nsGkAtoms::fontweight_->GetUTF16String(),
-                       nsGkAtoms::mathvariant_->GetUTF16String(),
-                       aData->Document());
+                     nsGkAtoms::mathvariant_->GetUTF16String(),
+                     aData->Document());
       if (value->Type() == nsAttrValue::eString &&
           !aData->PropertyIsSet(eCSSProperty_font_weight)) {
         nsAutoString str(value->GetStringValue());
@@ -754,25 +685,43 @@ nsMathMLElement::MapMathMLAttributesInto(const nsMappedAttributes* aAttributes,
         !aData->PropertyIsSet(eCSSProperty__moz_math_variant)) {
       nsAutoString str(value->GetStringValue());
       str.CompressWhitespace();
-      static const char sizes[19][23] = {
-        "normal", "bold", "italic", "bold-italic", "script", "bold-script",
-        "fraktur", "double-struck", "bold-fraktur", "sans-serif",
-        "bold-sans-serif", "sans-serif-italic", "sans-serif-bold-italic",
-        "monospace", "initial", "tailed", "looped", "stretched"
-      };
+      static const char sizes[19][23] = {"normal",
+                                         "bold",
+                                         "italic",
+                                         "bold-italic",
+                                         "script",
+                                         "bold-script",
+                                         "fraktur",
+                                         "double-struck",
+                                         "bold-fraktur",
+                                         "sans-serif",
+                                         "bold-sans-serif",
+                                         "sans-serif-italic",
+                                         "sans-serif-bold-italic",
+                                         "monospace",
+                                         "initial",
+                                         "tailed",
+                                         "looped",
+                                         "stretched"};
       static const int32_t values[MOZ_ARRAY_LENGTH(sizes)] = {
-        NS_MATHML_MATHVARIANT_NORMAL, NS_MATHML_MATHVARIANT_BOLD,
-        NS_MATHML_MATHVARIANT_ITALIC, NS_MATHML_MATHVARIANT_BOLD_ITALIC,
-        NS_MATHML_MATHVARIANT_SCRIPT, NS_MATHML_MATHVARIANT_BOLD_SCRIPT,
-        NS_MATHML_MATHVARIANT_FRAKTUR, NS_MATHML_MATHVARIANT_DOUBLE_STRUCK,
-        NS_MATHML_MATHVARIANT_BOLD_FRAKTUR, NS_MATHML_MATHVARIANT_SANS_SERIF,
-        NS_MATHML_MATHVARIANT_BOLD_SANS_SERIF,
-        NS_MATHML_MATHVARIANT_SANS_SERIF_ITALIC,
-        NS_MATHML_MATHVARIANT_SANS_SERIF_BOLD_ITALIC,
-        NS_MATHML_MATHVARIANT_MONOSPACE, NS_MATHML_MATHVARIANT_INITIAL,
-        NS_MATHML_MATHVARIANT_TAILED, NS_MATHML_MATHVARIANT_LOOPED,
-        NS_MATHML_MATHVARIANT_STRETCHED
-      };
+          NS_MATHML_MATHVARIANT_NORMAL,
+          NS_MATHML_MATHVARIANT_BOLD,
+          NS_MATHML_MATHVARIANT_ITALIC,
+          NS_MATHML_MATHVARIANT_BOLD_ITALIC,
+          NS_MATHML_MATHVARIANT_SCRIPT,
+          NS_MATHML_MATHVARIANT_BOLD_SCRIPT,
+          NS_MATHML_MATHVARIANT_FRAKTUR,
+          NS_MATHML_MATHVARIANT_DOUBLE_STRUCK,
+          NS_MATHML_MATHVARIANT_BOLD_FRAKTUR,
+          NS_MATHML_MATHVARIANT_SANS_SERIF,
+          NS_MATHML_MATHVARIANT_BOLD_SANS_SERIF,
+          NS_MATHML_MATHVARIANT_SANS_SERIF_ITALIC,
+          NS_MATHML_MATHVARIANT_SANS_SERIF_BOLD_ITALIC,
+          NS_MATHML_MATHVARIANT_MONOSPACE,
+          NS_MATHML_MATHVARIANT_INITIAL,
+          NS_MATHML_MATHVARIANT_TAILED,
+          NS_MATHML_MATHVARIANT_LOOPED,
+          NS_MATHML_MATHVARIANT_STRETCHED};
       for (uint32_t i = 0; i < ArrayLength(sizes); ++i) {
         if (str.EqualsASCII(sizes[i])) {
           aData->SetKeywordValue(eCSSProperty__moz_math_variant, values[i]);
@@ -801,8 +750,7 @@ nsMathMLElement::MapMathMLAttributesInto(const nsMappedAttributes* aAttributes,
   // default: "transparent"
   //
   if (aData->mSIDs & NS_STYLE_INHERIT_BIT(Background)) {
-    const nsAttrValue* value =
-      aAttributes->GetAttr(nsGkAtoms::mathbackground_);
+    const nsAttrValue* value = aAttributes->GetAttr(nsGkAtoms::mathbackground_);
     if (!value) {
       value = aAttributes->GetAttr(nsGkAtoms::background);
       if (value) {
@@ -872,8 +820,7 @@ nsMathMLElement::MapMathMLAttributesInto(const nsMappedAttributes* aAttributes,
       if (value && value->Type() == nsAttrValue::eString) {
         ParseNumericValue(value->GetStringValue(), width, 0, aData->Document());
         if (width.GetUnit() == eCSSUnit_Percent) {
-          aData->SetPercentValue(eCSSProperty_width,
-                                 width.GetPercentValue());
+          aData->SetPercentValue(eCSSProperty_width, width.GetPercentValue());
         } else if (width.GetUnit() != eCSSUnit_Null) {
           aData->SetLengthValue(eCSSProperty_width, width);
         }
@@ -906,10 +853,9 @@ nsMathMLElement::MapMathMLAttributesInto(const nsMappedAttributes* aAttributes,
     if (value && value->Type() == nsAttrValue::eString &&
         !aData->PropertyIsSet(eCSSProperty_direction)) {
       nsAutoString str(value->GetStringValue());
-      static const char dirs[][4] = { "ltr", "rtl" };
+      static const char dirs[][4] = {"ltr", "rtl"};
       static const int32_t dirValues[MOZ_ARRAY_LENGTH(dirs)] = {
-        NS_STYLE_DIRECTION_LTR, NS_STYLE_DIRECTION_RTL
-      };
+          NS_STYLE_DIRECTION_LTR, NS_STYLE_DIRECTION_RTL};
       for (uint32_t i = 0; i < ArrayLength(dirs); ++i) {
         if (str.EqualsASCII(dirs[i])) {
           aData->SetKeywordValue(eCSSProperty_direction, dirValues[i]);
@@ -920,43 +866,30 @@ nsMathMLElement::MapMathMLAttributesInto(const nsMappedAttributes* aAttributes,
   }
 }
 
-nsresult
-nsMathMLElement::GetEventTargetParent(EventChainPreVisitor& aVisitor)
-{
+nsresult nsMathMLElement::GetEventTargetParent(EventChainPreVisitor& aVisitor) {
   nsresult rv = Element::GetEventTargetParent(aVisitor);
   NS_ENSURE_SUCCESS(rv, rv);
 
   return GetEventTargetParentForLinks(aVisitor);
 }
 
-nsresult
-nsMathMLElement::PostHandleEvent(EventChainPostVisitor& aVisitor)
-{
+nsresult nsMathMLElement::PostHandleEvent(EventChainPostVisitor& aVisitor) {
   return PostHandleEventForLinks(aVisitor);
 }
 
 NS_IMPL_ELEMENT_CLONE(nsMathMLElement)
 
-EventStates
-nsMathMLElement::IntrinsicState() const
-{
+EventStates nsMathMLElement::IntrinsicState() const {
   return Link::LinkState() | nsMathMLElementBase::IntrinsicState() |
-    (mIncrementScriptLevel ?
-       NS_EVENT_STATE_INCREMENT_SCRIPT_LEVEL : EventStates());
+         (mIncrementScriptLevel ? NS_EVENT_STATE_INCREMENT_SCRIPT_LEVEL
+                                : EventStates());
 }
 
-bool
-nsMathMLElement::IsNodeOfType(uint32_t aFlags) const
-{
-  return false;
-}
+bool nsMathMLElement::IsNodeOfType(uint32_t aFlags) const { return false; }
 
-void
-nsMathMLElement::SetIncrementScriptLevel(bool aIncrementScriptLevel,
-                                         bool aNotify)
-{
-  if (aIncrementScriptLevel == mIncrementScriptLevel)
-    return;
+void nsMathMLElement::SetIncrementScriptLevel(bool aIncrementScriptLevel,
+                                              bool aNotify) {
+  if (aIncrementScriptLevel == mIncrementScriptLevel) return;
   mIncrementScriptLevel = aIncrementScriptLevel;
 
   NS_ASSERTION(aNotify, "We always notify!");
@@ -964,9 +897,7 @@ nsMathMLElement::SetIncrementScriptLevel(bool aIncrementScriptLevel,
   UpdateState(true);
 }
 
-bool
-nsMathMLElement::IsFocusableInternal(int32_t* aTabIndex, bool aWithMouse)
-{
+bool nsMathMLElement::IsFocusableInternal(int32_t* aTabIndex, bool aWithMouse) {
   nsCOMPtr<nsIURI> uri;
   if (IsLink(getter_AddRefs(uri))) {
     if (aTabIndex) {
@@ -982,9 +913,7 @@ nsMathMLElement::IsFocusableInternal(int32_t* aTabIndex, bool aWithMouse)
   return false;
 }
 
-bool
-nsMathMLElement::IsLink(nsIURI** aURI) const
-{
+bool nsMathMLElement::IsLink(nsIURI** aURI) const {
   // http://www.w3.org/TR/2010/REC-MathML3-20101021/chapter6.html#interf.link
   // The REC says that the following elements should not be linking elements:
   if (IsAnyOfMathMLElements(nsGkAtoms::mprescripts_, nsGkAtoms::none,
@@ -994,8 +923,8 @@ nsMathMLElement::IsLink(nsIURI** aURI) const
   }
 
   bool hasHref = false;
-  const nsAttrValue* href = mAttrsAndChildren.GetAttr(nsGkAtoms::href,
-                                                      kNameSpaceID_None);
+  const nsAttrValue* href =
+      mAttrsAndChildren.GetAttr(nsGkAtoms::href, kNameSpaceID_None);
   if (href) {
     // MathML href
     // The REC says: "When user agents encounter MathML elements with both href
@@ -1012,28 +941,24 @@ nsMathMLElement::IsLink(nsIURI** aURI) const
     // For any other values, we're either not a *clickable* XLink, or the end
     // result is poorly specified. Either way, we return false.
 
-    static Element::AttrValuesArray sTypeVals[] =
-      { &nsGkAtoms::_empty, &nsGkAtoms::simple, nullptr };
+    static Element::AttrValuesArray sTypeVals[] = {&nsGkAtoms::_empty,
+                                                   &nsGkAtoms::simple, nullptr};
 
-    static Element::AttrValuesArray sShowVals[] =
-      { &nsGkAtoms::_empty, &nsGkAtoms::_new, &nsGkAtoms::replace, nullptr };
+    static Element::AttrValuesArray sShowVals[] = {
+        &nsGkAtoms::_empty, &nsGkAtoms::_new, &nsGkAtoms::replace, nullptr};
 
-    static Element::AttrValuesArray sActuateVals[] =
-      { &nsGkAtoms::_empty, &nsGkAtoms::onRequest, nullptr };
+    static Element::AttrValuesArray sActuateVals[] = {
+        &nsGkAtoms::_empty, &nsGkAtoms::onRequest, nullptr};
 
     // Optimization: check for href first for early return
-    href = mAttrsAndChildren.GetAttr(nsGkAtoms::href,
-                                     kNameSpaceID_XLink);
+    href = mAttrsAndChildren.GetAttr(nsGkAtoms::href, kNameSpaceID_XLink);
     if (href &&
-        FindAttrValueIn(kNameSpaceID_XLink, nsGkAtoms::type,
-                        sTypeVals, eCaseMatters) !=
-        Element::ATTR_VALUE_NO_MATCH &&
-        FindAttrValueIn(kNameSpaceID_XLink, nsGkAtoms::show,
-                        sShowVals, eCaseMatters) !=
-        Element::ATTR_VALUE_NO_MATCH &&
-        FindAttrValueIn(kNameSpaceID_XLink, nsGkAtoms::actuate,
-                        sActuateVals, eCaseMatters) !=
-        Element::ATTR_VALUE_NO_MATCH) {
+        FindAttrValueIn(kNameSpaceID_XLink, nsGkAtoms::type, sTypeVals,
+                        eCaseMatters) != Element::ATTR_VALUE_NO_MATCH &&
+        FindAttrValueIn(kNameSpaceID_XLink, nsGkAtoms::show, sShowVals,
+                        eCaseMatters) != Element::ATTR_VALUE_NO_MATCH &&
+        FindAttrValueIn(kNameSpaceID_XLink, nsGkAtoms::actuate, sActuateVals,
+                        eCaseMatters) != Element::ATTR_VALUE_NO_MATCH) {
       hasHref = true;
     }
   }
@@ -1043,8 +968,8 @@ nsMathMLElement::IsLink(nsIURI** aURI) const
     // Get absolute URI
     nsAutoString hrefStr;
     href->ToString(hrefStr);
-    nsContentUtils::NewURIWithDocumentCharset(aURI, hrefStr,
-                                              OwnerDoc(), baseURI);
+    nsContentUtils::NewURIWithDocumentCharset(aURI, hrefStr, OwnerDoc(),
+                                              baseURI);
     // must promise out param is non-null if we return true
     return !!*aURI;
   }
@@ -1053,53 +978,45 @@ nsMathMLElement::IsLink(nsIURI** aURI) const
   return false;
 }
 
-void
-nsMathMLElement::GetLinkTarget(nsAString& aTarget)
-{
-  const nsAttrValue* target = mAttrsAndChildren.GetAttr(nsGkAtoms::target,
-                                                        kNameSpaceID_XLink);
+void nsMathMLElement::GetLinkTarget(nsAString& aTarget) {
+  const nsAttrValue* target =
+      mAttrsAndChildren.GetAttr(nsGkAtoms::target, kNameSpaceID_XLink);
   if (target) {
     target->ToString(aTarget);
   }
 
   if (aTarget.IsEmpty()) {
+    static Element::AttrValuesArray sShowVals[] = {
+        &nsGkAtoms::_new, &nsGkAtoms::replace, nullptr};
 
-    static Element::AttrValuesArray sShowVals[] =
-      { &nsGkAtoms::_new, &nsGkAtoms::replace, nullptr };
-
-    switch (FindAttrValueIn(kNameSpaceID_XLink, nsGkAtoms::show,
-                            sShowVals, eCaseMatters)) {
-    case 0:
-      aTarget.AssignLiteral("_blank");
-      return;
-    case 1:
-      return;
+    switch (FindAttrValueIn(kNameSpaceID_XLink, nsGkAtoms::show, sShowVals,
+                            eCaseMatters)) {
+      case 0:
+        aTarget.AssignLiteral("_blank");
+        return;
+      case 1:
+        return;
     }
     OwnerDoc()->GetBaseTarget(aTarget);
   }
 }
 
-already_AddRefed<nsIURI>
-nsMathMLElement::GetHrefURI() const
-{
+already_AddRefed<nsIURI> nsMathMLElement::GetHrefURI() const {
   nsCOMPtr<nsIURI> hrefURI;
   return IsLink(getter_AddRefs(hrefURI)) ? hrefURI.forget() : nullptr;
 }
 
-nsresult
-nsMathMLElement::AfterSetAttr(int32_t aNameSpaceID, nsAtom* aName,
-                              const nsAttrValue* aValue,
-                              const nsAttrValue* aOldValue,
-                              nsIPrincipal* aSubjectPrincipal,
-                              bool aNotify)
-{
+nsresult nsMathMLElement::AfterSetAttr(int32_t aNameSpaceID, nsAtom* aName,
+                                       const nsAttrValue* aValue,
+                                       const nsAttrValue* aOldValue,
+                                       nsIPrincipal* aSubjectPrincipal,
+                                       bool aNotify) {
   // It is important that this be done after the attribute is set/unset.
   // We will need the updated attribute value because notifying the document
   // that content states have changed will call IntrinsicState, which will try
   // to get updated information about the visitedness from Link.
-  if (aName == nsGkAtoms::href &&
-      (aNameSpaceID == kNameSpaceID_None ||
-       aNameSpaceID == kNameSpaceID_XLink)) {
+  if (aName == nsGkAtoms::href && (aNameSpaceID == kNameSpaceID_None ||
+                                   aNameSpaceID == kNameSpaceID_XLink)) {
     if (aValue && aNameSpaceID == kNameSpaceID_XLink) {
       WarnDeprecated(u"xlink:href", u"href", OwnerDoc());
     }
@@ -1108,12 +1025,11 @@ nsMathMLElement::AfterSetAttr(int32_t aNameSpaceID, nsAtom* aName,
     Link::ResetLinkState(aNotify, aValue || Link::ElementHasHref());
   }
 
-  return nsMathMLElementBase::AfterSetAttr(aNameSpaceID, aName, aValue,
-                                           aOldValue, aSubjectPrincipal, aNotify);
+  return nsMathMLElementBase::AfterSetAttr(
+      aNameSpaceID, aName, aValue, aOldValue, aSubjectPrincipal, aNotify);
 }
 
-JSObject*
-nsMathMLElement::WrapNode(JSContext *aCx, JS::Handle<JSObject*> aGivenProto)
-{
+JSObject* nsMathMLElement::WrapNode(JSContext* aCx,
+                                    JS::Handle<JSObject*> aGivenProto) {
   return ElementBinding::Wrap(aCx, this, aGivenProto);
 }
