@@ -44,12 +44,9 @@ NS_IMPL_CYCLE_COLLECTION_TRAVERSE_BEGIN(MediaStreamTrackSource)
   NS_IMPL_CYCLE_COLLECTION_TRAVERSE(mPrincipal)
 NS_IMPL_CYCLE_COLLECTION_TRAVERSE_END
 
-auto
-MediaStreamTrackSource::ApplyConstraints(
-    nsPIDOMWindowInner* aWindow,
-    const dom::MediaTrackConstraints& aConstraints,
-    CallerType aCallerType) -> already_AddRefed<PledgeVoid>
-{
+auto MediaStreamTrackSource::ApplyConstraints(
+    nsPIDOMWindowInner* aWindow, const dom::MediaTrackConstraints& aConstraints,
+    CallerType aCallerType) -> already_AddRefed<PledgeVoid> {
   RefPtr<PledgeVoid> p = new PledgeVoid();
   p->Reject(new MediaStreamError(aWindow,
                                  NS_LITERAL_STRING("OverconstrainedError"),
@@ -58,15 +55,16 @@ MediaStreamTrackSource::ApplyConstraints(
 }
 
 /**
- * PrincipalHandleListener monitors changes in PrincipalHandle of the media flowing
- * through the MediaStreamGraph.
+ * PrincipalHandleListener monitors changes in PrincipalHandle of the media
+ * flowing through the MediaStreamGraph.
  *
  * When the main thread principal for a MediaStreamTrack changes, its principal
  * will be set to the combination of the previous principal and the new one.
  *
- * As a PrincipalHandle change later happens on the MediaStreamGraph thread, we will
- * be notified. If the latest principal on main thread matches the PrincipalHandle
- * we just saw on MSG thread, we will set the track's principal to the new one.
+ * As a PrincipalHandle change later happens on the MediaStreamGraph thread, we
+ * will be notified. If the latest principal on main thread matches the
+ * PrincipalHandle we just saw on MSG thread, we will set the track's principal
+ * to the new one.
  *
  * We know at this point that the old principal has been flushed out and data
  * under it cannot leak to consumers.
@@ -75,21 +73,18 @@ MediaStreamTrackSource::ApplyConstraints(
  * will be a combination of its old principal and all the new ones until the
  * latest main thread principal matches the PrincipalHandle on the MSG thread.
  */
-class MediaStreamTrack::PrincipalHandleListener : public MediaStreamTrackListener
-{
-public:
-  explicit PrincipalHandleListener(MediaStreamTrack* aTrack)
-    : mTrack(aTrack)
-    {}
+class MediaStreamTrack::PrincipalHandleListener
+    : public MediaStreamTrackListener {
+ public:
+  explicit PrincipalHandleListener(MediaStreamTrack* aTrack) : mTrack(aTrack) {}
 
-  void Forget()
-  {
+  void Forget() {
     MOZ_ASSERT(NS_IsMainThread());
     mTrack = nullptr;
   }
 
-  void DoNotifyPrincipalHandleChanged(const PrincipalHandle& aNewPrincipalHandle)
-  {
+  void DoNotifyPrincipalHandleChanged(
+      const PrincipalHandle& aNewPrincipalHandle) {
     MOZ_ASSERT(NS_IsMainThread());
 
     if (!mTrack) {
@@ -99,19 +94,18 @@ public:
     mTrack->NotifyPrincipalHandleChanged(aNewPrincipalHandle);
   }
 
-  void NotifyPrincipalHandleChanged(MediaStreamGraph* aGraph,
-                                    const PrincipalHandle& aNewPrincipalHandle) override
-  {
+  void NotifyPrincipalHandleChanged(
+      MediaStreamGraph* aGraph,
+      const PrincipalHandle& aNewPrincipalHandle) override {
     aGraph->DispatchToMainThreadAfterStreamStateUpdate(
-      NewRunnableMethod<StoreCopyPassByConstLRef<PrincipalHandle>>(
-        "dom::MediaStreamTrack::PrincipalHandleListener::"
-        "DoNotifyPrincipalHandleChanged",
-        this,
-        &PrincipalHandleListener::DoNotifyPrincipalHandleChanged,
-        aNewPrincipalHandle));
+        NewRunnableMethod<StoreCopyPassByConstLRef<PrincipalHandle>>(
+            "dom::MediaStreamTrack::PrincipalHandleListener::"
+            "DoNotifyPrincipalHandleChanged",
+            this, &PrincipalHandleListener::DoNotifyPrincipalHandleChanged,
+            aNewPrincipalHandle));
   }
 
-protected:
+ protected:
   // These fields may only be accessed on the main thread
   MediaStreamTrack* mTrack;
 };
@@ -120,12 +114,15 @@ MediaStreamTrack::MediaStreamTrack(DOMMediaStream* aStream, TrackID aTrackID,
                                    TrackID aInputTrackID,
                                    MediaStreamTrackSource* aSource,
                                    const MediaTrackConstraints& aConstraints)
-  : mOwningStream(aStream), mTrackID(aTrackID),
-    mInputTrackID(aInputTrackID), mSource(aSource),
-    mPrincipal(aSource->GetPrincipal()),
-    mReadyState(MediaStreamTrackState::Live),
-    mEnabled(true), mMuted(false), mConstraints(aConstraints)
-{
+    : mOwningStream(aStream),
+      mTrackID(aTrackID),
+      mInputTrackID(aInputTrackID),
+      mSource(aSource),
+      mPrincipal(aSource->GetPrincipal()),
+      mReadyState(MediaStreamTrackState::Live),
+      mEnabled(true),
+      mMuted(false),
+      mConstraints(aConstraints) {
   GetSource().RegisterSink(this);
 
   if (GetOwnedStream()) {
@@ -135,7 +132,7 @@ MediaStreamTrack::MediaStreamTrack(DOMMediaStream* aStream, TrackID aTrackID,
 
   nsresult rv;
   nsCOMPtr<nsIUUIDGenerator> uuidgen =
-    do_GetService("@mozilla.org/uuid-generator;1", &rv);
+      do_GetService("@mozilla.org/uuid-generator;1", &rv);
 
   nsID uuid;
   memset(&uuid, 0, sizeof(uuid));
@@ -148,14 +145,9 @@ MediaStreamTrack::MediaStreamTrack(DOMMediaStream* aStream, TrackID aTrackID,
   mID = NS_ConvertASCIItoUTF16(chars);
 }
 
-MediaStreamTrack::~MediaStreamTrack()
-{
-  Destroy();
-}
+MediaStreamTrack::~MediaStreamTrack() { Destroy(); }
 
-void
-MediaStreamTrack::Destroy()
-{
+void MediaStreamTrack::Destroy() {
   if (mSource) {
     mSource->UnregisterSink(this);
   }
@@ -167,12 +159,14 @@ MediaStreamTrack::Destroy()
     mPrincipalHandleListener = nullptr;
   }
   // Remove all listeners -- avoid iterating over the list we're removing from
-  const nsTArray<RefPtr<MediaStreamTrackListener>> trackListeners(mTrackListeners);
+  const nsTArray<RefPtr<MediaStreamTrackListener>> trackListeners(
+      mTrackListeners);
   for (auto listener : trackListeners) {
     RemoveListener(listener);
   }
   // Do the same as above for direct listeners
-  const nsTArray<RefPtr<DirectMediaStreamTrackListener>> directTrackListeners(mDirectTrackListeners);
+  const nsTArray<RefPtr<DirectMediaStreamTrackListener>> directTrackListeners(
+      mDirectTrackListeners);
   for (auto listener : directTrackListeners) {
     RemoveDirectListener(listener);
   }
@@ -204,38 +198,29 @@ NS_IMPL_RELEASE_INHERITED(MediaStreamTrack, DOMEventTargetHelper)
 NS_INTERFACE_MAP_BEGIN_CYCLE_COLLECTION(MediaStreamTrack)
 NS_INTERFACE_MAP_END_INHERITING(DOMEventTargetHelper)
 
-nsPIDOMWindowInner*
-MediaStreamTrack::GetParentObject() const
-{
+nsPIDOMWindowInner* MediaStreamTrack::GetParentObject() const {
   MOZ_RELEASE_ASSERT(mOwningStream);
   return mOwningStream->GetParentObject();
 }
 
-void
-MediaStreamTrack::GetId(nsAString& aID) const
-{
-  aID = mID;
-}
+void MediaStreamTrack::GetId(nsAString& aID) const { aID = mID; }
 
-void
-MediaStreamTrack::SetEnabled(bool aEnabled)
-{
-  LOG(LogLevel::Info, ("MediaStreamTrack %p %s",
-                       this, aEnabled ? "Enabled" : "Disabled"));
+void MediaStreamTrack::SetEnabled(bool aEnabled) {
+  LOG(LogLevel::Info,
+      ("MediaStreamTrack %p %s", this, aEnabled ? "Enabled" : "Disabled"));
 
   if (mEnabled == aEnabled) {
     return;
   }
 
   mEnabled = aEnabled;
-  GetOwnedStream()->SetTrackEnabled(mTrackID, mEnabled ? DisabledTrackMode::ENABLED
-                                                       : DisabledTrackMode::SILENCE_BLACK);
+  GetOwnedStream()->SetTrackEnabled(
+      mTrackID,
+      mEnabled ? DisabledTrackMode::ENABLED : DisabledTrackMode::SILENCE_BLACK);
   GetSource().SinkEnabledStateChanged();
 }
 
-void
-MediaStreamTrack::Stop()
-{
+void MediaStreamTrack::Stop() {
   LOG(LogLevel::Info, ("MediaStreamTrack %p Stop()", this));
 
   if (Ended()) {
@@ -250,10 +235,13 @@ MediaStreamTrack::Stop()
 
   mSource->UnregisterSink(this);
 
-  MOZ_ASSERT(mOwningStream, "Every MediaStreamTrack needs an owning DOMMediaStream");
+  MOZ_ASSERT(mOwningStream,
+             "Every MediaStreamTrack needs an owning DOMMediaStream");
   DOMMediaStream::TrackPort* port = mOwningStream->FindOwnedTrackPort(*this);
-  MOZ_ASSERT(port, "A MediaStreamTrack must exist in its owning DOMMediaStream");
-  RefPtr<Pledge<bool>> p = port->BlockSourceTrackId(mInputTrackID, BlockingMode::CREATION);
+  MOZ_ASSERT(port,
+             "A MediaStreamTrack must exist in its owning DOMMediaStream");
+  RefPtr<Pledge<bool>> p =
+      port->BlockSourceTrackId(mInputTrackID, BlockingMode::CREATION);
   Unused << p;
 
   mReadyState = MediaStreamTrackState::Ended;
@@ -261,15 +249,12 @@ MediaStreamTrack::Stop()
   NotifyEnded();
 }
 
-void
-MediaStreamTrack::GetConstraints(dom::MediaTrackConstraints& aResult)
-{
+void MediaStreamTrack::GetConstraints(dom::MediaTrackConstraints& aResult) {
   aResult = mConstraints;
 }
 
-void
-MediaStreamTrack::GetSettings(dom::MediaTrackSettings& aResult, CallerType aCallerType)
-{
+void MediaStreamTrack::GetSettings(dom::MediaTrackSettings& aResult,
+                                   CallerType aCallerType) {
   GetSource().GetSettings(aResult);
 
   // Spoof values when privacy.resistFingerprinting is true.
@@ -278,21 +263,21 @@ MediaStreamTrack::GetSettings(dom::MediaTrackSettings& aResult, CallerType aCall
   }
   if (aResult.mFacingMode.WasPassed()) {
     aResult.mFacingMode.Value().Assign(NS_ConvertASCIItoUTF16(
-        VideoFacingModeEnumValues::strings[uint8_t(VideoFacingModeEnum::User)].value));
+        VideoFacingModeEnumValues::strings[uint8_t(VideoFacingModeEnum::User)]
+            .value));
   }
 }
 
-already_AddRefed<Promise>
-MediaStreamTrack::ApplyConstraints(const MediaTrackConstraints& aConstraints,
-                                   CallerType aCallerType,
-                                   ErrorResult &aRv)
-{
+already_AddRefed<Promise> MediaStreamTrack::ApplyConstraints(
+    const MediaTrackConstraints& aConstraints, CallerType aCallerType,
+    ErrorResult& aRv) {
   if (MOZ_LOG_TEST(gMediaStreamTrackLog, LogLevel::Info)) {
     nsString str;
     aConstraints.ToJSON(str);
 
     LOG(LogLevel::Info, ("MediaStreamTrack %p ApplyConstraints() with "
-                         "constraints %s", this, NS_ConvertUTF16toUTF8(str).get()));
+                         "constraints %s",
+                         this, NS_ConvertUTF16toUTF8(str).get()));
   }
 
   typedef media::Pledge<bool, MediaStreamError*> PledgeVoid;
@@ -307,37 +292,34 @@ MediaStreamTrack::ApplyConstraints(const MediaTrackConstraints& aConstraints,
 
   // Forward constraints to the source.
   //
-  // After GetSource().ApplyConstraints succeeds (after it's been to media-thread
-  // and back), and no sooner, do we set mConstraints to the newly applied values.
+  // After GetSource().ApplyConstraints succeeds (after it's been to
+  // media-thread and back), and no sooner, do we set mConstraints to the newly
+  // applied values.
 
   // Keep a reference to this, to make sure it's still here when we get back.
   RefPtr<MediaStreamTrack> that = this;
-  RefPtr<PledgeVoid> p = GetSource().ApplyConstraints(window, aConstraints,
-                                                      aCallerType);
-  p->Then([this, that, promise, aConstraints](bool& aDummy) mutable {
-    mConstraints = aConstraints;
-    promise->MaybeResolve(false);
-  }, [promise](MediaStreamError*& reason) mutable {
-    promise->MaybeReject(reason);
-  });
+  RefPtr<PledgeVoid> p =
+      GetSource().ApplyConstraints(window, aConstraints, aCallerType);
+  p->Then(
+      [this, that, promise, aConstraints](bool& aDummy) mutable {
+        mConstraints = aConstraints;
+        promise->MaybeResolve(false);
+      },
+      [promise](MediaStreamError*& reason) mutable {
+        promise->MaybeReject(reason);
+      });
   return promise.forget();
 }
 
-MediaStreamGraph*
-MediaStreamTrack::Graph()
-{
+MediaStreamGraph* MediaStreamTrack::Graph() {
   return GetOwnedStream()->Graph();
 }
 
-MediaStreamGraphImpl*
-MediaStreamTrack::GraphImpl()
-{
+MediaStreamGraphImpl* MediaStreamTrack::GraphImpl() {
   return GetOwnedStream()->GraphImpl();
 }
 
-void
-MediaStreamTrack::SetPrincipal(nsIPrincipal* aPrincipal)
-{
+void MediaStreamTrack::SetPrincipal(nsIPrincipal* aPrincipal) {
   if (aPrincipal == mPrincipal) {
     return;
   }
@@ -345,20 +327,17 @@ MediaStreamTrack::SetPrincipal(nsIPrincipal* aPrincipal)
 
   LOG(LogLevel::Info, ("MediaStreamTrack %p principal changed to %p. Now: "
                        "null=%d, codebase=%d, expanded=%d, system=%d",
-                       this, mPrincipal.get(),
-                       mPrincipal->GetIsNullPrincipal(),
+                       this, mPrincipal.get(), mPrincipal->GetIsNullPrincipal(),
                        mPrincipal->GetIsCodebasePrincipal(),
                        mPrincipal->GetIsExpandedPrincipal(),
                        mPrincipal->GetIsSystemPrincipal()));
-  for (PrincipalChangeObserver<MediaStreamTrack>* observer
-      : mPrincipalChangeObservers) {
+  for (PrincipalChangeObserver<MediaStreamTrack>* observer :
+       mPrincipalChangeObservers) {
     observer->PrincipalChanged(this);
   }
 }
 
-void
-MediaStreamTrack::PrincipalChanged()
-{
+void MediaStreamTrack::PrincipalChanged() {
   mPendingPrincipal = GetSource().GetPrincipal();
   nsCOMPtr<nsIPrincipal> newPrincipal = mPrincipal;
   LOG(LogLevel::Info, ("MediaStreamTrack %p Principal changed on main thread "
@@ -370,24 +349,21 @@ MediaStreamTrack::PrincipalChanged()
   }
 }
 
-void
-MediaStreamTrack::NotifyPrincipalHandleChanged(const PrincipalHandle& aNewPrincipalHandle)
-{
+void MediaStreamTrack::NotifyPrincipalHandleChanged(
+    const PrincipalHandle& aNewPrincipalHandle) {
   PrincipalHandle handle(aNewPrincipalHandle);
   LOG(LogLevel::Info, ("MediaStreamTrack %p principalHandle changed on "
                        "MediaStreamGraph thread to %p. Current principal: %p, "
                        "pending: %p",
-                       this, GetPrincipalFromHandle(handle),
-                       mPrincipal.get(), mPendingPrincipal.get()));
+                       this, GetPrincipalFromHandle(handle), mPrincipal.get(),
+                       mPendingPrincipal.get()));
   if (PrincipalHandleMatches(handle, mPendingPrincipal)) {
     SetPrincipal(mPendingPrincipal);
     mPendingPrincipal = nullptr;
   }
 }
 
-void
-MediaStreamTrack::MutedChanged(bool aNewState)
-{
+void MediaStreamTrack::MutedChanged(bool aNewState) {
   MOZ_ASSERT(NS_IsMainThread());
 
   if (mMuted == aNewState) {
@@ -395,18 +371,16 @@ MediaStreamTrack::MutedChanged(bool aNewState)
     return;
   }
 
-  LOG(LogLevel::Info, ("MediaStreamTrack %p became %s",
-                       this, aNewState ? "muted" : "unmuted"));
+  LOG(LogLevel::Info,
+      ("MediaStreamTrack %p became %s", this, aNewState ? "muted" : "unmuted"));
 
   mMuted = aNewState;
   nsString eventName =
-    aNewState ? NS_LITERAL_STRING("mute") : NS_LITERAL_STRING("unmute");
+      aNewState ? NS_LITERAL_STRING("mute") : NS_LITERAL_STRING("unmute");
   DispatchTrustedEvent(eventName);
 }
 
-void
-MediaStreamTrack::NotifyEnded()
-{
+void MediaStreamTrack::NotifyEnded() {
   MOZ_ASSERT(mReadyState == MediaStreamTrackState::Ended);
 
   auto consumers(mConsumers);
@@ -420,23 +394,17 @@ MediaStreamTrack::NotifyEnded()
   }
 }
 
-bool
-MediaStreamTrack::AddPrincipalChangeObserver(
-  PrincipalChangeObserver<MediaStreamTrack>* aObserver)
-{
+bool MediaStreamTrack::AddPrincipalChangeObserver(
+    PrincipalChangeObserver<MediaStreamTrack>* aObserver) {
   return mPrincipalChangeObservers.AppendElement(aObserver) != nullptr;
 }
 
-bool
-MediaStreamTrack::RemovePrincipalChangeObserver(
-  PrincipalChangeObserver<MediaStreamTrack>* aObserver)
-{
+bool MediaStreamTrack::RemovePrincipalChangeObserver(
+    PrincipalChangeObserver<MediaStreamTrack>* aObserver) {
   return mPrincipalChangeObservers.RemoveElement(aObserver);
 }
 
-void
-MediaStreamTrack::AddConsumer(MediaStreamTrackConsumer* aConsumer)
-{
+void MediaStreamTrack::AddConsumer(MediaStreamTrackConsumer* aConsumer) {
   MOZ_ASSERT(!mConsumers.Contains(aConsumer));
   mConsumers.AppendElement(aConsumer);
 
@@ -446,9 +414,7 @@ MediaStreamTrack::AddConsumer(MediaStreamTrackConsumer* aConsumer)
   }
 }
 
-void
-MediaStreamTrack::RemoveConsumer(MediaStreamTrackConsumer* aConsumer)
-{
+void MediaStreamTrack::RemoveConsumer(MediaStreamTrackConsumer* aConsumer) {
   mConsumers.RemoveElement(aConsumer);
 
   // Remove destroyed consumers for cleanliness
@@ -457,14 +423,12 @@ MediaStreamTrack::RemoveConsumer(MediaStreamTrackConsumer* aConsumer)
   }
 }
 
-already_AddRefed<MediaStreamTrack>
-MediaStreamTrack::Clone()
-{
+already_AddRefed<MediaStreamTrack> MediaStreamTrack::Clone() {
   // MediaStreamTracks are currently governed by streams, so we need a dummy
   // DOMMediaStream to own our track clone. The dummy will never see any
   // dynamically created tracks (no input stream) so no need for a SourceGetter.
   RefPtr<DOMMediaStream> newStream =
-    new DOMMediaStream(mOwningStream->GetParentObject(), nullptr);
+      new DOMMediaStream(mOwningStream->GetParentObject(), nullptr);
 
   MediaStreamGraph* graph = Graph();
   newStream->InitOwnedStreamCommon(graph);
@@ -473,25 +437,20 @@ MediaStreamTrack::Clone()
   return newStream->CloneDOMTrack(*this, mTrackID);
 }
 
-void
-MediaStreamTrack::SetReadyState(MediaStreamTrackState aState)
-{
+void MediaStreamTrack::SetReadyState(MediaStreamTrackState aState) {
   MOZ_ASSERT(!(mReadyState == MediaStreamTrackState::Ended &&
                aState == MediaStreamTrackState::Live),
              "We don't support overriding the ready state from ended to live");
 
   if (mReadyState == MediaStreamTrackState::Live &&
-      aState == MediaStreamTrackState::Ended &&
-      mSource) {
+      aState == MediaStreamTrackState::Ended && mSource) {
     mSource->UnregisterSink(this);
   }
 
   mReadyState = aState;
 }
 
-void
-MediaStreamTrack::OverrideEnded()
-{
+void MediaStreamTrack::OverrideEnded() {
   MOZ_ASSERT(NS_IsMainThread());
 
   if (Ended()) {
@@ -514,50 +473,39 @@ MediaStreamTrack::OverrideEnded()
   DispatchTrustedEvent(NS_LITERAL_STRING("ended"));
 }
 
-DOMMediaStream*
-MediaStreamTrack::GetInputDOMStream()
-{
+DOMMediaStream* MediaStreamTrack::GetInputDOMStream() {
   MediaStreamTrack* originalTrack =
-    mOriginalTrack ? mOriginalTrack.get() : this;
+      mOriginalTrack ? mOriginalTrack.get() : this;
   MOZ_RELEASE_ASSERT(originalTrack->mOwningStream);
   return originalTrack->mOwningStream;
 }
 
-MediaStream*
-MediaStreamTrack::GetInputStream()
-{
+MediaStream* MediaStreamTrack::GetInputStream() {
   DOMMediaStream* inputDOMStream = GetInputDOMStream();
   MOZ_RELEASE_ASSERT(inputDOMStream->GetInputStream());
   return inputDOMStream->GetInputStream();
 }
 
-ProcessedMediaStream*
-MediaStreamTrack::GetOwnedStream()
-{
-  if (!mOwningStream)
-  {
+ProcessedMediaStream* MediaStreamTrack::GetOwnedStream() {
+  if (!mOwningStream) {
     return nullptr;
   }
 
   return mOwningStream->GetOwnedStream();
 }
 
-void
-MediaStreamTrack::AddListener(MediaStreamTrackListener* aListener)
-{
-  LOG(LogLevel::Debug, ("MediaStreamTrack %p adding listener %p",
-                        this, aListener));
+void MediaStreamTrack::AddListener(MediaStreamTrackListener* aListener) {
+  LOG(LogLevel::Debug,
+      ("MediaStreamTrack %p adding listener %p", this, aListener));
   MOZ_ASSERT(GetOwnedStream());
 
   GetOwnedStream()->AddTrackListener(aListener, mTrackID);
   mTrackListeners.AppendElement(aListener);
 }
 
-void
-MediaStreamTrack::RemoveListener(MediaStreamTrackListener* aListener)
-{
-  LOG(LogLevel::Debug, ("MediaStreamTrack %p removing listener %p",
-                        this, aListener));
+void MediaStreamTrack::RemoveListener(MediaStreamTrackListener* aListener) {
+  LOG(LogLevel::Debug,
+      ("MediaStreamTrack %p removing listener %p", this, aListener));
 
   if (GetOwnedStream()) {
     GetOwnedStream()->RemoveTrackListener(aListener, mTrackID);
@@ -565,9 +513,8 @@ MediaStreamTrack::RemoveListener(MediaStreamTrackListener* aListener)
   }
 }
 
-void
-MediaStreamTrack::AddDirectListener(DirectMediaStreamTrackListener *aListener)
-{
+void MediaStreamTrack::AddDirectListener(
+    DirectMediaStreamTrackListener* aListener) {
   LOG(LogLevel::Debug, ("MediaStreamTrack %p (%s) adding direct listener %p to "
                         "stream %p, track %d",
                         this, AsAudioStreamTrack() ? "audio" : "video",
@@ -578,11 +525,11 @@ MediaStreamTrack::AddDirectListener(DirectMediaStreamTrackListener *aListener)
   mDirectTrackListeners.AppendElement(aListener);
 }
 
-void
-MediaStreamTrack::RemoveDirectListener(DirectMediaStreamTrackListener *aListener)
-{
-  LOG(LogLevel::Debug, ("MediaStreamTrack %p removing direct listener %p from stream %p",
-                        this, aListener, GetOwnedStream()));
+void MediaStreamTrack::RemoveDirectListener(
+    DirectMediaStreamTrackListener* aListener) {
+  LOG(LogLevel::Debug,
+      ("MediaStreamTrack %p removing direct listener %p from stream %p", this,
+       aListener, GetOwnedStream()));
 
   if (GetOwnedStream()) {
     GetOwnedStream()->RemoveDirectTrackListener(aListener, mTrackID);
@@ -590,20 +537,16 @@ MediaStreamTrack::RemoveDirectListener(DirectMediaStreamTrackListener *aListener
   }
 }
 
-already_AddRefed<MediaInputPort>
-MediaStreamTrack::ForwardTrackContentsTo(ProcessedMediaStream* aStream,
-                                         TrackID aDestinationTrackID)
-{
+already_AddRefed<MediaInputPort> MediaStreamTrack::ForwardTrackContentsTo(
+    ProcessedMediaStream* aStream, TrackID aDestinationTrackID) {
   MOZ_ASSERT(NS_IsMainThread());
   MOZ_RELEASE_ASSERT(aStream);
-  RefPtr<MediaInputPort> port =
-    aStream->AllocateInputPort(GetOwnedStream(), mTrackID, aDestinationTrackID);
+  RefPtr<MediaInputPort> port = aStream->AllocateInputPort(
+      GetOwnedStream(), mTrackID, aDestinationTrackID);
   return port.forget();
 }
 
-bool
-MediaStreamTrack::IsForwardedThrough(MediaInputPort* aPort)
-{
+bool MediaStreamTrack::IsForwardedThrough(MediaInputPort* aPort) {
   MOZ_ASSERT(NS_IsMainThread());
   MOZ_ASSERT(aPort);
   if (!aPort) {
@@ -613,5 +556,5 @@ MediaStreamTrack::IsForwardedThrough(MediaInputPort* aPort)
          aPort->PassTrackThrough(mTrackID);
 }
 
-} // namespace dom
-} // namespace mozilla
+}  // namespace dom
+}  // namespace mozilla
