@@ -50,7 +50,9 @@ namespace mozilla {
 
 extern LogModule* GetGMPLog();
 #define LOG(level, x, ...) MOZ_LOG(GetGMPLog(), (level), (x, ##__VA_ARGS__))
-#define LOGD(x, ...) LOG(mozilla::LogLevel::Debug, "GMPParent[%p|childPid=%d] " x, this, mChildPid, ##__VA_ARGS__)
+#define LOGD(x, ...)                                                  \
+  LOG(mozilla::LogLevel::Debug, "GMPParent[%p|childPid=%d] " x, this, \
+      mChildPid, ##__VA_ARGS__)
 
 #ifdef __CLASS__
 #undef __CLASS__
@@ -60,30 +62,26 @@ extern LogModule* GetGMPLog();
 namespace gmp {
 
 GMPParent::GMPParent(AbstractThread* aMainThread)
-  : mState(GMPStateNotLoaded)
-  , mProcess(nullptr)
-  , mDeleteProcessOnlyOnUnload(false)
-  , mAbnormalShutdownInProgress(false)
-  , mIsBlockingDeletion(false)
-  , mCanDecrypt(false)
-  , mGMPContentChildCount(0)
-  , mChildPid(0)
-  , mHoldingSelfRef(false)
-  , mMainThread(aMainThread)
-{
+    : mState(GMPStateNotLoaded),
+      mProcess(nullptr),
+      mDeleteProcessOnlyOnUnload(false),
+      mAbnormalShutdownInProgress(false),
+      mIsBlockingDeletion(false),
+      mCanDecrypt(false),
+      mGMPContentChildCount(0),
+      mChildPid(0),
+      mHoldingSelfRef(false),
+      mMainThread(aMainThread) {
   mPluginId = GeckoChildProcessHost::GetUniqueID();
   LOGD("GMPParent ctor id=%u", mPluginId);
 }
 
-GMPParent::~GMPParent()
-{
+GMPParent::~GMPParent() {
   LOGD("GMPParent dtor id=%u", mPluginId);
   MOZ_ASSERT(!mProcess);
 }
 
-nsresult
-GMPParent::CloneFrom(const GMPParent* aOther)
-{
+nsresult GMPParent::CloneFrom(const GMPParent* aOther) {
   MOZ_ASSERT(GMPEventTarget()->IsOnCurrentThread());
   MOZ_ASSERT(aOther->mDirectory && aOther->mService, "null plugin directory");
 
@@ -103,9 +101,8 @@ GMPParent::CloneFrom(const GMPParent* aOther)
   return NS_OK;
 }
 
-RefPtr<GenericPromise>
-GMPParent::Init(GeckoMediaPluginServiceParent* aService, nsIFile* aPluginDir)
-{
+RefPtr<GenericPromise> GMPParent::Init(GeckoMediaPluginServiceParent* aService,
+                                       nsIFile* aPluginDir) {
   MOZ_ASSERT(aPluginDir);
   MOZ_ASSERT(aService);
   MOZ_ASSERT(GMPEventTarget()->IsOnCurrentThread());
@@ -125,7 +122,8 @@ GMPParent::Init(GeckoMediaPluginServiceParent* aService, nsIFile* aPluginDir)
   if (NS_WARN_IF(NS_FAILED(rv))) {
     return GenericPromise::CreateAndReject(rv, __func__);
   }
-  LOGD("%s: for %s", __FUNCTION__, NS_LossyConvertUTF16toASCII(parentLeafName).get());
+  LOGD("%s: for %s", __FUNCTION__,
+       NS_LossyConvertUTF16toASCII(parentLeafName).get());
 
   MOZ_ASSERT(parentLeafName.Length() > 4);
   mName = Substring(parentLeafName, 4);
@@ -133,17 +131,13 @@ GMPParent::Init(GeckoMediaPluginServiceParent* aService, nsIFile* aPluginDir)
   return ReadGMPMetaData();
 }
 
-void
-GMPParent::Crash()
-{
+void GMPParent::Crash() {
   if (mState != GMPStateNotLoaded) {
     Unused << SendCrashPluginNow();
   }
 }
 
-nsresult
-GMPParent::LoadProcess()
-{
+nsresult GMPParent::LoadProcess() {
   MOZ_ASSERT(mDirectory, "Plugin directory cannot be NULL!");
   MOZ_ASSERT(GMPEventTarget()->IsOnCurrentThread());
   MOZ_ASSERT(mState == GMPStateNotLoaded);
@@ -176,10 +170,11 @@ GMPParent::LoadProcess()
     }
     LOGD("%s: Opened channel to new child process", __FUNCTION__);
 
-    // ComputeStorageId may return empty string, we leave the error handling to CDM.
-    // The CDM will reject the promise once we provide a empty string of storage id.
-    bool ok = SendProvideStorageId(
-      CDMStorageIdProvider::ComputeStorageId(mNodeId));
+    // ComputeStorageId may return empty string, we leave the error handling to
+    // CDM. The CDM will reject the promise once we provide a empty string of
+    // storage id.
+    bool ok =
+        SendProvideStorageId(CDMStorageIdProvider::ComputeStorageId(mNodeId));
     if (!ok) {
       LOGD("%s: Failed to send storage id to child process", __FUNCTION__);
       return NS_ERROR_FAILURE;
@@ -193,7 +188,8 @@ GMPParent::LoadProcess()
         LOGD("%s: Failed to send preload-libs to child process", __FUNCTION__);
         return NS_ERROR_FAILURE;
       }
-      LOGD("%s: Sent preload-libs ('%s') to child process", __FUNCTION__, mLibs.get());
+      LOGD("%s: Sent preload-libs ('%s') to child process", __FUNCTION__,
+           mLibs.get());
     }
 #endif
 
@@ -217,9 +213,7 @@ GMPParent::LoadProcess()
   return NS_OK;
 }
 
-mozilla::ipc::IPCResult
-GMPParent::RecvPGMPContentChildDestroyed()
-{
+mozilla::ipc::IPCResult GMPParent::RecvPGMPContentChildDestroyed() {
   --mGMPContentChildCount;
   if (!IsUsed()) {
     CloseIfUnused();
@@ -227,14 +221,11 @@ GMPParent::RecvPGMPContentChildDestroyed()
   return IPC_OK();
 }
 
-void
-GMPParent::CloseIfUnused()
-{
+void GMPParent::CloseIfUnused() {
   MOZ_ASSERT(GMPEventTarget()->IsOnCurrentThread());
   LOGD("%s", __FUNCTION__);
 
-  if ((mDeleteProcessOnlyOnUnload ||
-       mState == GMPStateLoaded ||
+  if ((mDeleteProcessOnlyOnUnload || mState == GMPStateLoaded ||
        mState == GMPStateUnloading) &&
       !IsUsed()) {
     // Ensure all timers are killed.
@@ -251,14 +242,12 @@ GMPParent::CloseIfUnused()
   }
 }
 
-void
-GMPParent::CloseActive(bool aDieWhenUnloaded)
-{
+void GMPParent::CloseActive(bool aDieWhenUnloaded) {
   LOGD("%s: state %d", __FUNCTION__, mState);
   MOZ_ASSERT(GMPEventTarget()->IsOnCurrentThread());
 
   if (aDieWhenUnloaded) {
-    mDeleteProcessOnlyOnUnload = true; // don't allow this to go back...
+    mDeleteProcessOnlyOnUnload = true;  // don't allow this to go back...
   }
   if (mState == GMPStateLoaded) {
     mState = GMPStateUnloading;
@@ -269,22 +258,14 @@ GMPParent::CloseActive(bool aDieWhenUnloaded)
   }
 }
 
-void
-GMPParent::MarkForDeletion()
-{
+void GMPParent::MarkForDeletion() {
   mDeleteProcessOnlyOnUnload = true;
   mIsBlockingDeletion = true;
 }
 
-bool
-GMPParent::IsMarkedForDeletion()
-{
-  return mIsBlockingDeletion;
-}
+bool GMPParent::IsMarkedForDeletion() { return mIsBlockingDeletion; }
 
-void
-GMPParent::Shutdown()
-{
+void GMPParent::Shutdown() {
   LOGD("%s", __FUNCTION__);
   MOZ_ASSERT(GMPEventTarget()->IsOnCurrentThread());
 
@@ -305,20 +286,18 @@ GMPParent::Shutdown()
   if (!mDeleteProcessOnlyOnUnload) {
     // Destroy ourselves and rise from the fire to save memory
     mService->ReAddOnGMPThread(self);
-  } // else we've been asked to die and stay dead
+  }  // else we've been asked to die and stay dead
   MOZ_ASSERT(mState == GMPStateNotLoaded);
 }
 
 class NotifyGMPShutdownTask : public Runnable {
-public:
+ public:
   explicit NotifyGMPShutdownTask(const nsAString& aNodeId)
-    : Runnable("NotifyGMPShutdownTask")
-    , mNodeId(aNodeId)
-  {
-  }
+      : Runnable("NotifyGMPShutdownTask"), mNodeId(aNodeId) {}
   NS_IMETHOD Run() override {
     MOZ_ASSERT(NS_IsMainThread());
-    nsCOMPtr<nsIObserverService> obsService = mozilla::services::GetObserverService();
+    nsCOMPtr<nsIObserverService> obsService =
+        mozilla::services::GetObserverService();
     MOZ_ASSERT(obsService);
     if (obsService) {
       obsService->NotifyObservers(nullptr, "gmp-shutdown", mNodeId.get());
@@ -328,9 +307,7 @@ public:
   nsString mNodeId;
 };
 
-void
-GMPParent::ChildTerminated()
-{
+void GMPParent::ChildTerminated() {
   RefPtr<GMPParent> self(this);
   nsCOMPtr<nsISerialEventTarget> gmpEventTarget = GMPEventTarget();
 
@@ -341,18 +318,15 @@ GMPParent::ChildTerminated()
     // removed so there is no harm in not trying to remove it again.
     LOGD("%s::%s: GMPEventTarget() returned nullptr.", __CLASS__, __FUNCTION__);
   } else {
-    gmpEventTarget->Dispatch(NewRunnableMethod<RefPtr<GMPParent>>(
-                               "gmp::GeckoMediaPluginServiceParent::PluginTerminated",
-                               mService,
-                               &GeckoMediaPluginServiceParent::PluginTerminated,
-                               self),
-                             NS_DISPATCH_NORMAL);
+    gmpEventTarget->Dispatch(
+        NewRunnableMethod<RefPtr<GMPParent>>(
+            "gmp::GeckoMediaPluginServiceParent::PluginTerminated", mService,
+            &GeckoMediaPluginServiceParent::PluginTerminated, self),
+        NS_DISPATCH_NORMAL);
   }
 }
 
-void
-GMPParent::DeleteProcess()
-{
+void GMPParent::DeleteProcess() {
   LOGD("%s", __FUNCTION__);
 
   if (mState != GMPStateClosing) {
@@ -361,14 +335,14 @@ GMPParent::DeleteProcess()
     mState = GMPStateClosing;
     Close();
   }
-  mProcess->Delete(NewRunnableMethod(
-    "gmp::GMPParent::ChildTerminated", this, &GMPParent::ChildTerminated));
+  mProcess->Delete(NewRunnableMethod("gmp::GMPParent::ChildTerminated", this,
+                                     &GMPParent::ChildTerminated));
   LOGD("%s: Shut down process", __FUNCTION__);
   mProcess = nullptr;
   mState = GMPStateNotLoaded;
 
-  nsCOMPtr<nsIRunnable> r
-    = new NotifyGMPShutdownTask(NS_ConvertUTF8toUTF16(mNodeId));
+  nsCOMPtr<nsIRunnable> r =
+      new NotifyGMPShutdownTask(NS_ConvertUTF8toUTF16(mNodeId));
   mMainThread->Dispatch(r.forget());
 
   if (mHoldingSelfRef) {
@@ -377,17 +351,11 @@ GMPParent::DeleteProcess()
   }
 }
 
-GMPState
-GMPParent::State() const
-{
-  return mState;
-}
+GMPState GMPParent::State() const { return mState; }
 
-nsCOMPtr<nsISerialEventTarget>
-GMPParent::GMPEventTarget()
-{
+nsCOMPtr<nsISerialEventTarget> GMPParent::GMPEventTarget() {
   nsCOMPtr<mozIGeckoMediaPluginService> mps =
-    do_GetService("@mozilla.org/gecko-media-plugin-service;1");
+      do_GetService("@mozilla.org/gecko-media-plugin-service;1");
   MOZ_ASSERT(mps);
   if (!mps) {
     return nullptr;
@@ -400,11 +368,9 @@ GMPParent::GMPEventTarget()
 }
 
 /* static */
-bool
-GMPCapability::Supports(const nsTArray<GMPCapability>& aCapabilities,
-                        const nsCString& aAPI,
-                        const nsTArray<nsCString>& aTags)
-{
+bool GMPCapability::Supports(const nsTArray<GMPCapability>& aCapabilities,
+                             const nsCString& aAPI,
+                             const nsTArray<nsCString>& aTags) {
   for (const nsCString& tag : aTags) {
     if (!GMPCapability::Supports(aCapabilities, aAPI, tag)) {
       return false;
@@ -414,11 +380,8 @@ GMPCapability::Supports(const nsTArray<GMPCapability>& aCapabilities,
 }
 
 /* static */
-bool
-GMPCapability::Supports(const nsTArray<GMPCapability>& aCapabilities,
-                        const nsCString& aAPI,
-                        const nsCString& aTag)
-{
+bool GMPCapability::Supports(const nsTArray<GMPCapability>& aCapabilities,
+                             const nsCString& aAPI, const nsCString& aTag) {
   for (const GMPCapability& capabilities : aCapabilities) {
     if (!capabilities.mAPIName.Equals(aAPI)) {
       continue;
@@ -445,14 +408,11 @@ GMPCapability::Supports(const nsTArray<GMPCapability>& aCapabilities,
   return false;
 }
 
-bool
-GMPParent::EnsureProcessLoaded()
-{
+bool GMPParent::EnsureProcessLoaded() {
   if (mState == GMPStateLoaded) {
     return true;
   }
-  if (mState == GMPStateClosing ||
-      mState == GMPStateUnloading) {
+  if (mState == GMPStateClosing || mState == GMPStateUnloading) {
     return false;
   }
 
@@ -461,18 +421,16 @@ GMPParent::EnsureProcessLoaded()
   return NS_SUCCEEDED(rv);
 }
 
-void
-GMPParent::WriteExtraDataForMinidump()
-{
-  mCrashReporter->AddNote(NS_LITERAL_CSTRING("GMPPlugin"), NS_LITERAL_CSTRING("1"));
-  mCrashReporter->AddNote(NS_LITERAL_CSTRING("PluginFilename"), NS_ConvertUTF16toUTF8(mName));
+void GMPParent::WriteExtraDataForMinidump() {
+  mCrashReporter->AddNote(NS_LITERAL_CSTRING("GMPPlugin"),
+                          NS_LITERAL_CSTRING("1"));
+  mCrashReporter->AddNote(NS_LITERAL_CSTRING("PluginFilename"),
+                          NS_ConvertUTF16toUTF8(mName));
   mCrashReporter->AddNote(NS_LITERAL_CSTRING("PluginName"), mDisplayName);
   mCrashReporter->AddNote(NS_LITERAL_CSTRING("PluginVersion"), mVersion);
 }
 
-bool
-GMPParent::GetCrashID(nsString& aResult)
-{
+bool GMPParent::GetCrashID(nsString& aResult) {
   if (!mCrashReporter) {
     return false;
   }
@@ -486,29 +444,29 @@ GMPParent::GetCrashID(nsString& aResult)
   return true;
 }
 
-static void
-GMPNotifyObservers(const uint32_t aPluginID, const nsACString& aPluginName, const nsAString& aPluginDumpID)
-{
+static void GMPNotifyObservers(const uint32_t aPluginID,
+                               const nsACString& aPluginName,
+                               const nsAString& aPluginDumpID) {
   nsCOMPtr<nsIObserverService> obs = mozilla::services::GetObserverService();
   nsCOMPtr<nsIWritablePropertyBag2> propbag =
-    do_CreateInstance("@mozilla.org/hash-property-bag;1");
+      do_CreateInstance("@mozilla.org/hash-property-bag;1");
   if (obs && propbag) {
     propbag->SetPropertyAsUint32(NS_LITERAL_STRING("pluginID"), aPluginID);
-    propbag->SetPropertyAsACString(NS_LITERAL_STRING("pluginName"), aPluginName);
-    propbag->SetPropertyAsAString(NS_LITERAL_STRING("pluginDumpID"), aPluginDumpID);
+    propbag->SetPropertyAsACString(NS_LITERAL_STRING("pluginName"),
+                                   aPluginName);
+    propbag->SetPropertyAsAString(NS_LITERAL_STRING("pluginDumpID"),
+                                  aPluginDumpID);
     obs->NotifyObservers(propbag, "gmp-plugin-crash", nullptr);
   }
 
   RefPtr<gmp::GeckoMediaPluginService> service =
-    gmp::GeckoMediaPluginService::GetGeckoMediaPluginService();
+      gmp::GeckoMediaPluginService::GetGeckoMediaPluginService();
   if (service) {
     service->RunPluginCrashCallbacks(aPluginID, aPluginName);
   }
 }
 
-void
-GMPParent::ActorDestroy(ActorDestroyReason aWhy)
-{
+void GMPParent::ActorDestroy(ActorDestroyReason aWhy) {
   LOGD("%s: (%d)", __FUNCTION__, (int)aWhy);
 
   if (AbnormalShutdown == aWhy) {
@@ -523,8 +481,8 @@ GMPParent::ActorDestroy(ActorDestroyReason aWhy)
     }
 
     // NotifyObservers is mainthread-only
-    nsCOMPtr<nsIRunnable> r = WrapRunnableNM(
-      &GMPNotifyObservers, mPluginId, mDisplayName, dumpID);
+    nsCOMPtr<nsIRunnable> r =
+        WrapRunnableNM(&GMPNotifyObservers, mPluginId, mDisplayName, dumpID);
     mMainThread->Dispatch(r.forget());
   }
 
@@ -545,71 +503,58 @@ GMPParent::ActorDestroy(ActorDestroyReason aWhy)
   }
 }
 
-mozilla::ipc::IPCResult
-GMPParent::RecvInitCrashReporter(Shmem&& aShmem, const NativeThreadId& aThreadId)
-{
-  mCrashReporter = MakeUnique<ipc::CrashReporterHost>(
-    GeckoProcessType_GMPlugin,
-    aShmem,
-    aThreadId);
+mozilla::ipc::IPCResult GMPParent::RecvInitCrashReporter(
+    Shmem&& aShmem, const NativeThreadId& aThreadId) {
+  mCrashReporter = MakeUnique<ipc::CrashReporterHost>(GeckoProcessType_GMPlugin,
+                                                      aShmem, aThreadId);
 
   return IPC_OK();
 }
 
-PGMPStorageParent*
-GMPParent::AllocPGMPStorageParent()
-{
+PGMPStorageParent* GMPParent::AllocPGMPStorageParent() {
   GMPStorageParent* p = new GMPStorageParent(mNodeId, this);
-  mStorage.AppendElement(p); // Addrefs, released in DeallocPGMPStorageParent.
+  mStorage.AppendElement(p);  // Addrefs, released in DeallocPGMPStorageParent.
   return p;
 }
 
-bool
-GMPParent::DeallocPGMPStorageParent(PGMPStorageParent* aActor)
-{
+bool GMPParent::DeallocPGMPStorageParent(PGMPStorageParent* aActor) {
   GMPStorageParent* p = static_cast<GMPStorageParent*>(aActor);
   p->Shutdown();
   mStorage.RemoveElement(p);
   return true;
 }
 
-mozilla::ipc::IPCResult
-GMPParent::RecvPGMPStorageConstructor(PGMPStorageParent* aActor)
-{
-  GMPStorageParent* p  = (GMPStorageParent*)aActor;
+mozilla::ipc::IPCResult GMPParent::RecvPGMPStorageConstructor(
+    PGMPStorageParent* aActor) {
+  GMPStorageParent* p = (GMPStorageParent*)aActor;
   if (NS_WARN_IF(NS_FAILED(p->Init()))) {
     return IPC_FAIL_NO_REASON(this);
   }
   return IPC_OK();
 }
 
-mozilla::ipc::IPCResult
-GMPParent::RecvPGMPTimerConstructor(PGMPTimerParent* actor)
-{
+mozilla::ipc::IPCResult GMPParent::RecvPGMPTimerConstructor(
+    PGMPTimerParent* actor) {
   return IPC_OK();
 }
 
-PGMPTimerParent*
-GMPParent::AllocPGMPTimerParent()
-{
+PGMPTimerParent* GMPParent::AllocPGMPTimerParent() {
   nsCOMPtr<nsISerialEventTarget> target = GMPEventTarget();
   GMPTimerParent* p = new GMPTimerParent(target);
-  mTimers.AppendElement(p); // Released in DeallocPGMPTimerParent, or on shutdown.
+  mTimers.AppendElement(
+      p);  // Released in DeallocPGMPTimerParent, or on shutdown.
   return p;
 }
 
-bool
-GMPParent::DeallocPGMPTimerParent(PGMPTimerParent* aActor)
-{
+bool GMPParent::DeallocPGMPTimerParent(PGMPTimerParent* aActor) {
   GMPTimerParent* p = static_cast<GMPTimerParent*>(aActor);
   p->Shutdown();
   mTimers.RemoveElement(p);
   return true;
 }
 
-bool
-ReadInfoField(GMPInfoFileParser& aParser, const nsCString& aKey, nsACString& aOutValue)
-{
+bool ReadInfoField(GMPInfoFileParser& aParser, const nsCString& aKey,
+                   nsACString& aOutValue) {
   if (!aParser.Contains(aKey) || aParser.Get(aKey).IsEmpty()) {
     return false;
   }
@@ -617,9 +562,7 @@ ReadInfoField(GMPInfoFileParser& aParser, const nsCString& aKey, nsACString& aOu
   return true;
 }
 
-RefPtr<GenericPromise>
-GMPParent::ReadGMPMetaData()
-{
+RefPtr<GenericPromise> GMPParent::ReadGMPMetaData() {
   MOZ_ASSERT(mDirectory, "Plugin directory cannot be NULL!");
   MOZ_ASSERT(!mName.IsEmpty(), "Plugin mName cannot be empty!");
 
@@ -644,9 +587,7 @@ GMPParent::ReadGMPMetaData()
   return ReadChromiumManifestFile(manifestFile);
 }
 
-RefPtr<GenericPromise>
-GMPParent::ReadGMPInfoFile(nsIFile* aFile)
-{
+RefPtr<GenericPromise> GMPParent::ReadGMPInfoFile(nsIFile* aFile) {
   GMPInfoFileParser parser;
   if (!parser.Init(aFile)) {
     return GenericPromise::CreateAndReject(NS_ERROR_FAILURE, __func__);
@@ -689,7 +630,8 @@ GMPParent::ReadGMPInfoFile(nsIFile* aFile)
       cap.mAPIName.Assign(Substring(api, 0, tagsStart));
 
       if ((tagsEnd - tagsStart) > 1) {
-        const nsDependentCSubstring ts(Substring(api, tagsStart + 1, tagsEnd - tagsStart - 1));
+        const nsDependentCSubstring ts(
+            Substring(api, tagsStart + 1, tagsEnd - tagsStart - 1));
         nsTArray<nsCString> tagTokens;
         SplitAt(":", ts, tagTokens);
         for (nsCString tag : tagTokens) {
@@ -708,35 +650,31 @@ GMPParent::ReadGMPInfoFile(nsIFile* aFile)
   return GenericPromise::CreateAndResolve(true, __func__);
 }
 
-RefPtr<GenericPromise>
-GMPParent::ReadChromiumManifestFile(nsIFile* aFile)
-{
+RefPtr<GenericPromise> GMPParent::ReadChromiumManifestFile(nsIFile* aFile) {
   nsAutoCString json;
   if (!ReadIntoString(aFile, json, 5 * 1024)) {
     return GenericPromise::CreateAndReject(NS_ERROR_FAILURE, __func__);
   }
 
   // DOM JSON parsing needs to run on the main thread.
-  return InvokeAsync(
-    mMainThread, this, __func__,
-    &GMPParent::ParseChromiumManifest, NS_ConvertUTF8toUTF16(json));
+  return InvokeAsync(mMainThread, this, __func__,
+                     &GMPParent::ParseChromiumManifest,
+                     NS_ConvertUTF8toUTF16(json));
 }
 
-static bool
-IsCDMAPISupported(const mozilla::dom::WidevineCDMManifest& aManifest)
-{
-  nsresult ignored; // Note: ToInteger returns 0 on failure.
+static bool IsCDMAPISupported(
+    const mozilla::dom::WidevineCDMManifest& aManifest) {
+  nsresult ignored;  // Note: ToInteger returns 0 on failure.
   int32_t moduleVersion = aManifest.mX_cdm_module_versions.ToInteger(&ignored);
   int32_t interfaceVersion =
-    aManifest.mX_cdm_interface_versions.ToInteger(&ignored);
+      aManifest.mX_cdm_interface_versions.ToInteger(&ignored);
   int32_t hostVersion = aManifest.mX_cdm_host_versions.ToInteger(&ignored);
-  return ChromiumCDMAdapter::Supports(
-    moduleVersion, interfaceVersion, hostVersion);
+  return ChromiumCDMAdapter::Supports(moduleVersion, interfaceVersion,
+                                      hostVersion);
 }
 
-RefPtr<GenericPromise>
-GMPParent::ParseChromiumManifest(const nsAString& aJSON)
-{
+RefPtr<GenericPromise> GMPParent::ParseChromiumManifest(
+    const nsAString& aJSON) {
   LOGD("%s: for '%s'", __FUNCTION__, NS_LossyConvertUTF16toASCII(aJSON).get());
 
   MOZ_ASSERT(NS_IsMainThread());
@@ -756,9 +694,9 @@ GMPParent::ParseChromiumManifest(const nsAString& aJSON)
 #if defined(XP_LINUX) && defined(MOZ_GMP_SANDBOX)
   if (!mozilla::SandboxInfo::Get().CanSandboxMedia()) {
     nsPrintfCString msg(
-      "GMPParent::ParseChromiumManifest: Plugin \"%s\" is an EME CDM"
-      " but this system can't sandbox it; not loading.",
-      mDisplayName.get());
+        "GMPParent::ParseChromiumManifest: Plugin \"%s\" is an EME CDM"
+        " but this system can't sandbox it; not loading.",
+        mDisplayName.get());
     printf_stderr("%s\n", msg.get());
     LOGD("%s", msg.get());
     return GenericPromise::CreateAndReject(NS_ERROR_FAILURE, __func__);
@@ -772,7 +710,8 @@ GMPParent::ParseChromiumManifest(const nsAString& aJSON)
   if (mDisplayName.EqualsASCII("clearkey")) {
     kEMEKeySystem = kEMEKeySystemClearkey;
 #if XP_WIN
-    mLibs = NS_LITERAL_CSTRING("dxva2.dll, msmpeg2vdec.dll, evr.dll, mfh264dec.dll, mfplat.dll");
+    mLibs = NS_LITERAL_CSTRING(
+        "dxva2.dll, msmpeg2vdec.dll, evr.dll, mfh264dec.dll, mfplat.dll");
 #endif
   } else if (mDisplayName.EqualsASCII("WidevineCdm")) {
     kEMEKeySystem = kEMEKeySystemWidevine;
@@ -821,9 +760,7 @@ GMPParent::ParseChromiumManifest(const nsAString& aJSON)
   return GenericPromise::CreateAndResolve(true, __func__);
 }
 
-bool
-GMPParent::CanBeSharedCrossNodeIds() const
-{
+bool GMPParent::CanBeSharedCrossNodeIds() const {
   return mNodeId.IsEmpty() &&
          // XXX bug 1159300 hack -- maybe remove after openh264 1.4
          // We don't want to use CDM decoders for non-encrypted playback
@@ -832,59 +769,40 @@ GMPParent::CanBeSharedCrossNodeIds() const
          !mCanDecrypt;
 }
 
-bool
-GMPParent::CanBeUsedFrom(const nsACString& aNodeId) const
-{
+bool GMPParent::CanBeUsedFrom(const nsACString& aNodeId) const {
   return mNodeId == aNodeId;
 }
 
-void
-GMPParent::SetNodeId(const nsACString& aNodeId)
-{
+void GMPParent::SetNodeId(const nsACString& aNodeId) {
   MOZ_ASSERT(!aNodeId.IsEmpty());
   mNodeId = aNodeId;
 }
 
-const nsCString&
-GMPParent::GetDisplayName() const
-{
-  return mDisplayName;
-}
+const nsCString& GMPParent::GetDisplayName() const { return mDisplayName; }
 
-const nsCString&
-GMPParent::GetVersion() const
-{
-  return mVersion;
-}
+const nsCString& GMPParent::GetVersion() const { return mVersion; }
 
-uint32_t
-GMPParent::GetPluginId() const
-{
-  return mPluginId;
-}
+uint32_t GMPParent::GetPluginId() const { return mPluginId; }
 
-void
-GMPParent::ResolveGetContentParentPromises()
-{
+void GMPParent::ResolveGetContentParentPromises() {
   nsTArray<UniquePtr<MozPromiseHolder<GetGMPContentParentPromise>>> promises;
   promises.SwapElements(mGetContentParentPromises);
   MOZ_ASSERT(mGetContentParentPromises.IsEmpty());
-  RefPtr<GMPContentParent::CloseBlocker> blocker(new GMPContentParent::CloseBlocker(mGMPContentParent));
+  RefPtr<GMPContentParent::CloseBlocker> blocker(
+      new GMPContentParent::CloseBlocker(mGMPContentParent));
   for (auto& holder : promises) {
     holder->Resolve(blocker, __func__);
   }
 }
 
-bool
-GMPParent::OpenPGMPContent()
-{
+bool GMPParent::OpenPGMPContent() {
   MOZ_ASSERT(GMPEventTarget()->IsOnCurrentThread());
   MOZ_ASSERT(!mGMPContentParent);
 
   Endpoint<PGMPContentParent> parent;
   Endpoint<PGMPContentChild> child;
   if (NS_WARN_IF(NS_FAILED(PGMPContent::CreateEndpoints(
-        base::GetCurrentProcId(), OtherPid(), &parent, &child)))) {
+          base::GetCurrentProcId(), OtherPid(), &parent, &child)))) {
     return false;
   }
 
@@ -903,9 +821,7 @@ GMPParent::OpenPGMPContent()
   return true;
 }
 
-void
-GMPParent::RejectGetContentParentPromises()
-{
+void GMPParent::RejectGetContentParentPromises() {
   nsTArray<UniquePtr<MozPromiseHolder<GetGMPContentParentPromise>>> promises;
   promises.SwapElements(mGetContentParentPromises);
   MOZ_ASSERT(mGetContentParentPromises.IsEmpty());
@@ -914,22 +830,23 @@ GMPParent::RejectGetContentParentPromises()
   }
 }
 
-void
-GMPParent::GetGMPContentParent(UniquePtr<MozPromiseHolder<GetGMPContentParentPromise>>&& aPromiseHolder)
-{
+void GMPParent::GetGMPContentParent(
+    UniquePtr<MozPromiseHolder<GetGMPContentParentPromise>>&& aPromiseHolder) {
   LOGD("%s %p", __FUNCTION__, this);
   MOZ_ASSERT(GMPEventTarget()->IsOnCurrentThread());
 
   if (mGMPContentParent) {
-    RefPtr<GMPContentParent::CloseBlocker> blocker(new GMPContentParent::CloseBlocker(mGMPContentParent));
+    RefPtr<GMPContentParent::CloseBlocker> blocker(
+        new GMPContentParent::CloseBlocker(mGMPContentParent));
     aPromiseHolder->Resolve(blocker, __func__);
   } else {
     mGetContentParentPromises.AppendElement(Move(aPromiseHolder));
     // If we don't have a GMPContentParent and we try to get one for the first
-    // time (mGetContentParentPromises.Length() == 1) then call PGMPContent::Open. If more
-    // calls to GetGMPContentParent happen before mGMPContentParent has been
-    // set then we should just store them, so that they get called when we set
-    // mGMPContentParent as a result of the PGMPContent::Open call.
+    // time (mGetContentParentPromises.Length() == 1) then call
+    // PGMPContent::Open. If more calls to GetGMPContentParent happen before
+    // mGMPContentParent has been set then we should just store them, so that
+    // they get called when we set mGMPContentParent as a result of the
+    // PGMPContent::Open call.
     if (mGetContentParentPromises.Length() == 1) {
       if (!EnsureProcessLoaded() || !OpenPGMPContent()) {
         RejectGetContentParentPromises();
@@ -943,16 +860,12 @@ GMPParent::GetGMPContentParent(UniquePtr<MozPromiseHolder<GetGMPContentParentPro
   }
 }
 
-already_AddRefed<GMPContentParent>
-GMPParent::ForgetGMPContentParent()
-{
+already_AddRefed<GMPContentParent> GMPParent::ForgetGMPContentParent() {
   MOZ_ASSERT(mGetContentParentPromises.IsEmpty());
   return Move(mGMPContentParent.forget());
 }
 
-bool
-GMPParent::EnsureProcessLoaded(base::ProcessId* aID)
-{
+bool GMPParent::EnsureProcessLoaded(base::ProcessId* aID) {
   if (!EnsureProcessLoaded()) {
     return false;
   }
@@ -960,20 +873,14 @@ GMPParent::EnsureProcessLoaded(base::ProcessId* aID)
   return true;
 }
 
-void
-GMPParent::IncrementGMPContentChildCount()
-{
-  ++mGMPContentChildCount;
-}
+void GMPParent::IncrementGMPContentChildCount() { ++mGMPContentChildCount; }
 
-nsString
-GMPParent::GetPluginBaseName() const
-{
+nsString GMPParent::GetPluginBaseName() const {
   return NS_LITERAL_STRING("gmp-") + mName;
 }
 
-} // namespace gmp
-} // namespace mozilla
+}  // namespace gmp
+}  // namespace mozilla
 
 #undef LOG
 #undef LOGD
