@@ -45,30 +45,22 @@
 struct JSContext;
 class JSObject;
 
-mozilla::LogModule* GetMediaSourceLog()
-{
+mozilla::LogModule* GetMediaSourceLog() {
   static mozilla::LazyLogModule sLogModule("MediaSource");
   return sLogModule;
 }
 
-mozilla::LogModule* GetMediaSourceAPILog()
-{
+mozilla::LogModule* GetMediaSourceAPILog() {
   static mozilla::LazyLogModule sLogModule("MediaSource");
   return sLogModule;
 }
 
-#define MSE_DEBUG(arg, ...)                                                    \
-  DDMOZ_LOG(GetMediaSourceLog(),                                               \
-            mozilla::LogLevel::Debug,                                          \
-            "::%s: " arg,                                                      \
-            __func__,                                                          \
-            ##__VA_ARGS__)
-#define MSE_API(arg, ...)                                                      \
-  DDMOZ_LOG(GetMediaSourceAPILog(),                                            \
-            mozilla::LogLevel::Debug,                                          \
-            "::%s: " arg,                                                      \
-            __func__,                                                          \
-            ##__VA_ARGS__)
+#define MSE_DEBUG(arg, ...)                                              \
+  DDMOZ_LOG(GetMediaSourceLog(), mozilla::LogLevel::Debug, "::%s: " arg, \
+            __func__, ##__VA_ARGS__)
+#define MSE_API(arg, ...)                                                   \
+  DDMOZ_LOG(GetMediaSourceAPILog(), mozilla::LogLevel::Debug, "::%s: " arg, \
+            __func__, ##__VA_ARGS__)
 
 // Arbitrary limit.
 static const unsigned int MAX_SOURCE_BUFFERS = 16;
@@ -78,17 +70,15 @@ namespace mozilla {
 // Returns true if we should enable MSE webm regardless of preferences.
 // 1. If MP4/H264 isn't supported:
 //   * Windows XP
-//   * Windows Vista and Server 2008 without the optional "Platform Update Supplement"
+//   * Windows Vista and Server 2008 without the optional "Platform Update
+//   Supplement"
 //   * N/KN editions (Europe and Korea) of Windows 7/8/8.1/10 without the
 //     optional "Windows Media Feature Pack"
 // 2. If H264 hardware acceleration is not available.
 // 3. The CPU is considered to be fast enough
-static bool
-IsWebMForced(DecoderDoctorDiagnostics* aDiagnostics)
-{
-  bool mp4supported =
-    DecoderTraits::IsMP4SupportedType(MediaContainerType(MEDIAMIMETYPE(VIDEO_MP4)),
-                                      aDiagnostics);
+static bool IsWebMForced(DecoderDoctorDiagnostics* aDiagnostics) {
+  bool mp4supported = DecoderTraits::IsMP4SupportedType(
+      MediaContainerType(MEDIAMIMETYPE(VIDEO_MP4)), aDiagnostics);
   bool hwsupported = gfx::gfxVars::CanUseHardwareVideoDecoding();
 #ifdef MOZ_WIDGET_ANDROID
   return !mp4supported || !hwsupported || VP9Benchmark::IsVP9DecodeFast() ||
@@ -101,9 +91,8 @@ IsWebMForced(DecoderDoctorDiagnostics* aDiagnostics)
 namespace dom {
 
 /* static */
-nsresult
-MediaSource::IsTypeSupported(const nsAString& aType, DecoderDoctorDiagnostics* aDiagnostics)
-{
+nsresult MediaSource::IsTypeSupported(const nsAString& aType,
+                                      DecoderDoctorDiagnostics* aDiagnostics) {
   if (aType.IsEmpty()) {
     return NS_ERROR_DOM_TYPE_ERR;
   }
@@ -113,8 +102,8 @@ MediaSource::IsTypeSupported(const nsAString& aType, DecoderDoctorDiagnostics* a
     return NS_ERROR_DOM_NOT_SUPPORTED_ERR;
   }
 
-  if (DecoderTraits::CanHandleContainerType(*containerType, aDiagnostics)
-      == CANPLAY_NO) {
+  if (DecoderTraits::CanHandleContainerType(*containerType, aDiagnostics) ==
+      CANPLAY_NO) {
     return NS_ERROR_DOM_NOT_SUPPORTED_ERR;
   }
 
@@ -131,11 +120,12 @@ MediaSource::IsTypeSupported(const nsAString& aType, DecoderDoctorDiagnostics* a
   if (mimeType == MEDIAMIMETYPE("video/webm")) {
     if (!(Preferences::GetBool("media.mediasource.webm.enabled", false) ||
           containerType->ExtendedType().Codecs().Contains(
-            NS_LITERAL_STRING("vp8")) ||
+              NS_LITERAL_STRING("vp8")) ||
 #ifdef MOZ_AV1
           // FIXME: Temporary comparison with the full codecs attribute.
           // See bug 1377015.
-          AOMDecoder::IsSupportedCodec(containerType->ExtendedType().Codecs().AsString()) ||
+          AOMDecoder::IsSupportedCodec(
+              containerType->ExtendedType().Codecs().AsString()) ||
 #endif
           IsWebMForced(aDiagnostics))) {
       return NS_ERROR_DOM_NOT_SUPPORTED_ERR;
@@ -153,11 +143,10 @@ MediaSource::IsTypeSupported(const nsAString& aType, DecoderDoctorDiagnostics* a
   return NS_ERROR_DOM_NOT_SUPPORTED_ERR;
 }
 
-/* static */ already_AddRefed<MediaSource>
-MediaSource::Constructor(const GlobalObject& aGlobal,
-                         ErrorResult& aRv)
-{
-  nsCOMPtr<nsPIDOMWindowInner> window = do_QueryInterface(aGlobal.GetAsSupports());
+/* static */ already_AddRefed<MediaSource> MediaSource::Constructor(
+    const GlobalObject& aGlobal, ErrorResult& aRv) {
+  nsCOMPtr<nsPIDOMWindowInner> window =
+      do_QueryInterface(aGlobal.GetAsSupports());
   if (!window) {
     aRv.Throw(NS_ERROR_UNEXPECTED);
     return nullptr;
@@ -167,8 +156,7 @@ MediaSource::Constructor(const GlobalObject& aGlobal,
   return mediaSource.forget();
 }
 
-MediaSource::~MediaSource()
-{
+MediaSource::~MediaSource() {
   MOZ_ASSERT(NS_IsMainThread());
   MSE_API("");
   if (mDecoder) {
@@ -176,32 +164,26 @@ MediaSource::~MediaSource()
   }
 }
 
-SourceBufferList*
-MediaSource::SourceBuffers()
-{
+SourceBufferList* MediaSource::SourceBuffers() {
   MOZ_ASSERT(NS_IsMainThread());
-  MOZ_ASSERT_IF(mReadyState == MediaSourceReadyState::Closed, mSourceBuffers->IsEmpty());
+  MOZ_ASSERT_IF(mReadyState == MediaSourceReadyState::Closed,
+                mSourceBuffers->IsEmpty());
   return mSourceBuffers;
 }
 
-SourceBufferList*
-MediaSource::ActiveSourceBuffers()
-{
+SourceBufferList* MediaSource::ActiveSourceBuffers() {
   MOZ_ASSERT(NS_IsMainThread());
-  MOZ_ASSERT_IF(mReadyState == MediaSourceReadyState::Closed, mActiveSourceBuffers->IsEmpty());
+  MOZ_ASSERT_IF(mReadyState == MediaSourceReadyState::Closed,
+                mActiveSourceBuffers->IsEmpty());
   return mActiveSourceBuffers;
 }
 
-MediaSourceReadyState
-MediaSource::ReadyState()
-{
+MediaSourceReadyState MediaSource::ReadyState() {
   MOZ_ASSERT(NS_IsMainThread());
   return mReadyState;
 }
 
-double
-MediaSource::Duration()
-{
+double MediaSource::Duration() {
   MOZ_ASSERT(NS_IsMainThread());
   if (mReadyState == MediaSourceReadyState::Closed) {
     return UnspecifiedNaN<double>();
@@ -210,9 +192,7 @@ MediaSource::Duration()
   return mDecoder->GetDuration();
 }
 
-void
-MediaSource::SetDuration(double aDuration, ErrorResult& aRv)
-{
+void MediaSource::SetDuration(double aDuration, ErrorResult& aRv) {
   MOZ_ASSERT(NS_IsMainThread());
   MSE_API("SetDuration(aDuration=%f, ErrorResult)", aDuration);
   if (aDuration < 0 || IsNaN(aDuration)) {
@@ -227,26 +207,21 @@ MediaSource::SetDuration(double aDuration, ErrorResult& aRv)
   DurationChange(aDuration, aRv);
 }
 
-void
-MediaSource::SetDuration(double aDuration)
-{
+void MediaSource::SetDuration(double aDuration) {
   MOZ_ASSERT(NS_IsMainThread());
   MSE_API("SetDuration(aDuration=%f)", aDuration);
   mDecoder->SetMediaSourceDuration(aDuration);
 }
 
-already_AddRefed<SourceBuffer>
-MediaSource::AddSourceBuffer(const nsAString& aType, ErrorResult& aRv)
-{
+already_AddRefed<SourceBuffer> MediaSource::AddSourceBuffer(
+    const nsAString& aType, ErrorResult& aRv) {
   MOZ_ASSERT(NS_IsMainThread());
   DecoderDoctorDiagnostics diagnostics;
   nsresult rv = IsTypeSupported(aType, &diagnostics);
-  diagnostics.StoreFormatDiagnostics(GetOwner()
-                                     ? GetOwner()->GetExtantDoc()
-                                     : nullptr,
-                                     aType, NS_SUCCEEDED(rv), __func__);
-  MSE_API("AddSourceBuffer(aType=%s)%s",
-          NS_ConvertUTF16toUTF8(aType).get(),
+  diagnostics.StoreFormatDiagnostics(
+      GetOwner() ? GetOwner()->GetExtantDoc() : nullptr, aType,
+      NS_SUCCEEDED(rv), __func__);
+  MSE_API("AddSourceBuffer(aType=%s)%s", NS_ConvertUTF16toUTF8(aType).get(),
           rv == NS_OK ? "" : " [not supported]");
   if (NS_FAILED(rv)) {
     aRv.Throw(rv);
@@ -267,7 +242,7 @@ MediaSource::AddSourceBuffer(const nsAString& aType, ErrorResult& aRv)
   }
   RefPtr<SourceBuffer> sourceBuffer = new SourceBuffer(this, *containerType);
   if (!sourceBuffer) {
-    aRv.Throw(NS_ERROR_FAILURE); // XXX need a better error here
+    aRv.Throw(NS_ERROR_FAILURE);  // XXX need a better error here
     return nullptr;
   }
   mSourceBuffers->Append(sourceBuffer);
@@ -276,9 +251,8 @@ MediaSource::AddSourceBuffer(const nsAString& aType, ErrorResult& aRv)
   return sourceBuffer.forget();
 }
 
-RefPtr<MediaSource::ActiveCompletionPromise>
-MediaSource::SourceBufferIsActive(SourceBuffer* aSourceBuffer)
-{
+RefPtr<MediaSource::ActiveCompletionPromise> MediaSource::SourceBufferIsActive(
+    SourceBuffer* aSourceBuffer) {
   MOZ_ASSERT(NS_IsMainThread());
   mActiveSourceBuffers->ClearSimple();
   bool initMissing = false;
@@ -310,9 +284,7 @@ MediaSource::SourceBufferIsActive(SourceBuffer* aSourceBuffer)
   return promise;
 }
 
-void
-MediaSource::CompletePendingTransactions()
-{
+void MediaSource::CompletePendingTransactions() {
   MOZ_ASSERT(NS_IsMainThread());
   MSE_DEBUG("Resolving %u promises", unsigned(mCompletionPromises.Length()));
   for (auto& promise : mCompletionPromises) {
@@ -321,9 +293,8 @@ MediaSource::CompletePendingTransactions()
   mCompletionPromises.Clear();
 }
 
-void
-MediaSource::RemoveSourceBuffer(SourceBuffer& aSourceBuffer, ErrorResult& aRv)
-{
+void MediaSource::RemoveSourceBuffer(SourceBuffer& aSourceBuffer,
+                                     ErrorResult& aRv) {
   MOZ_ASSERT(NS_IsMainThread());
   SourceBuffer* sourceBuffer = &aSourceBuffer;
   MSE_API("RemoveSourceBuffer(aSourceBuffer=%p)", sourceBuffer);
@@ -340,8 +311,8 @@ MediaSource::RemoveSourceBuffer(SourceBuffer& aSourceBuffer, ErrorResult& aRv)
   // For all sourceBuffer audioTracks, videoTracks, textTracks:
   //     set sourceBuffer to null
   //     remove sourceBuffer video, audio, text Tracks from MediaElement tracks
-  //     remove sourceBuffer video, audio, text Tracks and fire "removetrack" at affected lists
-  //     fire "removetrack" at modified MediaElement track lists
+  //     remove sourceBuffer video, audio, text Tracks and fire "removetrack" at
+  //     affected lists fire "removetrack" at modified MediaElement track lists
   // If removed enabled/selected, fire "change" at affected MediaElement list.
   if (mActiveSourceBuffers->Contains(sourceBuffer)) {
     mActiveSourceBuffers->Remove(sourceBuffer);
@@ -351,9 +322,8 @@ MediaSource::RemoveSourceBuffer(SourceBuffer& aSourceBuffer, ErrorResult& aRv)
   // TODO: Free all resources associated with sourceBuffer
 }
 
-void
-MediaSource::EndOfStream(const Optional<MediaSourceEndOfStreamError>& aError, ErrorResult& aRv)
-{
+void MediaSource::EndOfStream(
+    const Optional<MediaSourceEndOfStreamError>& aError, ErrorResult& aRv) {
   MOZ_ASSERT(NS_IsMainThread());
   MSE_API("EndOfStream(aError=%d)",
           aError.WasPassed() ? uint32_t(aError.Value()) : 0);
@@ -372,20 +342,18 @@ MediaSource::EndOfStream(const Optional<MediaSourceEndOfStreamError>& aError, Er
     return;
   }
   switch (aError.Value()) {
-  case MediaSourceEndOfStreamError::Network:
-    mDecoder->NetworkError(MediaResult(NS_ERROR_FAILURE, "MSE network"));
-    break;
-  case MediaSourceEndOfStreamError::Decode:
-    mDecoder->DecodeError(NS_ERROR_DOM_MEDIA_FATAL_ERR);
-    break;
-  default:
-    aRv.Throw(NS_ERROR_DOM_TYPE_ERR);
+    case MediaSourceEndOfStreamError::Network:
+      mDecoder->NetworkError(MediaResult(NS_ERROR_FAILURE, "MSE network"));
+      break;
+    case MediaSourceEndOfStreamError::Decode:
+      mDecoder->DecodeError(NS_ERROR_DOM_MEDIA_FATAL_ERR);
+      break;
+    default:
+      aRv.Throw(NS_ERROR_DOM_TYPE_ERR);
   }
 }
 
-void
-MediaSource::EndOfStream(const MediaResult& aError)
-{
+void MediaSource::EndOfStream(const MediaResult& aError) {
   MOZ_ASSERT(NS_IsMainThread());
   MSE_API("EndOfStream(aError=%s)", aError.ErrorName().get());
 
@@ -394,37 +362,32 @@ MediaSource::EndOfStream(const MediaResult& aError)
   mDecoder->DecodeError(aError);
 }
 
-/* static */ bool
-MediaSource::IsTypeSupported(const GlobalObject& aOwner, const nsAString& aType)
-{
+/* static */ bool MediaSource::IsTypeSupported(const GlobalObject& aOwner,
+                                               const nsAString& aType) {
   MOZ_ASSERT(NS_IsMainThread());
   DecoderDoctorDiagnostics diagnostics;
   nsresult rv = IsTypeSupported(aType, &diagnostics);
-  nsCOMPtr<nsPIDOMWindowInner> window = do_QueryInterface(aOwner.GetAsSupports());
+  nsCOMPtr<nsPIDOMWindowInner> window =
+      do_QueryInterface(aOwner.GetAsSupports());
   diagnostics.StoreFormatDiagnostics(window ? window->GetExtantDoc() : nullptr,
                                      aType, NS_SUCCEEDED(rv), __func__);
-  MOZ_LOG(GetMediaSourceAPILog(),
-          mozilla::LogLevel::Debug,
-          ("MediaSource::%s: IsTypeSupported(aType=%s) %s",
-           __func__,
+  MOZ_LOG(GetMediaSourceAPILog(), mozilla::LogLevel::Debug,
+          ("MediaSource::%s: IsTypeSupported(aType=%s) %s", __func__,
            NS_ConvertUTF16toUTF8(aType).get(),
            rv == NS_OK ? "OK" : "[not supported]"));
   return NS_SUCCEEDED(rv);
 }
 
-/* static */ bool
-MediaSource::Enabled(JSContext* cx, JSObject* aGlobal)
-{
+/* static */ bool MediaSource::Enabled(JSContext* cx, JSObject* aGlobal) {
   return Preferences::GetBool("media.mediasource.enabled");
 }
 
-void
-MediaSource::SetLiveSeekableRange(double aStart, double aEnd, ErrorResult& aRv)
-{
+void MediaSource::SetLiveSeekableRange(double aStart, double aEnd,
+                                       ErrorResult& aRv) {
   MOZ_ASSERT(NS_IsMainThread());
 
-  // 1. If the readyState attribute is not "open" then throw an InvalidStateError
-  // exception and abort these steps.
+  // 1. If the readyState attribute is not "open" then throw an
+  // InvalidStateError exception and abort these steps.
   if (mReadyState != MediaSourceReadyState::Open) {
     aRv.Throw(NS_ERROR_DOM_INVALID_STATE_ERR);
     return;
@@ -441,17 +404,15 @@ MediaSource::SetLiveSeekableRange(double aStart, double aEnd, ErrorResult& aRv)
   // containing a single range whose start position is start and end position is
   // end.
   mLiveSeekableRange =
-    Some(media::TimeInterval(media::TimeUnit::FromSeconds(aStart),
-                             media::TimeUnit::FromSeconds(aEnd)));
+      Some(media::TimeInterval(media::TimeUnit::FromSeconds(aStart),
+                               media::TimeUnit::FromSeconds(aEnd)));
 }
 
-void
-MediaSource::ClearLiveSeekableRange(ErrorResult& aRv)
-{
+void MediaSource::ClearLiveSeekableRange(ErrorResult& aRv) {
   MOZ_ASSERT(NS_IsMainThread());
 
-  // 1. If the readyState attribute is not "open" then throw an InvalidStateError
-  // exception and abort these steps.
+  // 1. If the readyState attribute is not "open" then throw an
+  // InvalidStateError exception and abort these steps.
   if (mReadyState != MediaSourceReadyState::Open) {
     aRv.Throw(NS_ERROR_DOM_INVALID_STATE_ERR);
     return;
@@ -462,9 +423,7 @@ MediaSource::ClearLiveSeekableRange(ErrorResult& aRv)
   mLiveSeekableRange.reset();
 }
 
-bool
-MediaSource::Attach(MediaSourceDecoder* aDecoder)
-{
+bool MediaSource::Attach(MediaSourceDecoder* aDecoder) {
   MOZ_ASSERT(NS_IsMainThread());
   MSE_DEBUG("Attach(aDecoder=%p) owner=%p", aDecoder, aDecoder->GetOwner());
   MOZ_ASSERT(aDecoder);
@@ -481,13 +440,11 @@ MediaSource::Attach(MediaSourceDecoder* aDecoder)
   return true;
 }
 
-void
-MediaSource::Detach()
-{
+void MediaSource::Detach() {
   MOZ_ASSERT(NS_IsMainThread());
   MOZ_RELEASE_ASSERT(mCompletionPromises.IsEmpty());
-  MSE_DEBUG("mDecoder=%p owner=%p",
-            mDecoder.get(), mDecoder ? mDecoder->GetOwner() : nullptr);
+  MSE_DEBUG("mDecoder=%p owner=%p", mDecoder.get(),
+            mDecoder ? mDecoder->GetOwner() : nullptr);
   if (!mDecoder) {
     MOZ_ASSERT(mReadyState == MediaSourceReadyState::Closed);
     MOZ_ASSERT(mActiveSourceBuffers->IsEmpty() && mSourceBuffers->IsEmpty());
@@ -506,12 +463,12 @@ MediaSource::Detach()
 }
 
 MediaSource::MediaSource(nsPIDOMWindowInner* aWindow)
-  : DOMEventTargetHelper(aWindow)
-  , mDecoder(nullptr)
-  , mPrincipal(nullptr)
-  , mAbstractMainThread(GetOwnerGlobal()->AbstractMainThreadFor(TaskCategory::Other))
-  , mReadyState(MediaSourceReadyState::Closed)
-{
+    : DOMEventTargetHelper(aWindow),
+      mDecoder(nullptr),
+      mPrincipal(nullptr),
+      mAbstractMainThread(
+          GetOwnerGlobal()->AbstractMainThreadFor(TaskCategory::Other)),
+      mReadyState(MediaSourceReadyState::Closed) {
   MOZ_ASSERT(NS_IsMainThread());
   mSourceBuffers = new SourceBufferList(this);
   mActiveSourceBuffers = new SourceBufferList(this);
@@ -525,9 +482,7 @@ MediaSource::MediaSource(nsPIDOMWindowInner* aWindow)
           aWindow, mSourceBuffers.get(), mActiveSourceBuffers.get());
 }
 
-void
-MediaSource::SetReadyState(MediaSourceReadyState aState)
-{
+void MediaSource::SetReadyState(MediaSourceReadyState aState) {
   MOZ_ASSERT(NS_IsMainThread());
   MOZ_ASSERT(aState != mReadyState);
   MSE_DEBUG("SetReadyState(aState=%" PRIu32 ") mReadyState=%" PRIu32,
@@ -563,25 +518,19 @@ MediaSource::SetReadyState(MediaSourceReadyState aState)
   NS_WARNING("Invalid MediaSource readyState transition");
 }
 
-void
-MediaSource::DispatchSimpleEvent(const char* aName)
-{
+void MediaSource::DispatchSimpleEvent(const char* aName) {
   MOZ_ASSERT(NS_IsMainThread());
   MSE_API("Dispatch event '%s'", aName);
   DispatchTrustedEvent(NS_ConvertUTF8toUTF16(aName));
 }
 
-void
-MediaSource::QueueAsyncSimpleEvent(const char* aName)
-{
+void MediaSource::QueueAsyncSimpleEvent(const char* aName) {
   MSE_DEBUG("Queuing event '%s'", aName);
   nsCOMPtr<nsIRunnable> event = new AsyncEventRunner<MediaSource>(this, aName);
   mAbstractMainThread->Dispatch(event.forget());
 }
 
-void
-MediaSource::DurationChange(double aNewDuration, ErrorResult& aRv)
-{
+void MediaSource::DurationChange(double aNewDuration, ErrorResult& aRv) {
   MOZ_ASSERT(NS_IsMainThread());
   MSE_DEBUG("DurationChange(aNewDuration=%f)", aNewDuration);
 
@@ -603,37 +552,29 @@ MediaSource::DurationChange(double aNewDuration, ErrorResult& aRv)
   double highestEndTime = mSourceBuffers->HighestEndTime();
   // 4. If new duration is less than highest end time, then
   //    4.1 Update new duration to equal highest end time.
-  aNewDuration =
-    std::max(aNewDuration, highestEndTime);
+  aNewDuration = std::max(aNewDuration, highestEndTime);
 
   // 5. Update the media duration to new duration and run the HTMLMediaElement
   // duration change algorithm.
   mDecoder->SetMediaSourceDuration(aNewDuration);
 }
 
-void
-MediaSource::GetMozDebugReaderData(nsAString& aString)
-{
+void MediaSource::GetMozDebugReaderData(nsAString& aString) {
   nsAutoCString result;
   mDecoder->GetMozDebugReaderData(result);
   aString = NS_ConvertUTF8toUTF16(result);
 }
 
-nsPIDOMWindowInner*
-MediaSource::GetParentObject() const
-{
-  return GetOwner();
-}
+nsPIDOMWindowInner* MediaSource::GetParentObject() const { return GetOwner(); }
 
-JSObject*
-MediaSource::WrapObject(JSContext* aCx, JS::Handle<JSObject*> aGivenProto)
-{
+JSObject* MediaSource::WrapObject(JSContext* aCx,
+                                  JS::Handle<JSObject*> aGivenProto) {
   return MediaSourceBinding::Wrap(aCx, this, aGivenProto);
 }
 
 NS_IMPL_CYCLE_COLLECTION_INHERITED(MediaSource, DOMEventTargetHelper,
-                                   mMediaElement,
-                                   mSourceBuffers, mActiveSourceBuffers)
+                                   mMediaElement, mSourceBuffers,
+                                   mActiveSourceBuffers)
 
 NS_IMPL_ADDREF_INHERITED(MediaSource, DOMEventTargetHelper)
 NS_IMPL_RELEASE_INHERITED(MediaSource, DOMEventTargetHelper)
@@ -645,6 +586,6 @@ NS_INTERFACE_MAP_END_INHERITING(DOMEventTargetHelper)
 #undef MSE_DEBUG
 #undef MSE_API
 
-} // namespace dom
+}  // namespace dom
 
-} // namespace mozilla
+}  // namespace mozilla
