@@ -24,7 +24,8 @@
 #include "TimeUnits.h"
 
 // GetCurrentTime is defined in winbase.h as zero argument macro forwarding to
-// GetTickCount() and conflicts with MediaDecoder::GetCurrentTime implementation.
+// GetTickCount() and conflicts with MediaDecoder::GetCurrentTime
+// implementation.
 #ifdef GetCurrentTime
 #undef GetCurrentTime
 #endif
@@ -35,26 +36,15 @@ class JSObject;
 extern mozilla::LogModule* GetMediaSourceLog();
 extern mozilla::LogModule* GetMediaSourceAPILog();
 
-#define MSE_DEBUG(arg, ...)                                                    \
-  DDMOZ_LOG(GetMediaSourceLog(),                                               \
-            mozilla::LogLevel::Debug,                                          \
-            "(%s)::%s: " arg,                                                  \
-            mType.OriginalString().Data(),                                     \
-            __func__,                                                          \
-            ##__VA_ARGS__)
+#define MSE_DEBUG(arg, ...)                                                  \
+  DDMOZ_LOG(GetMediaSourceLog(), mozilla::LogLevel::Debug, "(%s)::%s: " arg, \
+            mType.OriginalString().Data(), __func__, ##__VA_ARGS__)
 #define MSE_DEBUGV(arg, ...)                                                   \
-  DDMOZ_LOG(GetMediaSourceLog(),                                               \
-            mozilla::LogLevel::Verbose,                                        \
-            "(%s)::%s: " arg,                                                  \
-            mType.OriginalString().Data(),                                     \
-            __func__,                                                          \
-            ##__VA_ARGS__)
-#define MSE_API(arg, ...)                                                      \
-  DDMOZ_LOG(GetMediaSourceAPILog(),                                            \
-            mozilla::LogLevel::Debug,                                          \
-            "(%s)::%s: " arg,                                                  \
-            mType.OriginalString().Data(),                                     \
-            __func__,                                                          \
+  DDMOZ_LOG(GetMediaSourceLog(), mozilla::LogLevel::Verbose, "(%s)::%s: " arg, \
+            mType.OriginalString().Data(), __func__, ##__VA_ARGS__)
+#define MSE_API(arg, ...)                                              \
+  DDMOZ_LOG(GetMediaSourceAPILog(), mozilla::LogLevel::Debug,          \
+            "(%s)::%s: " arg, mType.OriginalString().Data(), __func__, \
             ##__VA_ARGS__)
 
 namespace mozilla {
@@ -64,9 +54,7 @@ typedef SourceBufferAttributes::AppendState AppendState;
 
 namespace dom {
 
-void
-SourceBuffer::SetMode(SourceBufferAppendMode aMode, ErrorResult& aRv)
-{
+void SourceBuffer::SetMode(SourceBufferAppendMode aMode, ErrorResult& aRv) {
   MOZ_ASSERT(NS_IsMainThread());
   MSE_API("SetMode(aMode=%" PRIu32 ")", static_cast<uint32_t>(aMode));
   if (!IsAttached() || mUpdating) {
@@ -82,7 +70,8 @@ SourceBuffer::SetMode(SourceBufferAppendMode aMode, ErrorResult& aRv)
   if (mMediaSource->ReadyState() == MediaSourceReadyState::Ended) {
     mMediaSource->SetReadyState(MediaSourceReadyState::Open);
   }
-  if (mCurrentAttributes.GetAppendState() == AppendState::PARSING_MEDIA_SEGMENT){
+  if (mCurrentAttributes.GetAppendState() ==
+      AppendState::PARSING_MEDIA_SEGMENT) {
     aRv.Throw(NS_ERROR_DOM_INVALID_STATE_ERR);
     return;
   }
@@ -95,9 +84,8 @@ SourceBuffer::SetMode(SourceBufferAppendMode aMode, ErrorResult& aRv)
   mCurrentAttributes.SetAppendMode(aMode);
 }
 
-void
-SourceBuffer::SetTimestampOffset(double aTimestampOffset, ErrorResult& aRv)
-{
+void SourceBuffer::SetTimestampOffset(double aTimestampOffset,
+                                      ErrorResult& aRv) {
   MOZ_ASSERT(NS_IsMainThread());
   MSE_API("SetTimestampOffset(aTimestampOffset=%f)", aTimestampOffset);
   if (!IsAttached() || mUpdating) {
@@ -108,22 +96,24 @@ SourceBuffer::SetTimestampOffset(double aTimestampOffset, ErrorResult& aRv)
   if (mMediaSource->ReadyState() == MediaSourceReadyState::Ended) {
     mMediaSource->SetReadyState(MediaSourceReadyState::Open);
   }
-  if (mCurrentAttributes.GetAppendState() == AppendState::PARSING_MEDIA_SEGMENT){
+  if (mCurrentAttributes.GetAppendState() ==
+      AppendState::PARSING_MEDIA_SEGMENT) {
     aRv.Throw(NS_ERROR_DOM_INVALID_STATE_ERR);
     return;
   }
   mCurrentAttributes.SetApparentTimestampOffset(aTimestampOffset);
   if (mCurrentAttributes.GetAppendMode() == SourceBufferAppendMode::Sequence) {
-    mCurrentAttributes.SetGroupStartTimestamp(mCurrentAttributes.GetTimestampOffset());
+    mCurrentAttributes.SetGroupStartTimestamp(
+        mCurrentAttributes.GetTimestampOffset());
   }
 }
 
-TimeRanges*
-SourceBuffer::GetBuffered(ErrorResult& aRv)
-{
+TimeRanges* SourceBuffer::GetBuffered(ErrorResult& aRv) {
   MOZ_ASSERT(NS_IsMainThread());
   // http://w3c.github.io/media-source/index.html#widl-SourceBuffer-buffered
-  // 1. If this object has been removed from the sourceBuffers attribute of the parent media source then throw an InvalidStateError exception and abort these steps.
+  // 1. If this object has been removed from the sourceBuffers attribute of the
+  // parent media source then throw an InvalidStateError exception and abort
+  // these steps.
   if (!IsAttached()) {
     aRv.Throw(NS_ERROR_DOM_INVALID_STATE_ERR);
     return nullptr;
@@ -136,7 +126,9 @@ SourceBuffer::GetBuffered(ErrorResult& aRv)
     rangeChanged = (intersection != currentValue);
     MSE_DEBUGV("currentValue=%s", DumpTimeRanges(currentValue).get());
   }
-  // 5. If intersection ranges does not contain the exact same range information as the current value of this attribute, then update the current value of this attribute to intersection ranges.
+  // 5. If intersection ranges does not contain the exact same range information
+  // as the current value of this attribute, then update the current value of
+  // this attribute to intersection ranges.
   if (rangeChanged) {
     mBuffered = new TimeRanges(ToSupports(this), intersection);
   }
@@ -144,15 +136,12 @@ SourceBuffer::GetBuffered(ErrorResult& aRv)
   return mBuffered;
 }
 
-media::TimeIntervals
-SourceBuffer::GetTimeIntervals()
-{
+media::TimeIntervals SourceBuffer::GetTimeIntervals() {
   return mTrackBuffersManager->Buffered();
 }
 
-void
-SourceBuffer::SetAppendWindowStart(double aAppendWindowStart, ErrorResult& aRv)
-{
+void SourceBuffer::SetAppendWindowStart(double aAppendWindowStart,
+                                        ErrorResult& aRv) {
   MOZ_ASSERT(NS_IsMainThread());
   MSE_API("SetAppendWindowStart(aAppendWindowStart=%f)", aAppendWindowStart);
   DDLOG(DDLogCategory::API, "SetAppendWindowStart", aAppendWindowStart);
@@ -168,9 +157,8 @@ SourceBuffer::SetAppendWindowStart(double aAppendWindowStart, ErrorResult& aRv)
   mCurrentAttributes.SetAppendWindowStart(aAppendWindowStart);
 }
 
-void
-SourceBuffer::SetAppendWindowEnd(double aAppendWindowEnd, ErrorResult& aRv)
-{
+void SourceBuffer::SetAppendWindowEnd(double aAppendWindowEnd,
+                                      ErrorResult& aRv) {
   MOZ_ASSERT(NS_IsMainThread());
   MSE_API("SetAppendWindowEnd(aAppendWindowEnd=%f)", aAppendWindowEnd);
   DDLOG(DDLogCategory::API, "SetAppendWindowEnd", aAppendWindowEnd);
@@ -186,9 +174,7 @@ SourceBuffer::SetAppendWindowEnd(double aAppendWindowEnd, ErrorResult& aRv)
   mCurrentAttributes.SetAppendWindowEnd(aAppendWindowEnd);
 }
 
-void
-SourceBuffer::AppendBuffer(const ArrayBuffer& aData, ErrorResult& aRv)
-{
+void SourceBuffer::AppendBuffer(const ArrayBuffer& aData, ErrorResult& aRv) {
   MOZ_ASSERT(NS_IsMainThread());
   MSE_API("AppendBuffer(ArrayBuffer)");
   aData.ComputeLengthAndData();
@@ -196,9 +182,8 @@ SourceBuffer::AppendBuffer(const ArrayBuffer& aData, ErrorResult& aRv)
   AppendData(aData.Data(), aData.Length(), aRv);
 }
 
-void
-SourceBuffer::AppendBuffer(const ArrayBufferView& aData, ErrorResult& aRv)
-{
+void SourceBuffer::AppendBuffer(const ArrayBufferView& aData,
+                                ErrorResult& aRv) {
   MOZ_ASSERT(NS_IsMainThread());
   MSE_API("AppendBuffer(ArrayBufferView)");
   aData.ComputeLengthAndData();
@@ -206,9 +191,7 @@ SourceBuffer::AppendBuffer(const ArrayBufferView& aData, ErrorResult& aRv)
   AppendData(aData.Data(), aData.Length(), aRv);
 }
 
-void
-SourceBuffer::Abort(ErrorResult& aRv)
-{
+void SourceBuffer::Abort(ErrorResult& aRv) {
   MOZ_ASSERT(NS_IsMainThread());
   MSE_API("Abort()");
   if (!IsAttached()) {
@@ -233,9 +216,7 @@ SourceBuffer::Abort(ErrorResult& aRv)
   mCurrentAttributes.SetAppendWindowEnd(PositiveInfinity<double>());
 }
 
-void
-SourceBuffer::AbortBufferAppend()
-{
+void SourceBuffer::AbortBufferAppend() {
   if (mUpdating) {
     mCompletionPromise.DisconnectIfExists();
     if (mPendingAppend.Exists()) {
@@ -246,15 +227,11 @@ SourceBuffer::AbortBufferAppend()
   }
 }
 
-void
-SourceBuffer::ResetParserState()
-{
+void SourceBuffer::ResetParserState() {
   mTrackBuffersManager->ResetParserState(mCurrentAttributes);
 }
 
-void
-SourceBuffer::Remove(double aStart, double aEnd, ErrorResult& aRv)
-{
+void SourceBuffer::Remove(double aStart, double aEnd, ErrorResult& aRv) {
   MOZ_ASSERT(NS_IsMainThread());
   MSE_API("Remove(aStart=%f, aEnd=%f)", aStart, aEnd);
   DDLOG(DDLogCategory::API, "Remove-from", aStart);
@@ -267,9 +244,8 @@ SourceBuffer::Remove(double aStart, double aEnd, ErrorResult& aRv)
     aRv.Throw(NS_ERROR_DOM_INVALID_STATE_ERR);
     return;
   }
-  if (IsNaN(mMediaSource->Duration()) ||
-      aStart < 0 || aStart > mMediaSource->Duration() ||
-      aEnd <= aStart || IsNaN(aEnd)) {
+  if (IsNaN(mMediaSource->Duration()) || aStart < 0 ||
+      aStart > mMediaSource->Duration() || aEnd <= aStart || IsNaN(aEnd)) {
     aRv.Throw(NS_ERROR_DOM_TYPE_ERR);
     return;
   }
@@ -280,16 +256,14 @@ SourceBuffer::Remove(double aStart, double aEnd, ErrorResult& aRv)
   RangeRemoval(aStart, aEnd);
 }
 
-void
-SourceBuffer::RangeRemoval(double aStart, double aEnd)
-{
+void SourceBuffer::RangeRemoval(double aStart, double aEnd) {
   StartUpdating();
 
   RefPtr<SourceBuffer> self = this;
-    mTrackBuffersManager->RangeRemoval(TimeUnit::FromSeconds(aStart),
-                                       TimeUnit::FromSeconds(aEnd))
+  mTrackBuffersManager
+      ->RangeRemoval(TimeUnit::FromSeconds(aStart), TimeUnit::FromSeconds(aEnd))
       ->Then(mAbstractMainThread, __func__,
-             [self] (bool) {
+             [self](bool) {
                self->mPendingRemoval.Complete();
                self->StopUpdating();
              },
@@ -297,9 +271,7 @@ SourceBuffer::RangeRemoval(double aStart, double aEnd)
       ->Track(mPendingRemoval);
 }
 
-void
-SourceBuffer::Detach()
-{
+void SourceBuffer::Detach() {
   MOZ_ASSERT(NS_IsMainThread());
   MSE_DEBUG("Detach");
   if (!mMediaSource) {
@@ -309,16 +281,14 @@ SourceBuffer::Detach()
   AbortBufferAppend();
   if (mTrackBuffersManager) {
     mMediaSource->GetDecoder()->GetDemuxer()->DetachSourceBuffer(
-      mTrackBuffersManager);
+        mTrackBuffersManager);
     mTrackBuffersManager->Detach();
   }
   mTrackBuffersManager = nullptr;
   mMediaSource = nullptr;
 }
 
-void
-SourceBuffer::Ended()
-{
+void SourceBuffer::Ended() {
   MOZ_ASSERT(NS_IsMainThread());
   MOZ_ASSERT(IsAttached());
   MSE_DEBUG("Ended");
@@ -327,24 +297,22 @@ SourceBuffer::Ended()
 
 SourceBuffer::SourceBuffer(MediaSource* aMediaSource,
                            const MediaContainerType& aType)
-  : DOMEventTargetHelper(aMediaSource->GetParentObject())
-  , mMediaSource(aMediaSource)
-  , mAbstractMainThread(aMediaSource->AbstractMainThread())
-  , mCurrentAttributes(aType.Type() == MEDIAMIMETYPE("audio/mpeg") ||
-                       aType.Type() == MEDIAMIMETYPE("audio/aac"))
-  , mUpdating(false)
-  , mActive(false)
-  , mType(aType)
-{
+    : DOMEventTargetHelper(aMediaSource->GetParentObject()),
+      mMediaSource(aMediaSource),
+      mAbstractMainThread(aMediaSource->AbstractMainThread()),
+      mCurrentAttributes(aType.Type() == MEDIAMIMETYPE("audio/mpeg") ||
+                         aType.Type() == MEDIAMIMETYPE("audio/aac")),
+      mUpdating(false),
+      mActive(false),
+      mType(aType) {
   MOZ_ASSERT(NS_IsMainThread());
   MOZ_ASSERT(aMediaSource);
 
   mTrackBuffersManager =
-    new TrackBuffersManager(aMediaSource->GetDecoder(), aType);
+      new TrackBuffersManager(aMediaSource->GetDecoder(), aType);
   DDLINKCHILD("track buffers manager", mTrackBuffersManager.get());
 
-  MSE_DEBUG("Create mTrackBuffersManager=%p",
-            mTrackBuffersManager.get());
+  MSE_DEBUG("Create mTrackBuffersManager=%p", mTrackBuffersManager.get());
 
   ErrorResult dummy;
   if (mCurrentAttributes.mGenerateTimestamps) {
@@ -353,56 +321,42 @@ SourceBuffer::SourceBuffer(MediaSource* aMediaSource,
     SetMode(SourceBufferAppendMode::Segments, dummy);
   }
   mMediaSource->GetDecoder()->GetDemuxer()->AttachSourceBuffer(
-    mTrackBuffersManager);
+      mTrackBuffersManager);
 }
 
-SourceBuffer::~SourceBuffer()
-{
+SourceBuffer::~SourceBuffer() {
   MOZ_ASSERT(NS_IsMainThread());
   MOZ_ASSERT(!mMediaSource);
   MSE_DEBUG("");
 }
 
-MediaSource*
-SourceBuffer::GetParentObject() const
-{
-  return mMediaSource;
-}
+MediaSource* SourceBuffer::GetParentObject() const { return mMediaSource; }
 
-JSObject*
-SourceBuffer::WrapObject(JSContext* aCx, JS::Handle<JSObject*> aGivenProto)
-{
+JSObject* SourceBuffer::WrapObject(JSContext* aCx,
+                                   JS::Handle<JSObject*> aGivenProto) {
   return SourceBufferBinding::Wrap(aCx, this, aGivenProto);
 }
 
-void
-SourceBuffer::DispatchSimpleEvent(const char* aName)
-{
+void SourceBuffer::DispatchSimpleEvent(const char* aName) {
   MOZ_ASSERT(NS_IsMainThread());
   MSE_API("Dispatch event '%s'", aName);
   DispatchTrustedEvent(NS_ConvertUTF8toUTF16(aName));
 }
 
-void
-SourceBuffer::QueueAsyncSimpleEvent(const char* aName)
-{
+void SourceBuffer::QueueAsyncSimpleEvent(const char* aName) {
   MSE_DEBUG("Queuing event '%s'", aName);
   nsCOMPtr<nsIRunnable> event = new AsyncEventRunner<SourceBuffer>(this, aName);
   mAbstractMainThread->Dispatch(event.forget());
 }
 
-void
-SourceBuffer::StartUpdating()
-{
+void SourceBuffer::StartUpdating() {
   MOZ_ASSERT(NS_IsMainThread());
   MOZ_ASSERT(!mUpdating);
   mUpdating = true;
   QueueAsyncSimpleEvent("updatestart");
 }
 
-void
-SourceBuffer::StopUpdating()
-{
+void SourceBuffer::StopUpdating() {
   MOZ_ASSERT(NS_IsMainThread());
   if (!mUpdating) {
     // The buffer append or range removal algorithm  has been interrupted by
@@ -414,18 +368,14 @@ SourceBuffer::StopUpdating()
   QueueAsyncSimpleEvent("updateend");
 }
 
-void
-SourceBuffer::AbortUpdating()
-{
+void SourceBuffer::AbortUpdating() {
   MOZ_ASSERT(NS_IsMainThread());
   mUpdating = false;
   QueueAsyncSimpleEvent("abort");
   QueueAsyncSimpleEvent("updateend");
 }
 
-void
-SourceBuffer::CheckEndTime()
-{
+void SourceBuffer::CheckEndTime() {
   MOZ_ASSERT(NS_IsMainThread());
   // Check if we need to update mMediaSource duration
   double endTime = mCurrentAttributes.GetGroupEndTimestamp().ToSeconds();
@@ -435,9 +385,8 @@ SourceBuffer::CheckEndTime()
   }
 }
 
-void
-SourceBuffer::AppendData(const uint8_t* aData, uint32_t aLength, ErrorResult& aRv)
-{
+void SourceBuffer::AppendData(const uint8_t* aData, uint32_t aLength,
+                              ErrorResult& aRv) {
   MSE_DEBUG("AppendData(aLength=%u)", aLength);
 
   RefPtr<MediaByteBuffer> data = PrepareAppend(aData, aLength, aRv);
@@ -447,15 +396,14 @@ SourceBuffer::AppendData(const uint8_t* aData, uint32_t aLength, ErrorResult& aR
   StartUpdating();
 
   mTrackBuffersManager->AppendData(data.forget(), mCurrentAttributes)
-    ->Then(mAbstractMainThread, __func__, this,
-           &SourceBuffer::AppendDataCompletedWithSuccess,
-           &SourceBuffer::AppendDataErrored)
-    ->Track(mPendingAppend);
+      ->Then(mAbstractMainThread, __func__, this,
+             &SourceBuffer::AppendDataCompletedWithSuccess,
+             &SourceBuffer::AppendDataErrored)
+      ->Track(mPendingAppend);
 }
 
-void
-SourceBuffer::AppendDataCompletedWithSuccess(const SourceBufferTask::AppendBufferResult& aResult)
-{
+void SourceBuffer::AppendDataCompletedWithSuccess(
+    const SourceBufferTask::AppendBufferResult& aResult) {
   MOZ_ASSERT(mUpdating);
   mPendingAppend.Complete();
   DDLOG(DDLogCategory::API, "AppendBuffer-completed", NS_OK);
@@ -466,13 +414,13 @@ SourceBuffer::AppendDataCompletedWithSuccess(const SourceBufferTask::AppendBuffe
       MSE_DEBUG("Init segment received");
       RefPtr<SourceBuffer> self = this;
       mMediaSource->SourceBufferIsActive(this)
-        ->Then(mAbstractMainThread, __func__,
-               [self, this]() {
-                 MSE_DEBUG("Complete AppendBuffer operation");
-                 mCompletionPromise.Complete();
-                 StopUpdating();
-               })
-        ->Track(mCompletionPromise);
+          ->Then(mAbstractMainThread, __func__,
+                 [self, this]() {
+                   MSE_DEBUG("Complete AppendBuffer operation");
+                   mCompletionPromise.Complete();
+                   StopUpdating();
+                 })
+          ->Track(mCompletionPromise);
     }
   }
   if (mActive) {
@@ -490,9 +438,7 @@ SourceBuffer::AppendDataCompletedWithSuccess(const SourceBufferTask::AppendBuffe
   }
 }
 
-void
-SourceBuffer::AppendDataErrored(const MediaResult& aError)
-{
+void SourceBuffer::AppendDataErrored(const MediaResult& aError) {
   MOZ_ASSERT(mUpdating);
   mPendingAppend.Complete();
   DDLOG(DDLogCategory::API, "AppendBuffer-error", aError);
@@ -508,9 +454,7 @@ SourceBuffer::AppendDataErrored(const MediaResult& aError)
   }
 }
 
-void
-SourceBuffer::AppendError(const MediaResult& aDecodeError)
-{
+void SourceBuffer::AppendError(const MediaResult& aDecodeError) {
   MOZ_ASSERT(NS_IsMainThread());
 
   ResetParserState();
@@ -525,9 +469,8 @@ SourceBuffer::AppendError(const MediaResult& aDecodeError)
   mMediaSource->EndOfStream(aDecodeError);
 }
 
-already_AddRefed<MediaByteBuffer>
-SourceBuffer::PrepareAppend(const uint8_t* aData, uint32_t aLength, ErrorResult& aRv)
-{
+already_AddRefed<MediaByteBuffer> SourceBuffer::PrepareAppend(
+    const uint8_t* aData, uint32_t aLength, ErrorResult& aRv) {
   typedef TrackBuffersManager::EvictDataResult Result;
 
   if (!IsAttached() || mUpdating) {
@@ -553,9 +496,9 @@ SourceBuffer::PrepareAppend(const uint8_t* aData, uint32_t aLength, ErrorResult&
   // TODO: Drive evictions off memory pressure notifications.
   // TODO: Consider a global eviction threshold  rather than per TrackBuffer.
   // Give a chance to the TrackBuffersManager to evict some data if needed.
-  Result evicted =
-    mTrackBuffersManager->EvictData(TimeUnit::FromSeconds(mMediaSource->GetDecoder()->GetCurrentTime()),
-                                    aLength);
+  Result evicted = mTrackBuffersManager->EvictData(
+      TimeUnit::FromSeconds(mMediaSource->GetDecoder()->GetCurrentTime()),
+      aLength);
 
   // See if we have enough free space to append our new data.
   if (evicted == Result::BUFFER_FULL) {
@@ -571,40 +514,32 @@ SourceBuffer::PrepareAppend(const uint8_t* aData, uint32_t aLength, ErrorResult&
   return data.forget();
 }
 
-double
-SourceBuffer::GetBufferedStart()
-{
+double SourceBuffer::GetBufferedStart() {
   MOZ_ASSERT(NS_IsMainThread());
   ErrorResult dummy;
   RefPtr<TimeRanges> ranges = GetBuffered(dummy);
   return ranges->Length() > 0 ? ranges->GetStartTime() : 0;
 }
 
-double
-SourceBuffer::GetBufferedEnd()
-{
+double SourceBuffer::GetBufferedEnd() {
   MOZ_ASSERT(NS_IsMainThread());
   ErrorResult dummy;
   RefPtr<TimeRanges> ranges = GetBuffered(dummy);
   return ranges->Length() > 0 ? ranges->GetEndTime() : 0;
 }
 
-double
-SourceBuffer::HighestStartTime()
-{
+double SourceBuffer::HighestStartTime() {
   MOZ_ASSERT(NS_IsMainThread());
   return mTrackBuffersManager
-         ? mTrackBuffersManager->HighestStartTime().ToSeconds()
-         : 0.0;
+             ? mTrackBuffersManager->HighestStartTime().ToSeconds()
+             : 0.0;
 }
 
-double
-SourceBuffer::HighestEndTime()
-{
+double SourceBuffer::HighestEndTime() {
   MOZ_ASSERT(NS_IsMainThread());
   return mTrackBuffersManager
-         ? mTrackBuffersManager->HighestEndTime().ToSeconds()
-         : 0.0;
+             ? mTrackBuffersManager->HighestEndTime().ToSeconds()
+             : 0.0;
 }
 
 NS_IMPL_CYCLE_COLLECTION_CLASS(SourceBuffer)
@@ -631,6 +566,6 @@ NS_INTERFACE_MAP_END_INHERITING(DOMEventTargetHelper)
 #undef MSE_DEBUGV
 #undef MSE_API
 
-} // namespace dom
+}  // namespace dom
 
-} // namespace mozilla
+}  // namespace mozilla
