@@ -32,23 +32,17 @@ class MediaRawData;
 class MediaSourceDemuxer;
 class SourceBufferResource;
 
-class SourceBufferTaskQueue
-{
-public:
-  SourceBufferTaskQueue() { }
+class SourceBufferTaskQueue {
+ public:
+  SourceBufferTaskQueue() {}
 
-  ~SourceBufferTaskQueue()
-  {
+  ~SourceBufferTaskQueue() {
     MOZ_ASSERT(mQueue.IsEmpty(), "All tasks must have been processed");
   }
 
-  void Push(SourceBufferTask* aTask)
-  {
-    mQueue.AppendElement(aTask);
-  }
+  void Push(SourceBufferTask* aTask) { mQueue.AppendElement(aTask); }
 
-  already_AddRefed<SourceBufferTask> Pop()
-  {
+  already_AddRefed<SourceBufferTask> Pop() {
     if (!mQueue.Length()) {
       return nullptr;
     }
@@ -57,23 +51,22 @@ public:
     return task.forget();
   }
 
-  nsTArray<RefPtr<SourceBufferTask>>::size_type Length() const
-  {
+  nsTArray<RefPtr<SourceBufferTask>>::size_type Length() const {
     return mQueue.Length();
   }
-private:
+
+ private:
   nsTArray<RefPtr<SourceBufferTask>> mQueue;
 };
 
 DDLoggedTypeDeclName(TrackBuffersManager);
 
-class TrackBuffersManager : public DecoderDoctorLifeLogger<TrackBuffersManager>
-{
-public:
+class TrackBuffersManager
+    : public DecoderDoctorLifeLogger<TrackBuffersManager> {
+ public:
   NS_INLINE_DECL_THREADSAFE_REFCOUNTING(TrackBuffersManager);
 
-  enum class EvictDataResult : int8_t
-  {
+  enum class EvictDataResult : int8_t {
     NO_DATA_EVICTED,
     CANT_EVICT,
     BUFFER_FULL,
@@ -107,17 +100,19 @@ public:
   // Queue a task to run the MSE range removal algorithm.
   // http://w3c.github.io/media-source/#sourcebuffer-coded-frame-removal
   RefPtr<RangeRemovalPromise> RangeRemoval(media::TimeUnit aStart,
-                                             media::TimeUnit aEnd);
+                                           media::TimeUnit aEnd);
 
   // Schedule data eviction if necessary as the next call to AppendData will
   // add aSize bytes.
   // Eviction is done in two steps, first remove data up to aPlaybackTime
   // and if still more space is needed remove from the end.
-  EvictDataResult EvictData(const media::TimeUnit& aPlaybackTime, int64_t aSize);
+  EvictDataResult EvictData(const media::TimeUnit& aPlaybackTime,
+                            int64_t aSize);
 
   // Returns the buffered range currently managed.
   // This may be called on any thread.
-  // Buffered must conform to http://w3c.github.io/media-source/index.html#widl-SourceBuffer-buffered
+  // Buffered must conform to
+  // http://w3c.github.io/media-source/index.html#widl-SourceBuffer-buffered
   media::TimeIntervals Buffered() const;
   media::TimeUnit HighestStartTime() const;
   media::TimeUnit HighestEndTime() const;
@@ -139,10 +134,7 @@ public:
   const media::TimeIntervals& Buffered(TrackInfo::TrackType) const;
   const media::TimeUnit& HighestStartTime(TrackInfo::TrackType) const;
   media::TimeIntervals SafeBuffered(TrackInfo::TrackType) const;
-  bool IsEnded() const
-  {
-    return mEnded;
-  }
+  bool IsEnded() const { return mEnded; }
   uint32_t Evictable(TrackInfo::TrackType aTrack) const;
   media::TimeUnit Seek(TrackInfo::TrackType aTrack,
                        const media::TimeUnit& aTime,
@@ -171,8 +163,9 @@ public:
 
   void AddSizeOfResources(MediaSourceDecoder::ResourceSizes* aSizes) const;
 
-private:
-  typedef MozPromise<bool, MediaResult, /* IsExclusive = */ true> CodedFrameProcessingPromise;
+ private:
+  typedef MozPromise<bool, MediaResult, /* IsExclusive = */ true>
+      CodedFrameProcessingPromise;
 
   // for MediaSourceDemuxer::GetMozDebugReaderData
   friend class MediaSourceDemuxer;
@@ -194,24 +187,20 @@ private:
   void CompleteCodedFrameProcessing();
   // Called by ResetParserState.
   void CompleteResetParserState();
-  RefPtr<RangeRemovalPromise>
-    CodedFrameRemovalWithPromise(media::TimeInterval aInterval);
+  RefPtr<RangeRemovalPromise> CodedFrameRemovalWithPromise(
+      media::TimeInterval aInterval);
   bool CodedFrameRemoval(media::TimeInterval aInterval);
   void SetAppendState(SourceBufferAttributes::AppendState aAppendState);
 
-  bool HasVideo() const
-  {
-    return mVideoTracks.mNumTracks > 0;
-  }
-  bool HasAudio() const
-  {
-    return mAudioTracks.mNumTracks > 0;
-  }
+  bool HasVideo() const { return mVideoTracks.mNumTracks > 0; }
+  bool HasAudio() const { return mAudioTracks.mNumTracks > 0; }
 
-  // The input buffer as per http://w3c.github.io/media-source/index.html#sourcebuffer-input-buffer
+  // The input buffer as per
+  // http://w3c.github.io/media-source/index.html#sourcebuffer-input-buffer
   RefPtr<MediaByteBuffer> mInputBuffer;
-  // Buffer full flag as per https://w3c.github.io/media-source/#sourcebuffer-buffer-full-flag.
-  // Accessed on both the main thread and the task queue.
+  // Buffer full flag as per
+  // https://w3c.github.io/media-source/#sourcebuffer-buffer-full-flag. Accessed
+  // on both the main thread and the task queue.
   Atomic<bool> mBufferFull;
   bool mFirstInitializationSegmentReceived;
   // Set to true once a new segment is started.
@@ -249,15 +238,13 @@ private:
   void OnDemuxFailed(TrackType aTrack, const MediaResult& aError);
   void DoDemuxVideo();
   void OnVideoDemuxCompleted(RefPtr<MediaTrackDemuxer::SamplesHolder> aSamples);
-  void OnVideoDemuxFailed(const MediaResult& aError)
-  {
+  void OnVideoDemuxFailed(const MediaResult& aError) {
     mVideoTracks.mDemuxRequest.Complete();
     OnDemuxFailed(TrackType::kVideoTrack, aError);
   }
   void DoDemuxAudio();
   void OnAudioDemuxCompleted(RefPtr<MediaTrackDemuxer::SamplesHolder> aSamples);
-  void OnAudioDemuxFailed(const MediaResult& aError)
-  {
+  void OnAudioDemuxFailed(const MediaResult& aError) {
     mAudioTracks.mDemuxRequest.Complete();
     OnDemuxFailed(TrackType::kAudioTrack, aError);
   }
@@ -265,17 +252,12 @@ private:
   // Dispatches an "encrypted" event is any sample in array has initData
   // present.
   void MaybeDispatchEncryptedEvent(
-    const nsTArray<RefPtr<MediaRawData>>& aSamples);
+      const nsTArray<RefPtr<MediaRawData>>& aSamples);
 
   void DoEvictData(const media::TimeUnit& aPlaybackTime, int64_t aSizeToEvict);
 
-  struct TrackData
-  {
-    TrackData()
-      : mNumTracks(0)
-      , mNeedRandomAccessPoint(true)
-      , mSizeBuffer(0)
-    {}
+  struct TrackData {
+    TrackData() : mNumTracks(0), mNeedRandomAccessPoint(true), mSizeBuffer(0) {}
     uint32_t mNumTracks;
     // Definition of variables:
     // https://w3c.github.io/media-source/#track-buffers
@@ -320,14 +302,12 @@ private:
     Maybe<uint32_t> mNextInsertionIndex;
     // Samples just demuxed, but not yet parsed.
     TrackBuffer mQueuedSamples;
-    const TrackBuffer& GetTrackBuffer() const
-    {
+    const TrackBuffer& GetTrackBuffer() const {
       MOZ_RELEASE_ASSERT(mBuffers.Length(),
                          "TrackBuffer must have been created");
       return mBuffers.LastElement();
     }
-    TrackBuffer& GetTrackBuffer()
-    {
+    TrackBuffer& GetTrackBuffer() {
       MOZ_RELEASE_ASSERT(mBuffers.Length(),
                          "TrackBuffer must have been created");
       return mBuffers.LastElement();
@@ -356,11 +336,9 @@ private:
     // Approximation of the next sample's presentation timestamp.
     media::TimeUnit mNextSampleTime;
 
-    struct EvictionIndex
-    {
+    struct EvictionIndex {
       EvictionIndex() { Reset(); }
-      void Reset()
-      {
+      void Reset() {
         mEvictable = 0;
         mLastIndex = 0;
       }
@@ -376,8 +354,7 @@ private:
     // is only written there.
     EvictionIndex mEvictionIndex;
 
-    void ResetAppendState()
-    {
+    void ResetAppendState() {
       mLastDecodeTimestamp.reset();
       mLastFrameDuration.reset();
       mHighestEndTimestamp.reset();
@@ -385,8 +362,7 @@ private:
       mNextInsertionIndex.reset();
     }
 
-    void Reset()
-    {
+    void Reset() {
       ResetAppendState();
       mEvictionIndex.Reset();
       for (auto& buffer : mBuffers) {
@@ -415,16 +391,14 @@ private:
   // Return the index at which frames were first removed or 0 if no frames
   // removed.
   uint32_t RemoveFrames(const media::TimeIntervals& aIntervals,
-                        TrackData& aTrackData,
-                        uint32_t aStartIndex);
+                        TrackData& aTrackData, uint32_t aStartIndex);
   // Recalculate track's evictable amount.
   void ResetEvictionIndex(TrackData& aTrackData);
   void UpdateEvictionIndex(TrackData& aTrackData, uint32_t aCurrentIndex);
   // Find index of sample. Return a negative value if not found.
   uint32_t FindSampleIndex(const TrackBuffer& aTrackBuffer,
                            const media::TimeInterval& aInterval);
-  const MediaRawData* GetSample(TrackInfo::TrackType aTrack,
-                                uint32_t aIndex,
+  const MediaRawData* GetSample(TrackInfo::TrackType aTrack, uint32_t aIndex,
                                 const media::TimeUnit& aExpectedDts,
                                 const media::TimeUnit& aExpectedPts,
                                 const media::TimeUnit& aFuzz);
@@ -437,9 +411,8 @@ private:
   // Trackbuffers definition.
   nsTArray<const TrackData*> GetTracksList() const;
   nsTArray<TrackData*> GetTracksList();
-  TrackData& GetTracksData(TrackType aTrack)
-  {
-    switch(aTrack) {
+  TrackData& GetTracksData(TrackType aTrack) {
+    switch (aTrack) {
       case TrackType::kVideoTrack:
         return mVideoTracks;
       case TrackType::kAudioTrack:
@@ -447,9 +420,8 @@ private:
         return mAudioTracks;
     }
   }
-  const TrackData& GetTracksData(TrackType aTrack) const
-  {
-    switch(aTrack) {
+  const TrackData& GetTracksData(TrackType aTrack) const {
+    switch (aTrack) {
       case TrackType::kVideoTrack:
         return mVideoTracks;
       case TrackType::kAudioTrack:
@@ -461,26 +433,22 @@ private:
   TrackData mAudioTracks;
 
   // TaskQueue methods and objects.
-  RefPtr<AutoTaskQueue> GetTaskQueueSafe() const
-  {
+  RefPtr<AutoTaskQueue> GetTaskQueueSafe() const {
     MutexAutoLock mut(mMutex);
     return mTaskQueue;
   }
-  NotNull<AbstractThread*> TaskQueueFromTaskQueue() const
-  {
+  NotNull<AbstractThread*> TaskQueueFromTaskQueue() const {
 #ifdef DEBUG
     RefPtr<AutoTaskQueue> taskQueue = GetTaskQueueSafe();
     MOZ_ASSERT(taskQueue && taskQueue->IsCurrentThreadIn());
 #endif
     return WrapNotNull(mTaskQueue.get());
   }
-  bool OnTaskQueue() const
-  {
+  bool OnTaskQueue() const {
     auto taskQueue = TaskQueueFromTaskQueue();
     return taskQueue->IsCurrentThreadIn();
   }
-  void ResetTaskQueue()
-  {
+  void ResetTaskQueue() {
     MutexAutoLock mut(mMutex);
     mTaskQueue = nullptr;
   }
@@ -507,7 +475,8 @@ private:
 
   // Return public highest end time across all aTracks.
   // Monitor must be held.
-  media::TimeUnit HighestEndTime(nsTArray<const media::TimeIntervals*>& aTracks) const;
+  media::TimeUnit HighestEndTime(
+      nsTArray<const media::TimeIntervals*>& aTracks) const;
 
   // Set to true if mediasource state changed to ended.
   Atomic<bool> mEnded;
@@ -516,8 +485,7 @@ private:
   Atomic<int64_t> mSizeSourceBuffer;
   const int64_t mVideoEvictionThreshold;
   const int64_t mAudioEvictionThreshold;
-  enum class EvictionState
-  {
+  enum class EvictionState {
     NO_EVICTION_NEEDED,
     EVICTION_NEEDED,
     EVICTION_COMPLETED,
@@ -537,6 +505,6 @@ private:
   MediaInfo mInfo;
 };
 
-} // namespace mozilla
+}  // namespace mozilla
 
 #endif /* MOZILLA_TRACKBUFFERSMANAGER_H_ */
