@@ -23,7 +23,7 @@
 #include "nsAutoRef.h"
 #include "NesteggPacketHolder.h"
 #include "XiphExtradata.h"
-#include "prprf.h"           // leaving it for PR_vsnprintf()
+#include "prprf.h"  // leaving it for PR_vsnprintf()
 #include "mozilla/IntegerPrintfMacros.h"
 #include "mozilla/Sprintf.h"
 
@@ -31,12 +31,9 @@
 #include <numeric>
 #include <stdint.h>
 
-#define WEBM_DEBUG(arg, ...)                                                   \
-  DDMOZ_LOG(gMediaDemuxerLog,                                                  \
-            mozilla::LogLevel::Debug,                                          \
-            "::%s: " arg,                                                      \
-            __func__,                                                          \
-            ##__VA_ARGS__)
+#define WEBM_DEBUG(arg, ...)                                          \
+  DDMOZ_LOG(gMediaDemuxerLog, mozilla::LogLevel::Debug, "::%s: " arg, \
+            __func__, ##__VA_ARGS__)
 extern mozilla::LazyLogModule gMediaDemuxerLog;
 
 namespace mozilla {
@@ -56,12 +53,11 @@ static Atomic<uint32_t> sStreamSourceID(0u);
 // Functions for reading and seeking using WebMDemuxer required for
 // nestegg_io. The 'user data' passed to these functions is the
 // demuxer.
-static int webmdemux_read(void* aBuffer, size_t aLength, void* aUserData)
-{
+static int webmdemux_read(void* aBuffer, size_t aLength, void* aUserData) {
   MOZ_ASSERT(aUserData);
   MOZ_ASSERT(aLength < UINT32_MAX);
   WebMDemuxer::NestEggContext* context =
-    reinterpret_cast<WebMDemuxer::NestEggContext*>(aUserData);
+      reinterpret_cast<WebMDemuxer::NestEggContext*>(aUserData);
   uint32_t count = aLength;
   if (context->IsMediaSource()) {
     int64_t length = context->GetEndDataOffset();
@@ -75,32 +71,28 @@ static int webmdemux_read(void* aBuffer, size_t aLength, void* aUserData)
   }
   uint32_t bytes = 0;
   nsresult rv =
-    context->GetResource()->Read(static_cast<char*>(aBuffer), count, &bytes);
+      context->GetResource()->Read(static_cast<char*>(aBuffer), count, &bytes);
   bool eof = bytes < aLength;
   return NS_FAILED(rv) ? -1 : eof ? 0 : 1;
 }
 
-static int webmdemux_seek(int64_t aOffset, int aWhence, void* aUserData)
-{
+static int webmdemux_seek(int64_t aOffset, int aWhence, void* aUserData) {
   MOZ_ASSERT(aUserData);
   WebMDemuxer::NestEggContext* context =
-    reinterpret_cast<WebMDemuxer::NestEggContext*>(aUserData);
+      reinterpret_cast<WebMDemuxer::NestEggContext*>(aUserData);
   nsresult rv = context->GetResource()->Seek(aWhence, aOffset);
   return NS_SUCCEEDED(rv) ? 0 : -1;
 }
 
-static int64_t webmdemux_tell(void* aUserData)
-{
+static int64_t webmdemux_tell(void* aUserData) {
   MOZ_ASSERT(aUserData);
   WebMDemuxer::NestEggContext* context =
-    reinterpret_cast<WebMDemuxer::NestEggContext*>(aUserData);
+      reinterpret_cast<WebMDemuxer::NestEggContext*>(aUserData);
   return context->GetResource()->Tell();
 }
 
-static void webmdemux_log(nestegg* aContext,
-                          unsigned int aSeverity,
-                          char const* aFormat, ...)
-{
+static void webmdemux_log(nestegg* aContext, unsigned int aSeverity,
+                          char const* aFormat, ...) {
   if (!MOZ_LOG_TEST(gNesteggLog, LogLevel::Debug)) {
     return;
   }
@@ -109,7 +101,7 @@ static void webmdemux_log(nestegg* aContext,
   char msg[256];
   const char* sevStr;
 
-  switch(aSeverity) {
+  switch (aSeverity) {
     case NESTEGG_LOG_DEBUG:
       sevStr = "DBG";
       break;
@@ -133,22 +125,19 @@ static void webmdemux_log(nestegg* aContext,
   va_start(args, aFormat);
 
   SprintfLiteral(msg, "%p [Nestegg-%s] ", aContext, sevStr);
-  PR_vsnprintf(msg+strlen(msg), sizeof(msg)-strlen(msg), aFormat, args);
+  PR_vsnprintf(msg + strlen(msg), sizeof(msg) - strlen(msg), aFormat, args);
   MOZ_LOG(gNesteggLog, LogLevel::Debug, ("%s", msg));
 
   va_end(args);
 }
 
-WebMDemuxer::NestEggContext::~NestEggContext()
-{
+WebMDemuxer::NestEggContext::~NestEggContext() {
   if (mContext) {
     nestegg_destroy(mContext);
   }
 }
 
-int
-WebMDemuxer::NestEggContext::Init()
-{
+int WebMDemuxer::NestEggContext::Init() {
   nestegg_io io;
   io.read = webmdemux_read;
   io.seek = webmdemux_seek;
@@ -163,41 +152,35 @@ WebMDemuxer::NestEggContext::Init()
 }
 
 WebMDemuxer::WebMDemuxer(MediaResource* aResource)
-  : WebMDemuxer(aResource, false)
-{
-}
+    : WebMDemuxer(aResource, false) {}
 
 WebMDemuxer::WebMDemuxer(MediaResource* aResource, bool aIsMediaSource)
-  : mVideoContext(this, aResource)
-  , mAudioContext(this, aResource)
-  , mBufferedState(nullptr)
-  , mInitData(nullptr)
-  , mVideoTrack(0)
-  , mAudioTrack(0)
-  , mSeekPreroll(0)
-  , mAudioCodec(-1)
-  , mVideoCodec(-1)
-  , mHasVideo(false)
-  , mHasAudio(false)
-  , mNeedReIndex(true)
-  , mLastWebMBlockOffset(-1)
-  , mIsMediaSource(aIsMediaSource)
-{
+    : mVideoContext(this, aResource),
+      mAudioContext(this, aResource),
+      mBufferedState(nullptr),
+      mInitData(nullptr),
+      mVideoTrack(0),
+      mAudioTrack(0),
+      mSeekPreroll(0),
+      mAudioCodec(-1),
+      mVideoCodec(-1),
+      mHasVideo(false),
+      mHasAudio(false),
+      mNeedReIndex(true),
+      mLastWebMBlockOffset(-1),
+      mIsMediaSource(aIsMediaSource) {
   DDLINKCHILD("resource", aResource);
   // Audio/video contexts hold a MediaResourceIndex.
   DDLINKCHILD("video context", mVideoContext.GetResource());
   DDLINKCHILD("audio context", mAudioContext.GetResource());
 }
 
-WebMDemuxer::~WebMDemuxer()
-{
+WebMDemuxer::~WebMDemuxer() {
   Reset(TrackInfo::kVideoTrack);
   Reset(TrackInfo::kAudioTrack);
 }
 
-RefPtr<WebMDemuxer::InitPromise>
-WebMDemuxer::Init()
-{
+RefPtr<WebMDemuxer::InitPromise> WebMDemuxer::Init() {
   InitBufferedState();
 
   if (NS_FAILED(ReadMetadata())) {
@@ -214,17 +197,13 @@ WebMDemuxer::Init()
   return InitPromise::CreateAndResolve(NS_OK, __func__);
 }
 
-void
-WebMDemuxer::InitBufferedState()
-{
+void WebMDemuxer::InitBufferedState() {
   MOZ_ASSERT(!mBufferedState);
   mBufferedState = new WebMBufferedState;
 }
 
-uint32_t
-WebMDemuxer::GetNumberTracks(TrackInfo::TrackType aType) const
-{
-  switch(aType) {
+uint32_t WebMDemuxer::GetNumberTracks(TrackInfo::TrackType aType) const {
+  switch (aType) {
     case TrackInfo::kAudioTrack:
       return mHasAudio ? 1 : 0;
     case TrackInfo::kVideoTrack:
@@ -234,11 +213,9 @@ WebMDemuxer::GetNumberTracks(TrackInfo::TrackType aType) const
   }
 }
 
-UniquePtr<TrackInfo>
-WebMDemuxer::GetTrackInfo(TrackInfo::TrackType aType,
-                          size_t aTrackNumber) const
-{
-  switch(aType) {
+UniquePtr<TrackInfo> WebMDemuxer::GetTrackInfo(TrackInfo::TrackType aType,
+                                               size_t aTrackNumber) const {
+  switch (aType) {
     case TrackInfo::kAudioTrack:
       return mInfo.mAudio.Clone();
     case TrackInfo::kVideoTrack:
@@ -248,23 +225,19 @@ WebMDemuxer::GetTrackInfo(TrackInfo::TrackType aType,
   }
 }
 
-already_AddRefed<MediaTrackDemuxer>
-WebMDemuxer::GetTrackDemuxer(TrackInfo::TrackType aType, uint32_t aTrackNumber)
-{
+already_AddRefed<MediaTrackDemuxer> WebMDemuxer::GetTrackDemuxer(
+    TrackInfo::TrackType aType, uint32_t aTrackNumber) {
   if (GetNumberTracks(aType) <= aTrackNumber) {
     return nullptr;
   }
-  RefPtr<WebMTrackDemuxer> e =
-    new WebMTrackDemuxer(this, aType, aTrackNumber);
+  RefPtr<WebMTrackDemuxer> e = new WebMTrackDemuxer(this, aType, aTrackNumber);
   DDLINKCHILD("track demuxer", e.get());
   mDemuxers.AppendElement(e);
 
   return e.forget();
 }
 
-nsresult
-WebMDemuxer::Reset(TrackInfo::TrackType aType)
-{
+nsresult WebMDemuxer::Reset(TrackInfo::TrackType aType) {
   if (aType == TrackInfo::kVideoTrack) {
     mVideoPackets.Reset();
   } else {
@@ -273,9 +246,7 @@ WebMDemuxer::Reset(TrackInfo::TrackType aType)
   return NS_OK;
 }
 
-nsresult
-WebMDemuxer::ReadMetadata()
-{
+nsresult WebMDemuxer::ReadMetadata() {
   int r = mVideoContext.Init();
   if (r == -1) {
     return NS_ERROR_FAILURE;
@@ -325,7 +296,7 @@ WebMDemuxer::ReadMetadata()
         return NS_ERROR_FAILURE;
       }
       mVideoCodec = nestegg_track_codec_id(context, track);
-      switch(mVideoCodec) {
+      switch (mVideoCodec) {
         case NESTEGG_CODEC_VP8:
           mInfo.mVideo.mMimeType = "video/vp8";
           break;
@@ -343,16 +314,12 @@ WebMDemuxer::ReadMetadata()
       // to the display size.
       unsigned int cropH = params.crop_right + params.crop_left;
       unsigned int cropV = params.crop_bottom + params.crop_top;
-      gfx::IntRect pictureRect(params.crop_left,
-                               params.crop_top,
-                               params.width - cropH,
-                               params.height - cropV);
+      gfx::IntRect pictureRect(params.crop_left, params.crop_top,
+                               params.width - cropH, params.height - cropV);
 
       // If the cropping data appears invalid then use the frame data
-      if (pictureRect.width <= 0 ||
-          pictureRect.height <= 0 ||
-          pictureRect.x < 0 ||
-          pictureRect.y < 0) {
+      if (pictureRect.width <= 0 || pictureRect.height <= 0 ||
+          pictureRect.x < 0 || pictureRect.y < 0) {
         pictureRect.x = 0;
         pictureRect.y = 0;
         pictureRect.width = params.width;
@@ -418,8 +385,8 @@ WebMDemuxer::ReadMetadata()
       } else if (mAudioCodec == NESTEGG_CODEC_OPUS) {
         mInfo.mAudio.mMimeType = "audio/opus";
         OpusDataDecoder::AppendCodecDelay(
-          mInfo.mAudio.mCodecSpecificConfig,
-          TimeUnit::FromNanoseconds(params.codec_delay).ToMicroseconds());
+            mInfo.mAudio.mCodecSpecificConfig,
+            TimeUnit::FromNanoseconds(params.codec_delay).ToMicroseconds());
       }
       mSeekPreroll = params.seek_preroll;
       mInfo.mAudio.mRate = params.rate;
@@ -431,8 +398,8 @@ WebMDemuxer::ReadMetadata()
         return NS_ERROR_FAILURE;
       }
 
-      AutoTArray<const unsigned char*,4> headers;
-      AutoTArray<size_t,4> headerLens;
+      AutoTArray<const unsigned char*, 4> headers;
+      AutoTArray<size_t, 4> headerLens;
       for (uint32_t header = 0; header < nheaders; ++header) {
         unsigned char* data = 0;
         size_t length = 0;
@@ -450,12 +417,11 @@ WebMDemuxer::ReadMetadata()
       // to avoid having libnestegg split them only for us to pack them again,
       // but libnestegg does not give us an API to access this data directly.
       if (nheaders > 1) {
-        if (!XiphHeadersToExtradata(mInfo.mAudio.mCodecSpecificConfig,
-                                    headers, headerLens)) {
+        if (!XiphHeadersToExtradata(mInfo.mAudio.mCodecSpecificConfig, headers,
+                                    headerLens)) {
           return NS_ERROR_FAILURE;
         }
-      }
-      else {
+      } else {
         mInfo.mAudio.mCodecSpecificConfig->AppendElements(headers[0],
                                                           headerLens[0]);
       }
@@ -474,28 +440,22 @@ WebMDemuxer::ReadMetadata()
   return NS_OK;
 }
 
-bool
-WebMDemuxer::IsSeekable() const
-{
+bool WebMDemuxer::IsSeekable() const {
   return Context(TrackInfo::kVideoTrack) &&
          nestegg_has_cues(Context(TrackInfo::kVideoTrack));
 }
 
-bool
-WebMDemuxer::IsSeekableOnlyInBufferedRanges() const
-{
+bool WebMDemuxer::IsSeekableOnlyInBufferedRanges() const {
   return Context(TrackInfo::kVideoTrack) &&
          !nestegg_has_cues(Context(TrackInfo::kVideoTrack));
 }
 
-void
-WebMDemuxer::EnsureUpToDateIndex()
-{
+void WebMDemuxer::EnsureUpToDateIndex() {
   if (!mNeedReIndex || !mInitData) {
     return;
   }
   AutoPinned<MediaResource> resource(
-    Resource(TrackInfo::kVideoTrack).GetResource());
+      Resource(TrackInfo::kVideoTrack).GetResource());
   MediaByteRangeSet byteRanges;
   nsresult rv = resource->GetCachedRanges(byteRanges);
   if (NS_FAILED(rv) || !byteRanges.Length()) {
@@ -512,16 +472,12 @@ WebMDemuxer::EnsureUpToDateIndex()
   MOZ_ASSERT(mLastWebMBlockOffset <= resource->GetLength());
 }
 
-void
-WebMDemuxer::NotifyDataArrived()
-{
+void WebMDemuxer::NotifyDataArrived() {
   WEBM_DEBUG("");
   mNeedReIndex = true;
 }
 
-void
-WebMDemuxer::NotifyDataRemoved()
-{
+void WebMDemuxer::NotifyDataRemoved() {
   mBufferedState->Reset();
   if (mInitData) {
     mBufferedState->NotifyDataArrived(mInitData->Elements(),
@@ -530,23 +486,20 @@ WebMDemuxer::NotifyDataRemoved()
   mNeedReIndex = true;
 }
 
-UniquePtr<EncryptionInfo>
-WebMDemuxer::GetCrypto()
-{
+UniquePtr<EncryptionInfo> WebMDemuxer::GetCrypto() {
   return mCrypto.IsEncrypted() ? MakeUnique<EncryptionInfo>(mCrypto) : nullptr;
 }
 
-CryptoTrack
-WebMDemuxer::GetTrackCrypto(TrackInfo::TrackType aType, size_t aTrackNumber)
-{
+CryptoTrack WebMDemuxer::GetTrackCrypto(TrackInfo::TrackType aType,
+                                        size_t aTrackNumber) {
   const int WEBM_IV_SIZE = 16;
-  const unsigned char * contentEncKeyId;
+  const unsigned char* contentEncKeyId;
   size_t contentEncKeyIdLength;
   CryptoTrack crypto;
   nestegg* context = Context(aType);
 
   int r = nestegg_track_content_enc_key_id(
-    context, aTrackNumber, &contentEncKeyId, &contentEncKeyIdLength);
+      context, aTrackNumber, &contentEncKeyId, &contentEncKeyIdLength);
 
   if (r == -1) {
     WEBM_DEBUG("nestegg_track_content_enc_key_id failed r=%d", r);
@@ -569,10 +522,8 @@ WebMDemuxer::GetTrackCrypto(TrackInfo::TrackType aType, size_t aTrackNumber)
   return crypto;
 }
 
-nsresult
-WebMDemuxer::GetNextPacket(TrackInfo::TrackType aType,
-                           MediaRawDataQueue *aSamples)
-{
+nsresult WebMDemuxer::GetNextPacket(TrackInfo::TrackType aType,
+                                    MediaRawDataQueue* aSamples) {
   if (mIsMediaSource) {
     // To ensure mLastWebMBlockOffset is properly up to date.
     EnsureUpToDateIndex();
@@ -645,7 +596,7 @@ WebMDemuxer::GetNextPacket(TrackInfo::TrackType aType,
 
   int64_t discardPadding = 0;
   if (aType == TrackInfo::kAudioTrack) {
-    (void) nestegg_packet_discard_padding(holder->Packet(), &discardPadding);
+    (void)nestegg_packet_discard_padding(holder->Packet(), &discardPadding);
   }
 
   int packetEncryption = nestegg_packet_encryption(holder->Packet());
@@ -663,89 +614,96 @@ WebMDemuxer::GetNextPacket(TrackInfo::TrackType aType,
     // Check packets for alpha information if file has declared alpha frames
     // may be present.
     if (mInfo.mVideo.HasAlpha()) {
-      r = nestegg_packet_additional_data(holder->Packet(),
-                                         1,
-                                         &alphaData,
+      r = nestegg_packet_additional_data(holder->Packet(), 1, &alphaData,
                                          &alphaLength);
       if (r == -1) {
         WEBM_DEBUG(
-          "nestegg_packet_additional_data failed to retrieve alpha data r=%d",
-          r);
+            "nestegg_packet_additional_data failed to retrieve alpha data r=%d",
+            r);
       }
     }
     bool isKeyframe = false;
     if (aType == TrackInfo::kAudioTrack) {
       isKeyframe = true;
     } else if (aType == TrackInfo::kVideoTrack) {
-      if (packetEncryption == NESTEGG_PACKET_HAS_SIGNAL_BYTE_ENCRYPTED) {
+      if (packetEncryption == NESTEGG_PACKET_HAS_SIGNAL_BYTE_ENCRYPTED ||
+          packetEncryption == NESTEGG_PACKET_HAS_SIGNAL_BYTE_PARTITIONED) {
         // Packet is encrypted, can't peek, use packet info
-        isKeyframe = nestegg_packet_has_keyframe(holder->Packet())
-                     == NESTEGG_PACKET_HAS_KEYFRAME_TRUE;
+        isKeyframe = nestegg_packet_has_keyframe(holder->Packet()) ==
+                     NESTEGG_PACKET_HAS_KEYFRAME_TRUE;
       } else {
+        MOZ_ASSERT(
+            packetEncryption == NESTEGG_PACKET_HAS_SIGNAL_BYTE_UNENCRYPTED ||
+                packetEncryption == NESTEGG_PACKET_HAS_SIGNAL_BYTE_FALSE,
+            "Unencrypted packet expected");
         auto sample = MakeSpan(data, length);
         auto alphaSample = MakeSpan(alphaData, alphaLength);
 
         switch (mVideoCodec) {
-        case NESTEGG_CODEC_VP8:
-          isKeyframe = VPXDecoder::IsKeyframe(sample, VPXDecoder::Codec::VP8);
-          if (isKeyframe && alphaLength) {
-            isKeyframe =
-              VPXDecoder::IsKeyframe(alphaSample, VPXDecoder::Codec::VP8);
-          }
-          break;
-        case NESTEGG_CODEC_VP9:
-          isKeyframe = VPXDecoder::IsKeyframe(sample, VPXDecoder::Codec::VP9);
-          if (isKeyframe && alphaLength) {
-            isKeyframe =
-              VPXDecoder::IsKeyframe(alphaSample, VPXDecoder::Codec::VP9);
-          }
-          break;
+          case NESTEGG_CODEC_VP8:
+            isKeyframe = VPXDecoder::IsKeyframe(sample, VPXDecoder::Codec::VP8);
+            if (isKeyframe && alphaLength) {
+              isKeyframe =
+                  VPXDecoder::IsKeyframe(alphaSample, VPXDecoder::Codec::VP8);
+            }
+            break;
+          case NESTEGG_CODEC_VP9:
+            isKeyframe = VPXDecoder::IsKeyframe(sample, VPXDecoder::Codec::VP9);
+            if (isKeyframe && alphaLength) {
+              isKeyframe =
+                  VPXDecoder::IsKeyframe(alphaSample, VPXDecoder::Codec::VP9);
+            }
+            break;
 #ifdef MOZ_AV1
-        case NESTEGG_CODEC_AV1:
-          isKeyframe = AOMDecoder::IsKeyframe(sample);
-          if (isKeyframe && alphaLength) {
-            isKeyframe = AOMDecoder::IsKeyframe(alphaSample);
-          }
-          break;
+          case NESTEGG_CODEC_AV1:
+            isKeyframe = AOMDecoder::IsKeyframe(sample);
+            if (isKeyframe && alphaLength) {
+              isKeyframe = AOMDecoder::IsKeyframe(alphaSample);
+            }
+            break;
 #endif
-        default:
-          NS_WARNING("Cannot detect keyframes in unknown WebM video codec");
-          return NS_ERROR_FAILURE;
+          default:
+            NS_WARNING("Cannot detect keyframes in unknown WebM video codec");
+            return NS_ERROR_FAILURE;
         }
         if (isKeyframe) {
           // For both VP8 and VP9, we only look for resolution changes
           // on keyframes. Other resolution changes are invalid.
           auto dimensions = gfx::IntSize(0, 0);
           switch (mVideoCodec) {
-          case NESTEGG_CODEC_VP8:
-            dimensions = VPXDecoder::GetFrameSize(sample, VPXDecoder::Codec::VP8);
-            break;
-          case NESTEGG_CODEC_VP9:
-            dimensions = VPXDecoder::GetFrameSize(sample, VPXDecoder::Codec::VP9);
-            break;
+            case NESTEGG_CODEC_VP8:
+              dimensions =
+                  VPXDecoder::GetFrameSize(sample, VPXDecoder::Codec::VP8);
+              break;
+            case NESTEGG_CODEC_VP9:
+              dimensions =
+                  VPXDecoder::GetFrameSize(sample, VPXDecoder::Codec::VP9);
+              break;
 #ifdef MOZ_AV1
-          case NESTEGG_CODEC_AV1:
-            dimensions = AOMDecoder::GetFrameSize(sample);
-            break;
+            case NESTEGG_CODEC_AV1:
+              dimensions = AOMDecoder::GetFrameSize(sample);
+              break;
 #endif
           }
           if (mLastSeenFrameSize.isSome() &&
               (dimensions != mLastSeenFrameSize.value())) {
             mInfo.mVideo.mDisplay = dimensions;
             mSharedVideoTrackInfo =
-              new TrackInfoSharedPtr(mInfo.mVideo, ++sStreamSourceID);
+                new TrackInfoSharedPtr(mInfo.mVideo, ++sStreamSourceID);
           }
           mLastSeenFrameSize = Some(dimensions);
         }
       }
     }
 
-    WEBM_DEBUG("push sample tstamp: %" PRId64 " next_tstamp: %" PRId64 " length: %zu kf: %d",
+    WEBM_DEBUG("push sample tstamp: %" PRId64 " next_tstamp: %" PRId64
+               " length: %zu kf: %d",
                tstamp, next_tstamp, length, isKeyframe);
     RefPtr<MediaRawData> sample;
     if (mInfo.mVideo.HasAlpha() && alphaLength != 0) {
       sample = new MediaRawData(data, length, alphaData, alphaLength);
-      if ((length && !sample->Data()) || (alphaLength && !sample->AlphaData())) {
+      if ((length && !sample->Data()) ||
+          (alphaLength && !sample->AlphaData())) {
         // OOM.
         return NS_ERROR_OUT_OF_MEMORY;
       }
@@ -771,15 +729,14 @@ WebMDemuxer::GetNextPacket(TrackInfo::TrackType aType,
         WEBM_DEBUG("Invalid negative discard padding");
       } else {
         discardFrames = TimeUnitToFrames(
-          TimeUnit::FromNanoseconds(discardPadding), mInfo.mAudio.mRate);
+            TimeUnit::FromNanoseconds(discardPadding), mInfo.mAudio.mRate);
       }
       if (discardFrames.isValid()) {
         sample->mDiscardPadding = discardFrames.value();
       }
     }
 
-    if (packetEncryption == NESTEGG_PACKET_HAS_SIGNAL_BYTE_UNENCRYPTED ||
-        packetEncryption == NESTEGG_PACKET_HAS_SIGNAL_BYTE_ENCRYPTED ||
+    if (packetEncryption == NESTEGG_PACKET_HAS_SIGNAL_BYTE_ENCRYPTED ||
         packetEncryption == NESTEGG_PACKET_HAS_SIGNAL_BYTE_PARTITIONED) {
       nsAutoPtr<MediaRawDataWriter> writer(sample->CreateWriter());
       unsigned char const* iv;
@@ -788,7 +745,12 @@ WebMDemuxer::GetNextPacket(TrackInfo::TrackType aType,
       writer->mCrypto.mValid = true;
       writer->mCrypto.mIVSize = ivLength;
       if (ivLength == 0) {
-        // Frame is not encrypted
+        // Frame is not encrypted. This shouldn't happen as it means the
+        // encryption bit is set on a frame with no IV, but we gracefully
+        // handle incase.
+        MOZ_ASSERT_UNREACHABLE(
+            "Unencrypted packets should not have the encryption bit set!");
+        WEBM_DEBUG("Unencrypted packet with encryption bit set");
         writer->mCrypto.mPlainSizes.AppendElement(length);
         writer->mCrypto.mEncryptedSizes.AppendElement(0);
       } else {
@@ -803,7 +765,8 @@ WebMDemuxer::GetNextPacket(TrackInfo::TrackType aType,
         if (packetEncryption == NESTEGG_PACKET_HAS_SIGNAL_BYTE_ENCRYPTED) {
           writer->mCrypto.mPlainSizes.AppendElement(0);
           writer->mCrypto.mEncryptedSizes.AppendElement(length);
-        } else if (packetEncryption == NESTEGG_PACKET_HAS_SIGNAL_BYTE_PARTITIONED) {
+        } else if (packetEncryption ==
+                   NESTEGG_PACKET_HAS_SIGNAL_BYTE_PARTITIONED) {
           uint8_t numPartitions = 0;
           const uint32_t* partitions = NULL;
           nestegg_packet_offsets(holder->Packet(), &partitions, &numPartitions);
@@ -861,9 +824,12 @@ WebMDemuxer::GetNextPacket(TrackInfo::TrackType aType,
 
           // Assert that the lengths of the encrypted and plain samples add to
           // the length of the data.
-          assert(((size_t)(std::accumulate(writer->mCrypto.mPlainSizes.begin(), writer->mCrypto.mPlainSizes.end(), 0) \
-                 + std::accumulate(writer->mCrypto.mEncryptedSizes.begin(), writer->mCrypto.mEncryptedSizes.end(), 0)) \
-                 == length));
+          assert(
+              ((size_t)(std::accumulate(writer->mCrypto.mPlainSizes.begin(),
+                                        writer->mCrypto.mPlainSizes.end(), 0) +
+                        std::accumulate(writer->mCrypto.mEncryptedSizes.begin(),
+                                        writer->mCrypto.mEncryptedSizes.end(),
+                                        0)) == length));
         }
       }
     }
@@ -875,10 +841,8 @@ WebMDemuxer::GetNextPacket(TrackInfo::TrackType aType,
   return NS_OK;
 }
 
-nsresult
-WebMDemuxer::NextPacket(TrackInfo::TrackType aType,
-                        RefPtr<NesteggPacketHolder>& aPacket)
-{
+nsresult WebMDemuxer::NextPacket(TrackInfo::TrackType aType,
+                                 RefPtr<NesteggPacketHolder>& aPacket) {
   bool isVideo = aType == TrackInfo::kVideoTrack;
 
   // Flag to indicate that we do need to playback these types of
@@ -890,7 +854,7 @@ WebMDemuxer::NextPacket(TrackInfo::TrackType aType,
   }
 
   // The packet queue for the type that we are interested in.
-  WebMPacketQueue &packets = isVideo ? mVideoPackets : mAudioPackets;
+  WebMPacketQueue& packets = isVideo ? mVideoPackets : mAudioPackets;
 
   if (packets.GetSize() > 0) {
     aPacket = packets.PopFront();
@@ -917,10 +881,8 @@ WebMDemuxer::NextPacket(TrackInfo::TrackType aType,
   } while (true);
 }
 
-nsresult
-WebMDemuxer::DemuxPacket(TrackInfo::TrackType aType,
-                         RefPtr<NesteggPacketHolder>& aPacket)
-{
+nsresult WebMDemuxer::DemuxPacket(TrackInfo::TrackType aType,
+                                  RefPtr<NesteggPacketHolder>& aPacket) {
   nestegg_packet* packet;
   int r = nestegg_read_packet(Context(aType), &packet);
   if (r == 0) {
@@ -946,22 +908,16 @@ WebMDemuxer::DemuxPacket(TrackInfo::TrackType aType,
   return NS_OK;
 }
 
-void
-WebMDemuxer::PushAudioPacket(NesteggPacketHolder* aItem)
-{
+void WebMDemuxer::PushAudioPacket(NesteggPacketHolder* aItem) {
   mAudioPackets.PushFront(aItem);
 }
 
-void
-WebMDemuxer::PushVideoPacket(NesteggPacketHolder* aItem)
-{
+void WebMDemuxer::PushVideoPacket(NesteggPacketHolder* aItem) {
   mVideoPackets.PushFront(aItem);
 }
 
-nsresult
-WebMDemuxer::SeekInternal(TrackInfo::TrackType aType,
-                          const TimeUnit& aTarget)
-{
+nsresult WebMDemuxer::SeekInternal(TrackInfo::TrackType aType,
+                                   const TimeUnit& aTarget) {
   EnsureUpToDateIndex();
   uint32_t trackToSeek = mHasVideo ? mVideoTrack : mAudioTrack;
   uint64_t target = aTarget.ToNanoseconds();
@@ -1016,12 +972,10 @@ WebMDemuxer::SeekInternal(TrackInfo::TrackType aType,
   return NS_OK;
 }
 
-media::TimeIntervals
-WebMDemuxer::GetBuffered()
-{
+media::TimeIntervals WebMDemuxer::GetBuffered() {
   EnsureUpToDateIndex();
   AutoPinned<MediaResource> resource(
-    Resource(TrackInfo::kVideoTrack).GetResource());
+      Resource(TrackInfo::kVideoTrack).GetResource());
 
   media::TimeIntervals buffered;
 
@@ -1033,7 +987,7 @@ WebMDemuxer::GetBuffered()
   uint64_t duration = 0;
   uint64_t startOffset = 0;
   if (!nestegg_duration(Context(TrackInfo::kVideoTrack), &duration)) {
-    if(mBufferedState->GetStartTime(&startOffset)) {
+    if (mBufferedState->GetStartTime(&startOffset)) {
       duration += startOffset;
     }
     WEBM_DEBUG("Duration: %f StartTime: %f",
@@ -1042,12 +996,11 @@ WebMDemuxer::GetBuffered()
   }
   for (uint32_t index = 0; index < ranges.Length(); index++) {
     uint64_t start, end;
-    bool rv = mBufferedState->CalculateBufferedForRange(ranges[index].mStart,
-                                                        ranges[index].mEnd,
-                                                        &start, &end);
+    bool rv = mBufferedState->CalculateBufferedForRange(
+        ranges[index].mStart, ranges[index].mEnd, &start, &end);
     if (rv) {
       NS_ASSERTION(startOffset <= start,
-          "startOffset negative or larger than start time");
+                   "startOffset negative or larger than start time");
 
       if (duration && end > duration) {
         WEBM_DEBUG("limit range to duration, end: %f duration: %f",
@@ -1064,39 +1017,28 @@ WebMDemuxer::GetBuffered()
   return buffered;
 }
 
-bool WebMDemuxer::GetOffsetForTime(uint64_t aTime, int64_t* aOffset)
-{
+bool WebMDemuxer::GetOffsetForTime(uint64_t aTime, int64_t* aOffset) {
   EnsureUpToDateIndex();
   return mBufferedState && mBufferedState->GetOffsetForTime(aTime, aOffset);
 }
 
-
-//WebMTrackDemuxer
+// WebMTrackDemuxer
 WebMTrackDemuxer::WebMTrackDemuxer(WebMDemuxer* aParent,
                                    TrackInfo::TrackType aType,
                                    uint32_t aTrackNumber)
-  : mParent(aParent)
-  , mType(aType)
-  , mNeedKeyframe(true)
-{
+    : mParent(aParent), mType(aType), mNeedKeyframe(true) {
   mInfo = mParent->GetTrackInfo(aType, aTrackNumber);
   MOZ_ASSERT(mInfo);
 }
 
-WebMTrackDemuxer::~WebMTrackDemuxer()
-{
-  mSamples.Reset();
-}
+WebMTrackDemuxer::~WebMTrackDemuxer() { mSamples.Reset(); }
 
-UniquePtr<TrackInfo>
-WebMTrackDemuxer::GetInfo() const
-{
+UniquePtr<TrackInfo> WebMTrackDemuxer::GetInfo() const {
   return mInfo->Clone();
 }
 
-RefPtr<WebMTrackDemuxer::SeekPromise>
-WebMTrackDemuxer::Seek(const TimeUnit& aTime)
-{
+RefPtr<WebMTrackDemuxer::SeekPromise> WebMTrackDemuxer::Seek(
+    const TimeUnit& aTime) {
   // Seeks to aTime. Upon success, SeekPromise will be resolved with the
   // actual time seeked to. Typically the random access point time
 
@@ -1111,7 +1053,8 @@ WebMTrackDemuxer::Seek(const TimeUnit& aTime)
     nsresult rv = mParent->GetNextPacket(mType, &mSamples);
     if (NS_FAILED(rv)) {
       if (rv == NS_ERROR_DOM_MEDIA_END_OF_STREAM) {
-        // Ignore the error for now, the next GetSample will be rejected with EOS.
+        // Ignore the error for now, the next GetSample will be rejected with
+        // EOS.
         return SeekPromise::CreateAndResolve(TimeUnit::Zero(), __func__);
       }
       return SeekPromise::CreateAndReject(rv, __func__);
@@ -1148,10 +1091,9 @@ WebMTrackDemuxer::Seek(const TimeUnit& aTime)
   return SeekPromise::CreateAndResolve(seekTime, __func__);
 }
 
-nsresult
-WebMTrackDemuxer::NextSample(RefPtr<MediaRawData>& aData)
-{
-  nsresult rv = NS_ERROR_DOM_MEDIA_END_OF_STREAM;;
+nsresult WebMTrackDemuxer::NextSample(RefPtr<MediaRawData>& aData) {
+  nsresult rv = NS_ERROR_DOM_MEDIA_END_OF_STREAM;
+  ;
   while (mSamples.GetSize() < 1 &&
          NS_SUCCEEDED((rv = mParent->GetNextPacket(mType, &mSamples)))) {
   }
@@ -1162,9 +1104,8 @@ WebMTrackDemuxer::NextSample(RefPtr<MediaRawData>& aData)
   return rv;
 }
 
-RefPtr<WebMTrackDemuxer::SamplesPromise>
-WebMTrackDemuxer::GetSamples(int32_t aNumSamples)
-{
+RefPtr<WebMTrackDemuxer::SamplesPromise> WebMTrackDemuxer::GetSamples(
+    int32_t aNumSamples) {
   RefPtr<SamplesHolder> samples = new SamplesHolder;
   MOZ_ASSERT(aNumSamples);
 
@@ -1192,9 +1133,7 @@ WebMTrackDemuxer::GetSamples(int32_t aNumSamples)
   }
 }
 
-void
-WebMTrackDemuxer::SetNextKeyFrameTime()
-{
+void WebMTrackDemuxer::SetNextKeyFrameTime() {
   if (mType != TrackInfo::kVideoTrack || mParent->IsMediaSource()) {
     return;
   }
@@ -1242,19 +1181,17 @@ WebMTrackDemuxer::SetNextKeyFrameTime()
 
   if (frameTime.IsValid()) {
     mNextKeyframeTime.emplace(frameTime);
-    WEBM_DEBUG("Next Keyframe %f (%u queued %.02fs)",
-               mNextKeyframeTime.value().ToSeconds(),
-               uint32_t(mSamples.GetSize()),
-               (mSamples.Last()->mTimecode - mSamples.First()->mTimecode).ToSeconds());
+    WEBM_DEBUG(
+        "Next Keyframe %f (%u queued %.02fs)",
+        mNextKeyframeTime.value().ToSeconds(), uint32_t(mSamples.GetSize()),
+        (mSamples.Last()->mTimecode - mSamples.First()->mTimecode).ToSeconds());
   } else {
     WEBM_DEBUG("Couldn't determine next keyframe time  (%u queued)",
                uint32_t(mSamples.GetSize()));
   }
 }
 
-void
-WebMTrackDemuxer::Reset()
-{
+void WebMTrackDemuxer::Reset() {
   mSamples.Reset();
   media::TimeIntervals buffered = GetBuffered();
   mNeedKeyframe = true;
@@ -1267,9 +1204,7 @@ WebMTrackDemuxer::Reset()
   }
 }
 
-void
-WebMTrackDemuxer::UpdateSamples(nsTArray<RefPtr<MediaRawData>>& aSamples)
-{
+void WebMTrackDemuxer::UpdateSamples(nsTArray<RefPtr<MediaRawData>>& aSamples) {
   for (const auto& sample : aSamples) {
     if (sample->mCrypto.mValid) {
       nsAutoPtr<MediaRawDataWriter> writer(sample->CreateWriter());
@@ -1284,9 +1219,7 @@ WebMTrackDemuxer::UpdateSamples(nsTArray<RefPtr<MediaRawData>>& aSamples)
   }
 }
 
-nsresult
-WebMTrackDemuxer::GetNextRandomAccessPoint(TimeUnit* aTime)
-{
+nsresult WebMTrackDemuxer::GetNextRandomAccessPoint(TimeUnit* aTime) {
   if (mNextKeyframeTime.isNothing()) {
     // There's no next key frame.
     *aTime = TimeUnit::FromInfinity();
@@ -1297,8 +1230,7 @@ WebMTrackDemuxer::GetNextRandomAccessPoint(TimeUnit* aTime)
 }
 
 RefPtr<WebMTrackDemuxer::SkipAccessPointPromise>
-WebMTrackDemuxer::SkipToNextRandomAccessPoint(const TimeUnit& aTimeThreshold)
-{
+WebMTrackDemuxer::SkipToNextRandomAccessPoint(const TimeUnit& aTimeThreshold) {
   uint32_t parsed = 0;
   bool found = false;
   RefPtr<MediaRawData> sample;
@@ -1308,8 +1240,8 @@ WebMTrackDemuxer::SkipToNextRandomAccessPoint(const TimeUnit& aTimeThreshold)
   while (!found && NS_SUCCEEDED((rv = NextSample(sample)))) {
     parsed++;
     if (sample->mKeyframe && sample->mTime >= aTimeThreshold) {
-      WEBM_DEBUG("next sample: %f (parsed: %d)",
-                 sample->mTime.ToSeconds(), parsed);
+      WEBM_DEBUG("next sample: %f (parsed: %d)", sample->mTime.ToSeconds(),
+                 parsed);
       found = true;
       mSamples.Reset();
       mSamples.PushFront(sample.forget());
@@ -1326,21 +1258,13 @@ WebMTrackDemuxer::SkipToNextRandomAccessPoint(const TimeUnit& aTimeThreshold)
   }
 }
 
-media::TimeIntervals
-WebMTrackDemuxer::GetBuffered()
-{
+media::TimeIntervals WebMTrackDemuxer::GetBuffered() {
   return mParent->GetBuffered();
 }
 
-void
-WebMTrackDemuxer::BreakCycles()
-{
-  mParent = nullptr;
-}
+void WebMTrackDemuxer::BreakCycles() { mParent = nullptr; }
 
-int64_t
-WebMTrackDemuxer::GetEvictionOffset(const TimeUnit& aTime)
-{
+int64_t WebMTrackDemuxer::GetEvictionOffset(const TimeUnit& aTime) {
   int64_t offset;
   if (!mParent->GetOffsetForTime(aTime.ToNanoseconds(), &offset)) {
     return 0;
@@ -1350,4 +1274,4 @@ WebMTrackDemuxer::GetEvictionOffset(const TimeUnit& aTime)
 }
 
 #undef WEBM_DEBUG
-} // namespace mozilla
+}  // namespace mozilla
