@@ -48,20 +48,13 @@ NS_INTERFACE_MAP_BEGIN_CYCLE_COLLECTION(LegacyMozTCPSocket)
 NS_INTERFACE_MAP_END
 
 LegacyMozTCPSocket::LegacyMozTCPSocket(nsPIDOMWindowInner* aWindow)
-: mGlobal(do_QueryInterface(aWindow))
-{
-}
+    : mGlobal(do_QueryInterface(aWindow)) {}
 
-LegacyMozTCPSocket::~LegacyMozTCPSocket()
-{
-}
+LegacyMozTCPSocket::~LegacyMozTCPSocket() {}
 
-already_AddRefed<TCPSocket>
-LegacyMozTCPSocket::Open(const nsAString& aHost,
-                         uint16_t aPort,
-                         const SocketOptions& aOptions,
-                         mozilla::ErrorResult& aRv)
-{
+already_AddRefed<TCPSocket> LegacyMozTCPSocket::Open(
+    const nsAString& aHost, uint16_t aPort, const SocketOptions& aOptions,
+    mozilla::ErrorResult& aRv) {
   AutoJSAPI api;
   if (NS_WARN_IF(!api.Init(mGlobal))) {
     aRv.Throw(NS_ERROR_FAILURE);
@@ -71,32 +64,27 @@ LegacyMozTCPSocket::Open(const nsAString& aHost,
   return TCPSocket::Constructor(globalObj, aHost, aPort, aOptions, aRv);
 }
 
-already_AddRefed<TCPServerSocket>
-LegacyMozTCPSocket::Listen(uint16_t aPort,
-                           const ServerSocketOptions& aOptions,
-                           uint16_t aBacklog,
-                           mozilla::ErrorResult& aRv)
-{
+already_AddRefed<TCPServerSocket> LegacyMozTCPSocket::Listen(
+    uint16_t aPort, const ServerSocketOptions& aOptions, uint16_t aBacklog,
+    mozilla::ErrorResult& aRv) {
   AutoJSAPI api;
   if (NS_WARN_IF(!api.Init(mGlobal))) {
     return nullptr;
   }
   GlobalObject globalObj(api.cx(), mGlobal->GetGlobalJSObject());
-  return TCPServerSocket::Constructor(globalObj, aPort, aOptions, aBacklog, aRv);
+  return TCPServerSocket::Constructor(globalObj, aPort, aOptions, aBacklog,
+                                      aRv);
 }
 
-bool
-LegacyMozTCPSocket::WrapObject(JSContext* aCx,
-                               JS::Handle<JSObject*> aGivenProto,
-                               JS::MutableHandle<JSObject*> aReflector)
-{
+bool LegacyMozTCPSocket::WrapObject(JSContext* aCx,
+                                    JS::Handle<JSObject*> aGivenProto,
+                                    JS::MutableHandle<JSObject*> aReflector) {
   return LegacyMozTCPSocketBinding::Wrap(aCx, this, aGivenProto, aReflector);
 }
 
 NS_IMPL_CYCLE_COLLECTION_CLASS(TCPSocket)
 
-NS_IMPL_CYCLE_COLLECTION_TRACE_BEGIN_INHERITED(TCPSocket,
-                                               DOMEventTargetHelper)
+NS_IMPL_CYCLE_COLLECTION_TRACE_BEGIN_INHERITED(TCPSocket, DOMEventTargetHelper)
 NS_IMPL_CYCLE_COLLECTION_TRACE_END
 
 NS_IMPL_CYCLE_COLLECTION_TRAVERSE_BEGIN_INHERITED(TCPSocket,
@@ -112,8 +100,7 @@ NS_IMPL_CYCLE_COLLECTION_TRAVERSE_BEGIN_INHERITED(TCPSocket,
   NS_IMPL_CYCLE_COLLECTION_TRAVERSE(mSocketBridgeParent)
 NS_IMPL_CYCLE_COLLECTION_TRAVERSE_END
 
-NS_IMPL_CYCLE_COLLECTION_UNLINK_BEGIN_INHERITED(TCPSocket,
-                                                DOMEventTargetHelper)
+NS_IMPL_CYCLE_COLLECTION_UNLINK_BEGIN_INHERITED(TCPSocket, DOMEventTargetHelper)
   NS_IMPL_CYCLE_COLLECTION_UNLINK(mTransport)
   NS_IMPL_CYCLE_COLLECTION_UNLINK(mSocketInputStream)
   NS_IMPL_CYCLE_COLLECTION_UNLINK(mSocketOutputStream)
@@ -138,23 +125,22 @@ NS_INTERFACE_MAP_BEGIN_CYCLE_COLLECTION(TCPSocket)
   NS_INTERFACE_MAP_ENTRY(nsITCPSocketCallback)
 NS_INTERFACE_MAP_END_INHERITING(DOMEventTargetHelper)
 
-TCPSocket::TCPSocket(nsIGlobalObject* aGlobal, const nsAString& aHost, uint16_t aPort,
-                     bool aSsl, bool aUseArrayBuffers)
-  : DOMEventTargetHelper(aGlobal)
-  , mReadyState(TCPReadyState::Closed)
-  , mUseArrayBuffers(aUseArrayBuffers)
-  , mHost(aHost)
-  , mPort(aPort)
-  , mSsl(aSsl)
-  , mAsyncCopierActive(false)
-  , mWaitingForDrain(false)
-  , mInnerWindowID(0)
-  , mBufferedAmount(0)
-  , mSuspendCount(0)
-  , mTrackingNumber(0)
-  , mWaitingForStartTLS(false)
-  , mObserversActive(false)
-{
+TCPSocket::TCPSocket(nsIGlobalObject* aGlobal, const nsAString& aHost,
+                     uint16_t aPort, bool aSsl, bool aUseArrayBuffers)
+    : DOMEventTargetHelper(aGlobal),
+      mReadyState(TCPReadyState::Closed),
+      mUseArrayBuffers(aUseArrayBuffers),
+      mHost(aHost),
+      mPort(aPort),
+      mSsl(aSsl),
+      mAsyncCopierActive(false),
+      mWaitingForDrain(false),
+      mInnerWindowID(0),
+      mBufferedAmount(0),
+      mSuspendCount(0),
+      mTrackingNumber(0),
+      mWaitingForStartTLS(false),
+      mObserversActive(false) {
   if (aGlobal) {
     nsCOMPtr<nsPIDOMWindowInner> window = do_QueryInterface(aGlobal);
     if (window) {
@@ -163,10 +149,10 @@ TCPSocket::TCPSocket(nsIGlobalObject* aGlobal, const nsAString& aHost, uint16_t
   }
 }
 
-TCPSocket::~TCPSocket()
-{
+TCPSocket::~TCPSocket() {
   if (mObserversActive) {
-    nsCOMPtr<nsIObserverService> obs = do_GetService("@mozilla.org/observer-service;1");
+    nsCOMPtr<nsIObserverService> obs =
+        do_GetService("@mozilla.org/observer-service;1");
     if (obs) {
       obs->RemoveObserver(this, "inner-window-destroyed");
       obs->RemoveObserver(this, "profile-change-net-teardown");
@@ -174,31 +160,35 @@ TCPSocket::~TCPSocket()
   }
 }
 
-nsresult
-TCPSocket::CreateStream()
-{
-  nsresult rv = mTransport->OpenInputStream(0, 0, 0, getter_AddRefs(mSocketInputStream));
+nsresult TCPSocket::CreateStream() {
+  nsresult rv =
+      mTransport->OpenInputStream(0, 0, 0, getter_AddRefs(mSocketInputStream));
   NS_ENSURE_SUCCESS(rv, rv);
-  rv = mTransport->OpenOutputStream(nsITransport::OPEN_UNBUFFERED, 0, 0, getter_AddRefs(mSocketOutputStream));
+  rv = mTransport->OpenOutputStream(nsITransport::OPEN_UNBUFFERED, 0, 0,
+                                    getter_AddRefs(mSocketOutputStream));
   NS_ENSURE_SUCCESS(rv, rv);
 
   // If the other side is not listening, we will
   // get an onInputStreamReady callback where available
   // raises to indicate the connection was refused.
-  nsCOMPtr<nsIAsyncInputStream> asyncStream = do_QueryInterface(mSocketInputStream);
+  nsCOMPtr<nsIAsyncInputStream> asyncStream =
+      do_QueryInterface(mSocketInputStream);
   NS_ENSURE_TRUE(asyncStream, NS_ERROR_NOT_AVAILABLE);
 
   nsCOMPtr<nsIEventTarget> mainTarget = GetMainThreadEventTarget();
-  rv = asyncStream->AsyncWait(this, nsIAsyncInputStream::WAIT_CLOSURE_ONLY, 0, mainTarget);
+  rv = asyncStream->AsyncWait(this, nsIAsyncInputStream::WAIT_CLOSURE_ONLY, 0,
+                              mainTarget);
   NS_ENSURE_SUCCESS(rv, rv);
 
   if (mUseArrayBuffers) {
-    mInputStreamBinary = do_CreateInstance("@mozilla.org/binaryinputstream;1", &rv);
+    mInputStreamBinary =
+        do_CreateInstance("@mozilla.org/binaryinputstream;1", &rv);
     NS_ENSURE_SUCCESS(rv, rv);
     rv = mInputStreamBinary->SetInputStream(mSocketInputStream);
     NS_ENSURE_SUCCESS(rv, rv);
   } else {
-    mInputStreamScriptable = do_CreateInstance("@mozilla.org/scriptableinputstream;1", &rv);
+    mInputStreamScriptable =
+        do_CreateInstance("@mozilla.org/scriptableinputstream;1", &rv);
     NS_ENSURE_SUCCESS(rv, rv);
     rv = mInputStreamScriptable->Init(mSocketInputStream);
     NS_ENSURE_SUCCESS(rv, rv);
@@ -207,9 +197,8 @@ TCPSocket::CreateStream()
   return NS_OK;
 }
 
-nsresult
-TCPSocket::InitWithUnconnectedTransport(nsISocketTransport* aTransport)
-{
+nsresult TCPSocket::InitWithUnconnectedTransport(
+    nsISocketTransport* aTransport) {
   mReadyState = TCPReadyState::Connecting;
   mTransport = aTransport;
 
@@ -224,14 +213,13 @@ TCPSocket::InitWithUnconnectedTransport(nsISocketTransport* aTransport)
   return NS_OK;
 }
 
-nsresult
-TCPSocket::Init()
-{
-  nsCOMPtr<nsIObserverService> obs = do_GetService("@mozilla.org/observer-service;1");
+nsresult TCPSocket::Init() {
+  nsCOMPtr<nsIObserverService> obs =
+      do_GetService("@mozilla.org/observer-service;1");
   if (obs) {
     mObserversActive = true;
-    obs->AddObserver(this, "inner-window-destroyed", true); // weak reference
-    obs->AddObserver(this, "profile-change-net-teardown", true); // weak ref
+    obs->AddObserver(this, "inner-window-destroyed", true);  // weak reference
+    obs->AddObserver(this, "profile-change-net-teardown", true);  // weak ref
   }
 
   if (XRE_GetProcessType() == GeckoProcessType_Content) {
@@ -247,7 +235,7 @@ TCPSocket::Init()
   }
 
   nsCOMPtr<nsISocketTransportService> sts =
-    do_GetService("@mozilla.org/network/socket-transport-service;1");
+      do_GetService("@mozilla.org/network/socket-transport-service;1");
 
   const char* socketTypes[1];
   if (mSsl) {
@@ -256,16 +244,15 @@ TCPSocket::Init()
     socketTypes[0] = "starttls";
   }
   nsCOMPtr<nsISocketTransport> transport;
-  nsresult rv = sts->CreateTransport(socketTypes, 1, NS_ConvertUTF16toUTF8(mHost), mPort,
-                                     nullptr, getter_AddRefs(transport));
+  nsresult rv =
+      sts->CreateTransport(socketTypes, 1, NS_ConvertUTF16toUTF8(mHost), mPort,
+                           nullptr, getter_AddRefs(transport));
   NS_ENSURE_SUCCESS(rv, rv);
 
   return InitWithUnconnectedTransport(transport);
 }
 
-void
-TCPSocket::InitWithSocketChild(TCPSocketChild* aSocketBridge)
-{
+void TCPSocket::InitWithSocketChild(TCPSocketChild* aSocketBridge) {
   mSocketBridgeChild = aSocketBridge;
   mReadyState = TCPReadyState::Open;
   mSocketBridgeChild->SetSocket(this);
@@ -273,9 +260,7 @@ TCPSocket::InitWithSocketChild(TCPSocketChild* aSocketBridge)
   mSocketBridgeChild->GetPort(&mPort);
 }
 
-nsresult
-TCPSocket::InitWithTransport(nsISocketTransport* aTransport)
-{
+nsresult TCPSocket::InitWithTransport(nsISocketTransport* aTransport) {
   mTransport = aTransport;
   nsresult rv = CreateStream();
   NS_ENSURE_SUCCESS(rv, rv);
@@ -294,9 +279,7 @@ TCPSocket::InitWithTransport(nsISocketTransport* aTransport)
   return NS_OK;
 }
 
-void
-TCPSocket::UpgradeToSecure(mozilla::ErrorResult& aRv)
-{
+void TCPSocket::UpgradeToSecure(mozilla::ErrorResult& aRv) {
   if (mReadyState != TCPReadyState::Open) {
     aRv.Throw(NS_ERROR_FAILURE);
     return;
@@ -321,38 +304,35 @@ TCPSocket::UpgradeToSecure(mozilla::ErrorResult& aRv)
 }
 
 namespace {
-class CopierCallbacks final : public nsIRequestObserver
-{
+class CopierCallbacks final : public nsIRequestObserver {
   RefPtr<TCPSocket> mOwner;
-public:
+
+ public:
   explicit CopierCallbacks(TCPSocket* aSocket) : mOwner(aSocket) {}
 
   NS_DECL_ISUPPORTS
   NS_DECL_NSIREQUESTOBSERVER
-private:
+ private:
   ~CopierCallbacks() {}
 };
 
 NS_IMPL_ISUPPORTS(CopierCallbacks, nsIRequestObserver)
 
 NS_IMETHODIMP
-CopierCallbacks::OnStartRequest(nsIRequest* aRequest, nsISupports* aContext)
-{
+CopierCallbacks::OnStartRequest(nsIRequest* aRequest, nsISupports* aContext) {
   return NS_OK;
 }
 
 NS_IMETHODIMP
-CopierCallbacks::OnStopRequest(nsIRequest* aRequest, nsISupports* aContext, nsresult aStatus)
-{
+CopierCallbacks::OnStopRequest(nsIRequest* aRequest, nsISupports* aContext,
+                               nsresult aStatus) {
   mOwner->NotifyCopyComplete(aStatus);
   mOwner = nullptr;
   return NS_OK;
 }
-} // unnamed namespace
+}  // unnamed namespace
 
-nsresult
-TCPSocket::EnsureCopying()
-{
+nsresult TCPSocket::EnsureCopying() {
   if (mAsyncCopierActive) {
     return NS_OK;
   }
@@ -362,7 +342,7 @@ TCPSocket::EnsureCopying()
   nsresult rv;
 
   nsCOMPtr<nsIMultiplexInputStream> multiplexStream =
-    do_CreateInstance("@mozilla.org/io/multiplex-input-stream;1", &rv);
+      do_CreateInstance("@mozilla.org/io/multiplex-input-stream;1", &rv);
   NS_ENSURE_SUCCESS(rv, rv);
 
   nsCOMPtr<nsIInputStream> stream = do_QueryInterface(multiplexStream);
@@ -374,21 +354,18 @@ TCPSocket::EnsureCopying()
   }
 
   nsCOMPtr<nsIAsyncStreamCopier> copier =
-    do_CreateInstance("@mozilla.org/network/async-stream-copier;1", &rv);
+      do_CreateInstance("@mozilla.org/network/async-stream-copier;1", &rv);
   NS_ENSURE_SUCCESS(rv, rv);
 
   nsCOMPtr<nsISocketTransportService> sts =
       do_GetService("@mozilla.org/network/socket-transport-service;1");
 
   nsCOMPtr<nsIEventTarget> target = do_QueryInterface(sts);
-  rv = copier->Init(stream,
-                    mSocketOutputStream,
-                    target,
-                    true, /* source buffered */
-                    false, /* sink buffered */
-                    BUFFER_SIZE,
-                    false, /* close source */
-                    false); /* close sink */
+  rv = copier->Init(stream, mSocketOutputStream, target,
+                    true,               /* source buffered */
+                    false,              /* sink buffered */
+                    BUFFER_SIZE, false, /* close source */
+                    false);             /* close sink */
   NS_ENSURE_SUCCESS(rv, rv);
 
   RefPtr<CopierCallbacks> callbacks = new CopierCallbacks(this);
@@ -398,9 +375,7 @@ TCPSocket::EnsureCopying()
   return NS_OK;
 }
 
-void
-TCPSocket::NotifyCopyComplete(nsresult aStatus)
-{
+void TCPSocket::NotifyCopyComplete(nsresult aStatus) {
   mAsyncCopierActive = false;
 
   // Let's update the buffered amount of data.
@@ -415,8 +390,8 @@ TCPSocket::NotifyCopyComplete(nsresult aStatus)
   mBufferedAmount = bufferedAmount;
 
   if (mSocketBridgeParent) {
-    mozilla::Unused << mSocketBridgeParent->SendUpdateBufferedAmount(BufferedAmount(),
-                                                                     mTrackingNumber);
+    mozilla::Unused << mSocketBridgeParent->SendUpdateBufferedAmount(
+        BufferedAmount(), mTrackingNumber);
   }
 
   if (NS_FAILED(aStatus)) {
@@ -463,9 +438,7 @@ TCPSocket::NotifyCopyComplete(nsresult aStatus)
   }
 }
 
-void
-TCPSocket::ActivateTLS()
-{
+void TCPSocket::ActivateTLS() {
   nsCOMPtr<nsISupports> securityInfo;
   mTransport->GetSecurityInfo(getter_AddRefs(securityInfo));
   nsCOMPtr<nsISSLSocketControl> socketControl = do_QueryInterface(securityInfo);
@@ -475,8 +448,7 @@ TCPSocket::ActivateTLS()
 }
 
 NS_IMETHODIMP
-TCPSocket::FireErrorEvent(const nsAString& aName, const nsAString& aType)
-{
+TCPSocket::FireErrorEvent(const nsAString& aName, const nsAString& aType) {
   if (mSocketBridgeParent) {
     mSocketBridgeParent->FireErrorEvent(aName, aType, mReadyState);
     return NS_OK;
@@ -489,7 +461,7 @@ TCPSocket::FireErrorEvent(const nsAString& aName, const nsAString& aType)
   init.mMessage = aType;
 
   RefPtr<TCPSocketErrorEvent> event =
-    TCPSocketErrorEvent::Constructor(this, NS_LITERAL_STRING("error"), init);
+      TCPSocketErrorEvent::Constructor(this, NS_LITERAL_STRING("error"), init);
   MOZ_ASSERT(event);
   event->SetTrusted(true);
   bool dummy;
@@ -498,8 +470,7 @@ TCPSocket::FireErrorEvent(const nsAString& aName, const nsAString& aType)
 }
 
 NS_IMETHODIMP
-TCPSocket::FireEvent(const nsAString& aType)
-{
+TCPSocket::FireEvent(const nsAString& aType) {
   if (mSocketBridgeParent) {
     mSocketBridgeParent->FireEvent(aType, mReadyState);
     return NS_OK;
@@ -515,8 +486,7 @@ TCPSocket::FireEvent(const nsAString& aType)
 
 NS_IMETHODIMP
 TCPSocket::FireDataArrayEvent(const nsAString& aType,
-                              const InfallibleTArray<uint8_t>& buffer)
-{
+                              const InfallibleTArray<uint8_t>& buffer) {
   AutoJSAPI api;
   if (NS_WARN_IF(!api.Init(GetOwnerGlobal()))) {
     return NS_ERROR_FAILURE;
@@ -533,8 +503,7 @@ TCPSocket::FireDataArrayEvent(const nsAString& aType,
 
 NS_IMETHODIMP
 TCPSocket::FireDataStringEvent(const nsAString& aType,
-                               const nsACString& aString)
-{
+                               const nsACString& aString) {
   AutoJSAPI api;
   if (NS_WARN_IF(!api.Init(GetOwnerGlobal()))) {
     return NS_ERROR_FAILURE;
@@ -549,9 +518,8 @@ TCPSocket::FireDataStringEvent(const nsAString& aType,
   return NS_ERROR_FAILURE;
 }
 
-nsresult
-TCPSocket::FireDataEvent(JSContext* aCx, const nsAString& aType, JS::Handle<JS::Value> aData)
-{
+nsresult TCPSocket::FireDataEvent(JSContext* aCx, const nsAString& aType,
+                                  JS::Handle<JS::Value> aData) {
   MOZ_ASSERT(!mSocketBridgeParent);
 
   RootedDictionary<TCPSocketEventInit> init(aCx);
@@ -559,41 +527,25 @@ TCPSocket::FireDataEvent(JSContext* aCx, const nsAString& aType, JS::Handle<JS::
   init.mCancelable = false;
   init.mData = aData;
 
-  RefPtr<TCPSocketEvent> event =
-    TCPSocketEvent::Constructor(this, aType, init);
+  RefPtr<TCPSocketEvent> event = TCPSocketEvent::Constructor(this, aType, init);
   event->SetTrusted(true);
   bool dummy;
   DispatchEvent(event, &dummy);
   return NS_OK;
 }
 
-JSObject*
-TCPSocket::WrapObject(JSContext* aCx, JS::Handle<JSObject*> aGivenProto)
-{
+JSObject* TCPSocket::WrapObject(JSContext* aCx,
+                                JS::Handle<JSObject*> aGivenProto) {
   return TCPSocketBinding::Wrap(aCx, this, aGivenProto);
 }
 
-void
-TCPSocket::GetHost(nsAString& aHost)
-{
-  aHost.Assign(mHost);
-}
+void TCPSocket::GetHost(nsAString& aHost) { aHost.Assign(mHost); }
 
-uint32_t
-TCPSocket::Port()
-{
-  return mPort;
-}
+uint32_t TCPSocket::Port() { return mPort; }
 
-bool
-TCPSocket::Ssl()
-{
-  return mSsl;
-}
+bool TCPSocket::Ssl() { return mSsl; }
 
-void
-TCPSocket::Suspend()
-{
+void TCPSocket::Suspend() {
   if (mSocketBridgeChild) {
     mSocketBridgeChild->SendSuspend();
     return;
@@ -604,9 +556,7 @@ TCPSocket::Suspend()
   mSuspendCount++;
 }
 
-void
-TCPSocket::Resume(mozilla::ErrorResult& aRv)
-{
+void TCPSocket::Resume(mozilla::ErrorResult& aRv) {
   if (mSocketBridgeChild) {
     mSocketBridgeChild->SendResume();
     return;
@@ -622,8 +572,7 @@ TCPSocket::Resume(mozilla::ErrorResult& aRv)
   mSuspendCount--;
 }
 
-nsresult
-TCPSocket::MaybeReportErrorAndCloseIfOpen(nsresult status) {
+nsresult TCPSocket::MaybeReportErrorAndCloseIfOpen(nsresult status) {
   // If we're closed, we've already reported the error or just don't need to
   // report the error.
   if (mReadyState == TCPReadyState::Closed) {
@@ -641,9 +590,10 @@ TCPSocket::MaybeReportErrorAndCloseIfOpen(nsresult status) {
 
     // security module? (and this is an error)
     if ((static_cast<uint32_t>(status) & 0xFF0000) == 0x5a0000) {
-      nsCOMPtr<nsINSSErrorsService> errSvc = do_GetService("@mozilla.org/nss_errors_service;1");
-      // getErrorClass will throw a generic NS_ERROR_FAILURE if the error code is
-      // somehow not in the set of covered errors.
+      nsCOMPtr<nsINSSErrorsService> errSvc =
+          do_GetService("@mozilla.org/nss_errors_service;1");
+      // getErrorClass will throw a generic NS_ERROR_FAILURE if the error code
+      // is somehow not in the set of covered errors.
       uint32_t errorClass;
       nsresult rv = errSvc->GetErrorClass(status, &errorClass);
       if (NS_FAILED(rv)) {
@@ -660,7 +610,8 @@ TCPSocket::MaybeReportErrorAndCloseIfOpen(nsresult status) {
       }
 
       // NSS_SEC errors (happen below the base value because of negative vals)
-      if ((static_cast<int32_t>(status) & 0xFFFF) < abs(nsINSSErrorsService::NSS_SEC_ERROR_BASE)) {
+      if ((static_cast<int32_t>(status) & 0xFFFF) <
+          abs(nsINSSErrorsService::NSS_SEC_ERROR_BASE)) {
         switch (static_cast<SECErrorCodes>(status)) {
           case SEC_ERROR_EXPIRED_CERTIFICATE:
             errName.AssignLiteral("SecurityExpiredCertificateError");
@@ -668,8 +619,8 @@ TCPSocket::MaybeReportErrorAndCloseIfOpen(nsresult status) {
           case SEC_ERROR_REVOKED_CERTIFICATE:
             errName.AssignLiteral("SecurityRevokedCertificateError");
             break;
-            // per bsmith, we will be unable to tell these errors apart very soon,
-            // so it makes sense to just folder them all together already.
+            // per bsmith, we will be unable to tell these errors apart very
+            // soon, so it makes sense to just folder them all together already.
           case SEC_ERROR_UNKNOWN_ISSUER:
           case SEC_ERROR_UNTRUSTED_ISSUER:
           case SEC_ERROR_UNTRUSTED_CERT:
@@ -680,7 +631,8 @@ TCPSocket::MaybeReportErrorAndCloseIfOpen(nsresult status) {
             errName.AssignLiteral("SecurityInadequateKeyUsageError");
             break;
           case SEC_ERROR_CERT_SIGNATURE_ALGORITHM_DISABLED:
-            errName.AssignLiteral("SecurityCertificateSignatureAlgorithmDisabledError");
+            errName.AssignLiteral(
+                "SecurityCertificateSignatureAlgorithmDisabledError");
             break;
           default:
             errName.AssignLiteral("SecurityError");
@@ -741,22 +693,13 @@ TCPSocket::MaybeReportErrorAndCloseIfOpen(nsresult status) {
   return FireEvent(NS_LITERAL_STRING("close"));
 }
 
-void
-TCPSocket::Close()
-{
-  CloseHelper(true);
-}
+void TCPSocket::Close() { CloseHelper(true); }
 
-void
-TCPSocket::CloseImmediately()
-{
-  CloseHelper(false);
-}
+void TCPSocket::CloseImmediately() { CloseHelper(false); }
 
-void
-TCPSocket::CloseHelper(bool waitForUnsentData)
-{
-  if (mReadyState == TCPReadyState::Closed || mReadyState == TCPReadyState::Closing) {
+void TCPSocket::CloseHelper(bool waitForUnsentData) {
+  if (mReadyState == TCPReadyState::Closed ||
+      mReadyState == TCPReadyState::Closing) {
     return;
   }
 
@@ -768,7 +711,6 @@ TCPSocket::CloseHelper(bool waitForUnsentData)
   }
 
   if (!mAsyncCopierActive || !waitForUnsentData) {
-
     mPendingData.Clear();
     mPendingDataAfterStartTLS.Clear();
 
@@ -784,20 +726,17 @@ TCPSocket::CloseHelper(bool waitForUnsentData)
   }
 }
 
-void
-TCPSocket::SendWithTrackingNumber(const nsACString& aData,
-                                  const uint32_t& aTrackingNumber,
-                                  mozilla::ErrorResult& aRv)
-{
+void TCPSocket::SendWithTrackingNumber(const nsACString& aData,
+                                       const uint32_t& aTrackingNumber,
+                                       mozilla::ErrorResult& aRv) {
   MOZ_ASSERT(mSocketBridgeParent);
   mTrackingNumber = aTrackingNumber;
   // The JSContext isn't necessary for string values; it's a codegen limitation.
   Send(nullptr, aData, aRv);
 }
 
-bool
-TCPSocket::Send(JSContext* aCx, const nsACString& aData, mozilla::ErrorResult& aRv)
-{
+bool TCPSocket::Send(JSContext* aCx, const nsACString& aData,
+                     mozilla::ErrorResult& aRv) {
   if (mReadyState != TCPReadyState::Open) {
     aRv.Throw(NS_ERROR_FAILURE);
     return false;
@@ -823,26 +762,20 @@ TCPSocket::Send(JSContext* aCx, const nsACString& aData, mozilla::ErrorResult& a
   return Send(stream, byteLength);
 }
 
-void
-TCPSocket::SendWithTrackingNumber(JSContext* aCx,
-                                  const ArrayBuffer& aData,
-                                  uint32_t aByteOffset,
-                                  const Optional<uint32_t>& aByteLength,
-                                  const uint32_t& aTrackingNumber,
-                                  mozilla::ErrorResult& aRv)
-{
+void TCPSocket::SendWithTrackingNumber(JSContext* aCx, const ArrayBuffer& aData,
+                                       uint32_t aByteOffset,
+                                       const Optional<uint32_t>& aByteLength,
+                                       const uint32_t& aTrackingNumber,
+                                       mozilla::ErrorResult& aRv) {
   MOZ_ASSERT(mSocketBridgeParent);
   mTrackingNumber = aTrackingNumber;
   Send(aCx, aData, aByteOffset, aByteLength, aRv);
 }
 
-bool
-TCPSocket::Send(JSContext* aCx,
-                const ArrayBuffer& aData,
-                uint32_t aByteOffset,
-                const Optional<uint32_t>& aByteLength,
-                mozilla::ErrorResult& aRv)
-{
+bool TCPSocket::Send(JSContext* aCx, const ArrayBuffer& aData,
+                     uint32_t aByteOffset,
+                     const Optional<uint32_t>& aByteLength,
+                     mozilla::ErrorResult& aRv) {
   if (mReadyState != TCPReadyState::Open) {
     aRv.Throw(NS_ERROR_FAILURE);
     return false;
@@ -851,10 +784,12 @@ TCPSocket::Send(JSContext* aCx,
   nsCOMPtr<nsIArrayBufferInputStream> stream;
 
   aData.ComputeLengthAndData();
-  uint32_t byteLength = aByteLength.WasPassed() ? aByteLength.Value() : aData.Length();
+  uint32_t byteLength =
+      aByteLength.WasPassed() ? aByteLength.Value() : aData.Length();
 
   if (mSocketBridgeChild) {
-    nsresult rv = mSocketBridgeChild->SendSend(aData, aByteOffset, byteLength, ++mTrackingNumber);
+    nsresult rv = mSocketBridgeChild->SendSend(aData, aByteOffset, byteLength,
+                                               ++mTrackingNumber);
     if (NS_WARN_IF(NS_FAILED(rv))) {
       aRv.Throw(rv);
       return false;
@@ -874,9 +809,7 @@ TCPSocket::Send(JSContext* aCx,
   return Send(stream, byteLength);
 }
 
-bool
-TCPSocket::Send(nsIInputStream* aStream, uint32_t aByteLength)
-{
+bool TCPSocket::Send(nsIInputStream* aStream, uint32_t aByteLength) {
   uint64_t newBufferedAmount = BufferedAmount() + aByteLength;
   bool bufferFull = newBufferedAmount > BUFFER_SIZE;
   if (bufferFull) {
@@ -908,15 +841,9 @@ TCPSocket::Send(nsIInputStream* aStream, uint32_t aByteLength)
   return !bufferFull;
 }
 
-TCPReadyState
-TCPSocket::ReadyState()
-{
-  return mReadyState;
-}
+TCPReadyState TCPSocket::ReadyState() { return mReadyState; }
 
-TCPSocketBinaryType
-TCPSocket::BinaryType()
-{
+TCPSocketBinaryType TCPSocket::BinaryType() {
   if (mUseArrayBuffers) {
     return TCPSocketBinaryType::Arraybuffer;
   } else {
@@ -924,38 +851,31 @@ TCPSocket::BinaryType()
   }
 }
 
-already_AddRefed<TCPSocket>
-TCPSocket::CreateAcceptedSocket(nsIGlobalObject* aGlobal,
-                                nsISocketTransport* aTransport,
-                                bool aUseArrayBuffers)
-{
-  RefPtr<TCPSocket> socket = new TCPSocket(aGlobal, EmptyString(), 0, false, aUseArrayBuffers);
+already_AddRefed<TCPSocket> TCPSocket::CreateAcceptedSocket(
+    nsIGlobalObject* aGlobal, nsISocketTransport* aTransport,
+    bool aUseArrayBuffers) {
+  RefPtr<TCPSocket> socket =
+      new TCPSocket(aGlobal, EmptyString(), 0, false, aUseArrayBuffers);
   nsresult rv = socket->InitWithTransport(aTransport);
   NS_ENSURE_SUCCESS(rv, nullptr);
   return socket.forget();
 }
 
-already_AddRefed<TCPSocket>
-TCPSocket::CreateAcceptedSocket(nsIGlobalObject* aGlobal,
-                                TCPSocketChild* aBridge,
-                                bool aUseArrayBuffers)
-{
-  RefPtr<TCPSocket> socket = new TCPSocket(aGlobal, EmptyString(), 0, false, aUseArrayBuffers);
+already_AddRefed<TCPSocket> TCPSocket::CreateAcceptedSocket(
+    nsIGlobalObject* aGlobal, TCPSocketChild* aBridge, bool aUseArrayBuffers) {
+  RefPtr<TCPSocket> socket =
+      new TCPSocket(aGlobal, EmptyString(), 0, false, aUseArrayBuffers);
   socket->InitWithSocketChild(aBridge);
   return socket.forget();
 }
 
-already_AddRefed<TCPSocket>
-TCPSocket::Constructor(const GlobalObject& aGlobal,
-                       const nsAString& aHost,
-                       uint16_t aPort,
-                       const SocketOptions& aOptions,
-                       mozilla::ErrorResult& aRv)
-{
+already_AddRefed<TCPSocket> TCPSocket::Constructor(
+    const GlobalObject& aGlobal, const nsAString& aHost, uint16_t aPort,
+    const SocketOptions& aOptions, mozilla::ErrorResult& aRv) {
   nsCOMPtr<nsIGlobalObject> global = do_QueryInterface(aGlobal.GetAsSupports());
   RefPtr<TCPSocket> socket =
-    new TCPSocket(global, aHost, aPort, aOptions.mUseSecureTransport,
-                  aOptions.mBinaryType == TCPSocketBinaryType::Arraybuffer);
+      new TCPSocket(global, aHost, aPort, aOptions.mUseSecureTransport,
+                    aOptions.mBinaryType == TCPSocketBinaryType::Arraybuffer);
   nsresult rv = socket->Init();
   if (NS_WARN_IF(NS_FAILED(rv))) {
     aRv.Throw(rv);
@@ -965,14 +885,13 @@ TCPSocket::Constructor(const GlobalObject& aGlobal,
   return socket.forget();
 }
 
-nsresult
-TCPSocket::CreateInputStreamPump()
-{
+nsresult TCPSocket::CreateInputStreamPump() {
   if (!mSocketInputStream) {
     return NS_ERROR_NOT_AVAILABLE;
   }
   nsresult rv;
-  mInputStreamPump = do_CreateInstance("@mozilla.org/network/input-stream-pump;1", &rv);
+  mInputStreamPump =
+      do_CreateInstance("@mozilla.org/network/input-stream-pump;1", &rv);
   NS_ENSURE_SUCCESS(rv, rv);
 
   rv = mInputStreamPump->Init(mSocketInputStream, 0, 0, false, nullptr);
@@ -990,9 +909,9 @@ TCPSocket::CreateInputStreamPump()
 
 NS_IMETHODIMP
 TCPSocket::OnTransportStatus(nsITransport* aTransport, nsresult aStatus,
-                             int64_t aProgress, int64_t aProgressMax)
-{
-  if (static_cast<uint32_t>(aStatus) != nsISocketTransport::STATUS_CONNECTED_TO) {
+                             int64_t aProgress, int64_t aProgressMax) {
+  if (static_cast<uint32_t>(aStatus) !=
+      nsISocketTransport::STATUS_CONNECTED_TO) {
     return NS_OK;
   }
 
@@ -1005,8 +924,7 @@ TCPSocket::OnTransportStatus(nsITransport* aTransport, nsresult aStatus,
 }
 
 NS_IMETHODIMP
-TCPSocket::OnInputStreamReady(nsIAsyncInputStream* aStream)
-{
+TCPSocket::OnInputStreamReady(nsIAsyncInputStream* aStream) {
   // Only used for detecting if the connection was refused.
 
   uint64_t dummy;
@@ -1018,20 +936,20 @@ TCPSocket::OnInputStreamReady(nsIAsyncInputStream* aStream)
 }
 
 NS_IMETHODIMP
-TCPSocket::OnStartRequest(nsIRequest* aRequest, nsISupports* aContext)
-{
+TCPSocket::OnStartRequest(nsIRequest* aRequest, nsISupports* aContext) {
   return NS_OK;
 }
 
 NS_IMETHODIMP
-TCPSocket::OnDataAvailable(nsIRequest* aRequest, nsISupports* aContext, nsIInputStream* aStream,
-                           uint64_t aOffset, uint32_t aCount)
-{
+TCPSocket::OnDataAvailable(nsIRequest* aRequest, nsISupports* aContext,
+                           nsIInputStream* aStream, uint64_t aOffset,
+                           uint32_t aCount) {
   if (mUseArrayBuffers) {
     nsTArray<uint8_t> buffer;
     buffer.SetCapacity(aCount);
     uint32_t actual;
-    nsresult rv = aStream->Read(reinterpret_cast<char*>(buffer.Elements()), aCount, &actual);
+    nsresult rv = aStream->Read(reinterpret_cast<char*>(buffer.Elements()),
+                                aCount, &actual);
     NS_ENSURE_SUCCESS(rv, rv);
     MOZ_ASSERT(actual == aCount);
     buffer.SetLength(actual);
@@ -1080,8 +998,8 @@ TCPSocket::OnDataAvailable(nsIRequest* aRequest, nsISupports* aContext, nsIInput
 }
 
 NS_IMETHODIMP
-TCPSocket::OnStopRequest(nsIRequest* aRequest, nsISupports* aContext, nsresult aStatus)
-{
+TCPSocket::OnStopRequest(nsIRequest* aRequest, nsISupports* aContext,
+                         nsresult aStatus) {
   mInputStreamPump = nullptr;
 
   if (mAsyncCopierActive && NS_SUCCEEDED(aStatus)) {
@@ -1098,23 +1016,20 @@ TCPSocket::OnStopRequest(nsIRequest* aRequest, nsISupports* aContext, nsresult a
   return NS_OK;
 }
 
-void
-TCPSocket::SetSocketBridgeParent(TCPSocketParent* aBridgeParent)
-{
+void TCPSocket::SetSocketBridgeParent(TCPSocketParent* aBridgeParent) {
   mSocketBridgeParent = aBridgeParent;
 }
 
 NS_IMETHODIMP
-TCPSocket::UpdateReadyState(uint32_t aReadyState)
-{
+TCPSocket::UpdateReadyState(uint32_t aReadyState) {
   MOZ_ASSERT(mSocketBridgeChild);
   mReadyState = static_cast<TCPReadyState>(aReadyState);
   return NS_OK;
 }
 
 NS_IMETHODIMP
-TCPSocket::UpdateBufferedAmount(uint32_t aBufferedAmount, uint32_t aTrackingNumber)
-{
+TCPSocket::UpdateBufferedAmount(uint32_t aBufferedAmount,
+                                uint32_t aTrackingNumber) {
   if (aTrackingNumber != mTrackingNumber) {
     return NS_OK;
   }
@@ -1129,8 +1044,8 @@ TCPSocket::UpdateBufferedAmount(uint32_t aBufferedAmount, uint32_t aTrackingNumb
 }
 
 NS_IMETHODIMP
-TCPSocket::Observe(nsISupports* aSubject, const char* aTopic, const char16_t* aData)
-{
+TCPSocket::Observe(nsISupports* aSubject, const char* aTopic,
+                   const char16_t* aData) {
   if (!strcmp(aTopic, "inner-window-destroyed")) {
     nsCOMPtr<nsISupportsPRUint64> wrapper = do_QueryInterface(aSubject);
     NS_ENSURE_TRUE(wrapper, NS_ERROR_FAILURE);
@@ -1151,9 +1066,8 @@ TCPSocket::Observe(nsISupports* aSubject, const char* aTopic, const char16_t* aD
 }
 
 /* static */
-bool
-TCPSocket::ShouldTCPSocketExist(JSContext* aCx, JSObject* aGlobal)
-{
+bool TCPSocket::ShouldTCPSocketExist(JSContext* aCx, JSObject* aGlobal) {
   JS::Rooted<JSObject*> global(aCx, aGlobal);
-  return nsContentUtils::IsSystemPrincipal(nsContentUtils::ObjectPrincipal(global));
+  return nsContentUtils::IsSystemPrincipal(
+      nsContentUtils::ObjectPrincipal(global));
 }
