@@ -50,17 +50,13 @@ NS_INTERFACE_MAP_END_INHERITING(DOMEventTargetHelper)
 NS_IMPL_ADDREF_INHERITED(PaymentRequest, DOMEventTargetHelper)
 NS_IMPL_RELEASE_INHERITED(PaymentRequest, DOMEventTargetHelper)
 
-bool
-PaymentRequest::PrefEnabled(JSContext* aCx, JSObject* aObj)
-{
+bool PaymentRequest::PrefEnabled(JSContext* aCx, JSObject* aObj) {
   return XRE_IsContentProcess() &&
          Preferences::GetBool("dom.payments.request.enabled");
 }
 
-nsresult
-PaymentRequest::IsValidStandardizedPMI(const nsAString& aIdentifier,
-                                       nsAString& aErrorMsg)
-{
+nsresult PaymentRequest::IsValidStandardizedPMI(const nsAString& aIdentifier,
+                                                nsAString& aErrorMsg) {
   /*
    *   The syntax of a standardized payment method identifier is given by the
    *   following [ABNF]:
@@ -79,13 +75,15 @@ PaymentRequest::IsValidStandardizedPMI(const nsAString& aIdentifier,
       aErrorMsg.Append(aIdentifier);
       aErrorMsg.AppendLiteral("' is not valid. The character '");
       aErrorMsg.Append(*start);
-      aErrorMsg.AppendLiteral("' at the beginning or after the '-' must be in the range [a-z].");
+      aErrorMsg.AppendLiteral(
+          "' at the beginning or after the '-' must be in the range [a-z].");
       return NS_ERROR_RANGE_ERR;
     }
     ++start;
     // the rest can be in the range %x61-7A + DIGITs
     while (start != end && *start != '-' &&
-           ((*start >= 'a' && *start <= 'z') || (*start >= '0' && *start <= '9'))) {
+           ((*start >= 'a' && *start <= 'z') ||
+            (*start >= '0' && *start <= '9'))) {
       ++start;
     }
     // if the char is not in the range %x61-7A + DIGITs, it must be '-'
@@ -113,10 +111,8 @@ PaymentRequest::IsValidStandardizedPMI(const nsAString& aIdentifier,
   return NS_OK;
 }
 
-nsresult
-PaymentRequest::IsValidPaymentMethodIdentifier(const nsAString& aIdentifier,
-                                               nsAString& aErrorMsg)
-{
+nsresult PaymentRequest::IsValidPaymentMethodIdentifier(
+    const nsAString& aIdentifier, nsAString& aErrorMsg) {
   if (aIdentifier.IsEmpty()) {
     aErrorMsg.AssignLiteral("Payment method identifier is required.");
     return NS_ERROR_TYPE_ERR;
@@ -135,11 +131,9 @@ PaymentRequest::IsValidPaymentMethodIdentifier(const nsAString& aIdentifier,
   uint32_t authorityPos = 0;
   int32_t authorityLen = 0;
   NS_ConvertUTF16toUTF8 url(aIdentifier);
-  nsresult rv = urlParser->ParseURL(url.get(),
-                                    url.Length(),
-                                    &schemePos, &schemeLen,
-                                    &authorityPos, &authorityLen,
-                                    nullptr, nullptr);
+  nsresult rv =
+      urlParser->ParseURL(url.get(), url.Length(), &schemePos, &schemeLen,
+                          &authorityPos, &authorityLen, nullptr, nullptr);
   NS_ENSURE_SUCCESS(rv, NS_ERROR_RANGE_ERR);
   if (schemeLen == -1) {
     // The PMI is not a URL-based PMI, check if it is a standardized PMI
@@ -166,13 +160,11 @@ PaymentRequest::IsValidPaymentMethodIdentifier(const nsAString& aIdentifier,
   int32_t hostnameLen = 0;
   int32_t port = 0;
 
-  NS_ConvertUTF16toUTF8 authority(Substring(aIdentifier, authorityPos, authorityLen));
-  rv = urlParser->ParseAuthority(authority.get(),
-                                 authority.Length(),
-                                 &usernamePos, &usernameLen,
-                                 &passwordPos, &passwordLen,
-                                 &hostnamePos, &hostnameLen,
-                                 &port);
+  NS_ConvertUTF16toUTF8 authority(
+      Substring(aIdentifier, authorityPos, authorityLen));
+  rv = urlParser->ParseAuthority(
+      authority.get(), authority.Length(), &usernamePos, &usernameLen,
+      &passwordPos, &passwordLen, &hostnamePos, &hostnameLen, &port);
   if (NS_FAILED(rv)) {
     // Handle the special cases that URLParser treats it as an invalid URL, but
     // are used in web-platform-test
@@ -200,8 +192,8 @@ PaymentRequest::IsValidPaymentMethodIdentifier(const nsAString& aIdentifier,
       passwordPos = 0;
       passwordLen = -1;
     }
-    // Parse server information when both username and password are empty or do not
-    // exist.
+    // Parse server information when both username and password are empty or do
+    // not exist.
     if ((usernameLen <= 0) && (passwordLen <= 0)) {
       if (authority.Length() - atPos - 1 == 0) {
         aErrorMsg.AssignLiteral("'");
@@ -211,11 +203,9 @@ PaymentRequest::IsValidPaymentMethodIdentifier(const nsAString& aIdentifier,
       }
       // Re-using nsIURLParser::ParseServerInfo to extract the hostname and port
       // information. This can help us to handle complicated IPv6 cases.
-      nsAutoCString serverInfo(Substring(authority,
-                                         atPos + 1,
-                                         authority.Length() - atPos - 1));
-      rv = urlParser->ParseServerInfo(serverInfo.get(),
-                                      serverInfo.Length(),
+      nsAutoCString serverInfo(
+          Substring(authority, atPos + 1, authority.Length() - atPos - 1));
+      rv = urlParser->ParseServerInfo(serverInfo.get(), serverInfo.Length(),
                                       &hostnamePos, &hostnameLen, &port);
       if (NS_FAILED(rv)) {
         // ParseServerInfo returns NS_ERROR_MALFORMED_URI in all fail cases, we
@@ -228,7 +218,8 @@ PaymentRequest::IsValidPaymentMethodIdentifier(const nsAString& aIdentifier,
   if (usernameLen > 0 || passwordLen > 0) {
     aErrorMsg.AssignLiteral("'");
     aErrorMsg.Append(aIdentifier);
-    aErrorMsg.AssignLiteral("' is not valid. Username and password must be empty.");
+    aErrorMsg.AssignLiteral(
+        "' is not valid. Username and password must be empty.");
     return NS_ERROR_RANGE_ERR;
   }
 
@@ -242,19 +233,17 @@ PaymentRequest::IsValidPaymentMethodIdentifier(const nsAString& aIdentifier,
   return NS_OK;
 }
 
-nsresult
-PaymentRequest::IsValidMethodData(JSContext* aCx,
-                                  const Sequence<PaymentMethodData>& aMethodData,
-                                  nsAString& aErrorMsg)
-{
+nsresult PaymentRequest::IsValidMethodData(
+    JSContext* aCx, const Sequence<PaymentMethodData>& aMethodData,
+    nsAString& aErrorMsg) {
   if (!aMethodData.Length()) {
     aErrorMsg.AssignLiteral("At least one payment method is required.");
     return NS_ERROR_TYPE_ERR;
   }
 
   for (const PaymentMethodData& methodData : aMethodData) {
-    nsresult rv = IsValidPaymentMethodIdentifier(methodData.mSupportedMethods,
-                                                 aErrorMsg);
+    nsresult rv =
+        IsValidPaymentMethodIdentifier(methodData.mSupportedMethods, aErrorMsg);
     if (NS_FAILED(rv)) {
       return rv;
     }
@@ -266,8 +255,7 @@ PaymentRequest::IsValidMethodData(JSContext* aCx,
         continue;
       }
       MOZ_ASSERT(aCx);
-      if (!service->IsValidBasicCardRequest(aCx,
-                                            methodData.mData.Value(),
+      if (!service->IsValidBasicCardRequest(aCx, methodData.mData.Value(),
                                             aErrorMsg)) {
         return NS_ERROR_TYPE_ERR;
       }
@@ -277,11 +265,9 @@ PaymentRequest::IsValidMethodData(JSContext* aCx,
   return NS_OK;
 }
 
-nsresult
-PaymentRequest::IsValidNumber(const nsAString& aItem,
-                              const nsAString& aStr,
-                              nsAString& aErrorMsg)
-{
+nsresult PaymentRequest::IsValidNumber(const nsAString& aItem,
+                                       const nsAString& aStr,
+                                       nsAString& aErrorMsg) {
   nsresult error = NS_ERROR_FAILURE;
 
   if (!aStr.IsEmpty()) {
@@ -298,8 +284,7 @@ PaymentRequest::IsValidNumber(const nsAString& aItem,
     //
     // For example, ".1" is not valid for '.' is not in [0-9],
     // and " 0.1" either for beginning with ' '
-    if (aValue.Last() != '.' &&
-        aValue.CharAt(beginningIndex) >= '0' &&
+    if (aValue.Last() != '.' && aValue.CharAt(beginningIndex) >= '0' &&
         aValue.CharAt(beginningIndex) <= '9') {
       aValue.ToFloat(&error);
     }
@@ -316,11 +301,9 @@ PaymentRequest::IsValidNumber(const nsAString& aItem,
   return NS_OK;
 }
 
-nsresult
-PaymentRequest::IsNonNegativeNumber(const nsAString& aItem,
-                                    const nsAString& aStr,
-                                    nsAString& aErrorMsg)
-{
+nsresult PaymentRequest::IsNonNegativeNumber(const nsAString& aItem,
+                                             const nsAString& aStr,
+                                             nsAString& aErrorMsg) {
   nsresult error = NS_ERROR_FAILURE;
 
   if (!aStr.IsEmpty()) {
@@ -328,8 +311,7 @@ PaymentRequest::IsNonNegativeNumber(const nsAString& aItem,
     // Ensure
     // - the beginning character is a digit in [0-9], and
     // - the last character is not '.'
-    if (aValue.Last() != '.' &&
-        aValue.First() >= '0' &&
+    if (aValue.Last() != '.' && aValue.First() >= '0' &&
         aValue.First() <= '9') {
       aValue.ToFloat(&error);
     }
@@ -340,55 +322,54 @@ PaymentRequest::IsNonNegativeNumber(const nsAString& aItem,
     aErrorMsg.Append(aItem);
     aErrorMsg.AppendLiteral("\"(");
     aErrorMsg.Append(aStr);
-    aErrorMsg.AppendLiteral(") must be a valid and non-negative decimal monetary value.");
+    aErrorMsg.AppendLiteral(
+        ") must be a valid and non-negative decimal monetary value.");
     return NS_ERROR_TYPE_ERR;
   }
   return NS_OK;
 }
 
-nsresult
-PaymentRequest::IsValidCurrency(const nsAString& aItem,
-                                const nsAString& aCurrency,
-                                nsAString& aErrorMsg)
-{
-   /*
-    *  According to spec in https://w3c.github.io/payment-request/#validity-checkers,
-    *  perform currency validation with following criteria
-    *  1. The currency length must be 3.
-    *  2. The currency contains any character that must be in the range "A" to "Z"
-    *     (U+0041 to U+005A) or the range "a" to "z" (U+0061 to U+007A)
-    */
-   if (aCurrency.Length() != 3) {
-     aErrorMsg.AssignLiteral("The length amount.currency of \"");
-     aErrorMsg.Append(aItem);
-     aErrorMsg.AppendLiteral("\"(");
-     aErrorMsg.Append(aCurrency);
-     aErrorMsg.AppendLiteral(") must be 3.");
-     return NS_ERROR_RANGE_ERR;
-   }
-   // Don't use nsUnicharUtils::ToUpperCase, it converts the invalid "ınr" PMI to
-   // to the valid one "INR".
-   for (uint32_t idx = 0; idx < aCurrency.Length(); ++idx) {
-     if ((aCurrency.CharAt(idx) >= 'A' && aCurrency.CharAt(idx) <= 'Z') ||
-         (aCurrency.CharAt(idx) >= 'a' && aCurrency.CharAt(idx) <= 'z')) {
-       continue;
-     }
-     aErrorMsg.AssignLiteral("The character amount.currency of \"");
-     aErrorMsg.Append(aItem);
-     aErrorMsg.AppendLiteral("\"(");
-     aErrorMsg.Append(aCurrency);
-     aErrorMsg.AppendLiteral(") must be in the range 'A' to 'Z'(U+0041 to U+005A) or 'a' to 'z'(U+0061 to U+007A).");
-     return NS_ERROR_RANGE_ERR;
-   }
-   return NS_OK;
+nsresult PaymentRequest::IsValidCurrency(const nsAString& aItem,
+                                         const nsAString& aCurrency,
+                                         nsAString& aErrorMsg) {
+  /*
+   *  According to spec in
+   * https://w3c.github.io/payment-request/#validity-checkers, perform currency
+   * validation with following criteria
+   *  1. The currency length must be 3.
+   *  2. The currency contains any character that must be in the range "A" to
+   * "Z" (U+0041 to U+005A) or the range "a" to "z" (U+0061 to U+007A)
+   */
+  if (aCurrency.Length() != 3) {
+    aErrorMsg.AssignLiteral("The length amount.currency of \"");
+    aErrorMsg.Append(aItem);
+    aErrorMsg.AppendLiteral("\"(");
+    aErrorMsg.Append(aCurrency);
+    aErrorMsg.AppendLiteral(") must be 3.");
+    return NS_ERROR_RANGE_ERR;
+  }
+  // Don't use nsUnicharUtils::ToUpperCase, it converts the invalid "ınr" PMI to
+  // to the valid one "INR".
+  for (uint32_t idx = 0; idx < aCurrency.Length(); ++idx) {
+    if ((aCurrency.CharAt(idx) >= 'A' && aCurrency.CharAt(idx) <= 'Z') ||
+        (aCurrency.CharAt(idx) >= 'a' && aCurrency.CharAt(idx) <= 'z')) {
+      continue;
+    }
+    aErrorMsg.AssignLiteral("The character amount.currency of \"");
+    aErrorMsg.Append(aItem);
+    aErrorMsg.AppendLiteral("\"(");
+    aErrorMsg.Append(aCurrency);
+    aErrorMsg.AppendLiteral(
+        ") must be in the range 'A' to 'Z'(U+0041 to U+005A) or 'a' to "
+        "'z'(U+0061 to U+007A).");
+    return NS_ERROR_RANGE_ERR;
+  }
+  return NS_OK;
 }
 
-nsresult
-PaymentRequest::IsValidCurrencyAmount(const nsAString& aItem,
-                                      const PaymentCurrencyAmount& aAmount,
-                                      const bool aIsTotalItem,
-                                      nsAString& aErrorMsg)
-{
+nsresult PaymentRequest::IsValidCurrencyAmount(
+    const nsAString& aItem, const PaymentCurrencyAmount& aAmount,
+    const bool aIsTotalItem, nsAString& aErrorMsg) {
   nsresult rv;
   if (aIsTotalItem) {
     rv = IsNonNegativeNumber(aItem, aAmount.mValue, aErrorMsg);
@@ -417,15 +398,13 @@ PaymentRequest::IsValidCurrencyAmount(const nsAString& aItem,
   return NS_OK;
 }
 
-nsresult
-PaymentRequest::IsValidDetailsInit(const PaymentDetailsInit& aDetails,
-                                   const bool aRequestShipping,
-                                   nsAString& aErrorMsg)
-{
+nsresult PaymentRequest::IsValidDetailsInit(const PaymentDetailsInit& aDetails,
+                                            const bool aRequestShipping,
+                                            nsAString& aErrorMsg) {
   // Check the amount.value and amount.currency of detail.total
   nsresult rv = IsValidCurrencyAmount(NS_LITERAL_STRING("details.total"),
                                       aDetails.mTotal.mAmount,
-                                      true, // isTotalItem
+                                      true,  // isTotalItem
                                       aErrorMsg);
   if (NS_FAILED(rv)) {
     return rv;
@@ -433,15 +412,13 @@ PaymentRequest::IsValidDetailsInit(const PaymentDetailsInit& aDetails,
   return IsValidDetailsBase(aDetails, aRequestShipping, aErrorMsg);
 }
 
-nsresult
-PaymentRequest::IsValidDetailsUpdate(const PaymentDetailsUpdate& aDetails,
-                                     const bool aRequestShipping)
-{
+nsresult PaymentRequest::IsValidDetailsUpdate(
+    const PaymentDetailsUpdate& aDetails, const bool aRequestShipping) {
   nsAutoString message;
   // Check the amount.value and amount.currency of detail.total
   nsresult rv = IsValidCurrencyAmount(NS_LITERAL_STRING("details.total"),
                                       aDetails.mTotal.mAmount,
-                                      true, // isTotalItem
+                                      true,  // isTotalItem
                                       message);
   if (NS_FAILED(rv)) {
     return rv;
@@ -449,18 +426,15 @@ PaymentRequest::IsValidDetailsUpdate(const PaymentDetailsUpdate& aDetails,
   return IsValidDetailsBase(aDetails, aRequestShipping, message);
 }
 
-nsresult
-PaymentRequest::IsValidDetailsBase(const PaymentDetailsBase& aDetails,
-                                   const bool aRequestShipping,
-                                   nsAString& aErrorMsg)
-{
+nsresult PaymentRequest::IsValidDetailsBase(const PaymentDetailsBase& aDetails,
+                                            const bool aRequestShipping,
+                                            nsAString& aErrorMsg) {
   nsresult rv;
   // Check the amount.value of each item in the display items
   if (aDetails.mDisplayItems.WasPassed()) {
     const Sequence<PaymentItem>& displayItems = aDetails.mDisplayItems.Value();
     for (const PaymentItem& displayItem : displayItems) {
-      rv = IsValidCurrencyAmount(displayItem.mLabel,
-                                 displayItem.mAmount,
+      rv = IsValidCurrencyAmount(displayItem.mLabel, displayItem.mAmount,
                                  false,  // isTotalItem
                                  aErrorMsg);
       if (NS_FAILED(rv)) {
@@ -471,7 +445,8 @@ PaymentRequest::IsValidDetailsBase(const PaymentDetailsBase& aDetails,
 
   // Check the shipping option
   if (aDetails.mShippingOptions.WasPassed() && aRequestShipping) {
-    const Sequence<PaymentShippingOption>& shippingOptions = aDetails.mShippingOptions.Value();
+    const Sequence<PaymentShippingOption>& shippingOptions =
+        aDetails.mShippingOptions.Value();
     nsTArray<nsString> seenIDs;
     for (const PaymentShippingOption& shippingOption : shippingOptions) {
       rv = IsValidCurrencyAmount(NS_LITERAL_STRING("details.shippingOptions"),
@@ -493,24 +468,26 @@ PaymentRequest::IsValidDetailsBase(const PaymentDetailsBase& aDetails,
 
   // Check payment details modifiers
   if (aDetails.mModifiers.WasPassed()) {
-    const Sequence<PaymentDetailsModifier>& modifiers = aDetails.mModifiers.Value();
+    const Sequence<PaymentDetailsModifier>& modifiers =
+        aDetails.mModifiers.Value();
     for (const PaymentDetailsModifier& modifier : modifiers) {
-      rv = IsValidPaymentMethodIdentifier(modifier.mSupportedMethods, aErrorMsg);
+      rv =
+          IsValidPaymentMethodIdentifier(modifier.mSupportedMethods, aErrorMsg);
       if (NS_FAILED(rv)) {
         return rv;
       }
       rv = IsValidCurrencyAmount(NS_LITERAL_STRING("details.modifiers.total"),
                                  modifier.mTotal.mAmount,
-                                 true, // isTotalItem
+                                 true,  // isTotalItem
                                  aErrorMsg);
       if (NS_FAILED(rv)) {
         return rv;
       }
       if (modifier.mAdditionalDisplayItems.WasPassed()) {
-        const Sequence<PaymentItem>& displayItems = modifier.mAdditionalDisplayItems.Value();
+        const Sequence<PaymentItem>& displayItems =
+            modifier.mAdditionalDisplayItems.Value();
         for (const PaymentItem& displayItem : displayItems) {
-          rv = IsValidCurrencyAmount(displayItem.mLabel,
-                                     displayItem.mAmount,
+          rv = IsValidCurrencyAmount(displayItem.mLabel, displayItem.mAmount,
                                      false,  // isTotalItem
                                      aErrorMsg);
           if (NS_FAILED(rv)) {
@@ -524,14 +501,12 @@ PaymentRequest::IsValidDetailsBase(const PaymentDetailsBase& aDetails,
   return NS_OK;
 }
 
-already_AddRefed<PaymentRequest>
-PaymentRequest::Constructor(const GlobalObject& aGlobal,
-                            const Sequence<PaymentMethodData>& aMethodData,
-                            const PaymentDetailsInit& aDetails,
-                            const PaymentOptions& aOptions,
-                            ErrorResult& aRv)
-{
-  nsCOMPtr<nsPIDOMWindowInner> window = do_QueryInterface(aGlobal.GetAsSupports());
+already_AddRefed<PaymentRequest> PaymentRequest::Constructor(
+    const GlobalObject& aGlobal, const Sequence<PaymentMethodData>& aMethodData,
+    const PaymentDetailsInit& aDetails, const PaymentOptions& aOptions,
+    ErrorResult& aRv) {
+  nsCOMPtr<nsPIDOMWindowInner> window =
+      do_QueryInterface(aGlobal.GetAsSupports());
   if (!window) {
     aRv.Throw(NS_ERROR_UNEXPECTED);
     return nullptr;
@@ -543,7 +518,6 @@ PaymentRequest::Constructor(const GlobalObject& aGlobal,
     return nullptr;
   }
 
-
   nsCOMPtr<nsIDocument> doc = window->GetExtantDoc();
   if (!doc) {
     aRv.Throw(NS_ERROR_UNEXPECTED);
@@ -563,9 +537,7 @@ PaymentRequest::Constructor(const GlobalObject& aGlobal,
 
   // Check payment methods and details
   nsAutoString message;
-  nsresult rv = IsValidMethodData(aGlobal.Context(),
-                                  aMethodData,
-                                  message);
+  nsresult rv = IsValidMethodData(aGlobal.Context(), aMethodData, message);
   if (NS_FAILED(rv)) {
     if (rv == NS_ERROR_TYPE_ERR) {
       aRv.ThrowTypeError<MSG_ILLEGAL_TYPE_PR_CONSTRUCTOR>(message);
@@ -591,8 +563,9 @@ PaymentRequest::Constructor(const GlobalObject& aGlobal,
 
   // Create PaymentRequest and set its |mId|
   RefPtr<PaymentRequest> request;
-  rv = manager->CreatePayment(aGlobal.Context(), window, topLevelPrincipal, aMethodData,
-                              aDetails, aOptions, getter_AddRefs(request));
+  rv = manager->CreatePayment(aGlobal.Context(), window, topLevelPrincipal,
+                              aMethodData, aDetails, aOptions,
+                              getter_AddRefs(request));
   if (NS_WARN_IF(NS_FAILED(rv))) {
     aRv.Throw(NS_ERROR_DOM_TYPE_ERR);
     return nullptr;
@@ -601,9 +574,8 @@ PaymentRequest::Constructor(const GlobalObject& aGlobal,
   return request.forget();
 }
 
-already_AddRefed<PaymentRequest>
-PaymentRequest::CreatePaymentRequest(nsPIDOMWindowInner* aWindow, nsresult& aRv)
-{
+already_AddRefed<PaymentRequest> PaymentRequest::CreatePaymentRequest(
+    nsPIDOMWindowInner* aWindow, nsresult& aRv) {
   // Generate a unique id for identification
   nsID uuid;
   aRv = nsContentUtils::GenerateUUIDInPlace(uuid);
@@ -624,20 +596,18 @@ PaymentRequest::CreatePaymentRequest(nsPIDOMWindowInner* aWindow, nsresult& aRv)
   return request.forget();
 }
 
-PaymentRequest::PaymentRequest(nsPIDOMWindowInner* aWindow, const nsAString& aInternalId)
-  : DOMEventTargetHelper(aWindow)
-  , mInternalId(aInternalId)
-  , mShippingAddress(nullptr)
-  , mUpdating(false)
-  , mUpdateError(NS_OK)
-  , mState(eCreated)
-{
+PaymentRequest::PaymentRequest(nsPIDOMWindowInner* aWindow,
+                               const nsAString& aInternalId)
+    : DOMEventTargetHelper(aWindow),
+      mInternalId(aInternalId),
+      mShippingAddress(nullptr),
+      mUpdating(false),
+      mUpdateError(NS_OK),
+      mState(eCreated) {
   MOZ_ASSERT(aWindow);
 }
 
-already_AddRefed<Promise>
-PaymentRequest::CanMakePayment(ErrorResult& aRv)
-{
+already_AddRefed<Promise> PaymentRequest::CanMakePayment(ErrorResult& aRv) {
   if (mState != eCreated) {
     aRv.Throw(NS_ERROR_DOM_INVALID_STATE_ERR);
     return nullptr;
@@ -670,17 +640,13 @@ PaymentRequest::CanMakePayment(ErrorResult& aRv)
   return promise.forget();
 }
 
-void
-PaymentRequest::RespondCanMakePayment(bool aResult)
-{
+void PaymentRequest::RespondCanMakePayment(bool aResult) {
   MOZ_ASSERT(mResultPromise);
   mResultPromise->MaybeResolve(aResult);
   mResultPromise = nullptr;
 }
 
-already_AddRefed<Promise>
-PaymentRequest::Show(ErrorResult& aRv)
-{
+already_AddRefed<Promise> PaymentRequest::Show(ErrorResult& aRv) {
   if (mState != eCreated) {
     aRv.Throw(NS_ERROR_DOM_INVALID_STATE_ERR);
     return nullptr;
@@ -717,9 +683,7 @@ PaymentRequest::Show(ErrorResult& aRv)
   return promise.forget();
 }
 
-void
-PaymentRequest::RejectShowPayment(nsresult aRejectReason)
-{
+void PaymentRequest::RejectShowPayment(nsresult aRejectReason) {
   MOZ_ASSERT(mAcceptPromise);
   MOZ_ASSERT(ReadyForUpdate());
 
@@ -728,14 +692,12 @@ PaymentRequest::RejectShowPayment(nsresult aRejectReason)
   mAcceptPromise = nullptr;
 }
 
-void
-PaymentRequest::RespondShowPayment(const nsAString& aMethodName,
-                                   const nsAString& aDetails,
-                                   const nsAString& aPayerName,
-                                   const nsAString& aPayerEmail,
-                                   const nsAString& aPayerPhone,
-                                   nsresult aRv)
-{
+void PaymentRequest::RespondShowPayment(const nsAString& aMethodName,
+                                        const nsAString& aDetails,
+                                        const nsAString& aPayerName,
+                                        const nsAString& aPayerEmail,
+                                        const nsAString& aPayerPhone,
+                                        nsresult aRv) {
   MOZ_ASSERT(mAcceptPromise);
   MOZ_ASSERT(ReadyForUpdate());
   MOZ_ASSERT(mState == eInteractive);
@@ -749,10 +711,9 @@ PaymentRequest::RespondShowPayment(const nsAString& aMethodName,
   mShippingAddress.swap(mFullShippingAddress);
   mFullShippingAddress = nullptr;
 
-  RefPtr<PaymentResponse> paymentResponse =
-    new PaymentResponse(GetOwner(), mInternalId, mId, aMethodName,
-                        mShippingOption, mShippingAddress, aDetails,
-                        aPayerName, aPayerEmail, aPayerPhone);
+  RefPtr<PaymentResponse> paymentResponse = new PaymentResponse(
+      GetOwner(), mInternalId, mId, aMethodName, mShippingOption,
+      mShippingAddress, aDetails, aPayerName, aPayerEmail, aPayerPhone);
   mResponse = paymentResponse;
   mAcceptPromise->MaybeResolve(paymentResponse);
 
@@ -760,16 +721,12 @@ PaymentRequest::RespondShowPayment(const nsAString& aMethodName,
   mAcceptPromise = nullptr;
 }
 
-void
-PaymentRequest::RespondComplete()
-{
+void PaymentRequest::RespondComplete() {
   MOZ_ASSERT(mResponse);
   mResponse->RespondComplete();
 }
 
-already_AddRefed<Promise>
-PaymentRequest::Abort(ErrorResult& aRv)
-{
+already_AddRefed<Promise> PaymentRequest::Abort(ErrorResult& aRv) {
   if (mState != eInteractive) {
     aRv.Throw(NS_ERROR_DOM_INVALID_STATE_ERR);
     return nullptr;
@@ -803,9 +760,7 @@ PaymentRequest::Abort(ErrorResult& aRv)
   return promise.forget();
 }
 
-void
-PaymentRequest::RespondAbortPayment(bool aSuccess)
-{
+void PaymentRequest::RespondAbortPayment(bool aSuccess) {
   // Check whether we are aborting the update:
   //
   // - If |mUpdateError| is not NS_OK, we are aborting the update as
@@ -837,9 +792,8 @@ PaymentRequest::RespondAbortPayment(bool aSuccess)
   }
 }
 
-nsresult
-PaymentRequest::UpdatePayment(JSContext* aCx, const PaymentDetailsUpdate& aDetails)
-{
+nsresult PaymentRequest::UpdatePayment(JSContext* aCx,
+                                       const PaymentDetailsUpdate& aDetails) {
   NS_ENSURE_ARG_POINTER(aCx);
   RefPtr<PaymentRequestManager> manager = PaymentRequestManager::GetSingleton();
   if (NS_WARN_IF(!manager)) {
@@ -852,9 +806,7 @@ PaymentRequest::UpdatePayment(JSContext* aCx, const PaymentDetailsUpdate& aDetai
   return NS_OK;
 }
 
-void
-PaymentRequest::AbortUpdate(nsresult aRv)
-{
+void PaymentRequest::AbortUpdate(nsresult aRv) {
   MOZ_ASSERT(NS_FAILED(aRv));
 
   // Close down any remaining user interface.
@@ -865,52 +817,33 @@ PaymentRequest::AbortUpdate(nsresult aRv)
     return;
   }
 
-  // Remember update error |aRv| and do the following steps in RespondShowPayment.
+  // Remember update error |aRv| and do the following steps in
+  // RespondShowPayment.
   // 1. Set target.state to closed
   // 2. Reject the promise target.acceptPromise with exception "aRv"
   // 3. Abort the algorithm with update error
   mUpdateError = aRv;
 }
 
-void
-PaymentRequest::GetId(nsAString& aRetVal) const
-{
-  aRetVal = mId;
-}
+void PaymentRequest::GetId(nsAString& aRetVal) const { aRetVal = mId; }
 
-void
-PaymentRequest::GetInternalId(nsAString& aRetVal)
-{
+void PaymentRequest::GetInternalId(nsAString& aRetVal) {
   aRetVal = mInternalId;
 }
 
-void
-PaymentRequest::SetId(const nsAString& aId)
-{
-  mId = aId;
-}
+void PaymentRequest::SetId(const nsAString& aId) { mId = aId; }
 
-bool
-PaymentRequest::Equals(const nsAString& aInternalId) const
-{
+bool PaymentRequest::Equals(const nsAString& aInternalId) const {
   return mInternalId.Equals(aInternalId);
 }
 
-bool
-PaymentRequest::ReadyForUpdate()
-{
+bool PaymentRequest::ReadyForUpdate() {
   return mState == eInteractive && !mUpdating;
 }
 
-void
-PaymentRequest::SetUpdating(bool aUpdating)
-{
-  mUpdating = aUpdating;
-}
+void PaymentRequest::SetUpdating(bool aUpdating) { mUpdating = aUpdating; }
 
-nsresult
-PaymentRequest::DispatchUpdateEvent(const nsAString& aType)
-{
+nsresult PaymentRequest::DispatchUpdateEvent(const nsAString& aType) {
   MOZ_ASSERT(ReadyForUpdate());
 
   PaymentRequestUpdateEventInit init;
@@ -918,7 +851,7 @@ PaymentRequest::DispatchUpdateEvent(const nsAString& aType)
   init.mCancelable = false;
 
   RefPtr<PaymentRequestUpdateEvent> event =
-    PaymentRequestUpdateEvent::Constructor(this, aType, init);
+      PaymentRequestUpdateEvent::Constructor(this, aType, init);
   event->SetTrusted(true);
   event->SetRequest(this);
 
@@ -926,81 +859,62 @@ PaymentRequest::DispatchUpdateEvent(const nsAString& aType)
   return DispatchEvent(event, &dummy);
 }
 
-already_AddRefed<PaymentAddress>
-PaymentRequest::GetShippingAddress() const
-{
+already_AddRefed<PaymentAddress> PaymentRequest::GetShippingAddress() const {
   RefPtr<PaymentAddress> address = mShippingAddress;
   return address.forget();
 }
 
-nsresult
-PaymentRequest::UpdateShippingAddress(const nsAString& aCountry,
-                                      const nsTArray<nsString>& aAddressLine,
-                                      const nsAString& aRegion,
-                                      const nsAString& aCity,
-                                      const nsAString& aDependentLocality,
-                                      const nsAString& aPostalCode,
-                                      const nsAString& aSortingCode,
-                                      const nsAString& aLanguageCode,
-                                      const nsAString& aOrganization,
-                                      const nsAString& aRecipient,
-                                      const nsAString& aPhone)
-{
+nsresult PaymentRequest::UpdateShippingAddress(
+    const nsAString& aCountry, const nsTArray<nsString>& aAddressLine,
+    const nsAString& aRegion, const nsAString& aCity,
+    const nsAString& aDependentLocality, const nsAString& aPostalCode,
+    const nsAString& aSortingCode, const nsAString& aLanguageCode,
+    const nsAString& aOrganization, const nsAString& aRecipient,
+    const nsAString& aPhone) {
   nsTArray<nsString> emptyArray;
-  mShippingAddress = new PaymentAddress(GetOwner(), aCountry, emptyArray,
-                                        aRegion, aCity, aDependentLocality,
-                                        aPostalCode, aSortingCode, aLanguageCode,
-                                        EmptyString(), EmptyString(), EmptyString());
-  mFullShippingAddress = new PaymentAddress(GetOwner(), aCountry, aAddressLine,
-                                            aRegion, aCity, aDependentLocality,
-                                            aPostalCode, aSortingCode, aLanguageCode,
-                                            aOrganization, aRecipient, aPhone);
+  mShippingAddress = new PaymentAddress(
+      GetOwner(), aCountry, emptyArray, aRegion, aCity, aDependentLocality,
+      aPostalCode, aSortingCode, aLanguageCode, EmptyString(), EmptyString(),
+      EmptyString());
+  mFullShippingAddress =
+      new PaymentAddress(GetOwner(), aCountry, aAddressLine, aRegion, aCity,
+                         aDependentLocality, aPostalCode, aSortingCode,
+                         aLanguageCode, aOrganization, aRecipient, aPhone);
   // Fire shippingaddresschange event
   return DispatchUpdateEvent(NS_LITERAL_STRING("shippingaddresschange"));
 }
 
-void
-PaymentRequest::SetShippingOption(const nsAString& aShippingOption)
-{
+void PaymentRequest::SetShippingOption(const nsAString& aShippingOption) {
   mShippingOption = aShippingOption;
 }
 
-void
-PaymentRequest::GetShippingOption(nsAString& aRetVal) const
-{
+void PaymentRequest::GetShippingOption(nsAString& aRetVal) const {
   aRetVal = mShippingOption;
 }
 
-nsresult
-PaymentRequest::UpdateShippingOption(const nsAString& aShippingOption)
-{
+nsresult PaymentRequest::UpdateShippingOption(
+    const nsAString& aShippingOption) {
   mShippingOption = aShippingOption;
 
   // Fire shippingaddresschange event
   return DispatchUpdateEvent(NS_LITERAL_STRING("shippingoptionchange"));
 }
 
-void
-PaymentRequest::SetShippingType(const Nullable<PaymentShippingType>& aShippingType)
-{
+void PaymentRequest::SetShippingType(
+    const Nullable<PaymentShippingType>& aShippingType) {
   mShippingType = aShippingType;
 }
 
-Nullable<PaymentShippingType>
-PaymentRequest::GetShippingType() const
-{
+Nullable<PaymentShippingType> PaymentRequest::GetShippingType() const {
   return mShippingType;
 }
 
-PaymentRequest::~PaymentRequest()
-{
-}
+PaymentRequest::~PaymentRequest() {}
 
-JSObject*
-PaymentRequest::WrapObject(JSContext* aCx, JS::Handle<JSObject*> aGivenProto)
-{
+JSObject* PaymentRequest::WrapObject(JSContext* aCx,
+                                     JS::Handle<JSObject*> aGivenProto) {
   return PaymentRequestBinding::Wrap(aCx, this, aGivenProto);
 }
 
-} // namespace dom
-} // namespace mozilla
+}  // namespace dom
+}  // namespace mozilla
