@@ -36,16 +36,12 @@
 
 // nsPluginStreamListenerPeer
 
-NS_IMPL_ISUPPORTS(nsPluginStreamListenerPeer,
-                  nsIStreamListener,
-                  nsIRequestObserver,
-                  nsIHttpHeaderVisitor,
-                  nsISupportsWeakReference,
-                  nsIInterfaceRequestor,
+NS_IMPL_ISUPPORTS(nsPluginStreamListenerPeer, nsIStreamListener,
+                  nsIRequestObserver, nsIHttpHeaderVisitor,
+                  nsISupportsWeakReference, nsIInterfaceRequestor,
                   nsIChannelEventSink)
 
-nsPluginStreamListenerPeer::nsPluginStreamListenerPeer()
-{
+nsPluginStreamListenerPeer::nsPluginStreamListenerPeer() {
   mStreamType = NP_NORMAL;
   mStartBinding = false;
   mRequestFailed = false;
@@ -59,11 +55,11 @@ nsPluginStreamListenerPeer::nsPluginStreamListenerPeer()
   mStreamComplete = 0;
 }
 
-nsPluginStreamListenerPeer::~nsPluginStreamListenerPeer()
-{
+nsPluginStreamListenerPeer::~nsPluginStreamListenerPeer() {
 #ifdef PLUGIN_LOGGING
   MOZ_LOG(nsPluginLogging::gPluginLog, PLUGIN_LOG_NORMAL,
-         ("nsPluginStreamListenerPeer::dtor this=%p, url=%s\n",this, mURLSpec.get()));
+          ("nsPluginStreamListenerPeer::dtor this=%p, url=%s\n", this,
+           mURLSpec.get()));
 #endif
 
   if (mPStreamListener) {
@@ -73,10 +69,9 @@ nsPluginStreamListenerPeer::~nsPluginStreamListenerPeer()
 
 // Called as a result of GetURL and PostURL, or by the host in the case of the
 // initial plugin stream.
-nsresult nsPluginStreamListenerPeer::Initialize(nsIURI *aURL,
-                                                nsNPAPIPluginInstance *aInstance,
-                                                nsNPAPIPluginStreamListener* aListener)
-{
+nsresult nsPluginStreamListenerPeer::Initialize(
+    nsIURI* aURL, nsNPAPIPluginInstance* aInstance,
+    nsNPAPIPluginStreamListener* aListener) {
 #ifdef PLUGIN_LOGGING
   MOZ_LOG(nsPluginLogging::gPluginLog, PLUGIN_LOG_NORMAL,
           ("nsPluginStreamListenerPeer::Initialize instance=%p, url=%s\n",
@@ -92,8 +87,9 @@ nsresult nsPluginStreamListenerPeer::Initialize(nsIURI *aURL,
 
   mURL = aURL;
 
-  NS_ASSERTION(mPluginInstance == nullptr,
-               "nsPluginStreamListenerPeer::Initialize mPluginInstance != nullptr");
+  NS_ASSERTION(
+      mPluginInstance == nullptr,
+      "nsPluginStreamListenerPeer::Initialize mPluginInstance != nullptr");
   mPluginInstance = aInstance;
 
   // If the plugin did not request this stream, e.g. the initial stream, we wont
@@ -110,9 +106,8 @@ nsresult nsPluginStreamListenerPeer::Initialize(nsIURI *aURL,
 }
 
 NS_IMETHODIMP
-nsPluginStreamListenerPeer::OnStartRequest(nsIRequest *request,
-                                           nsISupports* aContext)
-{
+nsPluginStreamListenerPeer::OnStartRequest(nsIRequest* request,
+                                           nsISupports* aContext) {
   nsresult rv = NS_OK;
   AUTO_PROFILER_LABEL("nsPluginStreamListenerPeer::OnStartRequest", OTHER);
 
@@ -146,15 +141,16 @@ nsPluginStreamListenerPeer::OnStartRequest(nsIRequest *request,
       return NS_ERROR_FAILURE;
     }
 
-    if (responseCode > 206) { // not normal
+    if (responseCode > 206) {  // not normal
       uint32_t wantsAllNetworkStreams = 0;
 
       // We don't always have an instance here already, but if we do, check
       // to see if it wants all streams.
       if (mPluginInstance) {
-        rv = mPluginInstance->GetValueFromPlugin(NPPVpluginWantsAllNetworkStreams,
-                                                 &wantsAllNetworkStreams);
-        // If the call returned an error code make sure we still use our default value.
+        rv = mPluginInstance->GetValueFromPlugin(
+            NPPVpluginWantsAllNetworkStreams, &wantsAllNetworkStreams);
+        // If the call returned an error code make sure we still use our default
+        // value.
         if (NS_FAILED(rv)) {
           wantsAllNetworkStreams = 0;
         }
@@ -169,8 +165,7 @@ nsPluginStreamListenerPeer::OnStartRequest(nsIRequest *request,
 
   nsAutoCString contentType;
   rv = channel->GetContentType(contentType);
-  if (NS_FAILED(rv))
-    return rv;
+  if (NS_FAILED(rv)) return rv;
 
   // Check ShouldProcess with content policy
   RefPtr<nsPluginInstanceOwner> owner;
@@ -188,12 +183,9 @@ nsPluginStreamListenerPeer::OnStartRequest(nsIRequest *request,
   int16_t shouldLoad = nsIContentPolicy::ACCEPT;
   rv = NS_CheckContentProcessPolicy(nsIContentPolicy::TYPE_OBJECT_SUBREQUEST,
                                     mURL,
-                                    principal, // loading principal
-                                    principal, // triggering principal
-                                    element,
-                                    contentType,
-                                    nullptr,
-                                    &shouldLoad);
+                                    principal,  // loading principal
+                                    principal,  // triggering principal
+                                    element, contentType, nullptr, &shouldLoad);
   if (NS_FAILED(rv) || NS_CP_REJECTED(shouldLoad)) {
     mRequestFailed = true;
     return NS_ERROR_CONTENT_BLOCKED;
@@ -204,13 +196,11 @@ nsPluginStreamListenerPeer::OnStartRequest(nsIRequest *request,
   // we'll create channel for byte range request.
   nsCOMPtr<nsIInterfaceRequestor> callbacks;
   channel->GetNotificationCallbacks(getter_AddRefs(callbacks));
-  if (callbacks)
-    mWeakPtrChannelCallbacks = do_GetWeakReference(callbacks);
+  if (callbacks) mWeakPtrChannelCallbacks = do_GetWeakReference(callbacks);
 
   nsCOMPtr<nsILoadGroup> loadGroup;
   channel->GetLoadGroup(getter_AddRefs(loadGroup));
-  if (loadGroup)
-    mWeakPtrChannelLoadGroup = do_GetWeakReference(loadGroup);
+  if (loadGroup) mWeakPtrChannelLoadGroup = do_GetWeakReference(loadGroup);
 
   int64_t length;
   rv = channel->GetContentLength(&length);
@@ -226,25 +216,23 @@ nsPluginStreamListenerPeer::OnStartRequest(nsIRequest *request,
       return NS_ERROR_FAILURE;
     }
     mLength = 0;
-  }
-  else {
+  } else {
     mLength = uint32_t(length);
   }
 
   nsCOMPtr<nsIURI> aURL;
   rv = channel->GetURI(getter_AddRefs(aURL));
-  if (NS_FAILED(rv))
-    return rv;
+  if (NS_FAILED(rv)) return rv;
 
   aURL->GetSpec(mURLSpec);
 
-  if (!contentType.IsEmpty())
-    mContentType = contentType;
+  if (!contentType.IsEmpty()) mContentType = contentType;
 
 #ifdef PLUGIN_LOGGING
   MOZ_LOG(nsPluginLogging::gPluginLog, PLUGIN_LOG_NOISY,
-         ("nsPluginStreamListenerPeer::OnStartRequest this=%p request=%p mime=%s, url=%s\n",
-          this, request, contentType.get(), mURLSpec.get()));
+          ("nsPluginStreamListenerPeer::OnStartRequest this=%p request=%p "
+           "mime=%s, url=%s\n",
+           this, request, contentType.get(), mURLSpec.get()));
 
   PR_LogFlush();
 #endif
@@ -258,48 +246,37 @@ nsPluginStreamListenerPeer::OnStartRequest(nsIRequest *request,
   return rv;
 }
 
-NS_IMETHODIMP nsPluginStreamListenerPeer::OnProgress(nsIRequest *request,
+NS_IMETHODIMP nsPluginStreamListenerPeer::OnProgress(nsIRequest* request,
                                                      nsISupports* aContext,
                                                      int64_t aProgress,
-                                                     int64_t aProgressMax)
-{
+                                                     int64_t aProgressMax) {
   nsresult rv = NS_OK;
   return rv;
 }
 
-NS_IMETHODIMP nsPluginStreamListenerPeer::OnStatus(nsIRequest *request,
+NS_IMETHODIMP nsPluginStreamListenerPeer::OnStatus(nsIRequest* request,
                                                    nsISupports* aContext,
                                                    nsresult aStatus,
-                                                   const char16_t* aStatusArg)
-{
+                                                   const char16_t* aStatusArg) {
   return NS_OK;
 }
 
-nsresult
-nsPluginStreamListenerPeer::GetContentType(char** result)
-{
+nsresult nsPluginStreamListenerPeer::GetContentType(char** result) {
   *result = const_cast<char*>(mContentType.get());
   return NS_OK;
 }
 
-
-nsresult
-nsPluginStreamListenerPeer::GetLength(uint32_t* result)
-{
+nsresult nsPluginStreamListenerPeer::GetLength(uint32_t* result) {
   *result = mLength;
   return NS_OK;
 }
 
-nsresult
-nsPluginStreamListenerPeer::GetLastModified(uint32_t* result)
-{
+nsresult nsPluginStreamListenerPeer::GetLastModified(uint32_t* result) {
   *result = mModified;
   return NS_OK;
 }
 
-nsresult
-nsPluginStreamListenerPeer::GetURL(const char** result)
-{
+nsresult nsPluginStreamListenerPeer::GetURL(const char** result) {
   *result = mURLSpec.get();
   return NS_OK;
 }
@@ -308,52 +285,39 @@ nsPluginStreamListenerPeer::GetURL(const char** result)
 // to use asyncOpen2() and do not want to touch the fragile logic
 // of byte range requests. Hence we just introduce this lightweight
 // wrapper to proxy the context.
-class PluginContextProxy final : public nsIStreamListener
-{
-public:
+class PluginContextProxy final : public nsIStreamListener {
+ public:
   NS_DECL_ISUPPORTS
 
-  PluginContextProxy(nsIStreamListener *aListener, nsISupports* aContext)
-    : mListener(aListener)
-    , mContext(aContext)
-  {
+  PluginContextProxy(nsIStreamListener* aListener, nsISupports* aContext)
+      : mListener(aListener), mContext(aContext) {
     MOZ_ASSERT(aListener);
     MOZ_ASSERT(aContext);
   }
 
   NS_IMETHOD
-  OnDataAvailable(nsIRequest* aRequest,
-                  nsISupports* aContext,
-                  nsIInputStream *aIStream,
-                  uint64_t aSourceOffset,
-                  uint32_t aLength) override
-  {
+  OnDataAvailable(nsIRequest* aRequest, nsISupports* aContext,
+                  nsIInputStream* aIStream, uint64_t aSourceOffset,
+                  uint32_t aLength) override {
     // Proxy OnDataAvailable using the internal context
-    return mListener->OnDataAvailable(aRequest,
-                                      mContext,
-                                      aIStream,
-                                      aSourceOffset,
-                                      aLength);
+    return mListener->OnDataAvailable(aRequest, mContext, aIStream,
+                                      aSourceOffset, aLength);
   }
 
   NS_IMETHOD
-  OnStartRequest(nsIRequest* aRequest, nsISupports* aContext) override
-  {
+  OnStartRequest(nsIRequest* aRequest, nsISupports* aContext) override {
     // Proxy OnStartRequest using the internal context
     return mListener->OnStartRequest(aRequest, mContext);
   }
 
   NS_IMETHOD
   OnStopRequest(nsIRequest* aRequest, nsISupports* aContext,
-                nsresult aStatusCode) override
-  {
+                nsresult aStatusCode) override {
     // Proxy OnStopRequest using the inernal context
-    return mListener->OnStopRequest(aRequest,
-                                    mContext,
-                                    aStatusCode);
+    return mListener->OnStopRequest(aRequest, mContext, aStatusCode);
   }
 
-private:
+ private:
   ~PluginContextProxy() {}
   nsCOMPtr<nsIStreamListener> mListener;
   nsCOMPtr<nsISupports> mContext;
@@ -361,50 +325,40 @@ private:
 
 NS_IMPL_ISUPPORTS(PluginContextProxy, nsIStreamListener)
 
-nsresult
-nsPluginStreamListenerPeer::GetStreamOffset(int32_t* result)
-{
+nsresult nsPluginStreamListenerPeer::GetStreamOffset(int32_t* result) {
   *result = mStreamOffset;
   return NS_OK;
 }
 
-nsresult
-nsPluginStreamListenerPeer::SetStreamOffset(int32_t value)
-{
+nsresult nsPluginStreamListenerPeer::SetStreamOffset(int32_t value) {
   mStreamOffset = value;
   return NS_OK;
 }
 
-NS_IMETHODIMP nsPluginStreamListenerPeer::OnDataAvailable(nsIRequest *request,
-                                                          nsISupports* aContext,
-                                                          nsIInputStream *aIStream,
-                                                          uint64_t sourceOffset,
-                                                          uint32_t aLength)
-{
+NS_IMETHODIMP nsPluginStreamListenerPeer::OnDataAvailable(
+    nsIRequest* request, nsISupports* aContext, nsIInputStream* aIStream,
+    uint64_t sourceOffset, uint32_t aLength) {
   if (mRequests.IndexOfObject(request) == -1) {
     MOZ_ASSERT(false, "Received OnDataAvailable for untracked request.");
     return NS_ERROR_UNEXPECTED;
   }
 
-  if (mRequestFailed)
-    return NS_ERROR_FAILURE;
+  if (mRequestFailed) return NS_ERROR_FAILURE;
 
   nsresult rv = NS_OK;
 
-  if (!mPStreamListener)
-    return NS_ERROR_FAILURE;
+  if (!mPStreamListener) return NS_ERROR_FAILURE;
 
-  const char * url = nullptr;
+  const char* url = nullptr;
   GetURL(&url);
 
   PLUGIN_LOG(PLUGIN_LOG_NOISY,
-             ("nsPluginStreamListenerPeer::OnDataAvailable this=%p request=%p, offset=%" PRIu64 ", length=%u, url=%s\n",
+             ("nsPluginStreamListenerPeer::OnDataAvailable this=%p request=%p, "
+              "offset=%" PRIu64 ", length=%u, url=%s\n",
               this, request, sourceOffset, aLength, url ? url : "no url set"));
 
   nsCOMPtr<nsIInputStream> stream = aIStream;
-  rv = mPStreamListener->OnDataAvailable(this,
-                                         stream,
-                                         aLength);
+  rv = mPStreamListener->OnDataAvailable(this, stream, aLength);
 
   // if a plugin returns an error, the peer must kill the stream
   //   else the stream and PluginStreamListener leak
@@ -415,10 +369,9 @@ NS_IMETHODIMP nsPluginStreamListenerPeer::OnDataAvailable(nsIRequest *request,
   return rv;
 }
 
-NS_IMETHODIMP nsPluginStreamListenerPeer::OnStopRequest(nsIRequest *request,
+NS_IMETHODIMP nsPluginStreamListenerPeer::OnStopRequest(nsIRequest* request,
                                                         nsISupports* aContext,
-                                                        nsresult aStatus)
-{
+                                                        nsresult aStatus) {
   nsresult rv = NS_OK;
 
   nsCOMPtr<nsIMultiPartChannel> mp = do_QueryInterface(request);
@@ -429,32 +382,28 @@ NS_IMETHODIMP nsPluginStreamListenerPeer::OnStopRequest(nsIRequest *request,
     }
   }
 
-  PLUGIN_LOG(PLUGIN_LOG_NOISY,
-             ("nsPluginStreamListenerPeer::OnStopRequest this=%p aStatus=%" PRIu32 " request=%p\n",
-              this, static_cast<uint32_t>(aStatus), request));
+  PLUGIN_LOG(
+      PLUGIN_LOG_NOISY,
+      ("nsPluginStreamListenerPeer::OnStopRequest this=%p aStatus=%" PRIu32
+       " request=%p\n",
+       this, static_cast<uint32_t>(aStatus), request));
 
   // if we still have pending stuff to do, lets not close the plugin socket.
-  if (--mPendingRequests > 0)
-    return NS_OK;
+  if (--mPendingRequests > 0) return NS_OK;
 
-  if (!mPStreamListener)
-    return NS_ERROR_FAILURE;
+  if (!mPStreamListener) return NS_ERROR_FAILURE;
 
   nsCOMPtr<nsIChannel> channel = do_QueryInterface(request);
-  if (!channel)
-    return NS_ERROR_FAILURE;
+  if (!channel) return NS_ERROR_FAILURE;
   // Set the content type to ensure we don't pass null to the plugin
   nsAutoCString aContentType;
   rv = channel->GetContentType(aContentType);
-  if (NS_FAILED(rv) && !mRequestFailed)
-    return rv;
+  if (NS_FAILED(rv) && !mRequestFailed) return rv;
 
-  if (!aContentType.IsEmpty())
-    mContentType = aContentType;
+  if (!aContentType.IsEmpty()) mContentType = aContentType;
 
   // set error status if stream failed so we notify the plugin
-  if (mRequestFailed)
-    aStatus = NS_ERROR_FAILURE;
+  if (mRequestFailed) aStatus = NS_ERROR_FAILURE;
 
   if (NS_FAILED(aStatus)) {
     // on error status cleanup the stream
@@ -479,9 +428,8 @@ NS_IMETHODIMP nsPluginStreamListenerPeer::OnStopRequest(nsIRequest *request,
   return NS_OK;
 }
 
-nsresult nsPluginStreamListenerPeer::SetUpStreamListener(nsIRequest *request,
-                                                         nsIURI* aURL)
-{
+nsresult nsPluginStreamListenerPeer::SetUpStreamListener(nsIRequest* request,
+                                                         nsIURI* aURL) {
   nsresult rv = NS_OK;
 
   // If we don't yet have a stream listener, we need to get
@@ -501,7 +449,8 @@ nsresult nsPluginStreamListenerPeer::SetUpStreamListener(nsIRequest *request,
       return NS_ERROR_FAILURE;
     }
 
-    mPStreamListener = static_cast<nsNPAPIPluginStreamListener*>(streamListener.get());
+    mPStreamListener =
+        static_cast<nsNPAPIPluginStreamListener*>(streamListener.get());
   }
 
   mPStreamListener->SetStreamListenerPeer(this);
@@ -526,11 +475,11 @@ nsresult nsPluginStreamListenerPeer::SetUpStreamListener(nsIRequest *request,
       // HTTP version: provide if available.  Defaults to empty string.
       nsCString ver;
       nsCOMPtr<nsIHttpChannelInternal> httpChannelInternal =
-      do_QueryInterface(channel);
+          do_QueryInterface(channel);
       if (httpChannelInternal) {
         uint32_t major, minor;
-        if (NS_SUCCEEDED(httpChannelInternal->GetResponseVersion(&major,
-                                                                 &minor))) {
+        if (NS_SUCCEEDED(
+                httpChannelInternal->GetResponseVersion(&major, &minor))) {
           ver = nsPrintfCString("/%" PRIu32 ".%" PRIu32, major, minor);
         }
       }
@@ -544,7 +493,8 @@ nsresult nsPluginStreamListenerPeer::SetUpStreamListener(nsIRequest *request,
       // Assemble everything and pass to listener.
       nsPrintfCString status("HTTP%s %" PRIu32 " %s", ver.get(), statusNum,
                              statusText.get());
-      static_cast<nsIHTTPHeaderListener*>(mPStreamListener)->StatusLine(status.get());
+      static_cast<nsIHTTPHeaderListener*>(mPStreamListener)
+          ->StatusLine(status.get());
     }
 
     // Also provide all HTTP response headers to our listener.
@@ -554,10 +504,12 @@ nsresult nsPluginStreamListenerPeer::SetUpStreamListener(nsIRequest *request,
     // we require a content len
     // get Last-Modified header for plugin info
     nsAutoCString lastModified;
-    if (NS_SUCCEEDED(httpChannel->GetResponseHeader(NS_LITERAL_CSTRING("last-modified"), lastModified)) &&
+    if (NS_SUCCEEDED(httpChannel->GetResponseHeader(
+            NS_LITERAL_CSTRING("last-modified"), lastModified)) &&
         !lastModified.IsEmpty()) {
       PRTime time64;
-      PR_ParseTimeString(lastModified.get(), true, &time64);  //convert string time to integer time
+      PR_ParseTimeString(lastModified.get(), true,
+                         &time64);  // convert string time to integer time
 
       // Convert PRTime to unix-style time_t, i.e. seconds since the epoch
       double fpTime = double(time64);
@@ -572,22 +524,20 @@ nsresult nsPluginStreamListenerPeer::SetUpStreamListener(nsIRequest *request,
 
   mStartBinding = true;
 
-  if (NS_FAILED(rv))
-    return rv;
+  if (NS_FAILED(rv)) return rv;
 
   return NS_OK;
 }
 
 NS_IMETHODIMP
-nsPluginStreamListenerPeer::VisitHeader(const nsACString &header, const nsACString &value)
-{
+nsPluginStreamListenerPeer::VisitHeader(const nsACString& header,
+                                        const nsACString& value) {
   return mPStreamListener->NewResponseHeader(PromiseFlatCString(header).get(),
                                              PromiseFlatCString(value).get());
 }
 
-nsresult
-nsPluginStreamListenerPeer::GetInterfaceGlobal(const nsIID& aIID, void** result)
-{
+nsresult nsPluginStreamListenerPeer::GetInterfaceGlobal(const nsIID& aIID,
+                                                        void** result) {
   if (!mPluginInstance) {
     return NS_ERROR_FAILURE;
   }
@@ -603,7 +553,7 @@ nsPluginStreamListenerPeer::GetInterfaceGlobal(const nsIID& aIID, void** result)
     return NS_ERROR_FAILURE;
   }
 
-  nsPIDOMWindowOuter *window = doc->GetWindow();
+  nsPIDOMWindowOuter* window = doc->GetWindow();
   if (!window) {
     return NS_ERROR_FAILURE;
   }
@@ -618,8 +568,7 @@ nsPluginStreamListenerPeer::GetInterfaceGlobal(const nsIID& aIID, void** result)
 }
 
 NS_IMETHODIMP
-nsPluginStreamListenerPeer::GetInterface(const nsIID& aIID, void** result)
-{
+nsPluginStreamListenerPeer::GetInterface(const nsIID& aIID, void** result) {
   // Provide nsIChannelEventSink ourselves, otherwise let our document's
   // script global object owner provide the interface.
   if (aIID.Equals(NS_GET_IID(nsIChannelEventSink))) {
@@ -634,35 +583,32 @@ nsPluginStreamListenerPeer::GetInterface(const nsIID& aIID, void** result)
  * callback, keeping nsPluginStreamListenerPeer::mRequests in sync with
  * which channel is active.
  */
-class ChannelRedirectProxyCallback : public nsIAsyncVerifyRedirectCallback
-{
-public:
+class ChannelRedirectProxyCallback : public nsIAsyncVerifyRedirectCallback {
+ public:
   ChannelRedirectProxyCallback(nsPluginStreamListenerPeer* listener,
                                nsIAsyncVerifyRedirectCallback* parent,
-                               nsIChannel* oldChannel,
-                               nsIChannel* newChannel)
-    : mWeakListener(do_GetWeakReference(static_cast<nsIStreamListener*>(listener)))
-    , mParent(parent)
-    , mOldChannel(oldChannel)
-    , mNewChannel(newChannel)
-  {
-  }
+                               nsIChannel* oldChannel, nsIChannel* newChannel)
+      : mWeakListener(
+            do_GetWeakReference(static_cast<nsIStreamListener*>(listener))),
+        mParent(parent),
+        mOldChannel(oldChannel),
+        mNewChannel(newChannel) {}
 
   ChannelRedirectProxyCallback() {}
 
   NS_DECL_ISUPPORTS
 
-  NS_IMETHOD OnRedirectVerifyCallback(nsresult aResult) override
-  {
+  NS_IMETHOD OnRedirectVerifyCallback(nsresult aResult) override {
     if (NS_SUCCEEDED(aResult)) {
       nsCOMPtr<nsIStreamListener> listener = do_QueryReferent(mWeakListener);
       if (listener)
-        static_cast<nsPluginStreamListenerPeer*>(listener.get())->ReplaceRequest(mOldChannel, mNewChannel);
+        static_cast<nsPluginStreamListenerPeer*>(listener.get())
+            ->ReplaceRequest(mOldChannel, mNewChannel);
     }
     return mParent->OnRedirectVerifyCallback(aResult);
   }
 
-private:
+ private:
   virtual ~ChannelRedirectProxyCallback() {}
 
   nsWeakPtr mWeakListener;
@@ -673,11 +619,10 @@ private:
 
 NS_IMPL_ISUPPORTS(ChannelRedirectProxyCallback, nsIAsyncVerifyRedirectCallback)
 
-
 NS_IMETHODIMP
-nsPluginStreamListenerPeer::AsyncOnChannelRedirect(nsIChannel *oldChannel, nsIChannel *newChannel,
-                                                   uint32_t flags, nsIAsyncVerifyRedirectCallback* callback)
-{
+nsPluginStreamListenerPeer::AsyncOnChannelRedirect(
+    nsIChannel* oldChannel, nsIChannel* newChannel, uint32_t flags,
+    nsIAsyncVerifyRedirectCallback* callback) {
   // Disallow redirects if we don't have a stream listener.
   if (!mPStreamListener) {
     return NS_ERROR_FAILURE;
@@ -707,20 +652,23 @@ nsPluginStreamListenerPeer::AsyncOnChannelRedirect(nsIChannel *oldChannel, nsICh
   }
 
   nsCOMPtr<nsIAsyncVerifyRedirectCallback> proxyCallback =
-    new ChannelRedirectProxyCallback(this, callback, oldChannel, newChannel);
+      new ChannelRedirectProxyCallback(this, callback, oldChannel, newChannel);
 
   // Give NPAPI a chance to control redirects.
-  bool notificationHandled = mPStreamListener->HandleRedirectNotification(oldChannel, newChannel, proxyCallback);
+  bool notificationHandled = mPStreamListener->HandleRedirectNotification(
+      oldChannel, newChannel, proxyCallback);
   if (notificationHandled) {
     return NS_OK;
   }
 
   // Fall back to channel event sink for window.
   nsCOMPtr<nsIChannelEventSink> channelEventSink;
-  nsresult rv = GetInterfaceGlobal(NS_GET_IID(nsIChannelEventSink), getter_AddRefs(channelEventSink));
+  nsresult rv = GetInterfaceGlobal(NS_GET_IID(nsIChannelEventSink),
+                                   getter_AddRefs(channelEventSink));
   if (NS_FAILED(rv)) {
     return rv;
   }
 
-  return channelEventSink->AsyncOnChannelRedirect(oldChannel, newChannel, flags, proxyCallback);
+  return channelEventSink->AsyncOnChannelRedirect(oldChannel, newChannel, flags,
+                                                  proxyCallback);
 }
