@@ -23,19 +23,17 @@ namespace dom {
 
 namespace {
 
-class PresentationTransportBuilderConstructorIPC final :
-  public nsIPresentationTransportBuilderConstructor
-{
-public:
+class PresentationTransportBuilderConstructorIPC final
+    : public nsIPresentationTransportBuilderConstructor {
+ public:
   NS_DECL_ISUPPORTS
   NS_DECL_NSIPRESENTATIONTRANSPORTBUILDERCONSTRUCTOR
 
-  explicit PresentationTransportBuilderConstructorIPC(PresentationParent* aParent)
-    : mParent(aParent)
-  {
-  }
+  explicit PresentationTransportBuilderConstructorIPC(
+      PresentationParent* aParent)
+      : mParent(aParent) {}
 
-private:
+ private:
   virtual ~PresentationTransportBuilderConstructorIPC() = default;
 
   RefPtr<PresentationParent> mParent;
@@ -46,9 +44,7 @@ NS_IMPL_ISUPPORTS(PresentationTransportBuilderConstructorIPC,
 
 NS_IMETHODIMP
 PresentationTransportBuilderConstructorIPC::CreateTransportBuilder(
-                              uint8_t aType,
-                              nsIPresentationSessionTransportBuilder** aRetval)
-{
+    uint8_t aType, nsIPresentationSessionTransportBuilder** aRetval) {
   if (NS_WARN_IF(!aRetval)) {
     return NS_ERROR_INVALID_ARG;
   }
@@ -56,7 +52,8 @@ PresentationTransportBuilderConstructorIPC::CreateTransportBuilder(
   *aRetval = nullptr;
 
   if (NS_WARN_IF(aType != nsIPresentationChannelDescription::TYPE_TCP &&
-                 aType != nsIPresentationChannelDescription::TYPE_DATACHANNEL)) {
+                 aType !=
+                     nsIPresentationChannelDescription::TYPE_DATACHANNEL)) {
     return NS_ERROR_INVALID_ARG;
   }
 
@@ -81,55 +78,45 @@ PresentationTransportBuilderConstructorIPC::CreateTransportBuilder(
   return NS_OK;
 }
 
-} // anonymous namespace
+}  // anonymous namespace
 
 /*
  * Implementation of PresentationParent
  */
 
-NS_IMPL_ISUPPORTS(PresentationParent,
-                  nsIPresentationAvailabilityListener,
+NS_IMPL_ISUPPORTS(PresentationParent, nsIPresentationAvailabilityListener,
                   nsIPresentationSessionListener,
                   nsIPresentationRespondingListener)
 
-PresentationParent::PresentationParent()
-{
-}
+PresentationParent::PresentationParent() {}
 
-/* virtual */ PresentationParent::~PresentationParent()
-{
-}
+/* virtual */ PresentationParent::~PresentationParent() {}
 
-bool
-PresentationParent::Init(ContentParentId aContentParentId)
-{
+bool PresentationParent::Init(ContentParentId aContentParentId) {
   MOZ_ASSERT(!mService);
   mService = do_GetService(PRESENTATION_SERVICE_CONTRACTID);
   mChildId = aContentParentId;
   return NS_WARN_IF(!mService) ? false : true;
 }
 
-void
-PresentationParent::ActorDestroy(ActorDestroyReason aWhy)
-{
+void PresentationParent::ActorDestroy(ActorDestroyReason aWhy) {
   mActorDestroyed = true;
 
   for (uint32_t i = 0; i < mSessionIdsAtController.Length(); i++) {
-    Unused << NS_WARN_IF(NS_FAILED(mService->
-      UnregisterSessionListener(mSessionIdsAtController[i],
-                                nsIPresentationService::ROLE_CONTROLLER)));
+    Unused << NS_WARN_IF(NS_FAILED(mService->UnregisterSessionListener(
+        mSessionIdsAtController[i], nsIPresentationService::ROLE_CONTROLLER)));
   }
   mSessionIdsAtController.Clear();
 
   for (uint32_t i = 0; i < mSessionIdsAtReceiver.Length(); i++) {
-    Unused << NS_WARN_IF(NS_FAILED(mService->
-      UnregisterSessionListener(mSessionIdsAtReceiver[i], nsIPresentationService::ROLE_RECEIVER)));
+    Unused << NS_WARN_IF(NS_FAILED(mService->UnregisterSessionListener(
+        mSessionIdsAtReceiver[i], nsIPresentationService::ROLE_RECEIVER)));
   }
   mSessionIdsAtReceiver.Clear();
 
   for (uint32_t i = 0; i < mWindowIds.Length(); i++) {
-    Unused << NS_WARN_IF(NS_FAILED(mService->
-      UnregisterRespondingListener(mWindowIds[i])));
+    Unused << NS_WARN_IF(
+        NS_FAILED(mService->UnregisterRespondingListener(mWindowIds[i])));
   }
   mWindowIds.Clear();
 
@@ -139,12 +126,11 @@ PresentationParent::ActorDestroy(ActorDestroyReason aWhy)
   mService = nullptr;
 }
 
-mozilla::ipc::IPCResult
-PresentationParent::RecvPPresentationRequestConstructor(
-  PPresentationRequestParent* aActor,
-  const PresentationIPCRequest& aRequest)
-{
-  PresentationRequestParent* actor = static_cast<PresentationRequestParent*>(aActor);
+mozilla::ipc::IPCResult PresentationParent::RecvPPresentationRequestConstructor(
+    PPresentationRequestParent* aActor,
+    const PresentationIPCRequest& aRequest) {
+  PresentationRequestParent* actor =
+      static_cast<PresentationRequestParent*>(aActor);
 
   nsresult rv = NS_ERROR_FAILURE;
   switch (aRequest.type()) {
@@ -176,67 +162,54 @@ PresentationParent::RecvPPresentationRequestConstructor(
   return IPC_OK();
 }
 
-PPresentationRequestParent*
-PresentationParent::AllocPPresentationRequestParent(
-  const PresentationIPCRequest& aRequest)
-{
+PPresentationRequestParent* PresentationParent::AllocPPresentationRequestParent(
+    const PresentationIPCRequest& aRequest) {
   MOZ_ASSERT(mService);
-  RefPtr<PresentationRequestParent> actor = new PresentationRequestParent(mService, mChildId);
+  RefPtr<PresentationRequestParent> actor =
+      new PresentationRequestParent(mService, mChildId);
   return actor.forget().take();
 }
 
-bool
-PresentationParent::DeallocPPresentationRequestParent(
-  PPresentationRequestParent* aActor)
-{
+bool PresentationParent::DeallocPPresentationRequestParent(
+    PPresentationRequestParent* aActor) {
   RefPtr<PresentationRequestParent> actor =
-    dont_AddRef(static_cast<PresentationRequestParent*>(aActor));
+      dont_AddRef(static_cast<PresentationRequestParent*>(aActor));
   return true;
 }
 
-PPresentationBuilderParent*
-PresentationParent::AllocPPresentationBuilderParent(const nsString& aSessionId,
-                                                    const uint8_t& aRole)
-{
-  NS_NOTREACHED("We should never be manually allocating AllocPPresentationBuilderParent actors");
+PPresentationBuilderParent* PresentationParent::AllocPPresentationBuilderParent(
+    const nsString& aSessionId, const uint8_t& aRole) {
+  NS_NOTREACHED(
+      "We should never be manually allocating AllocPPresentationBuilderParent "
+      "actors");
   return nullptr;
 }
 
-bool
-PresentationParent::DeallocPPresentationBuilderParent(
-  PPresentationBuilderParent* aActor)
-{
+bool PresentationParent::DeallocPPresentationBuilderParent(
+    PPresentationBuilderParent* aActor) {
   return true;
 }
 
-mozilla::ipc::IPCResult
-PresentationParent::Recv__delete__()
-{
+mozilla::ipc::IPCResult PresentationParent::Recv__delete__() {
   return IPC_OK();
 }
 
-mozilla::ipc::IPCResult
-PresentationParent::RecvRegisterAvailabilityHandler(
-                                       nsTArray<nsString>&& aAvailabilityUrls)
-{
+mozilla::ipc::IPCResult PresentationParent::RecvRegisterAvailabilityHandler(
+    nsTArray<nsString>&& aAvailabilityUrls) {
   MOZ_ASSERT(mService);
 
-  Unused << NS_WARN_IF(NS_FAILED(mService->RegisterAvailabilityListener(
-                                                             aAvailabilityUrls,
-                                                             this)));
+  Unused << NS_WARN_IF(NS_FAILED(
+      mService->RegisterAvailabilityListener(aAvailabilityUrls, this)));
   mContentAvailabilityUrls.AppendElements(aAvailabilityUrls);
   return IPC_OK();
 }
 
-mozilla::ipc::IPCResult
-PresentationParent::RecvUnregisterAvailabilityHandler(
-                                        nsTArray<nsString>&& aAvailabilityUrls)
-{
+mozilla::ipc::IPCResult PresentationParent::RecvUnregisterAvailabilityHandler(
+    nsTArray<nsString>&& aAvailabilityUrls) {
   MOZ_ASSERT(mService);
 
-  Unused << NS_WARN_IF(NS_FAILED(mService->UnregisterAvailabilityListener(
-                                                             aAvailabilityUrls,
-                                                             this)));
+  Unused << NS_WARN_IF(NS_FAILED(
+      mService->UnregisterAvailabilityListener(aAvailabilityUrls, this)));
   for (const auto& url : aAvailabilityUrls) {
     mContentAvailabilityUrls.RemoveElement(url);
   }
@@ -245,14 +218,13 @@ PresentationParent::RecvUnregisterAvailabilityHandler(
 
 /* virtual */ mozilla::ipc::IPCResult
 PresentationParent::RecvRegisterSessionHandler(const nsString& aSessionId,
-                                               const uint8_t& aRole)
-{
+                                               const uint8_t& aRole) {
   MOZ_ASSERT(mService);
 
   // Validate the accessibility (primarily for receiver side) so that a
   // compromised child process can't fake the ID.
-  if (NS_WARN_IF(!static_cast<PresentationService*>(mService.get())->
-                  IsSessionAccessible(aSessionId, aRole, OtherPid()))) {
+  if (NS_WARN_IF(!static_cast<PresentationService*>(mService.get())
+                      ->IsSessionAccessible(aSessionId, aRole, OtherPid()))) {
     return IPC_OK();
   }
 
@@ -261,50 +233,49 @@ PresentationParent::RecvRegisterSessionHandler(const nsString& aSessionId,
   } else {
     mSessionIdsAtReceiver.AppendElement(aSessionId);
   }
-  Unused << NS_WARN_IF(NS_FAILED(mService->RegisterSessionListener(aSessionId, aRole, this)));
+  Unused << NS_WARN_IF(
+      NS_FAILED(mService->RegisterSessionListener(aSessionId, aRole, this)));
   return IPC_OK();
 }
 
 /* virtual */ mozilla::ipc::IPCResult
 PresentationParent::RecvUnregisterSessionHandler(const nsString& aSessionId,
-                                                 const uint8_t& aRole)
-{
+                                                 const uint8_t& aRole) {
   MOZ_ASSERT(mService);
   if (nsIPresentationService::ROLE_CONTROLLER == aRole) {
     mSessionIdsAtController.RemoveElement(aSessionId);
   } else {
     mSessionIdsAtReceiver.RemoveElement(aSessionId);
   }
-  Unused << NS_WARN_IF(NS_FAILED(mService->UnregisterSessionListener(aSessionId, aRole)));
+  Unused << NS_WARN_IF(
+      NS_FAILED(mService->UnregisterSessionListener(aSessionId, aRole)));
   return IPC_OK();
 }
 
 /* virtual */ mozilla::ipc::IPCResult
-PresentationParent::RecvRegisterRespondingHandler(const uint64_t& aWindowId)
-{
+PresentationParent::RecvRegisterRespondingHandler(const uint64_t& aWindowId) {
   MOZ_ASSERT(mService);
 
   mWindowIds.AppendElement(aWindowId);
-  Unused << NS_WARN_IF(NS_FAILED(mService->RegisterRespondingListener(aWindowId, this)));
+  Unused << NS_WARN_IF(
+      NS_FAILED(mService->RegisterRespondingListener(aWindowId, this)));
   return IPC_OK();
 }
 
 /* virtual */ mozilla::ipc::IPCResult
-PresentationParent::RecvUnregisterRespondingHandler(const uint64_t& aWindowId)
-{
+PresentationParent::RecvUnregisterRespondingHandler(const uint64_t& aWindowId) {
   MOZ_ASSERT(mService);
   mWindowIds.RemoveElement(aWindowId);
-  Unused << NS_WARN_IF(NS_FAILED(mService->UnregisterRespondingListener(aWindowId)));
+  Unused << NS_WARN_IF(
+      NS_FAILED(mService->UnregisterRespondingListener(aWindowId)));
   return IPC_OK();
 }
 
 NS_IMETHODIMP
-PresentationParent::NotifyAvailableChange(const nsTArray<nsString>& aAvailabilityUrls,
-                                          bool aAvailable)
-{
+PresentationParent::NotifyAvailableChange(
+    const nsTArray<nsString>& aAvailabilityUrls, bool aAvailable) {
   if (NS_WARN_IF(mActorDestroyed ||
-                 !SendNotifyAvailableChange(aAvailabilityUrls,
-                                            aAvailable))) {
+                 !SendNotifyAvailableChange(aAvailabilityUrls, aAvailable))) {
     return NS_ERROR_FAILURE;
   }
   return NS_OK;
@@ -312,12 +283,9 @@ PresentationParent::NotifyAvailableChange(const nsTArray<nsString>& aAvailabilit
 
 NS_IMETHODIMP
 PresentationParent::NotifyStateChange(const nsAString& aSessionId,
-                                      uint16_t aState,
-                                      nsresult aReason)
-{
+                                      uint16_t aState, nsresult aReason) {
   if (NS_WARN_IF(mActorDestroyed ||
-                 !SendNotifySessionStateChange(nsString(aSessionId),
-                                               aState,
+                 !SendNotifySessionStateChange(nsString(aSessionId), aState,
                                                aReason))) {
     return NS_ERROR_FAILURE;
   }
@@ -326,12 +294,9 @@ PresentationParent::NotifyStateChange(const nsAString& aSessionId,
 
 NS_IMETHODIMP
 PresentationParent::NotifyMessage(const nsAString& aSessionId,
-                                  const nsACString& aData,
-                                  bool aIsBinary)
-{
+                                  const nsACString& aData, bool aIsBinary) {
   if (NS_WARN_IF(mActorDestroyed ||
-                 !SendNotifyMessage(nsString(aSessionId),
-                                    nsCString(aData),
+                 !SendNotifyMessage(nsString(aSessionId), nsCString(aData),
                                     aIsBinary))) {
     return NS_ERROR_FAILURE;
   }
@@ -340,8 +305,7 @@ PresentationParent::NotifyMessage(const nsAString& aSessionId,
 
 NS_IMETHODIMP
 PresentationParent::NotifySessionConnect(uint64_t aWindowId,
-                                         const nsAString& aSessionId)
-{
+                                         const nsAString& aSessionId) {
   if (NS_WARN_IF(mActorDestroyed ||
                  !SendNotifySessionConnect(aWindowId, nsString(aSessionId)))) {
     return NS_ERROR_FAILURE;
@@ -349,30 +313,24 @@ PresentationParent::NotifySessionConnect(uint64_t aWindowId,
   return NS_OK;
 }
 
-mozilla::ipc::IPCResult
-PresentationParent::RecvNotifyReceiverReady(const nsString& aSessionId,
-                                            const uint64_t& aWindowId,
-                                            const bool& aIsLoading)
-{
+mozilla::ipc::IPCResult PresentationParent::RecvNotifyReceiverReady(
+    const nsString& aSessionId, const uint64_t& aWindowId,
+    const bool& aIsLoading) {
   MOZ_ASSERT(mService);
 
   nsCOMPtr<nsIPresentationTransportBuilderConstructor> constructor =
-    new PresentationTransportBuilderConstructorIPC(this);
-  Unused << NS_WARN_IF(NS_FAILED(mService->NotifyReceiverReady(aSessionId,
-                                                               aWindowId,
-                                                               aIsLoading,
-                                                               constructor)));
+      new PresentationTransportBuilderConstructorIPC(this);
+  Unused << NS_WARN_IF(NS_FAILED(mService->NotifyReceiverReady(
+      aSessionId, aWindowId, aIsLoading, constructor)));
   return IPC_OK();
 }
 
-mozilla::ipc::IPCResult
-PresentationParent::RecvNotifyTransportClosed(const nsString& aSessionId,
-                                              const uint8_t& aRole,
-                                              const nsresult& aReason)
-{
+mozilla::ipc::IPCResult PresentationParent::RecvNotifyTransportClosed(
+    const nsString& aSessionId, const uint8_t& aRole, const nsresult& aReason) {
   MOZ_ASSERT(mService);
 
-  Unused << NS_WARN_IF(NS_FAILED(mService->NotifyTransportClosed(aSessionId, aRole, aReason)));
+  Unused << NS_WARN_IF(
+      NS_FAILED(mService->NotifyTransportClosed(aSessionId, aRole, aReason)));
   return IPC_OK();
 }
 
@@ -382,27 +340,19 @@ PresentationParent::RecvNotifyTransportClosed(const nsString& aSessionId,
 
 NS_IMPL_ISUPPORTS(PresentationRequestParent, nsIPresentationServiceCallback)
 
-PresentationRequestParent::PresentationRequestParent(nsIPresentationService* aService,
-                                                     ContentParentId aContentParentId)
-  : mService(aService)
-  , mChildId(aContentParentId)
-{
-}
+PresentationRequestParent::PresentationRequestParent(
+    nsIPresentationService* aService, ContentParentId aContentParentId)
+    : mService(aService), mChildId(aContentParentId) {}
 
-PresentationRequestParent::~PresentationRequestParent()
-{
-}
+PresentationRequestParent::~PresentationRequestParent() {}
 
-void
-PresentationRequestParent::ActorDestroy(ActorDestroyReason aWhy)
-{
+void PresentationRequestParent::ActorDestroy(ActorDestroyReason aWhy) {
   mActorDestroyed = true;
   mService = nullptr;
 }
 
-nsresult
-PresentationRequestParent::DoRequest(const StartSessionRequest& aRequest)
-{
+nsresult PresentationRequestParent::DoRequest(
+    const StartSessionRequest& aRequest) {
   MOZ_ASSERT(mService);
 
   mSessionId = aRequest.sessionId();
@@ -410,55 +360,54 @@ PresentationRequestParent::DoRequest(const StartSessionRequest& aRequest)
   nsCOMPtr<nsIDOMEventTarget> eventTarget;
   ContentProcessManager* cpm = ContentProcessManager::GetSingleton();
   RefPtr<TabParent> tp =
-    cpm->GetTopLevelTabParentByProcessAndTabId(mChildId, aRequest.tabId());
+      cpm->GetTopLevelTabParentByProcessAndTabId(mChildId, aRequest.tabId());
   if (tp) {
     eventTarget = do_QueryInterface(tp->GetOwnerElement());
   }
 
-  RefPtr<PresentationParent> parent = static_cast<PresentationParent*>(Manager());
+  RefPtr<PresentationParent> parent =
+      static_cast<PresentationParent*>(Manager());
   nsCOMPtr<nsIPresentationTransportBuilderConstructor> constructor =
-    new PresentationTransportBuilderConstructorIPC(parent);
+      new PresentationTransportBuilderConstructorIPC(parent);
   return mService->StartSession(aRequest.urls(), aRequest.sessionId(),
                                 aRequest.origin(), aRequest.deviceId(),
                                 aRequest.windowId(), eventTarget,
                                 aRequest.principal(), this, constructor);
 }
 
-nsresult
-PresentationRequestParent::DoRequest(const SendSessionMessageRequest& aRequest)
-{
+nsresult PresentationRequestParent::DoRequest(
+    const SendSessionMessageRequest& aRequest) {
   MOZ_ASSERT(mService);
 
   // Validate the accessibility (primarily for receiver side) so that a
   // compromised child process can't fake the ID.
-  if (NS_WARN_IF(!static_cast<PresentationService*>(mService.get())->
-                  IsSessionAccessible(aRequest.sessionId(), aRequest.role(), OtherPid()))) {
+  if (NS_WARN_IF(!static_cast<PresentationService*>(mService.get())
+                      ->IsSessionAccessible(aRequest.sessionId(),
+                                            aRequest.role(), OtherPid()))) {
     return SendResponse(NS_ERROR_DOM_SECURITY_ERR);
   }
 
   nsresult rv = mService->SendSessionMessage(aRequest.sessionId(),
-                                             aRequest.role(),
-                                             aRequest.data());
+                                             aRequest.role(), aRequest.data());
   if (NS_WARN_IF(NS_FAILED(rv))) {
     return SendResponse(rv);
   }
   return SendResponse(NS_OK);
 }
 
-nsresult
-PresentationRequestParent::DoRequest(const CloseSessionRequest& aRequest)
-{
+nsresult PresentationRequestParent::DoRequest(
+    const CloseSessionRequest& aRequest) {
   MOZ_ASSERT(mService);
 
   // Validate the accessibility (primarily for receiver side) so that a
   // compromised child process can't fake the ID.
-  if (NS_WARN_IF(!static_cast<PresentationService*>(mService.get())->
-                  IsSessionAccessible(aRequest.sessionId(), aRequest.role(), OtherPid()))) {
+  if (NS_WARN_IF(!static_cast<PresentationService*>(mService.get())
+                      ->IsSessionAccessible(aRequest.sessionId(),
+                                            aRequest.role(), OtherPid()))) {
     return SendResponse(NS_ERROR_DOM_SECURITY_ERR);
   }
 
-  nsresult rv = mService->CloseSession(aRequest.sessionId(),
-                                       aRequest.role(),
+  nsresult rv = mService->CloseSession(aRequest.sessionId(), aRequest.role(),
                                        aRequest.closedReason());
   if (NS_WARN_IF(NS_FAILED(rv))) {
     return SendResponse(rv);
@@ -466,56 +415,54 @@ PresentationRequestParent::DoRequest(const CloseSessionRequest& aRequest)
   return SendResponse(NS_OK);
 }
 
-nsresult
-PresentationRequestParent::DoRequest(const TerminateSessionRequest& aRequest)
-{
+nsresult PresentationRequestParent::DoRequest(
+    const TerminateSessionRequest& aRequest) {
   MOZ_ASSERT(mService);
 
   // Validate the accessibility (primarily for receiver side) so that a
   // compromised child process can't fake the ID.
-  if (NS_WARN_IF(!static_cast<PresentationService*>(mService.get())->
-                  IsSessionAccessible(aRequest.sessionId(), aRequest.role(), OtherPid()))) {
+  if (NS_WARN_IF(!static_cast<PresentationService*>(mService.get())
+                      ->IsSessionAccessible(aRequest.sessionId(),
+                                            aRequest.role(), OtherPid()))) {
     return SendResponse(NS_ERROR_DOM_SECURITY_ERR);
   }
 
-  nsresult rv = mService->TerminateSession(aRequest.sessionId(), aRequest.role());
+  nsresult rv =
+      mService->TerminateSession(aRequest.sessionId(), aRequest.role());
   if (NS_WARN_IF(NS_FAILED(rv))) {
     return SendResponse(rv);
   }
   return SendResponse(NS_OK);
 }
 
-nsresult
-PresentationRequestParent::DoRequest(const ReconnectSessionRequest& aRequest)
-{
+nsresult PresentationRequestParent::DoRequest(
+    const ReconnectSessionRequest& aRequest) {
   MOZ_ASSERT(mService);
 
   // Validate the accessibility (primarily for receiver side) so that a
   // compromised child process can't fake the ID.
-  if (NS_WARN_IF(!static_cast<PresentationService*>(mService.get())->
-    IsSessionAccessible(aRequest.sessionId(), aRequest.role(), OtherPid()))) {
-
+  if (NS_WARN_IF(!static_cast<PresentationService*>(mService.get())
+                      ->IsSessionAccessible(aRequest.sessionId(),
+                                            aRequest.role(), OtherPid()))) {
     // NOTE: Return NS_ERROR_DOM_NOT_FOUND_ERR here to match the spec.
     // https://w3c.github.io/presentation-api/#reconnecting-to-a-presentation
     return SendResponse(NS_ERROR_DOM_NOT_FOUND_ERR);
   }
 
   mSessionId = aRequest.sessionId();
-  return mService->ReconnectSession(aRequest.urls(),
-                                    aRequest.sessionId(),
-                                    aRequest.role(),
-                                    this);
+  return mService->ReconnectSession(aRequest.urls(), aRequest.sessionId(),
+                                    aRequest.role(), this);
 }
 
-nsresult
-PresentationRequestParent::DoRequest(const BuildTransportRequest& aRequest)
-{
+nsresult PresentationRequestParent::DoRequest(
+    const BuildTransportRequest& aRequest) {
   MOZ_ASSERT(mService);
 
   // Validate the accessibility (primarily for receiver side) so that a
   // compromised child process can't fake the ID.
-  if (NS_WARN_IF(!static_cast<PresentationService*>(mService.get())->
-                  IsSessionAccessible(aRequest.sessionId(), aRequest.role(), OtherPid()))) {
+  if (NS_WARN_IF(!static_cast<PresentationService*>(mService.get())
+                      ->IsSessionAccessible(aRequest.sessionId(),
+                                            aRequest.role(), OtherPid()))) {
     return SendResponse(NS_ERROR_DOM_SECURITY_ERR);
   }
 
@@ -527,21 +474,17 @@ PresentationRequestParent::DoRequest(const BuildTransportRequest& aRequest)
 }
 
 NS_IMETHODIMP
-PresentationRequestParent::NotifySuccess(const nsAString& aUrl)
-{
+PresentationRequestParent::NotifySuccess(const nsAString& aUrl) {
   Unused << SendNotifyRequestUrlSelected(nsString(aUrl));
   return SendResponse(NS_OK);
 }
 
 NS_IMETHODIMP
-PresentationRequestParent::NotifyError(nsresult aError)
-{
+PresentationRequestParent::NotifyError(nsresult aError) {
   return SendResponse(aError);
 }
 
-nsresult
-PresentationRequestParent::SendResponse(nsresult aResult)
-{
+nsresult PresentationRequestParent::SendResponse(nsresult aResult) {
   if (NS_WARN_IF(mActorDestroyed || !Send__delete__(this, aResult))) {
     return NS_ERROR_FAILURE;
   }
@@ -549,5 +492,5 @@ PresentationRequestParent::SendResponse(nsresult aResult)
   return NS_OK;
 }
 
-} // namespace dom
-} // namespace mozilla
+}  // namespace dom
+}  // namespace mozilla
