@@ -30,8 +30,8 @@
 class nsIURI;
 
 namespace JS {
-  class SourceBufferHolder;
-} // namespace JS
+class SourceBufferHolder;
+}  // namespace JS
 
 namespace mozilla {
 namespace dom {
@@ -46,25 +46,21 @@ class ScriptRequestProcessor;
 // Script loader implementation
 //////////////////////////////////////////////////////////////
 
-class ScriptLoader final : public nsISupports
-{
-  class MOZ_STACK_CLASS AutoCurrentScriptUpdater
-  {
-  public:
+class ScriptLoader final : public nsISupports {
+  class MOZ_STACK_CLASS AutoCurrentScriptUpdater {
+   public:
     AutoCurrentScriptUpdater(ScriptLoader* aScriptLoader,
                              nsIScriptElement* aCurrentScript)
-      : mOldScript(aScriptLoader->mCurrentScript)
-      , mScriptLoader(aScriptLoader)
-    {
+        : mOldScript(aScriptLoader->mCurrentScript),
+          mScriptLoader(aScriptLoader) {
       mScriptLoader->mCurrentScript = aCurrentScript;
     }
 
-    ~AutoCurrentScriptUpdater()
-    {
+    ~AutoCurrentScriptUpdater() {
       mScriptLoader->mCurrentScript.swap(mOldScript);
     }
 
-  private:
+   private:
     nsCOMPtr<nsIScriptElement> mOldScript;
     ScriptLoader* mScriptLoader;
   };
@@ -74,7 +70,7 @@ class ScriptLoader final : public nsISupports
   friend class ScriptLoadHandler;
   friend class AutoCurrentScriptUpdater;
 
-public:
+ public:
   explicit ScriptLoader(nsIDocument* aDocument);
 
   NS_DECL_CYCLE_COLLECTING_ISUPPORTS
@@ -85,20 +81,15 @@ public:
    * which it is initialized. This call forces the reference to
    * be dropped.
    */
-  void DropDocumentReference()
-  {
-    mDocument = nullptr;
-  }
+  void DropDocumentReference() { mDocument = nullptr; }
 
   /**
    * Add an observer for all scripts loaded through this loader.
    *
    * @param aObserver observer for all script processing.
    */
-  nsresult AddObserver(nsIScriptLoaderObserver* aObserver)
-  {
-    return mObservers.AppendObject(aObserver) ? NS_OK :
-      NS_ERROR_OUT_OF_MEMORY;
+  nsresult AddObserver(nsIScriptLoaderObserver* aObserver) {
+    return mObservers.AppendObject(aObserver) ? NS_OK : NS_ERROR_OUT_OF_MEMORY;
   }
 
   /**
@@ -106,8 +97,7 @@ public:
    *
    * @param aObserver observer to be removed
    */
-  void RemoveObserver(nsIScriptLoaderObserver* aObserver)
-  {
+  void RemoveObserver(nsIScriptLoaderObserver* aObserver) {
     mObservers.RemoveObject(aObserver);
   }
 
@@ -133,13 +123,9 @@ public:
    * Gets the currently executing script. This is useful if you want to
    * generate a unique key based on the currently executing script.
    */
-  nsIScriptElement* GetCurrentScript()
-  {
-    return mCurrentScript;
-  }
+  nsIScriptElement* GetCurrentScript() { return mCurrentScript; }
 
-  nsIScriptElement* GetCurrentParserInsertedScript()
-  {
+  nsIScriptElement* GetCurrentParserInsertedScript() {
     return mCurrentParserInsertedScript;
   }
 
@@ -149,13 +135,9 @@ public:
    * Any call to ProcessScriptElement() will return false. Note that
    * this DOES NOT disable currently loading or executing scripts.
    */
-  bool GetEnabled()
-  {
-    return mEnabled;
-  }
+  bool GetEnabled() { return mEnabled; }
 
-  void SetEnabled(bool aEnabled)
-  {
+  void SetEnabled(bool aEnabled) {
     if (!mEnabled && aEnabled) {
       ProcessPendingRequestsAsync();
     }
@@ -167,13 +149,11 @@ public:
    * scripts). Blockers will stop such scripts from executing, but not from
    * loading.
    */
-  void AddParserBlockingScriptExecutionBlocker()
-  {
+  void AddParserBlockingScriptExecutionBlocker() {
     ++mParserBlockingBlockerCount;
   }
 
-  void RemoveParserBlockingScriptExecutionBlocker()
-  {
+  void RemoveParserBlockingScriptExecutionBlocker() {
     if (!--mParserBlockingBlockerCount && ReadyToExecuteScripts()) {
       ProcessPendingRequestsAsync();
     }
@@ -183,13 +163,9 @@ public:
    * Add/remove a blocker for execution of all scripts.  Blockers will stop
    * scripts from executing, but not from loading.
    */
-  void AddExecuteBlocker()
-  {
-    ++mBlockerCount;
-  }
+  void AddExecuteBlocker() { ++mBlockerCount; }
 
-  void RemoveExecuteBlocker()
-  {
+  void RemoveExecuteBlocker() {
     MOZ_ASSERT(mBlockerCount);
     if (!--mBlockerCount) {
       ProcessPendingRequestsAsync();
@@ -214,15 +190,15 @@ public:
   static nsresult ConvertToUTF16(nsIChannel* aChannel, const uint8_t* aData,
                                  uint32_t aLength,
                                  const nsAString& aHintCharset,
-                                 nsIDocument* aDocument,
-                                 char16_t*& aBufOut, size_t& aLengthOut);
+                                 nsIDocument* aDocument, char16_t*& aBufOut,
+                                 size_t& aLengthOut);
 
-  static inline nsresult
-  ConvertToUTF16(nsIChannel* aChannel, const uint8_t* aData,
-                 uint32_t aLength, const nsAString& aHintCharset,
-                 nsIDocument* aDocument,
-                 JS::UniqueTwoByteChars& aBufOut, size_t& aLengthOut)
-  {
+  static inline nsresult ConvertToUTF16(nsIChannel* aChannel,
+                                        const uint8_t* aData, uint32_t aLength,
+                                        const nsAString& aHintCharset,
+                                        nsIDocument* aDocument,
+                                        JS::UniqueTwoByteChars& aBufOut,
+                                        size_t& aLengthOut) {
     char16_t* bufOut;
     nsresult rv = ConvertToUTF16(aChannel, aData, aLength, aHintCharset,
                                  aDocument, bufOut, aLengthOut);
@@ -240,8 +216,7 @@ public:
    */
   nsresult OnStreamComplete(nsIIncrementalStreamLoader* aLoader,
                             ScriptLoadRequest* aRequest,
-                            nsresult aChannelStatus,
-                            nsresult aSRIStatus,
+                            nsresult aChannelStatus, nsresult aSRIStatus,
                             SRICheckDataVerifier* aSRIDataVerifier);
 
   /**
@@ -258,8 +233,7 @@ public:
    * Starts deferring deferred scripts and puts them in the mDeferredRequests
    * queue instead.
    */
-  void BeginDeferringScripts()
-  {
+  void BeginDeferringScripts() {
     mDeferEnabled = true;
     if (mDocument) {
       mDocument->BlockOnload();
@@ -280,8 +254,7 @@ public:
   /**
    * Returns the number of pending scripts, deferred or not.
    */
-  uint32_t HasPendingOrCurrentScripts()
-  {
+  uint32_t HasPendingOrCurrentScripts() {
     return mCurrentScript || mParserBlockingRequest;
   }
 
@@ -296,15 +269,10 @@ public:
    * @param aIntegrity The expect hash url, if avail, of the request
    * @param aScriptFromHead Whether or not the script was a child of head
    */
-  virtual void PreloadURI(nsIURI* aURI,
-                          const nsAString& aCharset,
-                          const nsAString& aType,
-                          const nsAString& aCrossOrigin,
-                          const nsAString& aIntegrity,
-                          bool aScriptFromHead,
-                          bool aAsync,
-                          bool aDefer,
-                          bool aNoModule,
+  virtual void PreloadURI(nsIURI* aURI, const nsAString& aCharset,
+                          const nsAString& aType, const nsAString& aCrossOrigin,
+                          const nsAString& aIntegrity, bool aScriptFromHead,
+                          bool aAsync, bool aDefer, bool aNoModule,
                           const mozilla::net::ReferrerPolicy aReferrerPolicy);
 
   /**
@@ -313,13 +281,11 @@ public:
    */
   nsresult ProcessOffThreadRequest(ScriptLoadRequest* aRequest);
 
-  bool AddPendingChildLoader(ScriptLoader* aChild)
-  {
+  bool AddPendingChildLoader(ScriptLoader* aChild) {
     return mPendingChildLoaders.AppendElement(aChild) != nullptr;
   }
 
-  mozilla::dom::DocGroup* GetDocGroup() const
-  {
+  mozilla::dom::DocGroup* GetDocGroup() const {
     return mDocument->GetDocGroup();
   }
 
@@ -335,20 +301,21 @@ public:
    * any references to the JSScript or to the Request which might be used for
    * caching the encoded bytecode.
    */
-  void Destroy()
-  {
-    GiveUpBytecodeEncoding();
-  }
+  void Destroy() { GiveUpBytecodeEncoding(); }
 
-private:
+  /*
+   * Clear the map of loaded modules. Called when a Document object is reused
+   * for a different global.
+   */
+  void ClearModuleMap();
+
+ private:
   virtual ~ScriptLoader();
 
-  ScriptLoadRequest* CreateLoadRequest(ScriptKind aKind,
-                                       nsIURI* aURI,
-                                       nsIScriptElement* aElement,
-                                       mozilla::CORSMode aCORSMode,
-                                       const SRIMetadata& aIntegrity,
-                                       mozilla::net::ReferrerPolicy aReferrerPolicy);
+  ScriptLoadRequest* CreateLoadRequest(
+      ScriptKind aKind, nsIURI* aURI, nsIScriptElement* aElement,
+      mozilla::CORSMode aCORSMode, const SRIMetadata& aIntegrity,
+      mozilla::net::ReferrerPolicy aReferrerPolicy);
 
   /**
    * Unblocks the creator parser of the parser-blocking scripts.
@@ -360,29 +327,24 @@ private:
    */
   void ContinueParserAsync(ScriptLoadRequest* aParserBlockingRequest);
 
-
-  bool ProcessExternalScript(nsIScriptElement* aElement,
-                             ScriptKind aScriptKind,
+  bool ProcessExternalScript(nsIScriptElement* aElement, ScriptKind aScriptKind,
                              nsAutoString aTypeAttr,
                              nsIContent* aScriptContent);
 
-  bool ProcessInlineScript(nsIScriptElement* aElement,
-                           ScriptKind aScriptKind);
+  bool ProcessInlineScript(nsIScriptElement* aElement, ScriptKind aScriptKind);
 
   ScriptLoadRequest* LookupPreloadRequest(nsIScriptElement* aElement,
                                           ScriptKind aScriptKind);
 
   void GetSRIMetadata(const nsAString& aIntegrityAttr,
-                      SRIMetadata *aMetadataOut);
+                      SRIMetadata* aMetadataOut);
 
   /**
    * Helper function to check the content policy for a given request.
    */
   static nsresult CheckContentPolicy(nsIDocument* aDocument,
-                                     nsISupports* aContext,
-                                     nsIURI* aURI,
-                                     const nsAString& aType,
-                                     bool aIsPreLoad);
+                                     nsISupports* aContext, nsIURI* aURI,
+                                     const nsAString& aType, bool aIsPreLoad);
 
   /**
    * Start a load for aRequest's URI.
@@ -396,7 +358,7 @@ private:
    */
   nsresult RestartLoad(ScriptLoadRequest* aRequest);
 
-  void HandleLoadError(ScriptLoadRequest *aRequest, nsresult aResult);
+  void HandleLoadError(ScriptLoadRequest* aRequest, nsresult aResult);
 
   /**
    * Process any pending requests asynchronously (i.e. off an event) if there
@@ -419,36 +381,30 @@ private:
    * Return whether just this loader is ready to execute parser-blocking
    * scripts.
    */
-  bool SelfReadyToExecuteParserBlockingScripts()
-  {
+  bool SelfReadyToExecuteParserBlockingScripts() {
     return ReadyToExecuteScripts() && !mParserBlockingBlockerCount;
   }
 
   /**
    * Return whether this loader is ready to execute scripts in general.
    */
-  bool ReadyToExecuteScripts()
-  {
-    return mEnabled && !mBlockerCount;
-  }
+  bool ReadyToExecuteScripts() { return mEnabled && !mBlockerCount; }
 
-  nsresult VerifySRI(ScriptLoadRequest *aRequest,
-                     nsIIncrementalStreamLoader* aLoader,
-                     nsresult aSRIStatus,
+  nsresult VerifySRI(ScriptLoadRequest* aRequest,
+                     nsIIncrementalStreamLoader* aLoader, nsresult aSRIStatus,
                      SRICheckDataVerifier* aSRIDataVerifier) const;
 
-  nsresult SaveSRIHash(ScriptLoadRequest *aRequest,
+  nsresult SaveSRIHash(ScriptLoadRequest* aRequest,
                        SRICheckDataVerifier* aSRIDataVerifier) const;
 
-  void ReportErrorToConsole(ScriptLoadRequest *aRequest, nsresult aResult) const;
+  void ReportErrorToConsole(ScriptLoadRequest* aRequest,
+                            nsresult aResult) const;
 
   nsresult AttemptAsyncScriptCompile(ScriptLoadRequest* aRequest);
   nsresult ProcessRequest(ScriptLoadRequest* aRequest);
   nsresult CompileOffThreadOrProcessRequest(ScriptLoadRequest* aRequest);
-  void FireScriptAvailable(nsresult aResult,
-                           ScriptLoadRequest* aRequest);
-  void FireScriptEvaluated(nsresult aResult,
-                           ScriptLoadRequest* aRequest);
+  void FireScriptAvailable(nsresult aResult, ScriptLoadRequest* aRequest);
+  void FireScriptEvaluated(nsresult aResult, ScriptLoadRequest* aRequest);
   nsresult EvaluateScript(ScriptLoadRequest* aRequest);
 
   /**
@@ -495,9 +451,9 @@ private:
   JS::SourceBufferHolder GetScriptSource(ScriptLoadRequest* aRequest,
                                          nsAutoString& inlineData);
 
-  void SetModuleFetchStarted(ModuleLoadRequest *aRequest);
-  void SetModuleFetchFinishedAndResumeWaitingRequests(ModuleLoadRequest* aRequest,
-                                                      nsresult aResult);
+  void SetModuleFetchStarted(ModuleLoadRequest* aRequest);
+  void SetModuleFetchFinishedAndResumeWaitingRequests(
+      ModuleLoadRequest* aRequest, nsresult aResult);
 
   bool IsFetchingModule(ModuleLoadRequest* aRequest) const;
 
@@ -505,13 +461,12 @@ private:
   RefPtr<mozilla::GenericPromise> WaitForModuleFetch(nsIURI* aURL);
   ModuleScript* GetFetchedModule(nsIURI* aURL) const;
 
-  friend bool
-  HostResolveImportedModule(JSContext* aCx, unsigned argc, JS::Value* vp);
+  friend bool HostResolveImportedModule(JSContext* aCx, unsigned argc,
+                                        JS::Value* vp);
 
   // Returns wether we should save the bytecode of this script after the
   // execution of the script.
-  static bool
-  ShouldCacheBytecode(ScriptLoadRequest* aRequest);
+  static bool ShouldCacheBytecode(ScriptLoadRequest* aRequest);
 
   nsresult CreateModuleScript(ModuleLoadRequest* aRequest);
   nsresult ProcessFetchedModuleSource(ModuleLoadRequest* aRequest);
@@ -521,10 +476,10 @@ private:
   JS::Value FindFirstParseError(ModuleLoadRequest* aRequest);
   void StartFetchingModuleDependencies(ModuleLoadRequest* aRequest);
 
-  RefPtr<mozilla::GenericPromise>
-  StartFetchingModuleAndDependencies(ModuleLoadRequest* aParent, nsIURI* aURI);
+  RefPtr<mozilla::GenericPromise> StartFetchingModuleAndDependencies(
+      ModuleLoadRequest* aParent, nsIURI* aURI);
 
-  nsIDocument* mDocument;                   // [WEAK]
+  nsIDocument* mDocument;  // [WEAK]
   nsCOMArray<nsIScriptLoaderObserver> mObservers;
   ScriptLoadRequestList mNonAsyncExternalScriptInsertedRequests;
   // mLoadingAsyncRequests holds async requests while they're loading; when they
@@ -540,35 +495,32 @@ private:
   ScriptLoadRequestList mBytecodeEncodingQueue;
 
   // In mRequests, the additional information here is stored by the element.
-  struct PreloadInfo
-  {
+  struct PreloadInfo {
     RefPtr<ScriptLoadRequest> mRequest;
     nsString mCharset;
   };
 
   friend void ImplCycleCollectionUnlink(ScriptLoader::PreloadInfo& aField);
-  friend void ImplCycleCollectionTraverse(nsCycleCollectionTraversalCallback& aCallback,
-                                          ScriptLoader::PreloadInfo& aField,
-                                          const char* aName, uint32_t aFlags);
+  friend void ImplCycleCollectionTraverse(
+      nsCycleCollectionTraversalCallback& aCallback,
+      ScriptLoader::PreloadInfo& aField, const char* aName, uint32_t aFlags);
 
-  struct PreloadRequestComparator
-  {
-    bool Equals(const PreloadInfo& aPi, ScriptLoadRequest* const& aRequest) const
-    {
+  struct PreloadRequestComparator {
+    bool Equals(const PreloadInfo& aPi,
+                ScriptLoadRequest* const& aRequest) const {
       return aRequest == aPi.mRequest;
     }
   };
 
-  struct PreloadURIComparator
-  {
-    bool Equals(const PreloadInfo& aPi, nsIURI* const &aURI) const;
+  struct PreloadURIComparator {
+    bool Equals(const PreloadInfo& aPi, nsIURI* const& aURI) const;
   };
 
   nsTArray<PreloadInfo> mPreloads;
 
   nsCOMPtr<nsIScriptElement> mCurrentScript;
   nsCOMPtr<nsIScriptElement> mCurrentParserInsertedScript;
-  nsTArray< RefPtr<ScriptLoader> > mPendingChildLoaders;
+  nsTArray<RefPtr<ScriptLoader> > mPendingChildLoaders;
   uint32_t mParserBlockingBlockerCount;
   uint32_t mBlockerCount;
   uint32_t mNumberOfProcessors;
@@ -580,7 +532,8 @@ private:
   bool mGiveUpEncoding;
 
   // Module map
-  nsRefPtrHashtable<nsURIHashKey, mozilla::GenericPromise::Private> mFetchingModules;
+  nsRefPtrHashtable<nsURIHashKey, mozilla::GenericPromise::Private>
+      mFetchingModules;
   nsRefPtrHashtable<nsURIHashKey, ModuleScript> mFetchedModules;
 
   nsCOMPtr<nsIConsoleReportCollector> mReporter;
@@ -590,11 +543,9 @@ private:
   static LazyLogModule gScriptLoaderLog;
 };
 
-class nsAutoScriptLoaderDisabler
-{
-public:
-  explicit nsAutoScriptLoaderDisabler(nsIDocument* aDoc)
-  {
+class nsAutoScriptLoaderDisabler {
+ public:
+  explicit nsAutoScriptLoaderDisabler(nsIDocument* aDoc) {
     mLoader = aDoc->ScriptLoader();
     mWasEnabled = mLoader->GetEnabled();
     if (mWasEnabled) {
@@ -602,8 +553,7 @@ public:
     }
   }
 
-  ~nsAutoScriptLoaderDisabler()
-  {
+  ~nsAutoScriptLoaderDisabler() {
     if (mWasEnabled) {
       mLoader->SetEnabled(true);
     }
@@ -613,7 +563,7 @@ public:
   RefPtr<ScriptLoader> mLoader;
 };
 
-} // namespace dom
-} // namespace mozilla
+}  // namespace dom
+}  // namespace mozilla
 
-#endif // mozilla_dom_ScriptLoader_h
+#endif  // mozilla_dom_ScriptLoader_h
