@@ -29,15 +29,14 @@ class nsAtom;
 namespace mozilla {
 namespace dom {
 class SVGAnimationElement;
-} // namespace dom
-} // namespace mozilla
+}  // namespace dom
+}  // namespace mozilla
 
 //----------------------------------------------------------------------
 // nsSMILTimedElement
 
-class nsSMILTimedElement
-{
-public:
+class nsSMILTimedElement {
+ public:
   nsSMILTimedElement();
   ~nsSMILTimedElement();
 
@@ -105,10 +104,7 @@ public:
    *
    * @return the simple duration in milliseconds or INDEFINITE.
    */
-  nsSMILTimeValue GetSimpleDuration() const
-  {
-    return mSimpleDur;
-  }
+  nsSMILTimeValue GetSimpleDuration() const { return mSimpleDur; }
 
   /**
    * Methods for supporting hyperlinking
@@ -159,8 +155,7 @@ public:
    *                        instance time.
    */
   void UpdateInstanceTime(nsSMILInstanceTime* aInstanceTime,
-                          nsSMILTimeValue& aUpdatedTime,
-                          bool aIsBegin);
+                          nsSMILTimeValue& aUpdatedTime, bool aIsBegin);
 
   /**
    * Removes an instance time object from this element's list of instance times.
@@ -195,8 +190,8 @@ public:
    *
    * @param aClient   The time client to associate. Any previous time client
    *                  will be disassociated and no longer sampled. Setting this
-   *                  to nullptr will simply disassociate the previous client, if
-   *                  any.
+   *                  to nullptr will simply disassociate the previous client,
+   * if any.
    */
   void SetTimeClient(nsSMILAnimationFunction* aClient);
 
@@ -273,8 +268,8 @@ public:
    * otherwise.
    */
   bool SetAttr(nsAtom* aAttribute, const nsAString& aValue,
-                 nsAttrValue& aResult, Element* aContextNode,
-                 nsresult* aParseResult = nullptr);
+               nsAttrValue& aResult, Element* aContextNode,
+               nsresult* aParseResult = nullptr);
 
   /**
    * Attempts to unset an attribute on this timed element.
@@ -350,21 +345,21 @@ public:
 
   typedef bool (*RemovalTestFunction)(nsSMILInstanceTime* aInstance);
 
-protected:
+ protected:
   // Typedefs
   typedef nsTArray<nsAutoPtr<nsSMILTimeValueSpec> > TimeValueSpecList;
-  typedef nsTArray<RefPtr<nsSMILInstanceTime> >   InstanceTimeList;
-  typedef nsTArray<nsAutoPtr<nsSMILInterval> >      IntervalList;
+  typedef nsTArray<RefPtr<nsSMILInstanceTime> > InstanceTimeList;
+  typedef nsTArray<nsAutoPtr<nsSMILInterval> > IntervalList;
   typedef nsPtrHashKey<nsSMILTimeValueSpec> TimeValueSpecPtrKey;
   typedef nsTHashtable<TimeValueSpecPtrKey> TimeValueSpecHashSet;
 
   // Helper classes
   class InstanceTimeComparator {
-    public:
-      bool Equals(const nsSMILInstanceTime* aElem1,
-                    const nsSMILInstanceTime* aElem2) const;
-      bool LessThan(const nsSMILInstanceTime* aElem1,
-                      const nsSMILInstanceTime* aElem2) const;
+   public:
+    bool Equals(const nsSMILInstanceTime* aElem1,
+                const nsSMILInstanceTime* aElem2) const;
+    bool LessThan(const nsSMILInstanceTime* aElem1,
+                  const nsSMILInstanceTime* aElem2) const;
   };
 
   // Templated helper functions
@@ -375,39 +370,34 @@ protected:
   // Implementation helpers
   //
 
-  nsresult          SetBeginSpec(const nsAString& aBeginSpec,
-                                 Element* aContextNode,
-                                 RemovalTestFunction aRemove);
-  nsresult          SetEndSpec(const nsAString& aEndSpec,
-                               Element* aContextNode,
-                               RemovalTestFunction aRemove);
-  nsresult          SetSimpleDuration(const nsAString& aDurSpec);
-  nsresult          SetMin(const nsAString& aMinSpec);
-  nsresult          SetMax(const nsAString& aMaxSpec);
-  nsresult          SetRestart(const nsAString& aRestartSpec);
-  nsresult          SetRepeatCount(const nsAString& aRepeatCountSpec);
-  nsresult          SetRepeatDur(const nsAString& aRepeatDurSpec);
-  nsresult          SetFillMode(const nsAString& aFillModeSpec);
+  nsresult SetBeginSpec(const nsAString& aBeginSpec, Element* aContextNode,
+                        RemovalTestFunction aRemove);
+  nsresult SetEndSpec(const nsAString& aEndSpec, Element* aContextNode,
+                      RemovalTestFunction aRemove);
+  nsresult SetSimpleDuration(const nsAString& aDurSpec);
+  nsresult SetMin(const nsAString& aMinSpec);
+  nsresult SetMax(const nsAString& aMaxSpec);
+  nsresult SetRestart(const nsAString& aRestartSpec);
+  nsresult SetRepeatCount(const nsAString& aRepeatCountSpec);
+  nsresult SetRepeatDur(const nsAString& aRepeatDurSpec);
+  nsresult SetFillMode(const nsAString& aFillModeSpec);
 
-  void              UnsetBeginSpec(RemovalTestFunction aRemove);
-  void              UnsetEndSpec(RemovalTestFunction aRemove);
-  void              UnsetSimpleDuration();
-  void              UnsetMin();
-  void              UnsetMax();
-  void              UnsetRestart();
-  void              UnsetRepeatCount();
-  void              UnsetRepeatDur();
-  void              UnsetFillMode();
+  void UnsetBeginSpec(RemovalTestFunction aRemove);
+  void UnsetEndSpec(RemovalTestFunction aRemove);
+  void UnsetSimpleDuration();
+  void UnsetMin();
+  void UnsetMax();
+  void UnsetRestart();
+  void UnsetRepeatCount();
+  void UnsetRepeatDur();
+  void UnsetFillMode();
 
-  nsresult          SetBeginOrEndSpec(const nsAString& aSpec,
-                                      Element* aContextNode,
-                                      bool aIsBegin,
-                                      RemovalTestFunction aRemove);
-  void              ClearSpecs(TimeValueSpecList& aSpecs,
-                               InstanceTimeList& aInstances,
-                               RemovalTestFunction aRemove);
-  void              ClearIntervals();
-  void              DoSampleAt(nsSMILTime aContainerTime, bool aEndOnly);
+  nsresult SetBeginOrEndSpec(const nsAString& aSpec, Element* aContextNode,
+                             bool aIsBegin, RemovalTestFunction aRemove);
+  void ClearSpecs(TimeValueSpecList& aSpecs, InstanceTimeList& aInstances,
+                  RemovalTestFunction aRemove);
+  void ClearIntervals();
+  void DoSampleAt(nsSMILTime aContainerTime, bool aEndOnly);
 
   /**
    * Helper function to check for an early end and, if necessary, update the
@@ -503,31 +493,31 @@ protected:
    *                        returned).
    * @return  true if a suitable interval was found, false otherwise.
    */
-  bool              GetNextInterval(const nsSMILInterval* aPrevInterval,
-                                    const nsSMILInterval* aReplacedInterval,
-                                    const nsSMILInstanceTime* aFixedBeginTime,
-                                    nsSMILInterval& aResult) const;
+  bool GetNextInterval(const nsSMILInterval* aPrevInterval,
+                       const nsSMILInterval* aReplacedInterval,
+                       const nsSMILInstanceTime* aFixedBeginTime,
+                       nsSMILInterval& aResult) const;
   nsSMILInstanceTime* GetNextGreater(const InstanceTimeList& aList,
                                      const nsSMILTimeValue& aBase,
                                      int32_t& aPosition) const;
   nsSMILInstanceTime* GetNextGreaterOrEqual(const InstanceTimeList& aList,
                                             const nsSMILTimeValue& aBase,
                                             int32_t& aPosition) const;
-  nsSMILTimeValue   CalcActiveEnd(const nsSMILTimeValue& aBegin,
-                                  const nsSMILTimeValue& aEnd) const;
-  nsSMILTimeValue   GetRepeatDuration() const;
-  nsSMILTimeValue   ApplyMinAndMax(const nsSMILTimeValue& aDuration) const;
-  nsSMILTime        ActiveTimeToSimpleTime(nsSMILTime aActiveTime,
-                                           uint32_t& aRepeatIteration);
+  nsSMILTimeValue CalcActiveEnd(const nsSMILTimeValue& aBegin,
+                                const nsSMILTimeValue& aEnd) const;
+  nsSMILTimeValue GetRepeatDuration() const;
+  nsSMILTimeValue ApplyMinAndMax(const nsSMILTimeValue& aDuration) const;
+  nsSMILTime ActiveTimeToSimpleTime(nsSMILTime aActiveTime,
+                                    uint32_t& aRepeatIteration);
   nsSMILInstanceTime* CheckForEarlyEnd(
-                        const nsSMILTimeValue& aContainerTime) const;
-  void              UpdateCurrentInterval(bool aForceChangeNotice = false);
-  void              SampleSimpleTime(nsSMILTime aActiveTime);
-  void              SampleFillValue();
-  nsresult          AddInstanceTimeFromCurrentTime(nsSMILTime aCurrentTime,
-                        double aOffsetSeconds, bool aIsBegin);
-  void              RegisterMilestone();
-  bool              GetNextMilestone(nsSMILMilestone& aNextMilestone) const;
+      const nsSMILTimeValue& aContainerTime) const;
+  void UpdateCurrentInterval(bool aForceChangeNotice = false);
+  void SampleSimpleTime(nsSMILTime aActiveTime);
+  void SampleFillValue();
+  nsresult AddInstanceTimeFromCurrentTime(nsSMILTime aCurrentTime,
+                                          double aOffsetSeconds, bool aIsBegin);
+  void RegisterMilestone();
+  bool GetNextMilestone(nsSMILMilestone& aNextMilestone) const;
 
   // Notification methods. Note that these notifications can result in nested
   // calls to this same object. Therefore,
@@ -535,26 +525,22 @@ protected:
   //      a consistent state to receive callbacks, and
   // (ii) after calling these methods we must assume that the state of the
   //      element may have changed.
-  void              NotifyNewInterval();
-  void              NotifyChangedInterval(nsSMILInterval* aInterval,
-                                          bool aBeginObjectChanged,
-                                          bool aEndObjectChanged);
+  void NotifyNewInterval();
+  void NotifyChangedInterval(nsSMILInterval* aInterval,
+                             bool aBeginObjectChanged, bool aEndObjectChanged);
 
-  void              FireTimeEventAsync(mozilla::EventMessage aMsg,
-                                       int32_t aDetail);
+  void FireTimeEventAsync(mozilla::EventMessage aMsg, int32_t aDetail);
   const nsSMILInstanceTime* GetEffectiveBeginInstance() const;
   const nsSMILInterval* GetPreviousInterval() const;
-  bool              HasPlayed() const { return !mOldIntervals.IsEmpty(); }
-  bool              HasClientInFillRange() const;
-  bool              EndHasEventConditions() const;
-  bool              AreEndTimesDependentOn(
-                      const nsSMILInstanceTime* aBase) const;
+  bool HasPlayed() const { return !mOldIntervals.IsEmpty(); }
+  bool HasClientInFillRange() const;
+  bool EndHasEventConditions() const;
+  bool AreEndTimesDependentOn(const nsSMILInstanceTime* aBase) const;
 
   // Reset the current interval by first passing ownership to a temporary
   // variable so that if Unlink() results in us receiving a callback,
   // mCurrentInterval will be nullptr and we will be in a consistent state.
-  void ResetCurrentInterval()
-  {
+  void ResetCurrentInterval() {
     if (mCurrentInterval) {
       // Transfer ownership to temp var. (This sets mCurrentInterval to null.)
       nsAutoPtr<nsSMILInterval> interval(mozilla::Move(mCurrentInterval));
@@ -565,48 +551,43 @@ protected:
   //
   // Members
   //
-  mozilla::dom::SVGAnimationElement* mAnimationElement; // [weak] won't outlive
-                                                        // owner
-  TimeValueSpecList               mBeginSpecs; // [strong]
-  TimeValueSpecList               mEndSpecs; // [strong]
+  mozilla::dom::SVGAnimationElement* mAnimationElement;  // [weak] won't outlive
+                                                         // owner
+  TimeValueSpecList mBeginSpecs;                         // [strong]
+  TimeValueSpecList mEndSpecs;                           // [strong]
 
-  nsSMILTimeValue                 mSimpleDur;
+  nsSMILTimeValue mSimpleDur;
 
-  nsSMILRepeatCount               mRepeatCount;
-  nsSMILTimeValue                 mRepeatDur;
+  nsSMILRepeatCount mRepeatCount;
+  nsSMILTimeValue mRepeatDur;
 
-  nsSMILTimeValue                 mMin;
-  nsSMILTimeValue                 mMax;
+  nsSMILTimeValue mMin;
+  nsSMILTimeValue mMax;
 
-  enum nsSMILFillMode : uint8_t
-  {
-    FILL_REMOVE,
-    FILL_FREEZE
-  };
-  nsSMILFillMode                  mFillMode;
+  enum nsSMILFillMode : uint8_t { FILL_REMOVE, FILL_FREEZE };
+  nsSMILFillMode mFillMode;
   static const nsAttrValue::EnumTable sFillModeTable[];
 
-  enum nsSMILRestartMode : uint8_t
-  {
+  enum nsSMILRestartMode : uint8_t {
     RESTART_ALWAYS,
     RESTART_WHENNOTACTIVE,
     RESTART_NEVER
   };
-  nsSMILRestartMode               mRestartMode;
+  nsSMILRestartMode mRestartMode;
   static const nsAttrValue::EnumTable sRestartModeTable[];
 
-  InstanceTimeList                mBeginInstances;
-  InstanceTimeList                mEndInstances;
-  uint32_t                        mInstanceSerialIndex;
+  InstanceTimeList mBeginInstances;
+  InstanceTimeList mEndInstances;
+  uint32_t mInstanceSerialIndex;
 
-  nsSMILAnimationFunction*        mClient;
-  nsAutoPtr<nsSMILInterval>       mCurrentInterval;
-  IntervalList                    mOldIntervals;
-  uint32_t                        mCurrentRepeatIteration;
-  nsSMILMilestone                 mPrevRegisteredMilestone;
-  static const nsSMILMilestone    sMaxMilestone;
-  static const uint8_t            sMaxNumIntervals;
-  static const uint8_t            sMaxNumInstanceTimes;
+  nsSMILAnimationFunction* mClient;
+  nsAutoPtr<nsSMILInterval> mCurrentInterval;
+  IntervalList mOldIntervals;
+  uint32_t mCurrentRepeatIteration;
+  nsSMILMilestone mPrevRegisteredMilestone;
+  static const nsSMILMilestone sMaxMilestone;
+  static const uint8_t sMaxNumIntervals;
+  static const uint8_t sMaxNumInstanceTimes;
 
   // Set of dependent time value specs to be notified when establishing a new
   // current interval. Change notifications and delete notifications are handled
@@ -620,54 +601,47 @@ protected:
    * The state of the element in its life-cycle. These states are based on the
    * element life-cycle described in SMILANIM 3.6.8
    */
-  enum nsSMILElementState
-  {
+  enum nsSMILElementState {
     STATE_STARTUP,
     STATE_WAITING,
     STATE_ACTIVE,
     STATE_POSTACTIVE
   };
-  nsSMILElementState              mElementState;
+  nsSMILElementState mElementState;
 
-  enum nsSMILSeekState
-  {
+  enum nsSMILSeekState {
     SEEK_NOT_SEEKING,
     SEEK_FORWARD_FROM_ACTIVE,
     SEEK_FORWARD_FROM_INACTIVE,
     SEEK_BACKWARD_FROM_ACTIVE,
     SEEK_BACKWARD_FROM_INACTIVE
   };
-  nsSMILSeekState                 mSeekState;
+  nsSMILSeekState mSeekState;
 
   // Used to batch updates to the timing model
   class AutoIntervalUpdateBatcher;
   bool mDeferIntervalUpdates;
-  bool mDoDeferredUpdate; // Set if an update to the current interval was
-                          // requested while mDeferIntervalUpdates was set
+  bool mDoDeferredUpdate;  // Set if an update to the current interval was
+                           // requested while mDeferIntervalUpdates was set
   bool mIsDisabled;
 
   // Stack-based helper class to call UpdateCurrentInterval when it is destroyed
   class AutoIntervalUpdater;
 
   // Recursion depth checking
-  uint8_t              mDeleteCount;
-  uint8_t              mUpdateIntervalRecursionDepth;
+  uint8_t mDeleteCount;
+  uint8_t mUpdateIntervalRecursionDepth;
   static const uint8_t sMaxUpdateIntervalRecursionDepth;
 };
 
-inline void
-ImplCycleCollectionUnlink(nsSMILTimedElement& aField)
-{
+inline void ImplCycleCollectionUnlink(nsSMILTimedElement& aField) {
   aField.Unlink();
 }
 
-inline void
-ImplCycleCollectionTraverse(nsCycleCollectionTraversalCallback& aCallback,
-                            nsSMILTimedElement& aField,
-                            const char* aName,
-                            uint32_t aFlags = 0)
-{
+inline void ImplCycleCollectionTraverse(
+    nsCycleCollectionTraversalCallback& aCallback, nsSMILTimedElement& aField,
+    const char* aName, uint32_t aFlags = 0) {
   aField.Traverse(&aCallback);
 }
 
-#endif // NS_SMILTIMEDELEMENT_H_
+#endif  // NS_SMILTIMEDELEMENT_H_
