@@ -44,63 +44,55 @@ static bool gPrefProximitySensorEnabled = false;
 static bool gPrefAmbientLightSensorEnabled = false;
 
 static const nsTArray<nsIDOMWindow*>::index_type NoIndex =
-  nsTArray<nsIDOMWindow*>::NoIndex;
+    nsTArray<nsIDOMWindow*>::NoIndex;
 
-class nsDeviceSensorData final : public nsIDeviceSensorData
-{
-public:
+class nsDeviceSensorData final : public nsIDeviceSensorData {
+ public:
   NS_DECL_ISUPPORTS
   NS_DECL_NSIDEVICESENSORDATA
 
   nsDeviceSensorData(unsigned long type, double x, double y, double z);
 
-private:
+ private:
   ~nsDeviceSensorData();
 
-protected:
+ protected:
   unsigned long mType;
   double mX, mY, mZ;
 };
 
-nsDeviceSensorData::nsDeviceSensorData(unsigned long type, double x, double y, double z)
-  : mType(type), mX(x), mY(y), mZ(z)
-{
-}
+nsDeviceSensorData::nsDeviceSensorData(unsigned long type, double x, double y,
+                                       double z)
+    : mType(type), mX(x), mY(y), mZ(z) {}
 
 NS_INTERFACE_MAP_BEGIN(nsDeviceSensorData)
-NS_INTERFACE_MAP_ENTRY_AMBIGUOUS(nsISupports, nsIDeviceSensorData)
+  NS_INTERFACE_MAP_ENTRY_AMBIGUOUS(nsISupports, nsIDeviceSensorData)
 NS_INTERFACE_MAP_END
 
 NS_IMPL_ADDREF(nsDeviceSensorData)
 NS_IMPL_RELEASE(nsDeviceSensorData)
 
-nsDeviceSensorData::~nsDeviceSensorData()
-{
-}
+nsDeviceSensorData::~nsDeviceSensorData() {}
 
-NS_IMETHODIMP nsDeviceSensorData::GetType(uint32_t *aType)
-{
+NS_IMETHODIMP nsDeviceSensorData::GetType(uint32_t* aType) {
   NS_ENSURE_ARG_POINTER(aType);
   *aType = mType;
   return NS_OK;
 }
 
-NS_IMETHODIMP nsDeviceSensorData::GetX(double *aX)
-{
+NS_IMETHODIMP nsDeviceSensorData::GetX(double* aX) {
   NS_ENSURE_ARG_POINTER(aX);
   *aX = mX;
   return NS_OK;
 }
 
-NS_IMETHODIMP nsDeviceSensorData::GetY(double *aY)
-{
+NS_IMETHODIMP nsDeviceSensorData::GetY(double* aY) {
   NS_ENSURE_ARG_POINTER(aY);
   *aY = mY;
   return NS_OK;
 }
 
-NS_IMETHODIMP nsDeviceSensorData::GetZ(double *aZ)
-{
+NS_IMETHODIMP nsDeviceSensorData::GetZ(double* aZ) {
   NS_ENSURE_ARG_POINTER(aZ);
   *aZ = mZ;
   return NS_OK;
@@ -108,39 +100,31 @@ NS_IMETHODIMP nsDeviceSensorData::GetZ(double *aZ)
 
 NS_IMPL_ISUPPORTS(nsDeviceSensors, nsIDeviceSensors)
 
-nsDeviceSensors::nsDeviceSensors()
-{
+nsDeviceSensors::nsDeviceSensors() {
   mIsUserProximityNear = false;
   mLastDOMMotionEventTime = TimeStamp::Now();
-  Preferences::AddBoolVarCache(&gPrefSensorsEnabled,
-                              "device.sensors.enabled",
-                              true);
+  Preferences::AddBoolVarCache(&gPrefSensorsEnabled, "device.sensors.enabled",
+                               true);
   Preferences::AddBoolVarCache(&gPrefMotionSensorEnabled,
-                              "device.sensors.motion.enabled",
-                              true);
+                               "device.sensors.motion.enabled", true);
   Preferences::AddBoolVarCache(&gPrefOrientationSensorEnabled,
-                              "device.sensors.orientation.enabled",
-                              true);
+                               "device.sensors.orientation.enabled", true);
   Preferences::AddBoolVarCache(&gPrefProximitySensorEnabled,
-                              "device.sensors.proximity.enabled",
-                              false);
+                               "device.sensors.proximity.enabled", false);
   Preferences::AddBoolVarCache(&gPrefAmbientLightSensorEnabled,
-                              "device.sensors.ambientLight.enabled",
-                              false);
+                               "device.sensors.ambientLight.enabled", false);
 
   for (int i = 0; i < NUM_SENSOR_TYPE; i++) {
-    nsTArray<nsIDOMWindow*> *windows = new nsTArray<nsIDOMWindow*>();
+    nsTArray<nsIDOMWindow*>* windows = new nsTArray<nsIDOMWindow*>();
     mWindowListeners.AppendElement(windows);
   }
 
   mLastDOMMotionEventTime = TimeStamp::Now();
 }
 
-nsDeviceSensors::~nsDeviceSensors()
-{
+nsDeviceSensors::~nsDeviceSensors() {
   for (int i = 0; i < NUM_SENSOR_TYPE; i++) {
-    if (IsSensorEnabled(i))
-      UnregisterSensorObserver((SensorType)i, this);
+    if (IsSensorEnabled(i)) UnregisterSensorObserver((SensorType)i, this);
   }
 
   for (int i = 0; i < NUM_SENSOR_TYPE; i++) {
@@ -148,8 +132,9 @@ nsDeviceSensors::~nsDeviceSensors()
   }
 }
 
-NS_IMETHODIMP nsDeviceSensors::HasWindowListener(uint32_t aType, nsIDOMWindow *aWindow, bool *aRetVal)
-{
+NS_IMETHODIMP nsDeviceSensors::HasWindowListener(uint32_t aType,
+                                                 nsIDOMWindow* aWindow,
+                                                 bool* aRetVal) {
   if (!IsSensorAllowedByPref(aType, aWindow))
     *aRetVal = false;
   else
@@ -158,18 +143,14 @@ NS_IMETHODIMP nsDeviceSensors::HasWindowListener(uint32_t aType, nsIDOMWindow *a
   return NS_OK;
 }
 
-class DeviceSensorTestEvent : public Runnable
-{
-public:
+class DeviceSensorTestEvent : public Runnable {
+ public:
   DeviceSensorTestEvent(nsDeviceSensors* aTarget, uint32_t aType)
-    : mozilla::Runnable("DeviceSensorTestEvent")
-    , mTarget(aTarget)
-    , mType(aType)
-  {
-  }
+      : mozilla::Runnable("DeviceSensorTestEvent"),
+        mTarget(aTarget),
+        mType(aType) {}
 
-  NS_IMETHOD Run() override
-  {
+  NS_IMETHOD Run() override {
     SensorData sensorData;
     sensorData.sensor() = static_cast<SensorType>(mType);
     sensorData.timestamp() = PR_Now();
@@ -182,20 +163,18 @@ public:
     return NS_OK;
   }
 
-private:
+ private:
   RefPtr<nsDeviceSensors> mTarget;
   uint32_t mType;
 };
 
 static bool sTestSensorEvents = false;
 
-NS_IMETHODIMP nsDeviceSensors::AddWindowListener(uint32_t aType, nsIDOMWindow *aWindow)
-{
-  if (!IsSensorAllowedByPref(aType, aWindow))
-    return NS_OK;
+NS_IMETHODIMP nsDeviceSensors::AddWindowListener(uint32_t aType,
+                                                 nsIDOMWindow* aWindow) {
+  if (!IsSensorAllowedByPref(aType, aWindow)) return NS_OK;
 
-  if (mWindowListeners[aType]->IndexOf(aWindow) != NoIndex)
-    return NS_OK;
+  if (mWindowListeners[aType]->IndexOf(aWindow) != NoIndex) return NS_OK;
 
   if (!IsSensorEnabled(aType)) {
     RegisterSensorObserver((SensorType)aType, this);
@@ -207,8 +186,7 @@ NS_IMETHODIMP nsDeviceSensors::AddWindowListener(uint32_t aType, nsIDOMWindow *a
   if (!sPrefCacheInitialized) {
     sPrefCacheInitialized = true;
     Preferences::AddBoolVarCache(&sTestSensorEvents,
-                                 "device.sensors.test.events",
-                                 false);
+                                 "device.sensors.test.events", false);
   }
 
   if (sTestSensorEvents) {
@@ -219,10 +197,9 @@ NS_IMETHODIMP nsDeviceSensors::AddWindowListener(uint32_t aType, nsIDOMWindow *a
   return NS_OK;
 }
 
-NS_IMETHODIMP nsDeviceSensors::RemoveWindowListener(uint32_t aType, nsIDOMWindow *aWindow)
-{
-  if (mWindowListeners[aType]->IndexOf(aWindow) == NoIndex)
-    return NS_OK;
+NS_IMETHODIMP nsDeviceSensors::RemoveWindowListener(uint32_t aType,
+                                                    nsIDOMWindow* aWindow) {
+  if (mWindowListeners[aType]->IndexOf(aWindow) == NoIndex) return NS_OK;
 
   mWindowListeners[aType]->RemoveElement(aWindow);
 
@@ -232,17 +209,14 @@ NS_IMETHODIMP nsDeviceSensors::RemoveWindowListener(uint32_t aType, nsIDOMWindow
   return NS_OK;
 }
 
-NS_IMETHODIMP nsDeviceSensors::RemoveWindowAsListener(nsIDOMWindow *aWindow)
-{
+NS_IMETHODIMP nsDeviceSensors::RemoveWindowAsListener(nsIDOMWindow* aWindow) {
   for (int i = 0; i < NUM_SENSOR_TYPE; i++) {
     RemoveWindowListener((SensorType)i, aWindow);
   }
   return NS_OK;
 }
 
-static bool
-WindowCannotReceiveSensorEvent (nsPIDOMWindowInner* aWindow)
-{
+static bool WindowCannotReceiveSensorEvent(nsPIDOMWindowInner* aWindow) {
   // Check to see if this window is in the background.  If
   // it is and it does not have the "background-sensors" permission,
   // don't send any device motion events to it.
@@ -270,11 +244,11 @@ WindowCannotReceiveSensorEvent (nsPIDOMWindowInner* aWindow)
   }
 
   if (disabled) {
-    nsCOMPtr<nsIPermissionManager> permMgr =
-      services::GetPermissionManager();
+    nsCOMPtr<nsIPermissionManager> permMgr = services::GetPermissionManager();
     NS_ENSURE_TRUE(permMgr, true);
     uint32_t permission = nsIPermissionManager::DENY_ACTION;
-    permMgr->TestPermissionFromWindow(aWindow, "background-sensors", &permission);
+    permMgr->TestPermissionFromWindow(aWindow, "background-sensors",
+                                      &permission);
     return permission != nsIPermissionManager::ALLOW_ACTION;
   }
 
@@ -282,20 +256,13 @@ WindowCannotReceiveSensorEvent (nsPIDOMWindowInner* aWindow)
 }
 
 // Holds the device orientation in Euler angle degrees (azimuth, pitch, roll).
-struct Orientation
-{
-  enum OrientationReference
-  {
-    kRelative = 0,
-    kAbsolute
-  };
+struct Orientation {
+  enum OrientationReference { kRelative = 0, kAbsolute };
 
-  static Orientation RadToDeg(const Orientation& aOrient)
-  {
+  static Orientation RadToDeg(const Orientation& aOrient) {
     const static double kRadToDeg = 180.0 / M_PI;
-    return { aOrient.alpha * kRadToDeg,
-             aOrient.beta * kRadToDeg,
-             aOrient.gamma * kRadToDeg };
+    return {aOrient.alpha * kRadToDeg, aOrient.beta * kRadToDeg,
+            aOrient.gamma * kRadToDeg};
   }
 
   double alpha;
@@ -303,21 +270,21 @@ struct Orientation
   double gamma;
 };
 
-static Orientation
-RotationVectorToOrientation(double aX, double aY, double aZ, double aW) {
+static Orientation RotationVectorToOrientation(double aX, double aY, double aZ,
+                                               double aW) {
   double mat[9];
 
-  mat[0] = 1 - 2*aY*aY - 2*aZ*aZ;
-  mat[1] = 2*aX*aY - 2*aZ*aW;
-  mat[2] = 2*aX*aZ + 2*aY*aW;
+  mat[0] = 1 - 2 * aY * aY - 2 * aZ * aZ;
+  mat[1] = 2 * aX * aY - 2 * aZ * aW;
+  mat[2] = 2 * aX * aZ + 2 * aY * aW;
 
-  mat[3] = 2*aX*aY + 2*aZ*aW;
-  mat[4] = 1 - 2*aX*aX - 2*aZ*aZ;
-  mat[5] = 2*aY*aZ - 2*aX*aW;
+  mat[3] = 2 * aX * aY + 2 * aZ * aW;
+  mat[4] = 1 - 2 * aX * aX - 2 * aZ * aZ;
+  mat[5] = 2 * aY * aZ - 2 * aX * aW;
 
-  mat[6] = 2*aX*aZ - 2*aY*aW;
-  mat[7] = 2*aY*aZ + 2*aX*aW;
-  mat[8] = 1 - 2*aX*aX - 2*aY*aY;
+  mat[6] = 2 * aX * aZ - 2 * aY * aW;
+  mat[7] = 2 * aY * aZ + 2 * aX * aW;
+  mat[8] = 1 - 2 * aX * aX - 2 * aY * aY;
 
   Orientation orient;
 
@@ -348,15 +315,13 @@ RotationVectorToOrientation(double aX, double aY, double aZ, double aW) {
   }
 
   if (orient.alpha < 0) {
-    orient.alpha += 2*M_PI;
+    orient.alpha += 2 * M_PI;
   }
 
   return Orientation::RadToDeg(orient);
 }
 
-void
-nsDeviceSensors::Notify(const mozilla::hal::SensorData& aSensorData)
-{
+void nsDeviceSensors::Notify(const mozilla::hal::SensorData& aSensorData) {
   uint32_t type = aSensorData.sensor();
 
   const InfallibleTArray<float>& values = aSensorData.values();
@@ -372,19 +337,21 @@ nsDeviceSensors::Notify(const mozilla::hal::SensorData& aSensorData)
     windowListeners.AppendObject(mWindowListeners[type]->SafeElementAt(i));
   }
 
-  for (uint32_t i = windowListeners.Count(); i > 0 ; ) {
+  for (uint32_t i = windowListeners.Count(); i > 0;) {
     --i;
 
-    nsCOMPtr<nsPIDOMWindowInner> pwindow = do_QueryInterface(windowListeners[i]);
+    nsCOMPtr<nsPIDOMWindowInner> pwindow =
+        do_QueryInterface(windowListeners[i]);
     if (WindowCannotReceiveSensorEvent(pwindow)) {
-        continue;
+      continue;
     }
 
     if (nsCOMPtr<nsIDocument> doc = pwindow->GetDoc()) {
-      nsCOMPtr<mozilla::dom::EventTarget> target = do_QueryInterface(windowListeners[i]);
+      nsCOMPtr<mozilla::dom::EventTarget> target =
+          do_QueryInterface(windowListeners[i]);
       if (type == nsIDeviceSensorData::TYPE_ACCELERATION ||
-        type == nsIDeviceSensorData::TYPE_LINEAR_ACCELERATION ||
-        type == nsIDeviceSensorData::TYPE_GYROSCOPE) {
+          type == nsIDeviceSensorData::TYPE_LINEAR_ACCELERATION ||
+          type == nsIDeviceSensorData::TYPE_GYROSCOPE) {
         FireDOMMotionEvent(doc, target, type, timestamp, x, y, z);
       } else if (type == nsIDeviceSensorData::TYPE_ORIENTATION) {
         FireDOMOrientationEvent(target, x, y, z, Orientation::kAbsolute);
@@ -405,16 +372,14 @@ nsDeviceSensors::Notify(const mozilla::hal::SensorData& aSensorData)
   }
 }
 
-void
-nsDeviceSensors::FireDOMLightEvent(mozilla::dom::EventTarget* aTarget,
-                                   double aValue)
-{
+void nsDeviceSensors::FireDOMLightEvent(mozilla::dom::EventTarget* aTarget,
+                                        double aValue) {
   DeviceLightEventInit init;
   init.mBubbles = true;
   init.mCancelable = false;
   init.mValue = round(aValue);
-  RefPtr<DeviceLightEvent> event =
-    DeviceLightEvent::Constructor(aTarget, NS_LITERAL_STRING("devicelight"), init);
+  RefPtr<DeviceLightEvent> event = DeviceLightEvent::Constructor(
+      aTarget, NS_LITERAL_STRING("devicelight"), init);
 
   event->SetTrusted(true);
 
@@ -422,22 +387,17 @@ nsDeviceSensors::FireDOMLightEvent(mozilla::dom::EventTarget* aTarget,
   aTarget->DispatchEvent(event, &defaultActionEnabled);
 }
 
-void
-nsDeviceSensors::FireDOMProximityEvent(mozilla::dom::EventTarget* aTarget,
-                                       double aValue,
-                                       double aMin,
-                                       double aMax)
-{
+void nsDeviceSensors::FireDOMProximityEvent(mozilla::dom::EventTarget* aTarget,
+                                            double aValue, double aMin,
+                                            double aMax) {
   DeviceProximityEventInit init;
   init.mBubbles = true;
   init.mCancelable = false;
   init.mValue = aValue;
   init.mMin = aMin;
   init.mMax = aMax;
-  RefPtr<DeviceProximityEvent> event =
-    DeviceProximityEvent::Constructor(aTarget,
-                                      NS_LITERAL_STRING("deviceproximity"),
-                                      init);
+  RefPtr<DeviceProximityEvent> event = DeviceProximityEvent::Constructor(
+      aTarget, NS_LITERAL_STRING("deviceproximity"), init);
   event->SetTrusted(true);
 
   bool defaultActionEnabled;
@@ -455,18 +415,14 @@ nsDeviceSensors::FireDOMProximityEvent(mozilla::dom::EventTarget* aTarget,
   }
 }
 
-void
-nsDeviceSensors::FireDOMUserProximityEvent(mozilla::dom::EventTarget* aTarget,
-                                           bool aNear)
-{
+void nsDeviceSensors::FireDOMUserProximityEvent(
+    mozilla::dom::EventTarget* aTarget, bool aNear) {
   UserProximityEventInit init;
   init.mBubbles = true;
   init.mCancelable = false;
   init.mNear = aNear;
-  RefPtr<UserProximityEvent> event =
-    UserProximityEvent::Constructor(aTarget,
-                                    NS_LITERAL_STRING("userproximity"),
-                                    init);
+  RefPtr<UserProximityEvent> event = UserProximityEvent::Constructor(
+      aTarget, NS_LITERAL_STRING("userproximity"), init);
 
   event->SetTrusted(true);
 
@@ -474,13 +430,9 @@ nsDeviceSensors::FireDOMUserProximityEvent(mozilla::dom::EventTarget* aTarget,
   aTarget->DispatchEvent(event, &defaultActionEnabled);
 }
 
-void
-nsDeviceSensors::FireDOMOrientationEvent(EventTarget* aTarget,
-                                         double aAlpha,
-                                         double aBeta,
-                                         double aGamma,
-                                         bool aIsAbsolute)
-{
+void nsDeviceSensors::FireDOMOrientationEvent(EventTarget* aTarget,
+                                              double aAlpha, double aBeta,
+                                              double aGamma, bool aIsAbsolute) {
   DeviceOrientationEventInit init;
   init.mBubbles = true;
   init.mCancelable = false;
@@ -489,17 +441,16 @@ nsDeviceSensors::FireDOMOrientationEvent(EventTarget* aTarget,
   init.mGamma.SetValue(aGamma);
   init.mAbsolute = aIsAbsolute;
 
-  auto Dispatch = [&](EventTarget* aEventTarget, const nsAString& aType)
-  {
+  auto Dispatch = [&](EventTarget* aEventTarget, const nsAString& aType) {
     RefPtr<DeviceOrientationEvent> event =
-      DeviceOrientationEvent::Constructor(aEventTarget, aType, init);
+        DeviceOrientationEvent::Constructor(aEventTarget, aType, init);
     event->SetTrusted(true);
     bool dummy;
     aEventTarget->DispatchEvent(event, &dummy);
   };
 
-  Dispatch(aTarget, aIsAbsolute ? NS_LITERAL_STRING("absolutedeviceorientation") :
-                                  NS_LITERAL_STRING("deviceorientation"));
+  Dispatch(aTarget, aIsAbsolute ? NS_LITERAL_STRING("absolutedeviceorientation")
+                                : NS_LITERAL_STRING("deviceorientation"));
 
   // This is used to determine whether relative events have been dispatched
   // during the current session, in which case we don't dispatch the additional
@@ -518,47 +469,41 @@ nsDeviceSensors::FireDOMOrientationEvent(EventTarget* aTarget,
   }
 }
 
-void
-nsDeviceSensors::FireDOMMotionEvent(nsIDocument *doc,
-                                    EventTarget* target,
-                                    uint32_t type,
-                                    PRTime timestamp,
-                                    double x,
-                                    double y,
-                                    double z)
-{
+void nsDeviceSensors::FireDOMMotionEvent(nsIDocument* doc, EventTarget* target,
+                                         uint32_t type, PRTime timestamp,
+                                         double x, double y, double z) {
   // Attempt to coalesce events
   TimeDuration sensorPollDuration =
-    TimeDuration::FromMilliseconds(DEFAULT_SENSOR_POLL);
+      TimeDuration::FromMilliseconds(DEFAULT_SENSOR_POLL);
   bool fireEvent =
-    (TimeStamp::Now() > mLastDOMMotionEventTime + sensorPollDuration) ||
-    sTestSensorEvents;
+      (TimeStamp::Now() > mLastDOMMotionEventTime + sensorPollDuration) ||
+      sTestSensorEvents;
 
   switch (type) {
-  case nsIDeviceSensorData::TYPE_LINEAR_ACCELERATION:
-    if (!mLastAcceleration) {
-      mLastAcceleration.emplace();
-    }
-    mLastAcceleration->mX.SetValue(x);
-    mLastAcceleration->mY.SetValue(y);
-    mLastAcceleration->mZ.SetValue(z);
-    break;
-  case nsIDeviceSensorData::TYPE_ACCELERATION:
-    if (!mLastAccelerationIncludingGravity) {
-      mLastAccelerationIncludingGravity.emplace();
-    }
-    mLastAccelerationIncludingGravity->mX.SetValue(x);
-    mLastAccelerationIncludingGravity->mY.SetValue(y);
-    mLastAccelerationIncludingGravity->mZ.SetValue(z);
-    break;
-  case nsIDeviceSensorData::TYPE_GYROSCOPE:
-    if (!mLastRotationRate) {
-      mLastRotationRate.emplace();
-    }
-    mLastRotationRate->mAlpha.SetValue(x);
-    mLastRotationRate->mBeta.SetValue(y);
-    mLastRotationRate->mGamma.SetValue(z);
-    break;
+    case nsIDeviceSensorData::TYPE_LINEAR_ACCELERATION:
+      if (!mLastAcceleration) {
+        mLastAcceleration.emplace();
+      }
+      mLastAcceleration->mX.SetValue(x);
+      mLastAcceleration->mY.SetValue(y);
+      mLastAcceleration->mZ.SetValue(z);
+      break;
+    case nsIDeviceSensorData::TYPE_ACCELERATION:
+      if (!mLastAccelerationIncludingGravity) {
+        mLastAccelerationIncludingGravity.emplace();
+      }
+      mLastAccelerationIncludingGravity->mX.SetValue(x);
+      mLastAccelerationIncludingGravity->mY.SetValue(y);
+      mLastAccelerationIncludingGravity->mZ.SetValue(z);
+      break;
+    case nsIDeviceSensorData::TYPE_GYROSCOPE:
+      if (!mLastRotationRate) {
+        mLastRotationRate.emplace();
+      }
+      mLastRotationRate->mAlpha.SetValue(x);
+      mLastRotationRate->mBeta.SetValue(y);
+      mLastRotationRate->mGamma.SetValue(z);
+      break;
   }
 
   if (fireEvent) {
@@ -571,8 +516,7 @@ nsDeviceSensors::FireDOMMotionEvent(nsIDocument *doc,
     if (!mLastRotationRate) {
       mLastRotationRate.emplace();
     }
-  } else if (!mLastAcceleration ||
-             !mLastAccelerationIncludingGravity ||
+  } else if (!mLastAcceleration || !mLastAccelerationIncludingGravity ||
              !mLastRotationRate) {
     return;
   }
@@ -586,14 +530,10 @@ nsDeviceSensors::FireDOMMotionEvent(nsIDocument *doc,
 
   DeviceMotionEvent* me = static_cast<DeviceMotionEvent*>(event.get());
 
-  me->InitDeviceMotionEvent(NS_LITERAL_STRING("devicemotion"),
-                            true,
-                            false,
-                            *mLastAcceleration,
-                            *mLastAccelerationIncludingGravity,
-                            *mLastRotationRate,
-                            Nullable<double>(DEFAULT_SENSOR_POLL),
-                            Nullable<uint64_t>(timestamp));
+  me->InitDeviceMotionEvent(
+      NS_LITERAL_STRING("devicemotion"), true, false, *mLastAcceleration,
+      *mLastAccelerationIncludingGravity, *mLastRotationRate,
+      Nullable<double>(DEFAULT_SENSOR_POLL), Nullable<uint64_t>(timestamp));
 
   event->SetTrusted(true);
 
@@ -606,9 +546,8 @@ nsDeviceSensors::FireDOMMotionEvent(nsIDocument *doc,
   mLastDOMMotionEventTime = TimeStamp::Now();
 }
 
-bool
-nsDeviceSensors::IsSensorAllowedByPref(uint32_t aType, nsIDOMWindow* aWindow)
-{
+bool nsDeviceSensors::IsSensorAllowedByPref(uint32_t aType,
+                                            nsIDOMWindow* aWindow) {
   // checks "device.sensors.enabled" master pref
   if (!gPrefSensorsEnabled) {
     return false;
@@ -621,45 +560,45 @@ nsDeviceSensors::IsSensorAllowedByPref(uint32_t aType, nsIDOMWindow* aWindow)
   }
 
   switch (aType) {
-  case nsIDeviceSensorData::TYPE_LINEAR_ACCELERATION:
-  case nsIDeviceSensorData::TYPE_ACCELERATION:
-  case nsIDeviceSensorData::TYPE_GYROSCOPE:
-    // checks "device.sensors.motion.enabled" pref
-    if (!gPrefMotionSensorEnabled) {
+    case nsIDeviceSensorData::TYPE_LINEAR_ACCELERATION:
+    case nsIDeviceSensorData::TYPE_ACCELERATION:
+    case nsIDeviceSensorData::TYPE_GYROSCOPE:
+      // checks "device.sensors.motion.enabled" pref
+      if (!gPrefMotionSensorEnabled) {
+        return false;
+      } else if (doc) {
+        doc->WarnOnceAbout(nsIDocument::eMotionEvent);
+      }
+      break;
+    case nsIDeviceSensorData::TYPE_GAME_ROTATION_VECTOR:
+    case nsIDeviceSensorData::TYPE_ORIENTATION:
+    case nsIDeviceSensorData::TYPE_ROTATION_VECTOR:
+      // checks "device.sensors.orientation.enabled" pref
+      if (!gPrefOrientationSensorEnabled) {
+        return false;
+      } else if (doc) {
+        doc->WarnOnceAbout(nsIDocument::eOrientationEvent);
+      }
+      break;
+    case nsIDeviceSensorData::TYPE_PROXIMITY:
+      // checks "device.sensors.proximity.enabled" pref
+      if (!gPrefProximitySensorEnabled) {
+        return false;
+      } else if (doc) {
+        doc->WarnOnceAbout(nsIDocument::eProximityEvent, true);
+      }
+      break;
+    case nsIDeviceSensorData::TYPE_LIGHT:
+      // checks "device.sensors.ambientLight.enabled" pref
+      if (!gPrefAmbientLightSensorEnabled) {
+        return false;
+      } else if (doc) {
+        doc->WarnOnceAbout(nsIDocument::eAmbientLightEvent, true);
+      }
+      break;
+    default:
+      MOZ_ASSERT_UNREACHABLE("Device sensor type not recognised");
       return false;
-    } else if (doc) {
-      doc->WarnOnceAbout(nsIDocument::eMotionEvent);
-    }
-    break;
-  case nsIDeviceSensorData::TYPE_GAME_ROTATION_VECTOR:
-  case nsIDeviceSensorData::TYPE_ORIENTATION:
-  case nsIDeviceSensorData::TYPE_ROTATION_VECTOR:
-    // checks "device.sensors.orientation.enabled" pref
-    if (!gPrefOrientationSensorEnabled) {
-      return false;
-    } else if (doc) {
-      doc->WarnOnceAbout(nsIDocument::eOrientationEvent);
-    }
-    break;
-  case nsIDeviceSensorData::TYPE_PROXIMITY:
-    // checks "device.sensors.proximity.enabled" pref
-    if (!gPrefProximitySensorEnabled) {
-      return false;
-    } else if (doc) {
-      doc->WarnOnceAbout(nsIDocument::eProximityEvent, true);
-    }
-    break;
-  case nsIDeviceSensorData::TYPE_LIGHT:
-    // checks "device.sensors.ambientLight.enabled" pref
-    if (!gPrefAmbientLightSensorEnabled) {
-      return false;
-    } else if (doc) {
-      doc->WarnOnceAbout(nsIDocument::eAmbientLightEvent, true);
-    }
-    break;
-  default:
-    MOZ_ASSERT_UNREACHABLE("Device sensor type not recognised");
-    return false;
   }
 
   if (!window) {
