@@ -21,9 +21,10 @@
 
 using namespace mozilla::ipc;
 
-// Forward decl because of nsHTMLDocument.h's complex dependency on /layout/style
+// Forward decl because of nsHTMLDocument.h's complex dependency on
+// /layout/style
 class nsHTMLDocument {
-public:
+ public:
   bool IsRegistrableDomainSuffixOfOrEqualTo(const nsAString& aHostSuffixString,
                                             const nsACString& aOrigHost);
 };
@@ -38,9 +39,10 @@ NS_NAMED_LITERAL_STRING(kGetAssertion, "navigator.id.getAssertion");
 
 // Bug #1436078 - Permit Google Accounts. Remove in Bug #1436085 in Jan 2023.
 NS_NAMED_LITERAL_STRING(kGoogleAccountsAppId1,
-  "https://www.gstatic.com/securitykey/origins.json");
-NS_NAMED_LITERAL_STRING(kGoogleAccountsAppId2,
-  "https://www.gstatic.com/securitykey/a/google.com/origins.json");
+                        "https://www.gstatic.com/securitykey/origins.json");
+NS_NAMED_LITERAL_STRING(
+    kGoogleAccountsAppId2,
+    "https://www.gstatic.com/securitykey/a/google.com/origins.json");
 
 NS_INTERFACE_MAP_BEGIN_CYCLE_COLLECTION(U2F)
   NS_WRAPPERCACHE_INTERFACE_MAP_ENTRY
@@ -57,9 +59,7 @@ NS_IMPL_CYCLE_COLLECTION_WRAPPERCACHE(U2F, mParent)
  * Utility Functions
  **********************************************************************/
 
-static ErrorCode
-ConvertNSResultToErrorCode(const nsresult& aError)
-{
+static ErrorCode ConvertNSResultToErrorCode(const nsresult& aError) {
   if (aError == NS_ERROR_DOM_TIMEOUT_ERR) {
     return ErrorCode::TIMEOUT;
   }
@@ -70,9 +70,8 @@ ConvertNSResultToErrorCode(const nsresult& aError)
   return ErrorCode::OTHER_ERROR;
 }
 
-static uint32_t
-AdjustedTimeoutMillis(const Optional<Nullable<int32_t>>& opt_aSeconds)
-{
+static uint32_t AdjustedTimeoutMillis(
+    const Optional<Nullable<int32_t>>& opt_aSeconds) {
   uint32_t adjustedTimeoutMillis = 30000u;
   if (opt_aSeconds.WasPassed() && !opt_aSeconds.Value().IsNull()) {
     adjustedTimeoutMillis = opt_aSeconds.Value().Value() * 1000u;
@@ -82,14 +81,13 @@ AdjustedTimeoutMillis(const Optional<Nullable<int32_t>>& opt_aSeconds)
   return adjustedTimeoutMillis;
 }
 
-static nsresult
-AssembleClientData(const nsAString& aOrigin, const nsAString& aTyp,
-                   const nsAString& aChallenge,
-                   /* out */ nsString& aClientData)
-{
+static nsresult AssembleClientData(const nsAString& aOrigin,
+                                   const nsAString& aTyp,
+                                   const nsAString& aChallenge,
+                                   /* out */ nsString& aClientData) {
   MOZ_ASSERT(NS_IsMainThread());
   U2FClientData clientDataObject;
-  clientDataObject.mTyp.Construct(aTyp); // "Typ" from the U2F specification
+  clientDataObject.mTyp.Construct(aTyp);  // "Typ" from the U2F specification
   clientDataObject.mChallenge.Construct(aChallenge);
   clientDataObject.mOrigin.Construct(aOrigin);
 
@@ -100,11 +98,9 @@ AssembleClientData(const nsAString& aOrigin, const nsAString& aTyp,
   return NS_OK;
 }
 
-static void
-RegisteredKeysToScopedCredentialList(const nsAString& aAppId,
-  const nsTArray<RegisteredKey>& aKeys,
-  nsTArray<WebAuthnScopedCredential>& aList)
-{
+static void RegisteredKeysToScopedCredentialList(
+    const nsAString& aAppId, const nsTArray<RegisteredKey>& aKeys,
+    nsTArray<WebAuthnScopedCredential>& aList) {
   for (const RegisteredKey& key : aKeys) {
     // Check for required attributes
     if (!key.mVersion.WasPassed() || !key.mKeyHandle.WasPassed() ||
@@ -129,15 +125,13 @@ RegisteredKeysToScopedCredentialList(const nsAString& aAppId,
   }
 }
 
-static nsresult
-BuildTransactionHashes(const nsCString& aRpId,
-                       const nsCString& aClientDataJSON,
-                       /* out */ CryptoBuffer& aRpIdHash,
-                       /* out */ CryptoBuffer& aClientDataHash)
-{
+static nsresult BuildTransactionHashes(
+    const nsCString& aRpId, const nsCString& aClientDataJSON,
+    /* out */ CryptoBuffer& aRpIdHash,
+    /* out */ CryptoBuffer& aClientDataHash) {
   nsresult srv;
   nsCOMPtr<nsICryptoHash> hashService =
-    do_CreateInstance(NS_CRYPTO_HASH_CONTRACTID, &srv);
+      do_CreateInstance(NS_CRYPTO_HASH_CONTRACTID, &srv);
   if (NS_FAILED(srv)) {
     return srv;
   }
@@ -167,7 +161,7 @@ BuildTransactionHashes(const nsCString& aRpId,
 
     MOZ_LOG(gU2FLog, LogLevel::Debug,
             ("dom::U2FManager::Rp ID Hash (base64): %s",
-              NS_ConvertUTF16toUTF8(base64).get()));
+             NS_ConvertUTF16toUTF8(base64).get()));
 
     Unused << NS_WARN_IF(NS_FAILED(aClientDataHash.ToJwkBase64(base64)));
 
@@ -176,7 +170,7 @@ BuildTransactionHashes(const nsCString& aRpId,
 
     MOZ_LOG(gU2FLog, LogLevel::Debug,
             ("dom::U2FManager::Client Data Hash (base64): %s",
-              NS_ConvertUTF16toUTF8(base64).get()));
+             NS_ConvertUTF16toUTF8(base64).get()));
   }
 
   return NS_OK;
@@ -186,12 +180,11 @@ BuildTransactionHashes(const nsCString& aRpId,
  * U2F JavaScript API Implementation
  **********************************************************************/
 
-U2F::~U2F()
-{
+U2F::~U2F() {
   MOZ_ASSERT(NS_IsMainThread());
 
   if (mTransaction.isSome()) {
-    RejectTransaction(NS_ERROR_ABORT);
+    ClearTransaction();
   }
 
   if (mChild) {
@@ -201,9 +194,7 @@ U2F::~U2F()
   }
 }
 
-void
-U2F::Init(ErrorResult& aRv)
-{
+void U2F::Init(ErrorResult& aRv) {
   MOZ_ASSERT(mParent);
 
   nsCOMPtr<nsIDocument> doc = mParent->GetDoc();
@@ -225,16 +216,13 @@ U2F::Init(ErrorResult& aRv)
   }
 }
 
-/* virtual */ JSObject*
-U2F::WrapObject(JSContext* aCx, JS::Handle<JSObject*> aGivenProto)
-{
+/* virtual */ JSObject* U2F::WrapObject(JSContext* aCx,
+                                        JS::Handle<JSObject*> aGivenProto) {
   return U2FBinding::Wrap(aCx, this, aGivenProto);
 }
 
-template<typename T, typename C>
-void
-U2F::ExecuteCallback(T& aResp, nsMainThreadPtrHandle<C>& aCb)
-{
+template <typename T, typename C>
+void U2F::ExecuteCallback(T& aResp, nsMainThreadPtrHandle<C>& aCb) {
   MOZ_ASSERT(NS_IsMainThread());
   MOZ_ASSERT(aCb);
 
@@ -245,17 +233,15 @@ U2F::ExecuteCallback(T& aResp, nsMainThreadPtrHandle<C>& aCb)
   ErrorResult error;
   aCb->Call(aResp, error);
   NS_WARNING_ASSERTION(!error.Failed(), "dom::U2F::Promise callback failed");
-  error.SuppressException(); // Useful exceptions already emitted
+  error.SuppressException();  // Useful exceptions already emitted
 }
 
-void
-U2F::Register(const nsAString& aAppId,
-              const Sequence<RegisterRequest>& aRegisterRequests,
-              const Sequence<RegisteredKey>& aRegisteredKeys,
-              U2FRegisterCallback& aCallback,
-              const Optional<Nullable<int32_t>>& opt_aTimeoutSeconds,
-              ErrorResult& aRv)
-{
+void U2F::Register(const nsAString& aAppId,
+                   const Sequence<RegisterRequest>& aRegisterRequests,
+                   const Sequence<RegisteredKey>& aRegisteredKeys,
+                   U2FRegisterCallback& aCallback,
+                   const Optional<Nullable<int32_t>>& opt_aTimeoutSeconds,
+                   ErrorResult& aRv) {
   MOZ_ASSERT(NS_IsMainThread());
 
   if (mTransaction.isSome()) {
@@ -263,8 +249,8 @@ U2F::Register(const nsAString& aAppId,
   }
 
   nsMainThreadPtrHandle<U2FRegisterCallback> callback(
-    new nsMainThreadPtrHolder<U2FRegisterCallback>("U2F::Register::callback",
-                                                   &aCallback));
+      new nsMainThreadPtrHolder<U2FRegisterCallback>("U2F::Register::callback",
+                                                     &aCallback));
 
   // Ensure we have a callback.
   if (NS_WARN_IF(!callback)) {
@@ -275,7 +261,8 @@ U2F::Register(const nsAString& aAppId,
   nsString adjustedAppId(aAppId);
   if (!EvaluateAppID(mParent, mOrigin, U2FOperation::Register, adjustedAppId)) {
     RegisterResponse response;
-    response.mErrorCode.Construct(static_cast<uint32_t>(ErrorCode::BAD_REQUEST));
+    response.mErrorCode.Construct(
+        static_cast<uint32_t>(ErrorCode::BAD_REQUEST));
     ExecuteCallback(response, callback);
     return;
   }
@@ -302,7 +289,8 @@ U2F::Register(const nsAString& aAppId,
   // Did we not get a valid RegisterRequest? Abort.
   if (clientDataJSON.IsEmpty()) {
     RegisterResponse response;
-    response.mErrorCode.Construct(static_cast<uint32_t>(ErrorCode::BAD_REQUEST));
+    response.mErrorCode.Construct(
+        static_cast<uint32_t>(ErrorCode::BAD_REQUEST));
     ExecuteCallback(response, callback);
     return;
   }
@@ -315,17 +303,19 @@ U2F::Register(const nsAString& aAppId,
   auto clientData = NS_ConvertUTF16toUTF8(clientDataJSON);
 
   CryptoBuffer rpIdHash, clientDataHash;
-  if (NS_FAILED(BuildTransactionHashes(cAppId, clientData,
-                                       rpIdHash, clientDataHash))) {
+  if (NS_FAILED(BuildTransactionHashes(cAppId, clientData, rpIdHash,
+                                       clientDataHash))) {
     RegisterResponse response;
-    response.mErrorCode.Construct(static_cast<uint32_t>(ErrorCode::OTHER_ERROR));
+    response.mErrorCode.Construct(
+        static_cast<uint32_t>(ErrorCode::OTHER_ERROR));
     ExecuteCallback(response, callback);
     return;
   }
 
   if (!MaybeCreateBackgroundActor()) {
     RegisterResponse response;
-    response.mErrorCode.Construct(static_cast<uint32_t>(ErrorCode::OTHER_ERROR));
+    response.mErrorCode.Construct(
+        static_cast<uint32_t>(ErrorCode::OTHER_ERROR));
     ExecuteCallback(response, callback);
     return;
   }
@@ -336,30 +326,23 @@ U2F::Register(const nsAString& aAppId,
   nsTArray<WebAuthnExtension> extensions;
 
   // Default values for U2F.
-  WebAuthnAuthenticatorSelection authSelection(false /* requireResidentKey */,
-                                               false /* requireUserVerification */,
-                                               false /* requirePlatformAttachment */);
+  WebAuthnAuthenticatorSelection authSelection(
+      false /* requireResidentKey */, false /* requireUserVerification */,
+      false /* requirePlatformAttachment */);
 
   uint32_t adjustedTimeoutMillis = AdjustedTimeoutMillis(opt_aTimeoutSeconds);
 
-  WebAuthnMakeCredentialInfo info(mOrigin,
-                                  rpIdHash,
-                                  clientDataHash,
-                                  adjustedTimeoutMillis,
-                                  excludeList,
-                                  extensions,
-                                  authSelection,
-                                  false /* RequestDirectAttestation */);
+  WebAuthnMakeCredentialInfo info(
+      mOrigin, rpIdHash, clientDataHash, adjustedTimeoutMillis, excludeList,
+      extensions, authSelection, false /* RequestDirectAttestation */);
 
   MOZ_ASSERT(mTransaction.isNothing());
   mTransaction = Some(U2FTransaction(clientData, Move(AsVariant(callback))));
   mChild->SendRequestRegister(mTransaction.ref().mId, info);
 }
 
-void
-U2F::FinishMakeCredential(const uint64_t& aTransactionId,
-                          const WebAuthnMakeCredentialResult& aResult)
-{
+void U2F::FinishMakeCredential(const uint64_t& aTransactionId,
+                               const WebAuthnMakeCredentialResult& aResult) {
   MOZ_ASSERT(NS_IsMainThread());
 
   // Check for a valid transaction.
@@ -404,20 +387,17 @@ U2F::FinishMakeCredential(const uint64_t& aTransactionId,
 
   // Keep the callback pointer alive.
   nsMainThreadPtrHandle<U2FRegisterCallback> callback(
-    mTransaction.ref().GetRegisterCallback());
+      mTransaction.ref().GetRegisterCallback());
 
   ClearTransaction();
   ExecuteCallback(response, callback);
 }
 
-void
-U2F::Sign(const nsAString& aAppId,
-          const nsAString& aChallenge,
-          const Sequence<RegisteredKey>& aRegisteredKeys,
-          U2FSignCallback& aCallback,
-          const Optional<Nullable<int32_t>>& opt_aTimeoutSeconds,
-          ErrorResult& aRv)
-{
+void U2F::Sign(const nsAString& aAppId, const nsAString& aChallenge,
+               const Sequence<RegisteredKey>& aRegisteredKeys,
+               U2FSignCallback& aCallback,
+               const Optional<Nullable<int32_t>>& opt_aTimeoutSeconds,
+               ErrorResult& aRv) {
   MOZ_ASSERT(NS_IsMainThread());
 
   if (mTransaction.isSome()) {
@@ -425,8 +405,8 @@ U2F::Sign(const nsAString& aAppId,
   }
 
   nsMainThreadPtrHandle<U2FSignCallback> callback(
-    new nsMainThreadPtrHolder<U2FSignCallback>("U2F::Sign::callback",
-                                               &aCallback));
+      new nsMainThreadPtrHolder<U2FSignCallback>("U2F::Sign::callback",
+                                                 &aCallback));
 
   // Ensure we have a callback.
   if (NS_WARN_IF(!callback)) {
@@ -437,7 +417,8 @@ U2F::Sign(const nsAString& aAppId,
   nsString adjustedAppId(aAppId);
   if (!EvaluateAppID(mParent, mOrigin, U2FOperation::Sign, adjustedAppId)) {
     SignResponse response;
-    response.mErrorCode.Construct(static_cast<uint32_t>(ErrorCode::BAD_REQUEST));
+    response.mErrorCode.Construct(
+        static_cast<uint32_t>(ErrorCode::BAD_REQUEST));
     ExecuteCallback(response, callback);
     return;
   }
@@ -446,11 +427,12 @@ U2F::Sign(const nsAString& aAppId,
   nsCString cAppId = NS_ConvertUTF16toUTF8(adjustedAppId);
 
   nsAutoString clientDataJSON;
-  nsresult rv = AssembleClientData(mOrigin, kGetAssertion, aChallenge,
-                                   clientDataJSON);
+  nsresult rv =
+      AssembleClientData(mOrigin, kGetAssertion, aChallenge, clientDataJSON);
   if (NS_WARN_IF(NS_FAILED(rv))) {
     SignResponse response;
-    response.mErrorCode.Construct(static_cast<uint32_t>(ErrorCode::BAD_REQUEST));
+    response.mErrorCode.Construct(
+        static_cast<uint32_t>(ErrorCode::BAD_REQUEST));
     ExecuteCallback(response, callback);
     return;
   }
@@ -463,17 +445,19 @@ U2F::Sign(const nsAString& aAppId,
   auto clientData = NS_ConvertUTF16toUTF8(clientDataJSON);
 
   CryptoBuffer rpIdHash, clientDataHash;
-  if (NS_FAILED(BuildTransactionHashes(cAppId, clientData,
-                                       rpIdHash, clientDataHash))) {
+  if (NS_FAILED(BuildTransactionHashes(cAppId, clientData, rpIdHash,
+                                       clientDataHash))) {
     SignResponse response;
-    response.mErrorCode.Construct(static_cast<uint32_t>(ErrorCode::OTHER_ERROR));
+    response.mErrorCode.Construct(
+        static_cast<uint32_t>(ErrorCode::OTHER_ERROR));
     ExecuteCallback(response, callback);
     return;
   }
 
   if (!MaybeCreateBackgroundActor()) {
     SignResponse response;
-    response.mErrorCode.Construct(static_cast<uint32_t>(ErrorCode::OTHER_ERROR));
+    response.mErrorCode.Construct(
+        static_cast<uint32_t>(ErrorCode::OTHER_ERROR));
     ExecuteCallback(response, callback);
     return;
   }
@@ -485,11 +469,8 @@ U2F::Sign(const nsAString& aAppId,
 
   uint32_t adjustedTimeoutMillis = AdjustedTimeoutMillis(opt_aTimeoutSeconds);
 
-  WebAuthnGetAssertionInfo info(mOrigin,
-                                rpIdHash,
-                                clientDataHash,
-                                adjustedTimeoutMillis,
-                                permittedList,
+  WebAuthnGetAssertionInfo info(mOrigin, rpIdHash, clientDataHash,
+                                adjustedTimeoutMillis, permittedList,
                                 false, /* requireUserVerification */
                                 extensions);
 
@@ -498,10 +479,8 @@ U2F::Sign(const nsAString& aAppId,
   mChild->SendRequestSign(mTransaction.ref().mId, info);
 }
 
-void
-U2F::FinishGetAssertion(const uint64_t& aTransactionId,
-                        const WebAuthnGetAssertionResult& aResult)
-{
+void U2F::FinishGetAssertion(const uint64_t& aTransactionId,
+                             const WebAuthnGetAssertionResult& aResult) {
   MOZ_ASSERT(NS_IsMainThread());
 
   // Check for a valid transaction.
@@ -541,7 +520,7 @@ U2F::FinishGetAssertion(const uint64_t& aTransactionId,
   nsresult rvKeyHandle = credBuf.ToJwkBase64(keyHandleBase64);
   if (NS_WARN_IF(NS_FAILED(rvClientData)) ||
       NS_WARN_IF(NS_FAILED(rvSignatureData) ||
-      NS_WARN_IF(NS_FAILED(rvKeyHandle)))) {
+                 NS_WARN_IF(NS_FAILED(rvKeyHandle)))) {
     RejectTransaction(NS_ERROR_ABORT);
     return;
   }
@@ -554,15 +533,13 @@ U2F::FinishGetAssertion(const uint64_t& aTransactionId,
 
   // Keep the callback pointer alive.
   nsMainThreadPtrHandle<U2FSignCallback> callback(
-    mTransaction.ref().GetSignCallback());
+      mTransaction.ref().GetSignCallback());
 
   ClearTransaction();
   ExecuteCallback(response, callback);
 }
 
-void
-U2F::ClearTransaction()
-{
+void U2F::ClearTransaction() {
   if (!NS_WARN_IF(mTransaction.isNothing())) {
     StopListeningForVisibilityEvents();
   }
@@ -570,9 +547,7 @@ U2F::ClearTransaction()
   mTransaction.reset();
 }
 
-void
-U2F::RejectTransaction(const nsresult& aError)
-{
+void U2F::RejectTransaction(const nsresult& aError) {
   if (NS_WARN_IF(mTransaction.isNothing())) {
     return;
   }
@@ -600,9 +575,7 @@ U2F::RejectTransaction(const nsresult& aError)
   }
 }
 
-void
-U2F::CancelTransaction(const nsresult& aError)
-{
+void U2F::CancelTransaction(const nsresult& aError) {
   if (!NS_WARN_IF(!mChild || mTransaction.isNothing())) {
     mChild->SendRequestCancel(mTransaction.ref().mId);
   }
@@ -610,9 +583,8 @@ U2F::CancelTransaction(const nsresult& aError)
   RejectTransaction(aError);
 }
 
-void
-U2F::RequestAborted(const uint64_t& aTransactionId, const nsresult& aError)
-{
+void U2F::RequestAborted(const uint64_t& aTransactionId,
+                         const nsresult& aError) {
   MOZ_ASSERT(NS_IsMainThread());
 
   if (mTransaction.isSome() && mTransaction.ref().mId == aTransactionId) {
@@ -620,5 +592,5 @@ U2F::RequestAborted(const uint64_t& aTransactionId, const nsresult& aError)
   }
 }
 
-} // namespace dom
-} // namespace mozilla
+}  // namespace dom
+}  // namespace mozilla
