@@ -24,9 +24,12 @@
 // name causes the window.u2f object to disappear until preferences get
 // reloaded, as its pref is a substring!
 #define PREF_U2F_NSSTOKEN_COUNTER "security.webauth.softtoken_counter"
-#define PREF_WEBAUTHN_SOFTTOKEN_ENABLED "security.webauth.webauthn_enable_softtoken"
-#define PREF_WEBAUTHN_USBTOKEN_ENABLED "security.webauth.webauthn_enable_usbtoken"
-#define PREF_WEBAUTHN_ALLOW_DIRECT_ATTESTATION "security.webauth.webauthn_testing_allow_direct_attestation"
+#define PREF_WEBAUTHN_SOFTTOKEN_ENABLED \
+  "security.webauth.webauthn_enable_softtoken"
+#define PREF_WEBAUTHN_USBTOKEN_ENABLED \
+  "security.webauth.webauthn_enable_usbtoken"
+#define PREF_WEBAUTHN_ALLOW_DIRECT_ATTESTATION \
+  "security.webauth.webauthn_testing_allow_direct_attestation"
 
 namespace mozilla {
 namespace dom {
@@ -42,90 +45,80 @@ static mozilla::LazyLogModule gU2FTokenManagerLog("u2fkeymanager");
 StaticRefPtr<U2FTokenManager> gU2FTokenManager;
 StaticRefPtr<U2FPrefManager> gPrefManager;
 static nsIThread* gBackgroundThread;
-}
+}  // namespace
 
 // Data for WebAuthn UI prompt notifications.
 static const char16_t kRegisterPromptNotifcation[] =
-  u"{\"action\":\"register\",\"tid\":%llu,\"origin\":\"%s\"}";
+    u"{\"action\":\"register\",\"tid\":%llu,\"origin\":\"%s\"}";
 static const char16_t kRegisterDirectPromptNotifcation[] =
-  u"{\"action\":\"register-direct\",\"tid\":%llu,\"origin\":\"%s\"}";
+    u"{\"action\":\"register-direct\",\"tid\":%llu,\"origin\":\"%s\"}";
 static const char16_t kSignPromptNotifcation[] =
-  u"{\"action\":\"sign\",\"tid\":%llu,\"origin\":\"%s\"}";
+    u"{\"action\":\"sign\",\"tid\":%llu,\"origin\":\"%s\"}";
 static const char16_t kCancelPromptNotifcation[] =
-  u"{\"action\":\"cancel\",\"tid\":%llu}";
+    u"{\"action\":\"cancel\",\"tid\":%llu}";
 
-class U2FPrefManager final : public nsIObserver
-{
-private:
-  U2FPrefManager() :
-    mPrefMutex("U2FPrefManager Mutex")
-  {
-    UpdateValues();
-  }
+class U2FPrefManager final : public nsIObserver {
+ private:
+  U2FPrefManager() : mPrefMutex("U2FPrefManager Mutex") { UpdateValues(); }
   ~U2FPrefManager() = default;
 
-public:
+ public:
   NS_DECL_ISUPPORTS
 
-  static U2FPrefManager* GetOrCreate()
-  {
+  static U2FPrefManager* GetOrCreate() {
     MOZ_ASSERT(NS_IsMainThread());
     if (!gPrefManager) {
       gPrefManager = new U2FPrefManager();
-      Preferences::AddStrongObserver(gPrefManager, PREF_WEBAUTHN_SOFTTOKEN_ENABLED);
+      Preferences::AddStrongObserver(gPrefManager,
+                                     PREF_WEBAUTHN_SOFTTOKEN_ENABLED);
       Preferences::AddStrongObserver(gPrefManager, PREF_U2F_NSSTOKEN_COUNTER);
-      Preferences::AddStrongObserver(gPrefManager, PREF_WEBAUTHN_USBTOKEN_ENABLED);
-      Preferences::AddStrongObserver(gPrefManager, PREF_WEBAUTHN_ALLOW_DIRECT_ATTESTATION);
+      Preferences::AddStrongObserver(gPrefManager,
+                                     PREF_WEBAUTHN_USBTOKEN_ENABLED);
+      Preferences::AddStrongObserver(gPrefManager,
+                                     PREF_WEBAUTHN_ALLOW_DIRECT_ATTESTATION);
       ClearOnShutdown(&gPrefManager, ShutdownPhase::ShutdownThreads);
     }
     return gPrefManager;
   }
 
-  static U2FPrefManager* Get()
-  {
-    return gPrefManager;
-  }
+  static U2FPrefManager* Get() { return gPrefManager; }
 
-  bool GetSoftTokenEnabled()
-  {
+  bool GetSoftTokenEnabled() {
     MutexAutoLock lock(mPrefMutex);
     return mSoftTokenEnabled;
   }
 
-  int GetSoftTokenCounter()
-  {
+  int GetSoftTokenCounter() {
     MutexAutoLock lock(mPrefMutex);
     return mSoftTokenCounter;
   }
 
-  bool GetUsbTokenEnabled()
-  {
+  bool GetUsbTokenEnabled() {
     MutexAutoLock lock(mPrefMutex);
     return mUsbTokenEnabled;
   }
 
-  bool GetAllowDirectAttestationForTesting()
-  {
+  bool GetAllowDirectAttestationForTesting() {
     MutexAutoLock lock(mPrefMutex);
     return mAllowDirectAttestation;
   }
 
   NS_IMETHODIMP
-  Observe(nsISupports* aSubject,
-          const char* aTopic,
-          const char16_t* aData) override
-  {
+  Observe(nsISupports* aSubject, const char* aTopic,
+          const char16_t* aData) override {
     UpdateValues();
     return NS_OK;
   }
-private:
+
+ private:
   void UpdateValues() {
     MOZ_ASSERT(NS_IsMainThread());
     MutexAutoLock lock(mPrefMutex);
     mSoftTokenEnabled = Preferences::GetBool(PREF_WEBAUTHN_SOFTTOKEN_ENABLED);
     mSoftTokenCounter = Preferences::GetUint(PREF_U2F_NSSTOKEN_COUNTER);
     mUsbTokenEnabled = Preferences::GetBool(PREF_WEBAUTHN_USBTOKEN_ENABLED);
-    mAllowDirectAttestation = Preferences::GetBool(PREF_WEBAUTHN_ALLOW_DIRECT_ATTESTATION);
+    mAllowDirectAttestation =
+        Preferences::GetBool(PREF_WEBAUTHN_ALLOW_DIRECT_ATTESTATION);
   }
 
   Mutex mPrefMutex;
@@ -144,9 +137,7 @@ NS_IMPL_ISUPPORTS(U2FPrefManager, nsIObserver);
 NS_IMPL_ISUPPORTS(U2FTokenManager, nsIU2FTokenManager);
 
 U2FTokenManager::U2FTokenManager()
-  : mTransactionParent(nullptr)
-  , mLastTransactionId(0)
-{
+    : mTransactionParent(nullptr), mLastTransactionId(0) {
   MOZ_ASSERT(XRE_IsParentProcess());
   // Create on the main thread to make sure ClearOnShutdown() works.
   MOZ_ASSERT(NS_IsMainThread());
@@ -154,10 +145,8 @@ U2FTokenManager::U2FTokenManager()
   U2FPrefManager::GetOrCreate();
 }
 
-//static
-void
-U2FTokenManager::Initialize()
-{
+// static
+void U2FTokenManager::Initialize() {
   if (!XRE_IsParentProcess()) {
     return;
   }
@@ -167,27 +156,22 @@ U2FTokenManager::Initialize()
   ClearOnShutdown(&gU2FTokenManager);
 }
 
-//static
-U2FTokenManager*
-U2FTokenManager::Get()
-{
+// static
+U2FTokenManager* U2FTokenManager::Get() {
   MOZ_ASSERT(XRE_IsParentProcess());
   // We should only be accessing this on the background thread
   MOZ_ASSERT(!NS_IsMainThread());
   return gU2FTokenManager;
 }
 
-void
-U2FTokenManager::AbortTransaction(const uint64_t& aTransactionId,
-                                  const nsresult& aError)
-{
+void U2FTokenManager::AbortTransaction(const uint64_t& aTransactionId,
+                                       const nsresult& aError) {
   Unused << mTransactionParent->SendAbort(aTransactionId, aError);
   ClearTransaction();
 }
 
-void
-U2FTokenManager::MaybeClearTransaction(PWebAuthnTransactionParent* aParent)
-{
+void U2FTokenManager::MaybeClearTransaction(
+    PWebAuthnTransactionParent* aParent) {
   // Only clear if we've been requested to do so by our current transaction
   // parent.
   if (mTransactionParent == aParent) {
@@ -195,9 +179,7 @@ U2FTokenManager::MaybeClearTransaction(PWebAuthnTransactionParent* aParent)
   }
 }
 
-void
-U2FTokenManager::ClearTransaction()
-{
+void U2FTokenManager::ClearTransaction() {
   if (mLastTransactionId > 0) {
     // Remove any prompts we might be showing for the current transaction.
     SendPromptNotification(kCancelPromptNotifcation, mLastTransactionId);
@@ -222,9 +204,9 @@ U2FTokenManager::ClearTransaction()
   mPendingRegisterInfo.reset();
 }
 
-template<typename ...T> void
-U2FTokenManager::SendPromptNotification(const char16_t* aFormat, T... aArgs)
-{
+template <typename... T>
+void U2FTokenManager::SendPromptNotification(const char16_t* aFormat,
+                                             T... aArgs) {
   mozilla::ipc::AssertIsOnBackgroundThread();
 
   nsAutoString json;
@@ -235,12 +217,10 @@ U2FTokenManager::SendPromptNotification(const char16_t* aFormat, T... aArgs)
       &U2FTokenManager::RunSendPromptNotification, json));
 
   MOZ_ALWAYS_SUCCEEDS(
-    GetMainThreadEventTarget()->Dispatch(r.forget(), NS_DISPATCH_NORMAL));
+      GetMainThreadEventTarget()->Dispatch(r.forget(), NS_DISPATCH_NORMAL));
 }
 
-void
-U2FTokenManager::RunSendPromptNotification(nsString aJSON)
-{
+void U2FTokenManager::RunSendPromptNotification(nsString aJSON) {
   MOZ_ASSERT(NS_IsMainThread());
 
   nsCOMPtr<nsIObserverService> os = services::GetObserverService();
@@ -249,12 +229,11 @@ U2FTokenManager::RunSendPromptNotification(nsString aJSON)
   }
 
   nsCOMPtr<nsIU2FTokenManager> self = do_QueryInterface(this);
-  MOZ_ALWAYS_SUCCEEDS(os->NotifyObservers(self, "webauthn-prompt", aJSON.get()));
+  MOZ_ALWAYS_SUCCEEDS(
+      os->NotifyObservers(self, "webauthn-prompt", aJSON.get()));
 }
 
-RefPtr<U2FTokenTransport>
-U2FTokenManager::GetTokenManagerImpl()
-{
+RefPtr<U2FTokenTransport> U2FTokenManager::GetTokenManagerImpl() {
   MOZ_ASSERT(U2FPrefManager::Get());
   mozilla::ipc::AssertIsOnBackgroundThread();
 
@@ -287,11 +266,10 @@ U2FTokenManager::GetTokenManagerImpl()
   return nullptr;
 }
 
-void
-U2FTokenManager::Register(PWebAuthnTransactionParent* aTransactionParent,
-                          const uint64_t& aTransactionId,
-                          const WebAuthnMakeCredentialInfo& aTransactionInfo)
-{
+void U2FTokenManager::Register(
+    PWebAuthnTransactionParent* aTransactionParent,
+    const uint64_t& aTransactionId,
+    const WebAuthnMakeCredentialInfo& aTransactionInfo) {
   MOZ_LOG(gU2FTokenManagerLog, LogLevel::Debug, ("U2FAuthRegister"));
 
   ClearTransaction();
@@ -321,8 +299,7 @@ U2FTokenManager::Register(PWebAuthnTransactionParent* aTransactionParent,
   if (aTransactionInfo.RequestDirectAttestation() &&
       !U2FPrefManager::Get()->GetAllowDirectAttestationForTesting()) {
     NS_ConvertUTF16toUTF8 origin(aTransactionInfo.Origin());
-    SendPromptNotification(kRegisterDirectPromptNotifcation,
-                           aTransactionId,
+    SendPromptNotification(kRegisterDirectPromptNotifcation, aTransactionId,
                            origin.get());
 
     MOZ_ASSERT(mPendingRegisterInfo.isNothing());
@@ -332,54 +309,47 @@ U2FTokenManager::Register(PWebAuthnTransactionParent* aTransactionParent,
   }
 }
 
-void
-U2FTokenManager::DoRegister(const WebAuthnMakeCredentialInfo& aInfo)
-{
+void U2FTokenManager::DoRegister(const WebAuthnMakeCredentialInfo& aInfo) {
   mozilla::ipc::AssertIsOnBackgroundThread();
   MOZ_ASSERT(mLastTransactionId > 0);
 
   // Show a prompt that lets the user cancel the ongoing transaction.
   NS_ConvertUTF16toUTF8 origin(aInfo.Origin());
-  SendPromptNotification(kRegisterPromptNotifcation,
-                         mLastTransactionId,
+  SendPromptNotification(kRegisterPromptNotifcation, mLastTransactionId,
                          origin.get());
 
   uint64_t tid = mLastTransactionId;
   mozilla::TimeStamp startTime = mozilla::TimeStamp::Now();
   bool requestDirectAttestation = aInfo.RequestDirectAttestation();
 
-  mTokenManagerImpl
-    ->Register(aInfo)
-    ->Then(GetCurrentThreadSerialEventTarget(), __func__,
-          [tid, startTime, requestDirectAttestation](WebAuthnMakeCredentialResult&& aResult) {
-            U2FTokenManager* mgr = U2FTokenManager::Get();
-            // The token manager implementations set DirectAttestationPermitted
-            // to false by default. Override this here with information from
-            // the JS prompt.
-            aResult.DirectAttestationPermitted() = requestDirectAttestation;
-            mgr->MaybeConfirmRegister(tid, aResult);
-            Telemetry::ScalarAdd(
-              Telemetry::ScalarID::SECURITY_WEBAUTHN_USED,
-              NS_LITERAL_STRING("U2FRegisterFinish"), 1);
-            Telemetry::AccumulateTimeDelta(
-              Telemetry::WEBAUTHN_CREATE_CREDENTIAL_MS,
-              startTime);
-          },
-          [tid](nsresult rv) {
-            MOZ_ASSERT(NS_FAILED(rv));
-            U2FTokenManager* mgr = U2FTokenManager::Get();
-            mgr->MaybeAbortRegister(tid, rv);
-            Telemetry::ScalarAdd(
-              Telemetry::ScalarID::SECURITY_WEBAUTHN_USED,
-              NS_LITERAL_STRING("U2FRegisterAbort"), 1);
-          })
-    ->Track(mRegisterPromise);
+  mTokenManagerImpl->Register(aInfo)
+      ->Then(GetCurrentThreadSerialEventTarget(), __func__,
+             [tid, startTime, requestDirectAttestation](
+                 WebAuthnMakeCredentialResult&& aResult) {
+               U2FTokenManager* mgr = U2FTokenManager::Get();
+               // The token manager implementations set
+               // DirectAttestationPermitted to false by default. Override this
+               // here with information from the JS prompt.
+               aResult.DirectAttestationPermitted() = requestDirectAttestation;
+               mgr->MaybeConfirmRegister(tid, aResult);
+               Telemetry::ScalarAdd(Telemetry::ScalarID::SECURITY_WEBAUTHN_USED,
+                                    NS_LITERAL_STRING("U2FRegisterFinish"), 1);
+               Telemetry::AccumulateTimeDelta(
+                   Telemetry::WEBAUTHN_CREATE_CREDENTIAL_MS, startTime);
+             },
+             [tid](nsresult rv) {
+               MOZ_ASSERT(NS_FAILED(rv));
+               U2FTokenManager* mgr = U2FTokenManager::Get();
+               mgr->MaybeAbortRegister(tid, rv);
+               Telemetry::ScalarAdd(Telemetry::ScalarID::SECURITY_WEBAUTHN_USED,
+                                    NS_LITERAL_STRING("U2FRegisterAbort"), 1);
+             })
+      ->Track(mRegisterPromise);
 }
 
-void
-U2FTokenManager::MaybeConfirmRegister(const uint64_t& aTransactionId,
-                                      const WebAuthnMakeCredentialResult& aResult)
-{
+void U2FTokenManager::MaybeConfirmRegister(
+    const uint64_t& aTransactionId,
+    const WebAuthnMakeCredentialResult& aResult) {
   MOZ_ASSERT(mLastTransactionId == aTransactionId);
   mRegisterPromise.Complete();
 
@@ -387,20 +357,16 @@ U2FTokenManager::MaybeConfirmRegister(const uint64_t& aTransactionId,
   ClearTransaction();
 }
 
-void
-U2FTokenManager::MaybeAbortRegister(const uint64_t& aTransactionId,
-                                    const nsresult& aError)
-{
+void U2FTokenManager::MaybeAbortRegister(const uint64_t& aTransactionId,
+                                         const nsresult& aError) {
   MOZ_ASSERT(mLastTransactionId == aTransactionId);
   mRegisterPromise.Complete();
   AbortTransaction(aTransactionId, aError);
 }
 
-void
-U2FTokenManager::Sign(PWebAuthnTransactionParent* aTransactionParent,
-                      const uint64_t& aTransactionId,
-                      const WebAuthnGetAssertionInfo& aTransactionInfo)
-{
+void U2FTokenManager::Sign(PWebAuthnTransactionParent* aTransactionParent,
+                           const uint64_t& aTransactionId,
+                           const WebAuthnGetAssertionInfo& aTransactionInfo) {
   MOZ_LOG(gU2FTokenManagerLog, LogLevel::Debug, ("U2FAuthSign"));
 
   ClearTransaction();
@@ -420,41 +386,33 @@ U2FTokenManager::Sign(PWebAuthnTransactionParent* aTransactionParent,
 
   // Show a prompt that lets the user cancel the ongoing transaction.
   NS_ConvertUTF16toUTF8 origin(aTransactionInfo.Origin());
-  SendPromptNotification(kSignPromptNotifcation,
-                         aTransactionId,
-                         origin.get());
+  SendPromptNotification(kSignPromptNotifcation, aTransactionId, origin.get());
 
   uint64_t tid = mLastTransactionId = aTransactionId;
   mozilla::TimeStamp startTime = mozilla::TimeStamp::Now();
 
-  mTokenManagerImpl
-    ->Sign(aTransactionInfo)
-    ->Then(GetCurrentThreadSerialEventTarget(), __func__,
-      [tid, startTime](WebAuthnGetAssertionResult&& aResult) {
-        U2FTokenManager* mgr = U2FTokenManager::Get();
-        mgr->MaybeConfirmSign(tid, aResult);
-        Telemetry::ScalarAdd(
-          Telemetry::ScalarID::SECURITY_WEBAUTHN_USED,
-          NS_LITERAL_STRING("U2FSignFinish"), 1);
-        Telemetry::AccumulateTimeDelta(
-          Telemetry::WEBAUTHN_GET_ASSERTION_MS,
-          startTime);
-      },
-      [tid](nsresult rv) {
-        MOZ_ASSERT(NS_FAILED(rv));
-        U2FTokenManager* mgr = U2FTokenManager::Get();
-        mgr->MaybeAbortSign(tid, rv);
-        Telemetry::ScalarAdd(
-          Telemetry::ScalarID::SECURITY_WEBAUTHN_USED,
-          NS_LITERAL_STRING("U2FSignAbort"), 1);
-      })
-    ->Track(mSignPromise);
+  mTokenManagerImpl->Sign(aTransactionInfo)
+      ->Then(GetCurrentThreadSerialEventTarget(), __func__,
+             [tid, startTime](WebAuthnGetAssertionResult&& aResult) {
+               U2FTokenManager* mgr = U2FTokenManager::Get();
+               mgr->MaybeConfirmSign(tid, aResult);
+               Telemetry::ScalarAdd(Telemetry::ScalarID::SECURITY_WEBAUTHN_USED,
+                                    NS_LITERAL_STRING("U2FSignFinish"), 1);
+               Telemetry::AccumulateTimeDelta(
+                   Telemetry::WEBAUTHN_GET_ASSERTION_MS, startTime);
+             },
+             [tid](nsresult rv) {
+               MOZ_ASSERT(NS_FAILED(rv));
+               U2FTokenManager* mgr = U2FTokenManager::Get();
+               mgr->MaybeAbortSign(tid, rv);
+               Telemetry::ScalarAdd(Telemetry::ScalarID::SECURITY_WEBAUTHN_USED,
+                                    NS_LITERAL_STRING("U2FSignAbort"), 1);
+             })
+      ->Track(mSignPromise);
 }
 
-void
-U2FTokenManager::MaybeConfirmSign(const uint64_t& aTransactionId,
-                                  const WebAuthnGetAssertionResult& aResult)
-{
+void U2FTokenManager::MaybeConfirmSign(
+    const uint64_t& aTransactionId, const WebAuthnGetAssertionResult& aResult) {
   MOZ_ASSERT(mLastTransactionId == aTransactionId);
   mSignPromise.Complete();
 
@@ -462,19 +420,15 @@ U2FTokenManager::MaybeConfirmSign(const uint64_t& aTransactionId,
   ClearTransaction();
 }
 
-void
-U2FTokenManager::MaybeAbortSign(const uint64_t& aTransactionId,
-                                const nsresult& aError)
-{
+void U2FTokenManager::MaybeAbortSign(const uint64_t& aTransactionId,
+                                     const nsresult& aError) {
   MOZ_ASSERT(mLastTransactionId == aTransactionId);
   mSignPromise.Complete();
   AbortTransaction(aTransactionId, aError);
 }
 
-void
-U2FTokenManager::Cancel(PWebAuthnTransactionParent* aParent,
-                        const uint64_t& aTransactionId)
-{
+void U2FTokenManager::Cancel(PWebAuthnTransactionParent* aParent,
+                             const uint64_t& aTransactionId) {
   if (mTransactionParent != aParent || mLastTransactionId != aTransactionId) {
     return;
   }
@@ -487,8 +441,7 @@ U2FTokenManager::Cancel(PWebAuthnTransactionParent* aParent,
 
 NS_IMETHODIMP
 U2FTokenManager::ResumeRegister(uint64_t aTransactionId,
-                                bool aPermitDirectAttestation)
-{
+                                bool aPermitDirectAttestation) {
   MOZ_ASSERT(XRE_IsParentProcess());
   MOZ_ASSERT(NS_IsMainThread());
 
@@ -504,10 +457,8 @@ U2FTokenManager::ResumeRegister(uint64_t aTransactionId,
   return gBackgroundThread->Dispatch(r.forget(), NS_DISPATCH_NORMAL);
 }
 
-void
-U2FTokenManager::RunResumeRegister(uint64_t aTransactionId,
-                                   bool aPermitDirectAttestation)
-{
+void U2FTokenManager::RunResumeRegister(uint64_t aTransactionId,
+                                        bool aPermitDirectAttestation) {
   mozilla::ipc::AssertIsOnBackgroundThread();
 
   if (NS_WARN_IF(mPendingRegisterInfo.isNothing())) {
@@ -520,7 +471,7 @@ U2FTokenManager::RunResumeRegister(uint64_t aTransactionId,
 
   // Forward whether the user opted into direct attestation.
   mPendingRegisterInfo.ref().RequestDirectAttestation() =
-    aPermitDirectAttestation;
+      aPermitDirectAttestation;
 
   // Resume registration and cleanup.
   DoRegister(mPendingRegisterInfo.ref());
@@ -528,8 +479,7 @@ U2FTokenManager::RunResumeRegister(uint64_t aTransactionId,
 }
 
 NS_IMETHODIMP
-U2FTokenManager::Cancel(uint64_t aTransactionId)
-{
+U2FTokenManager::Cancel(uint64_t aTransactionId) {
   MOZ_ASSERT(XRE_IsParentProcess());
   MOZ_ASSERT(NS_IsMainThread());
 
@@ -537,16 +487,14 @@ U2FTokenManager::Cancel(uint64_t aTransactionId)
     return NS_ERROR_FAILURE;
   }
 
-  nsCOMPtr<nsIRunnable> r(NewRunnableMethod<uint64_t>(
-      "U2FTokenManager::RunCancel", this,
-      &U2FTokenManager::RunCancel, aTransactionId));
+  nsCOMPtr<nsIRunnable> r(
+      NewRunnableMethod<uint64_t>("U2FTokenManager::RunCancel", this,
+                                  &U2FTokenManager::RunCancel, aTransactionId));
 
   return gBackgroundThread->Dispatch(r.forget(), NS_DISPATCH_NORMAL);
 }
 
-void
-U2FTokenManager::RunCancel(uint64_t aTransactionId)
-{
+void U2FTokenManager::RunCancel(uint64_t aTransactionId) {
   mozilla::ipc::AssertIsOnBackgroundThread();
 
   if (mLastTransactionId != aTransactionId) {
@@ -560,5 +508,5 @@ U2FTokenManager::RunCancel(uint64_t aTransactionId)
   AbortTransaction(aTransactionId, NS_ERROR_DOM_ABORT_ERR);
 }
 
-}
-}
+}  // namespace dom
+}  // namespace mozilla
