@@ -68,14 +68,11 @@ NS_IMPL_CYCLE_COLLECTION_CLASS(nsBindingManager)
 NS_IMPL_CYCLE_COLLECTION_UNLINK_BEGIN(nsBindingManager)
   tmp->mDestroyed = true;
 
-  if (tmp->mBoundContentSet)
-    tmp->mBoundContentSet->Clear();
+  if (tmp->mBoundContentSet) tmp->mBoundContentSet->Clear();
 
-  if (tmp->mDocumentTable)
-    tmp->mDocumentTable->Clear();
+  if (tmp->mDocumentTable) tmp->mDocumentTable->Clear();
 
-  if (tmp->mLoadingDocTable)
-    tmp->mLoadingDocTable->Clear();
+  if (tmp->mLoadingDocTable) tmp->mLoadingDocTable->Clear();
 
   if (tmp->mWrapperTable) {
     tmp->mWrapperTable->Clear();
@@ -89,7 +86,6 @@ NS_IMPL_CYCLE_COLLECTION_UNLINK_BEGIN(nsBindingManager)
   }
 NS_IMPL_CYCLE_COLLECTION_UNLINK_END
 
-
 NS_IMPL_CYCLE_COLLECTION_TRAVERSE_BEGIN(nsBindingManager)
   // The hashes keyed on nsIContent are traversed from the nsIContent itself.
   if (tmp->mDocumentTable) {
@@ -119,37 +115,27 @@ NS_IMPL_CYCLE_COLLECTING_RELEASE(nsBindingManager)
 
 // Constructors/Destructors
 nsBindingManager::nsBindingManager(nsIDocument* aDocument)
-  : mProcessingAttachedStack(false),
-    mDestroyed(false),
-    mAttachedStackSizeOnOutermost(0),
-    mDocument(aDocument)
-{
-}
+    : mProcessingAttachedStack(false),
+      mDestroyed(false),
+      mAttachedStackSizeOnOutermost(0),
+      mDocument(aDocument) {}
 
-nsBindingManager::~nsBindingManager(void)
-{
-  mDestroyed = true;
-}
+nsBindingManager::~nsBindingManager(void) { mDestroyed = true; }
 
-nsXBLBinding*
-nsBindingManager::GetBindingWithContent(const nsIContent* aContent)
-{
+nsXBLBinding* nsBindingManager::GetBindingWithContent(
+    const nsIContent* aContent) {
   nsXBLBinding* binding = aContent ? aContent->GetXBLBinding() : nullptr;
   return binding ? binding->GetBindingWithContent() : nullptr;
 }
 
-void
-nsBindingManager::AddBoundContent(nsIContent* aContent)
-{
+void nsBindingManager::AddBoundContent(nsIContent* aContent) {
   if (!mBoundContentSet) {
-    mBoundContentSet = new nsTHashtable<nsRefPtrHashKey<nsIContent> >;
+    mBoundContentSet = new nsTHashtable<nsRefPtrHashKey<nsIContent>>;
   }
   mBoundContentSet->PutEntry(aContent);
 }
 
-void
-nsBindingManager::RemoveBoundContent(nsIContent* aContent)
-{
+void nsBindingManager::RemoveBoundContent(nsIContent* aContent) {
   if (mBoundContentSet) {
     mBoundContentSet->RemoveEntry(aContent);
   }
@@ -158,9 +144,7 @@ nsBindingManager::RemoveBoundContent(nsIContent* aContent)
   SetWrappedJS(aContent, nullptr);
 }
 
-nsIXPConnectWrappedJS*
-nsBindingManager::GetWrappedJS(nsIContent* aContent)
-{
+nsIXPConnectWrappedJS* nsBindingManager::GetWrappedJS(nsIContent* aContent) {
   if (!mWrapperTable) {
     return nullptr;
   }
@@ -172,9 +156,8 @@ nsBindingManager::GetWrappedJS(nsIContent* aContent)
   return mWrapperTable->GetWeak(aContent);
 }
 
-nsresult
-nsBindingManager::SetWrappedJS(nsIContent* aContent, nsIXPConnectWrappedJS* aWrappedJS)
-{
+nsresult nsBindingManager::SetWrappedJS(nsIContent* aContent,
+                                        nsIXPConnectWrappedJS* aWrappedJS) {
   if (mDestroyed) {
     return NS_OK;
   }
@@ -202,11 +185,9 @@ nsBindingManager::SetWrappedJS(nsIContent* aContent, nsIXPConnectWrappedJS* aWra
   return NS_OK;
 }
 
-void
-nsBindingManager::RemovedFromDocumentInternal(nsIContent* aContent,
-                                              nsIDocument* aOldDocument,
-                                              DestructorHandling aDestructorHandling)
-{
+void nsBindingManager::RemovedFromDocumentInternal(
+    nsIContent* aContent, nsIDocument* aOldDocument,
+    DestructorHandling aDestructorHandling) {
   NS_PRECONDITION(aOldDocument != nullptr, "no old document");
 
   RefPtr<nsXBLBinding> binding = aContent->GetXBLBinding();
@@ -228,10 +209,9 @@ nsBindingManager::RemovedFromDocumentInternal(nsIContent* aContent,
   aContent->SetXBLInsertionPoint(nullptr);
 }
 
-nsAtom*
-nsBindingManager::ResolveTag(nsIContent* aContent, int32_t* aNameSpaceID)
-{
-  nsXBLBinding *binding = aContent->GetXBLBinding();
+nsAtom* nsBindingManager::ResolveTag(nsIContent* aContent,
+                                     int32_t* aNameSpaceID) {
+  nsXBLBinding* binding = aContent->GetXBLBinding();
 
   if (binding) {
     nsAtom* base = binding->GetBaseTag(aNameSpaceID);
@@ -245,27 +225,20 @@ nsBindingManager::ResolveTag(nsIContent* aContent, int32_t* aNameSpaceID)
   return aContent->NodeInfo()->NameAtom();
 }
 
-nsresult
-nsBindingManager::GetAnonymousNodesFor(nsIContent* aContent,
-                                       nsIDOMNodeList** aResult)
-{
+nsresult nsBindingManager::GetAnonymousNodesFor(nsIContent* aContent,
+                                                nsIDOMNodeList** aResult) {
   NS_IF_ADDREF(*aResult = GetAnonymousNodesFor(aContent));
   return NS_OK;
 }
 
-nsINodeList*
-nsBindingManager::GetAnonymousNodesFor(nsIContent* aContent)
-{
+nsINodeList* nsBindingManager::GetAnonymousNodesFor(nsIContent* aContent) {
   nsXBLBinding* binding = GetBindingWithContent(aContent);
   return binding ? binding->GetAnonymousNodeList() : nullptr;
 }
 
-nsresult
-nsBindingManager::ClearBinding(Element* aElement)
-{
+nsresult nsBindingManager::ClearBinding(Element* aElement) {
   // Hold a ref to the binding so it won't die when we remove it from our table
-  RefPtr<nsXBLBinding> binding =
-    aElement ? aElement->GetXBLBinding() : nullptr;
+  RefPtr<nsXBLBinding> binding = aElement ? aElement->GetXBLBinding() : nullptr;
 
   if (!binding) {
     return NS_OK;
@@ -299,39 +272,32 @@ nsBindingManager::ClearBinding(Element* aElement)
   // been removed and style may have changed due to the removal of the
   // anonymous children.
   // XXXbz this should be using the current doc (if any), not the owner doc.
-  presShell = doc->GetShell(); // get the shell again, just in case it changed
+  presShell = doc->GetShell();  // get the shell again, just in case it changed
   NS_ENSURE_TRUE(presShell, NS_ERROR_FAILURE);
 
   presShell->PostRecreateFramesFor(aElement);
   return NS_OK;
 }
 
-nsresult
-nsBindingManager::LoadBindingDocument(nsIDocument* aBoundDoc,
-                                      nsIURI* aURL,
-                                      nsIPrincipal* aOriginPrincipal)
-{
+nsresult nsBindingManager::LoadBindingDocument(nsIDocument* aBoundDoc,
+                                               nsIURI* aURL,
+                                               nsIPrincipal* aOriginPrincipal) {
   NS_PRECONDITION(aURL, "Must have a URI to load!");
 
   // First we need to load our binding.
   nsXBLService* xblService = nsXBLService::GetInstance();
-  if (!xblService)
-    return NS_ERROR_FAILURE;
+  if (!xblService) return NS_ERROR_FAILURE;
 
   // Load the binding doc.
   RefPtr<nsXBLDocumentInfo> info;
-  xblService->LoadBindingDocumentInfo(nullptr, aBoundDoc, aURL,
-                                      aOriginPrincipal, true,
-                                      getter_AddRefs(info));
-  if (!info)
-    return NS_ERROR_FAILURE;
+  xblService->LoadBindingDocumentInfo(
+      nullptr, aBoundDoc, aURL, aOriginPrincipal, true, getter_AddRefs(info));
+  if (!info) return NS_ERROR_FAILURE;
 
   return NS_OK;
 }
 
-void
-nsBindingManager::RemoveFromAttachedQueue(nsXBLBinding* aBinding)
-{
+void nsBindingManager::RemoveFromAttachedQueue(nsXBLBinding* aBinding) {
   // Don't remove items here as that could mess up an executing
   // ProcessAttachedQueue. Instead, null the entry in the queue.
   size_t index = mAttachedStack.IndexOf(aBinding);
@@ -340,9 +306,7 @@ nsBindingManager::RemoveFromAttachedQueue(nsXBLBinding* aBinding)
   }
 }
 
-nsresult
-nsBindingManager::AddToAttachedQueue(nsXBLBinding* aBinding)
-{
+nsresult nsBindingManager::AddToAttachedQueue(nsXBLBinding* aBinding) {
   mAttachedStack.AppendElement(aBinding);
 
   // If we're in the middle of processing our queue already, don't
@@ -357,43 +321,37 @@ nsBindingManager::AddToAttachedQueue(nsXBLBinding* aBinding)
   }
 
   return NS_OK;
-
 }
 
-void
-nsBindingManager::PostProcessAttachedQueueEvent()
-{
+void nsBindingManager::PostProcessAttachedQueueEvent() {
   MOZ_ASSERT(NS_IsMainThread());
   if (!mDocument) {
     return;
   }
   mProcessAttachedQueueEvent =
-    NewRunnableMethod("nsBindingManager::DoProcessAttachedQueue",
-                      this, &nsBindingManager::DoProcessAttachedQueue);
-  nsresult rv = mDocument->EventTargetFor(TaskCategory::Other)->Dispatch(do_AddRef(mProcessAttachedQueueEvent));
+      NewRunnableMethod("nsBindingManager::DoProcessAttachedQueue", this,
+                        &nsBindingManager::DoProcessAttachedQueue);
+  nsresult rv = mDocument->EventTargetFor(TaskCategory::Other)
+                    ->Dispatch(do_AddRef(mProcessAttachedQueueEvent));
   if (NS_SUCCEEDED(rv)) {
     mDocument->BlockOnload();
   }
 }
 
 // static
-void
-nsBindingManager::PostPAQEventCallback(nsITimer* aTimer, void* aClosure)
-{
-  RefPtr<nsBindingManager> mgr =
-    already_AddRefed<nsBindingManager>(static_cast<nsBindingManager*>(aClosure));
+void nsBindingManager::PostPAQEventCallback(nsITimer* aTimer, void* aClosure) {
+  RefPtr<nsBindingManager> mgr = already_AddRefed<nsBindingManager>(
+      static_cast<nsBindingManager*>(aClosure));
   mgr->PostProcessAttachedQueueEvent();
   NS_RELEASE(aTimer);
 }
 
-void
-nsBindingManager::DoProcessAttachedQueue()
-{
+void nsBindingManager::DoProcessAttachedQueue() {
   if (!mProcessingAttachedStack) {
     ProcessAttachedQueue();
 
     NS_ASSERTION(mAttachedStack.Length() == 0,
-               "Shouldn't have pending bindings!");
+                 "Shouldn't have pending bindings!");
 
     mProcessAttachedQueueEvent = nullptr;
   } else {
@@ -405,12 +363,9 @@ nsBindingManager::DoProcessAttachedQueue()
     // event loop non-empty and trigger bug 1021240 on OS X.
     nsresult rv = NS_ERROR_FAILURE;
     nsCOMPtr<nsITimer> timer;
-    rv = NS_NewTimerWithFuncCallback(getter_AddRefs(timer),
-                                     PostPAQEventCallback,
-                                     this,
-                                     100,
-                                     nsITimer::TYPE_ONE_SHOT,
-                                     "nsBindingManager::DoProcessAttachedQueue");
+    rv = NS_NewTimerWithFuncCallback(
+        getter_AddRefs(timer), PostPAQEventCallback, this, 100,
+        nsITimer::TYPE_ONE_SHOT, "nsBindingManager::DoProcessAttachedQueue");
     if (NS_SUCCEEDED(rv)) {
       NS_ADDREF_THIS();
       // We drop our reference to the timer here, since the timer callback is
@@ -428,9 +383,7 @@ nsBindingManager::DoProcessAttachedQueue()
   }
 }
 
-void
-nsBindingManager::ProcessAttachedQueueInternal(uint32_t aSkipSize)
-{
+void nsBindingManager::ProcessAttachedQueueInternal(uint32_t aSkipSize) {
   mProcessingAttachedStack = true;
 
   // Excute constructors. Do this from high index to low
@@ -455,9 +408,7 @@ nsBindingManager::ProcessAttachedQueueInternal(uint32_t aSkipSize)
 }
 
 // Keep bindings and bound elements alive while executing detached handlers.
-void
-nsBindingManager::ExecuteDetachedHandlers()
-{
+void nsBindingManager::ExecuteDetachedHandlers() {
   // Walk our hashtable of bindings.
   if (!mBoundContentSet) {
     return;
@@ -481,13 +432,12 @@ nsBindingManager::ExecuteDetachedHandlers()
   }
 }
 
-nsresult
-nsBindingManager::PutXBLDocumentInfo(nsXBLDocumentInfo* aDocumentInfo)
-{
+nsresult nsBindingManager::PutXBLDocumentInfo(
+    nsXBLDocumentInfo* aDocumentInfo) {
   NS_PRECONDITION(aDocumentInfo, "Must have a non-null documentinfo!");
 
   if (!mDocumentTable) {
-    mDocumentTable = new nsRefPtrHashtable<nsURIHashKey,nsXBLDocumentInfo>();
+    mDocumentTable = new nsRefPtrHashtable<nsURIHashKey, nsXBLDocumentInfo>();
   }
 
   mDocumentTable->Put(aDocumentInfo->DocumentURI(), aDocumentInfo);
@@ -495,57 +445,44 @@ nsBindingManager::PutXBLDocumentInfo(nsXBLDocumentInfo* aDocumentInfo)
   return NS_OK;
 }
 
-void
-nsBindingManager::RemoveXBLDocumentInfo(nsXBLDocumentInfo* aDocumentInfo)
-{
+void nsBindingManager::RemoveXBLDocumentInfo(nsXBLDocumentInfo* aDocumentInfo) {
   if (mDocumentTable) {
     mDocumentTable->Remove(aDocumentInfo->DocumentURI());
   }
 }
 
-nsXBLDocumentInfo*
-nsBindingManager::GetXBLDocumentInfo(nsIURI* aURL)
-{
-  if (!mDocumentTable)
-    return nullptr;
+nsXBLDocumentInfo* nsBindingManager::GetXBLDocumentInfo(nsIURI* aURL) {
+  if (!mDocumentTable) return nullptr;
 
   return mDocumentTable->GetWeak(aURL);
 }
 
-nsresult
-nsBindingManager::PutLoadingDocListener(nsIURI* aURL, nsIStreamListener* aListener)
-{
+nsresult nsBindingManager::PutLoadingDocListener(nsIURI* aURL,
+                                                 nsIStreamListener* aListener) {
   NS_PRECONDITION(aListener, "Must have a non-null listener!");
 
   if (!mLoadingDocTable) {
     mLoadingDocTable =
-      new nsInterfaceHashtable<nsURIHashKey,nsIStreamListener>();
+        new nsInterfaceHashtable<nsURIHashKey, nsIStreamListener>();
   }
   mLoadingDocTable->Put(aURL, aListener);
 
   return NS_OK;
 }
 
-nsIStreamListener*
-nsBindingManager::GetLoadingDocListener(nsIURI* aURL)
-{
-  if (!mLoadingDocTable)
-    return nullptr;
+nsIStreamListener* nsBindingManager::GetLoadingDocListener(nsIURI* aURL) {
+  if (!mLoadingDocTable) return nullptr;
 
   return mLoadingDocTable->GetWeak(aURL);
 }
 
-void
-nsBindingManager::RemoveLoadingDocListener(nsIURI* aURL)
-{
+void nsBindingManager::RemoveLoadingDocListener(nsIURI* aURL) {
   if (mLoadingDocTable) {
     mLoadingDocTable->Remove(aURL);
   }
 }
 
-void
-nsBindingManager::FlushSkinBindings()
-{
+void nsBindingManager::FlushSkinBindings() {
   if (!mBoundContentSet) {
     return;
   }
@@ -572,21 +509,20 @@ struct AntiRecursionData {
   REFNSIID iid;
   AntiRecursionData* next;
 
-  AntiRecursionData(nsIContent* aElement,
-                    REFNSIID aIID,
+  AntiRecursionData(nsIContent* aElement, REFNSIID aIID,
                     AntiRecursionData* aNext)
-    : element(aElement), iid(aIID), next(aNext) {}
+      : element(aElement), iid(aIID), next(aNext) {}
 };
 
-nsresult
-nsBindingManager::GetBindingImplementation(nsIContent* aContent, REFNSIID aIID,
-                                           void** aResult)
-{
+nsresult nsBindingManager::GetBindingImplementation(nsIContent* aContent,
+                                                    REFNSIID aIID,
+                                                    void** aResult) {
   *aResult = nullptr;
-  nsXBLBinding *binding = aContent ? aContent->GetXBLBinding() : nullptr;
+  nsXBLBinding* binding = aContent ? aContent->GetXBLBinding() : nullptr;
   if (binding) {
     // The binding should not be asked for nsISupports
-    NS_ASSERTION(!aIID.Equals(NS_GET_IID(nsISupports)), "Asking a binding for nsISupports");
+    NS_ASSERTION(!aIID.Equals(NS_GET_IID(nsISupports)),
+                 "Asking a binding for nsISupports");
     if (binding->ImplementsInterface(aIID)) {
       nsCOMPtr<nsIXPConnectWrappedJS> wrappedJS = GetWrappedJS(aContent);
 
@@ -625,8 +561,7 @@ nsBindingManager::GetBindingImplementation(nsIContent* aContent, REFNSIID aIID,
 
         list = item.next;
 
-        if (*aResult)
-          return rv;
+        if (*aResult) return rv;
 
         // No result was found, so this must be another XBL interface.
         // Fall through to create a new wrapper.
@@ -638,7 +573,7 @@ nsBindingManager::GetBindingImplementation(nsIContent* aContent, REFNSIID aIID,
       jsapi.Init();
       JSContext* cx = jsapi.cx();
 
-      nsIXPConnect *xpConnect = nsContentUtils::XPConnect();
+      nsIXPConnect* xpConnect = nsContentUtils::XPConnect();
 
       JS::Rooted<JSObject*> jsobj(cx, aContent->GetWrapper());
       NS_ENSURE_TRUE(jsobj, NS_NOINTERFACE);
@@ -658,14 +593,14 @@ nsBindingManager::GetBindingImplementation(nsIContent* aContent, REFNSIID aIID,
       NS_ENSURE_TRUE(ok, NS_ERROR_OUT_OF_MEMORY);
       MOZ_ASSERT_IF(js::IsWrapper(jsobj), xpc::IsXrayWrapper(jsobj));
 
-      nsresult rv = xpConnect->WrapJSAggregatedToNative(aContent, cx,
-                                                        jsobj, aIID, aResult);
-      if (NS_FAILED(rv))
-        return rv;
+      nsresult rv = xpConnect->WrapJSAggregatedToNative(aContent, cx, jsobj,
+                                                        aIID, aResult);
+      if (NS_FAILED(rv)) return rv;
 
-      // We successfully created a wrapper.  We will own this wrapper for as long as the binding remains
-      // alive.  At the time the binding is cleared out of the bindingManager, we will remove the wrapper
-      // from the bindingManager as well.
+      // We successfully created a wrapper.  We will own this wrapper for as
+      // long as the binding remains alive.  At the time the binding is cleared
+      // out of the bindingManager, we will remove the wrapper from the
+      // bindingManager as well.
       nsISupports* supp = static_cast<nsISupports*>(*aResult);
       wrappedJS = do_QueryInterface(supp);
       SetWrappedJS(aContent, wrappedJS);
@@ -679,21 +614,19 @@ nsBindingManager::GetBindingImplementation(nsIContent* aContent, REFNSIID aIID,
 }
 
 #ifdef MOZ_OLD_STYLE
-nsresult
-nsBindingManager::WalkRules(nsIStyleRuleProcessor::EnumFunc aFunc,
-                            ElementDependentRuleProcessorData* aData,
-                            bool* aCutOffInheritance)
-{
+nsresult nsBindingManager::WalkRules(nsIStyleRuleProcessor::EnumFunc aFunc,
+                                     ElementDependentRuleProcessorData* aData,
+                                     bool* aCutOffInheritance) {
   *aCutOffInheritance = false;
 
   NS_ASSERTION(aData->mElement, "How did that happen?");
 
   // Walk the binding scope chain, starting with the binding attached to our
   // content, up till we run out of scopes or we get cut off.
-  nsIContent *content = aData->mElement;
+  nsIContent* content = aData->mElement;
 
   do {
-    nsXBLBinding *binding = content->GetXBLBinding();
+    nsXBLBinding* binding = content->GetXBLBinding();
     if (binding) {
       binding->WalkRules(aFunc, aData);
       // If we're not looking at our original content, allow the binding to cut
@@ -707,7 +640,7 @@ nsBindingManager::WalkRules(nsIStyleRuleProcessor::EnumFunc aFunc,
     }
 
     if (content->IsRootOfNativeAnonymousSubtree()) {
-      break; // Deliberately cut off style inheritance here.
+      break;  // Deliberately cut off style inheritance here.
     }
 
     content = content->GetBindingParent();
@@ -721,10 +654,8 @@ nsBindingManager::WalkRules(nsIStyleRuleProcessor::EnumFunc aFunc,
 }
 #endif
 
-bool
-nsBindingManager::EnumerateBoundContentProtoBindings(
-  const BoundContentProtoBindingCallback& aCallback) const
-{
+bool nsBindingManager::EnumerateBoundContentProtoBindings(
+    const BoundContentProtoBindingCallback& aCallback) const {
   if (!mBoundContentSet) {
     return true;
   }
@@ -732,8 +663,7 @@ nsBindingManager::EnumerateBoundContentProtoBindings(
   nsTHashtable<nsPtrHashKey<nsXBLPrototypeBinding>> bindings;
   for (auto iter = mBoundContentSet->Iter(); !iter.Done(); iter.Next()) {
     nsIContent* boundContent = iter.Get()->GetKey();
-    for (nsXBLBinding* binding = boundContent->GetXBLBinding();
-         binding;
+    for (nsXBLBinding* binding = boundContent->GetXBLBinding(); binding;
          binding = binding->GetBaseBinding()) {
       nsXBLPrototypeBinding* proto = binding->PrototypeBinding();
       // If we have already invoked the callback with a binding, we
@@ -752,10 +682,8 @@ nsBindingManager::EnumerateBoundContentProtoBindings(
 }
 
 #ifdef MOZ_OLD_STYLE
-void
-nsBindingManager::WalkAllRules(nsIStyleRuleProcessor::EnumFunc aFunc,
-                               ElementDependentRuleProcessorData* aData)
-{
+void nsBindingManager::WalkAllRules(nsIStyleRuleProcessor::EnumFunc aFunc,
+                                    ElementDependentRuleProcessorData* aData) {
   EnumerateBoundContentProtoBindings([=](nsXBLPrototypeBinding* aProto) {
     nsIStyleRuleProcessor* ruleProcessor = aProto->GetRuleProcessor();
     if (ruleProcessor) {
@@ -766,22 +694,21 @@ nsBindingManager::WalkAllRules(nsIStyleRuleProcessor::EnumFunc aFunc,
 }
 #endif
 
-bool
-nsBindingManager::MediumFeaturesChanged(nsPresContext* aPresContext,
-                                        mozilla::MediaFeatureChangeReason aReason)
-{
+bool nsBindingManager::MediumFeaturesChanged(
+    nsPresContext* aPresContext, mozilla::MediaFeatureChangeReason aReason) {
   MOZ_ASSERT(!mDocument->IsStyledByServo());
 #ifdef MOZ_OLD_STYLE
   bool rulesChanged = false;
   RefPtr<nsPresContext> presContext = aPresContext;
-  EnumerateBoundContentProtoBindings([=, &rulesChanged](nsXBLPrototypeBinding* aProto) {
-    nsIStyleRuleProcessor* ruleProcessor = aProto->GetRuleProcessor();
-    if (ruleProcessor) {
-      bool thisChanged = ruleProcessor->MediumFeaturesChanged(presContext);
-      rulesChanged = rulesChanged || thisChanged;
-    }
-    return true;
-  });
+  EnumerateBoundContentProtoBindings(
+      [=, &rulesChanged](nsXBLPrototypeBinding* aProto) {
+        nsIStyleRuleProcessor* ruleProcessor = aProto->GetRuleProcessor();
+        if (ruleProcessor) {
+          bool thisChanged = ruleProcessor->MediumFeaturesChanged(presContext);
+          rulesChanged = rulesChanged || thisChanged;
+        }
+        return true;
+      });
   return rulesChanged;
 #else
   MOZ_CRASH("old style system disabled");
@@ -789,19 +716,15 @@ nsBindingManager::MediumFeaturesChanged(nsPresContext* aPresContext,
 #endif
 }
 
-void
-nsBindingManager::AppendAllSheets(nsTArray<StyleSheet*>& aArray)
-{
+void nsBindingManager::AppendAllSheets(nsTArray<StyleSheet*>& aArray) {
   EnumerateBoundContentProtoBindings([&aArray](nsXBLPrototypeBinding* aProto) {
     aProto->AppendStyleSheetsTo(aArray);
     return true;
   });
 }
 
-static void
-InsertAppendedContent(XBLChildrenElement* aPoint,
-                      nsIContent* aFirstNewContent)
-{
+static void InsertAppendedContent(XBLChildrenElement* aPoint,
+                                  nsIContent* aFirstNewContent) {
   int32_t insertionIndex;
   if (nsIContent* prevSibling = aFirstNewContent->GetPreviousSibling()) {
     // If we have a previous sibling, then it must already be in aPoint. Find
@@ -819,16 +742,13 @@ InsertAppendedContent(XBLChildrenElement* aPoint,
   }
 
   // Do the inserting.
-  for (nsIContent* currentChild = aFirstNewContent;
-       currentChild;
+  for (nsIContent* currentChild = aFirstNewContent; currentChild;
        currentChild = currentChild->GetNextSibling()) {
     aPoint->InsertInsertedChildAt(currentChild, insertionIndex++);
   }
 }
 
-void
-nsBindingManager::ContentAppended(nsIContent* aFirstNewContent)
-{
+void nsBindingManager::ContentAppended(nsIContent* aFirstNewContent) {
   // Try to find insertion points for all the new kids.
   XBLChildrenElement* point = nullptr;
   nsIContent* container = aFirstNewContent->GetParent();
@@ -893,16 +813,12 @@ nsBindingManager::ContentAppended(nsIContent* aFirstNewContent)
   } while (parent);
 }
 
-void
-nsBindingManager::ContentInserted(nsIContent* aChild)
-{
+void nsBindingManager::ContentInserted(nsIContent* aChild) {
   HandleChildInsertion(aChild->GetParent(), aChild, false);
 }
 
-void
-nsBindingManager::ContentRemoved(nsIContent* aChild,
-                                 nsIContent* aPreviousSibling)
-{
+void nsBindingManager::ContentRemoved(nsIContent* aChild,
+                                      nsIContent* aPreviousSibling) {
   aChild->SetXBLInsertionPoint(nullptr);
 
   XBLChildrenElement* point = nullptr;
@@ -950,9 +866,7 @@ nsBindingManager::ContentRemoved(nsIContent* aChild,
   } while (parent);
 }
 
-void
-nsBindingManager::ClearInsertionPointsRecursively(nsIContent* aContent)
-{
+void nsBindingManager::ClearInsertionPointsRecursively(nsIContent* aContent) {
   if (aContent->NodeInfo()->Equals(nsGkAtoms::children, kNameSpaceID_XBL)) {
     static_cast<XBLChildrenElement*>(aContent)->ClearInsertedChildren();
   }
@@ -963,9 +877,7 @@ nsBindingManager::ClearInsertionPointsRecursively(nsIContent* aContent)
   }
 }
 
-void
-nsBindingManager::DropDocumentReference()
-{
+void nsBindingManager::DropDocumentReference() {
   mDestroyed = true;
 
   // Make sure to not run any more XBL constructors
@@ -981,10 +893,8 @@ nsBindingManager::DropDocumentReference()
   mDocument = nullptr;
 }
 
-void
-nsBindingManager::Traverse(nsIContent *aContent,
-                           nsCycleCollectionTraversalCallback &cb)
-{
+void nsBindingManager::Traverse(nsIContent* aContent,
+                                nsCycleCollectionTraversalCallback& cb) {
   if (!aContent->HasFlag(NODE_MAY_BE_IN_BINDING_MNGR) ||
       !aContent->IsElement()) {
     // Don't traverse if content is not in this binding manager.
@@ -996,24 +906,24 @@ nsBindingManager::Traverse(nsIContent *aContent,
   }
 
   if (mBoundContentSet && mBoundContentSet->Contains(aContent)) {
-    NS_CYCLE_COLLECTION_NOTE_EDGE_NAME(cb, "[via binding manager] mBoundContentSet entry");
+    NS_CYCLE_COLLECTION_NOTE_EDGE_NAME(
+        cb, "[via binding manager] mBoundContentSet entry");
     cb.NoteXPCOMChild(aContent);
   }
 
-  nsIXPConnectWrappedJS *value = GetWrappedJS(aContent);
+  nsIXPConnectWrappedJS* value = GetWrappedJS(aContent);
   if (value) {
-    NS_CYCLE_COLLECTION_NOTE_EDGE_NAME(cb, "[via binding manager] mWrapperTable key");
+    NS_CYCLE_COLLECTION_NOTE_EDGE_NAME(
+        cb, "[via binding manager] mWrapperTable key");
     cb.NoteXPCOMChild(aContent);
-    NS_CYCLE_COLLECTION_NOTE_EDGE_NAME(cb, "[via binding manager] mWrapperTable value");
+    NS_CYCLE_COLLECTION_NOTE_EDGE_NAME(
+        cb, "[via binding manager] mWrapperTable value");
     cb.NoteXPCOMChild(value);
   }
 }
 
-void
-nsBindingManager::HandleChildInsertion(nsIContent* aContainer,
-                                       nsIContent* aChild,
-                                       bool aAppend)
-{
+void nsBindingManager::HandleChildInsertion(nsIContent* aContainer,
+                                            nsIContent* aChild, bool aAppend) {
   MOZ_ASSERT(aChild, "Must have child");
 
   XBLChildrenElement* point = nullptr;
@@ -1071,22 +981,19 @@ nsBindingManager::HandleChildInsertion(nsIContent* aContainer,
   }
 }
 
-nsIContent*
-nsBindingManager::FindNestedSingleInsertionPoint(nsIContent* aContainer,
-                                                 bool* aMulti)
-{
+nsIContent* nsBindingManager::FindNestedSingleInsertionPoint(
+    nsIContent* aContainer, bool* aMulti) {
   *aMulti = false;
 
   nsIContent* parent = aContainer;
   if (aContainer->IsActiveChildrenElement()) {
-    if (static_cast<XBLChildrenElement*>(aContainer)->
-          HasInsertedChildren()) {
+    if (static_cast<XBLChildrenElement*>(aContainer)->HasInsertedChildren()) {
       return nullptr;
     }
     parent = aContainer->GetParent();
   }
 
-  while(parent) {
+  while (parent) {
     nsXBLBinding* binding = GetBindingWithContent(parent);
     if (!binding) {
       break;
@@ -1112,9 +1019,7 @@ nsBindingManager::FindNestedSingleInsertionPoint(nsIContent* aContainer,
   return parent;
 }
 
-size_t
-nsBindingManager::SizeOfIncludingThis(MallocSizeOf aMallocSizeOf) const
-{
+size_t nsBindingManager::SizeOfIncludingThis(MallocSizeOf aMallocSizeOf) const {
   size_t n = aMallocSizeOf(this);
 
 #define SHALLOW_SIZE_INCLUDING(field_) \
@@ -1135,7 +1040,7 @@ nsBindingManager::SizeOfIncludingThis(MallocSizeOf aMallocSizeOf) const
       nsXBLDocumentInfo* docInfo = iter.UserData();
 #ifdef MOZ_XUL
       nsXBLDocumentInfo* cachedInfo =
-        cache->GetXBLDocumentInfo(iter.Key(), backendType);
+          cache->GetXBLDocumentInfo(iter.Key(), backendType);
       if (cachedInfo == docInfo) {
         // If this binding has been cached, skip it since it can be
         // reused by other documents.
