@@ -67,70 +67,59 @@ using namespace mozilla::dom;
 //
 // The JS class for XBLBinding
 //
-static void
-XBLFinalize(JSFreeOp *fop, JSObject *obj)
-{
+static void XBLFinalize(JSFreeOp* fop, JSObject* obj) {
   nsXBLDocumentInfo* docInfo =
-    static_cast<nsXBLDocumentInfo*>(::JS_GetPrivate(obj));
+      static_cast<nsXBLDocumentInfo*>(::JS_GetPrivate(obj));
   DeferredFinalize(docInfo);
 }
 
-static bool
-XBLEnumerate(JSContext *cx, JS::Handle<JSObject*> obj)
-{
-  nsXBLPrototypeBinding* protoBinding =
-    static_cast<nsXBLPrototypeBinding*>(::JS_GetReservedSlot(obj, 0).toPrivate());
+static bool XBLEnumerate(JSContext* cx, JS::Handle<JSObject*> obj) {
+  nsXBLPrototypeBinding* protoBinding = static_cast<nsXBLPrototypeBinding*>(
+      ::JS_GetReservedSlot(obj, 0).toPrivate());
   MOZ_ASSERT(protoBinding);
 
   return protoBinding->ResolveAllFields(cx, obj);
 }
 
 static const JSClassOps gPrototypeJSClassOps = {
-    nullptr, nullptr,
-    XBLEnumerate, nullptr, nullptr,
-    nullptr, XBLFinalize,
-    nullptr, nullptr, nullptr, nullptr
-};
+    nullptr,     nullptr, XBLEnumerate, nullptr, nullptr, nullptr,
+    XBLFinalize, nullptr, nullptr,      nullptr, nullptr};
 
 static const JSClass gPrototypeJSClass = {
     "XBL prototype JSClass",
-    JSCLASS_HAS_PRIVATE |
-    JSCLASS_PRIVATE_IS_NSISUPPORTS |
-    JSCLASS_FOREGROUND_FINALIZE |
-    // Our one reserved slot holds the relevant nsXBLPrototypeBinding
-    JSCLASS_HAS_RESERVED_SLOTS(1),
-    &gPrototypeJSClassOps
-};
+    JSCLASS_HAS_PRIVATE | JSCLASS_PRIVATE_IS_NSISUPPORTS |
+        JSCLASS_FOREGROUND_FINALIZE |
+        // Our one reserved slot holds the relevant nsXBLPrototypeBinding
+        JSCLASS_HAS_RESERVED_SLOTS(1),
+    &gPrototypeJSClassOps};
 
-// Implementation /////////////////////////////////////////////////////////////////
+// Implementation //////////////////////////////////////////////////////////////
 
 // Constructors/Destructors
 nsXBLBinding::nsXBLBinding(nsXBLPrototypeBinding* aBinding)
-  : mMarkedForDeath(false)
-  , mUsingContentXBLScope(false)
-  , mIsShadowRootBinding(false)
-  , mPrototypeBinding(aBinding)
-{
+    : mMarkedForDeath(false),
+      mUsingContentXBLScope(false),
+      mIsShadowRootBinding(false),
+      mPrototypeBinding(aBinding) {
   NS_ASSERTION(mPrototypeBinding, "Must have a prototype binding!");
   // Grab a ref to the document info so the prototype binding won't die
   NS_ADDREF(mPrototypeBinding->XBLDocumentInfo());
 }
 
 // Constructor used by web components.
-nsXBLBinding::nsXBLBinding(ShadowRoot* aShadowRoot, nsXBLPrototypeBinding* aBinding)
-  : mMarkedForDeath(false),
-    mUsingContentXBLScope(false),
-    mIsShadowRootBinding(true),
-    mPrototypeBinding(aBinding),
-    mContent(aShadowRoot)
-{
+nsXBLBinding::nsXBLBinding(ShadowRoot* aShadowRoot,
+                           nsXBLPrototypeBinding* aBinding)
+    : mMarkedForDeath(false),
+      mUsingContentXBLScope(false),
+      mIsShadowRootBinding(true),
+      mPrototypeBinding(aBinding),
+      mContent(aShadowRoot) {
   NS_ASSERTION(mPrototypeBinding, "Must have a prototype binding!");
   // Grab a ref to the document info so the prototype binding won't die
   NS_ADDREF(mPrototypeBinding->XBLDocumentInfo());
 }
 
-nsXBLBinding::~nsXBLBinding(void)
-{
+nsXBLBinding::~nsXBLBinding(void) {
   if (mContent && !mIsShadowRootBinding) {
     // It is unnecessary to uninstall anonymous content in a shadow tree
     // because the ShadowRoot itself is a DocumentFragment and does not
@@ -169,20 +158,16 @@ NS_IMPL_CYCLE_COLLECTION_TRAVERSE_END
 NS_IMPL_CYCLE_COLLECTION_ROOT_NATIVE(nsXBLBinding, AddRef)
 NS_IMPL_CYCLE_COLLECTION_UNROOT_NATIVE(nsXBLBinding, Release)
 
-void
-nsXBLBinding::SetBaseBinding(nsXBLBinding* aBinding)
-{
+void nsXBLBinding::SetBaseBinding(nsXBLBinding* aBinding) {
   if (mNextBinding) {
     NS_ERROR("Base XBL binding is already defined!");
     return;
   }
 
-  mNextBinding = aBinding; // Comptr handles rel/add
+  mNextBinding = aBinding;  // Comptr handles rel/add
 }
 
-nsXBLBinding*
-nsXBLBinding::GetBindingWithContent()
-{
+nsXBLBinding* nsXBLBinding::GetBindingWithContent() {
   if (mContent) {
     return this;
   }
@@ -190,11 +175,9 @@ nsXBLBinding::GetBindingWithContent()
   return mNextBinding ? mNextBinding->GetBindingWithContent() : nullptr;
 }
 
-void
-nsXBLBinding::BindAnonymousContent(nsIContent* aAnonParent,
-                                   nsIContent* aElement,
-                                   bool aChromeOnlyContent)
-{
+void nsXBLBinding::BindAnonymousContent(nsIContent* aAnonParent,
+                                        nsIContent* aElement,
+                                        bool aChromeOnlyContent) {
   // We need to ensure two things.
   // (1) The anonymous content should be fooled into thinking it's in the bound
   // element's document, assuming that the bound element is in a document
@@ -208,8 +191,7 @@ nsXBLBinding::BindAnonymousContent(nsIContent* aAnonParent,
   bool allowScripts = AllowScripts();
 
   nsAutoScriptBlocker scriptBlocker;
-  for (nsIContent* child = aAnonParent->GetFirstChild();
-       child;
+  for (nsIContent* child = aAnonParent->GetFirstChild(); child;
        child = child->GetNextSibling()) {
     child->UnbindFromTree();
     if (aChromeOnlyContent) {
@@ -217,8 +199,7 @@ nsXBLBinding::BindAnonymousContent(nsIContent* aAnonParent,
                       NODE_IS_ROOT_OF_CHROME_ONLY_ACCESS);
     }
     child->SetFlags(NODE_IS_ANONYMOUS_ROOT);
-    nsresult rv =
-      child->BindToTree(doc, aElement, mBoundElement, allowScripts);
+    nsresult rv = child->BindToTree(doc, aElement, mBoundElement, allowScripts);
     if (NS_FAILED(rv)) {
       // Oh, well... Just give up.
       // XXXbz This really shouldn't be a void method!
@@ -238,19 +219,16 @@ nsXBLBinding::BindAnonymousContent(nsIContent* aAnonParent,
   }
 }
 
-void
-nsXBLBinding::UnbindAnonymousContent(nsIDocument* aDocument,
-                                     nsIContent* aAnonParent,
-                                     bool aNullParent)
-{
+void nsXBLBinding::UnbindAnonymousContent(nsIDocument* aDocument,
+                                          nsIContent* aAnonParent,
+                                          bool aNullParent) {
   nsAutoScriptBlocker scriptBlocker;
   // Hold a strong ref while doing this, just in case.
   nsCOMPtr<nsIContent> anonParent = aAnonParent;
 #ifdef MOZ_XUL
   XULDocument* xuldoc = aDocument ? aDocument->AsXULDocument() : nullptr;
 #endif
-  for (nsIContent* child = aAnonParent->GetFirstChild();
-       child;
+  for (nsIContent* child = aAnonParent->GetFirstChild(); child;
        child = child->GetNextSibling()) {
     child->UnbindFromTree(true, aNullParent);
 #ifdef MOZ_XUL
@@ -261,12 +239,9 @@ nsXBLBinding::UnbindAnonymousContent(nsIDocument* aDocument,
   }
 }
 
-void
-nsXBLBinding::SetBoundElement(Element* aElement)
-{
+void nsXBLBinding::SetBoundElement(Element* aElement) {
   mBoundElement = aElement;
-  if (mNextBinding)
-    mNextBinding->SetBoundElement(aElement);
+  if (mNextBinding) mNextBinding->SetBoundElement(aElement);
 
   if (!mBoundElement) {
     return;
@@ -280,34 +255,28 @@ nsXBLBinding::SetBoundElement(Element* aElement)
   // is not given in the handler declaration.
   nsCOMPtr<nsIGlobalObject> go = mBoundElement->OwnerDoc()->GetScopeObject();
   NS_ENSURE_TRUE_VOID(go && go->GetGlobalJSObject());
-  mUsingContentXBLScope = xpc::UseContentXBLScope(JS::GetObjectRealmOrNull(go->GetGlobalJSObject()));
+  mUsingContentXBLScope = xpc::UseContentXBLScope(
+      JS::GetObjectRealmOrNull(go->GetGlobalJSObject()));
 }
 
-bool
-nsXBLBinding::HasStyleSheets() const
-{
+bool nsXBLBinding::HasStyleSheets() const {
   // Find out if we need to re-resolve style.  We'll need to do this
   // if we have additional stylesheets in our binding document.
-  if (mPrototypeBinding->HasStyleSheets())
-    return true;
+  if (mPrototypeBinding->HasStyleSheets()) return true;
 
   return mNextBinding ? mNextBinding->HasStyleSheets() : false;
 }
 
-void
-nsXBLBinding::GenerateAnonymousContent()
-{
+void nsXBLBinding::GenerateAnonymousContent() {
   NS_ASSERTION(!nsContentUtils::IsSafeToRunScript(),
                "Someone forgot a script blocker");
 
   // Fetch the content element for this binding.
-  Element* content =
-    mPrototypeBinding->GetImmediateChild(nsGkAtoms::content);
+  Element* content = mPrototypeBinding->GetImmediateChild(nsGkAtoms::content);
 
   if (!content) {
     // We have no anonymous content.
-    if (mNextBinding)
-      mNextBinding->GenerateAnonymousContent();
+    if (mNextBinding) mNextBinding->GenerateAnonymousContent();
 
     return;
   }
@@ -321,9 +290,8 @@ nsXBLBinding::GenerateAnonymousContent()
   if (hasContent) {
     nsIDocument* doc = mBoundElement->OwnerDoc();
 
-    nsCOMPtr<nsINode> clonedNode =
-      nsNodeUtils::Clone(content, true, doc->NodeInfoManager(), nullptr,
-                         IgnoreErrors());
+    nsCOMPtr<nsINode> clonedNode = nsNodeUtils::Clone(
+        content, true, doc->NodeInfoManager(), nullptr, IgnoreErrors());
     // FIXME: Bug 1399558, Why is this code OK assuming that nsNodeUtils::Clone
     // never fails?
     mContent = clonedNode->AsElement();
@@ -331,7 +299,8 @@ nsXBLBinding::GenerateAnonymousContent()
     // Search for <xbl:children> elements in the XBL content. In the presence
     // of multiple default insertion points, we use the last one in document
     // order.
-    for (nsIContent* child = mContent; child; child = child->GetNextNode(mContent)) {
+    for (nsIContent* child = mContent; child;
+         child = child->GetNextNode(mContent)) {
       if (child->NodeInfo()->Equals(nsGkAtoms::children, kNameSpaceID_XBL)) {
         XBLChildrenElement* point = static_cast<XBLChildrenElement*>(child);
         if (point->IsDefaultInsertion()) {
@@ -350,7 +319,8 @@ nsXBLBinding::GenerateAnonymousContent()
     // Insert explicit children into insertion points
     if (mDefaultInsertionPoint && mInsertionPoints.IsEmpty()) {
       ExplicitChildIterator iter(mBoundElement);
-      for (nsIContent* child = iter.GetNextChild(); child; child = iter.GetNextChild()) {
+      for (nsIContent* child = iter.GetNextChild(); child;
+           child = iter.GetNextChild()) {
         mDefaultInsertionPoint->AppendInsertedChild(child);
       }
     } else {
@@ -358,12 +328,13 @@ nsXBLBinding::GenerateAnonymousContent()
       // we need to make sure to do the compatibility hack below if the bound
       // node has any non <xul:template> or <xul:observes> children.
       ExplicitChildIterator iter(mBoundElement);
-      for (nsIContent* child = iter.GetNextChild(); child; child = iter.GetNextChild()) {
+      for (nsIContent* child = iter.GetNextChild(); child;
+           child = iter.GetNextChild()) {
         XBLChildrenElement* point = FindInsertionPointForInternal(child);
         if (point) {
           point->AppendInsertedChild(child);
         } else {
-          NodeInfo *ni = child->NodeInfo();
+          NodeInfo* ni = child->NodeInfo();
           if (ni->NamespaceID() != kNameSpaceID_XUL ||
               (!ni->Equals(nsGkAtoms::_template) &&
                !ni->Equals(nsGkAtoms::observes))) {
@@ -421,16 +392,13 @@ nsXBLBinding::GenerateAnonymousContent()
     // FIXME(emilio): It'd be nice to make `mContent` a `RefPtr<Element>`, but
     // as of right now it can also be a ShadowRoot (we don't enter in this
     // codepath though). Move Shadow DOM outside XBL and then fix that.
-    if (mContent)
-      mContent->AsElement()->UnsetAttr(namespaceID, name, false);
+    if (mContent) mContent->AsElement()->UnsetAttr(namespaceID, name, false);
   }
 }
 
-nsIURI*
-nsXBLBinding::GetSourceDocURI()
-{
+nsIURI* nsXBLBinding::GetSourceDocURI() {
   nsIContent* targetContent =
-    mPrototypeBinding->GetImmediateChild(nsGkAtoms::content);
+      mPrototypeBinding->GetImmediateChild(nsGkAtoms::content);
   if (!targetContent) {
     return nullptr;
   }
@@ -438,22 +406,18 @@ nsXBLBinding::GetSourceDocURI()
   return targetContent->OwnerDoc()->GetDocumentURI();
 }
 
-XBLChildrenElement*
-nsXBLBinding::FindInsertionPointFor(nsIContent* aChild)
-{
+XBLChildrenElement* nsXBLBinding::FindInsertionPointFor(nsIContent* aChild) {
   // XXX We should get rid of this function as it causes us to traverse the
   // binding chain multiple times
   if (mContent) {
     return FindInsertionPointForInternal(aChild);
   }
 
-  return mNextBinding ? mNextBinding->FindInsertionPointFor(aChild)
-                      : nullptr;
+  return mNextBinding ? mNextBinding->FindInsertionPointFor(aChild) : nullptr;
 }
 
-XBLChildrenElement*
-nsXBLBinding::FindInsertionPointForInternal(nsIContent* aChild)
-{
+XBLChildrenElement* nsXBLBinding::FindInsertionPointForInternal(
+    nsIContent* aChild) {
   for (uint32_t i = 0; i < mInsertionPoints.Length(); ++i) {
     XBLChildrenElement* point = mInsertionPoints[i];
     if (point->Includes(aChild)) {
@@ -464,9 +428,7 @@ nsXBLBinding::FindInsertionPointForInternal(nsIContent* aChild)
   return mDefaultInsertionPoint;
 }
 
-void
-nsXBLBinding::ClearInsertionPoints()
-{
+void nsXBLBinding::ClearInsertionPoints() {
   if (mDefaultInsertionPoint) {
     mDefaultInsertionPoint->ClearInsertedChildren();
   }
@@ -476,9 +438,7 @@ nsXBLBinding::ClearInsertionPoints()
   }
 }
 
-nsAnonymousContentList*
-nsXBLBinding::GetAnonymousNodeList()
-{
+nsAnonymousContentList* nsXBLBinding::GetAnonymousNodeList() {
   if (!mContent) {
     return mNextBinding ? mNextBinding->GetAnonymousNodeList() : nullptr;
   }
@@ -490,30 +450,26 @@ nsXBLBinding::GetAnonymousNodeList()
   return mAnonymousContentList;
 }
 
-void
-nsXBLBinding::InstallEventHandlers()
-{
+void nsXBLBinding::InstallEventHandlers() {
   // Don't install handlers if scripts aren't allowed.
   if (AllowScripts()) {
     // Fetch the handlers prototypes for this binding.
-    nsXBLPrototypeHandler* handlerChain = mPrototypeBinding->GetPrototypeHandlers();
+    nsXBLPrototypeHandler* handlerChain =
+        mPrototypeBinding->GetPrototypeHandlers();
 
     if (handlerChain) {
-      EventListenerManager* manager = mBoundElement->GetOrCreateListenerManager();
-      if (!manager)
-        return;
+      EventListenerManager* manager =
+          mBoundElement->GetOrCreateListenerManager();
+      if (!manager) return;
 
-      bool isChromeDoc =
-        nsContentUtils::IsChromeDoc(mBoundElement->OwnerDoc());
+      bool isChromeDoc = nsContentUtils::IsChromeDoc(mBoundElement->OwnerDoc());
       bool isChromeBinding = mPrototypeBinding->IsChrome();
       nsXBLPrototypeHandler* curr;
       for (curr = handlerChain; curr; curr = curr->GetNextHandler()) {
         // Fetch the event type.
         RefPtr<nsAtom> eventAtom = curr->GetEventName();
-        if (!eventAtom ||
-            eventAtom == nsGkAtoms::keyup ||
-            eventAtom == nsGkAtoms::keydown ||
-            eventAtom == nsGkAtoms::keypress)
+        if (!eventAtom || eventAtom == nsGkAtoms::keyup ||
+            eventAtom == nsGkAtoms::keydown || eventAtom == nsGkAtoms::keypress)
           continue;
 
         nsXBLEventHandler* handler = curr->GetEventHandler();
@@ -523,26 +479,27 @@ nsXBLBinding::InstallEventHandlers()
           flags.mCapture = (curr->GetPhase() == NS_PHASE_CAPTURING);
 
           // If this is a command, add it in the system event group
-          if ((curr->GetType() & (NS_HANDLER_TYPE_XBL_COMMAND |
-                                  NS_HANDLER_TYPE_SYSTEM)) &&
-              (isChromeBinding || mBoundElement->IsInNativeAnonymousSubtree())) {
+          if ((curr->GetType() &
+               (NS_HANDLER_TYPE_XBL_COMMAND | NS_HANDLER_TYPE_SYSTEM)) &&
+              (isChromeBinding ||
+               mBoundElement->IsInNativeAnonymousSubtree())) {
             flags.mInSystemGroup = true;
           }
 
           bool hasAllowUntrustedAttr = curr->HasAllowUntrustedAttr();
           if ((hasAllowUntrustedAttr && curr->AllowUntrustedEvents()) ||
-              (!hasAllowUntrustedAttr && !isChromeDoc && !mUsingContentXBLScope)) {
+              (!hasAllowUntrustedAttr && !isChromeDoc &&
+               !mUsingContentXBLScope)) {
             flags.mAllowUntrustedEvents = true;
           }
 
-          manager->AddEventListenerByType(handler,
-                                          nsDependentAtomString(eventAtom),
-                                          flags);
+          manager->AddEventListenerByType(
+              handler, nsDependentAtomString(eventAtom), flags);
         }
       }
 
       const nsCOMArray<nsXBLKeyEventHandler>* keyHandlers =
-        mPrototypeBinding->GetKeyEventHandlers();
+          mPrototypeBinding->GetKeyEventHandlers();
       int32_t i;
       for (i = 0; i < keyHandlers->Count(); ++i) {
         nsXBLKeyEventHandler* handler = keyHandlers->ObjectAt(i);
@@ -559,8 +516,8 @@ nsXBLBinding::InstallEventHandlers()
         EventListenerFlags flags;
         flags.mCapture = (handler->GetPhase() == NS_PHASE_CAPTURING);
 
-        if ((handler->GetType() & (NS_HANDLER_TYPE_XBL_COMMAND |
-                                   NS_HANDLER_TYPE_SYSTEM)) &&
+        if ((handler->GetType() &
+             (NS_HANDLER_TYPE_XBL_COMMAND | NS_HANDLER_TYPE_SYSTEM)) &&
             (isChromeBinding || mBoundElement->IsInNativeAnonymousSubtree())) {
           flags.mInSystemGroup = true;
         }
@@ -575,13 +532,10 @@ nsXBLBinding::InstallEventHandlers()
     }
   }
 
-  if (mNextBinding)
-    mNextBinding->InstallEventHandlers();
+  if (mNextBinding) mNextBinding->InstallEventHandlers();
 }
 
-nsresult
-nsXBLBinding::InstallImplementation()
-{
+nsresult nsXBLBinding::InstallImplementation() {
   // Always install the base class properties first, so that
   // derived classes can reference the base class properties.
 
@@ -590,62 +544,49 @@ nsXBLBinding::InstallImplementation()
     NS_ENSURE_SUCCESS(rv, rv);
   }
 
-  // iterate through each property in the prototype's list and install the property.
-  if (AllowScripts())
-    return mPrototypeBinding->InstallImplementation(this);
+  // iterate through each property in the prototype's list and install the
+  // property.
+  if (AllowScripts()) return mPrototypeBinding->InstallImplementation(this);
 
   return NS_OK;
 }
 
-nsAtom*
-nsXBLBinding::GetBaseTag(int32_t* aNameSpaceID)
-{
-  nsAtom *tag = mPrototypeBinding->GetBaseTag(aNameSpaceID);
-  if (!tag && mNextBinding)
-    return mNextBinding->GetBaseTag(aNameSpaceID);
+nsAtom* nsXBLBinding::GetBaseTag(int32_t* aNameSpaceID) {
+  nsAtom* tag = mPrototypeBinding->GetBaseTag(aNameSpaceID);
+  if (!tag && mNextBinding) return mNextBinding->GetBaseTag(aNameSpaceID);
 
   return tag;
 }
 
-void
-nsXBLBinding::AttributeChanged(nsAtom* aAttribute, int32_t aNameSpaceID,
-                               bool aRemoveFlag, bool aNotify)
-{
-  // XXX Change if we ever allow multiple bindings in a chain to contribute anonymous content
+void nsXBLBinding::AttributeChanged(nsAtom* aAttribute, int32_t aNameSpaceID,
+                                    bool aRemoveFlag, bool aNotify) {
+  // XXX Change if we ever allow multiple bindings in a chain to contribute
+  // anonymous content
   if (!mContent) {
     if (mNextBinding)
-      mNextBinding->AttributeChanged(aAttribute, aNameSpaceID,
-                                     aRemoveFlag, aNotify);
+      mNextBinding->AttributeChanged(aAttribute, aNameSpaceID, aRemoveFlag,
+                                     aNotify);
   } else {
     mPrototypeBinding->AttributeChanged(aAttribute, aNameSpaceID, aRemoveFlag,
                                         mBoundElement, mContent, aNotify);
   }
 }
 
-void
-nsXBLBinding::ExecuteAttachedHandler()
-{
-  if (mNextBinding)
-    mNextBinding->ExecuteAttachedHandler();
+void nsXBLBinding::ExecuteAttachedHandler() {
+  if (mNextBinding) mNextBinding->ExecuteAttachedHandler();
 
-  if (AllowScripts())
-    mPrototypeBinding->BindingAttached(mBoundElement);
+  if (AllowScripts()) mPrototypeBinding->BindingAttached(mBoundElement);
 }
 
-void
-nsXBLBinding::ExecuteDetachedHandler()
-{
-  if (AllowScripts())
-    mPrototypeBinding->BindingDetached(mBoundElement);
+void nsXBLBinding::ExecuteDetachedHandler() {
+  if (AllowScripts()) mPrototypeBinding->BindingDetached(mBoundElement);
 
-  if (mNextBinding)
-    mNextBinding->ExecuteDetachedHandler();
+  if (mNextBinding) mNextBinding->ExecuteDetachedHandler();
 }
 
-void
-nsXBLBinding::UnhookEventHandlers()
-{
-  nsXBLPrototypeHandler* handlerChain = mPrototypeBinding->GetPrototypeHandlers();
+void nsXBLBinding::UnhookEventHandlers() {
+  nsXBLPrototypeHandler* handlerChain =
+      mPrototypeBinding->GetPrototypeHandlers();
 
   if (handlerChain) {
     EventListenerManager* manager = mBoundElement->GetExistingListenerManager();
@@ -662,10 +603,8 @@ nsXBLBinding::UnhookEventHandlers()
       }
 
       RefPtr<nsAtom> eventAtom = curr->GetEventName();
-      if (!eventAtom ||
-          eventAtom == nsGkAtoms::keyup ||
-          eventAtom == nsGkAtoms::keydown ||
-          eventAtom == nsGkAtoms::keypress)
+      if (!eventAtom || eventAtom == nsGkAtoms::keyup ||
+          eventAtom == nsGkAtoms::keydown || eventAtom == nsGkAtoms::keypress)
         continue;
 
       // Figure out if we're using capturing or not.
@@ -675,19 +614,18 @@ nsXBLBinding::UnhookEventHandlers()
       // If this is a command, remove it from the system event group,
       // otherwise remove it from the standard event group.
 
-      if ((curr->GetType() & (NS_HANDLER_TYPE_XBL_COMMAND |
-                              NS_HANDLER_TYPE_SYSTEM)) &&
+      if ((curr->GetType() &
+           (NS_HANDLER_TYPE_XBL_COMMAND | NS_HANDLER_TYPE_SYSTEM)) &&
           (isChromeBinding || mBoundElement->IsInNativeAnonymousSubtree())) {
         flags.mInSystemGroup = true;
       }
 
-      manager->RemoveEventListenerByType(handler,
-                                         nsDependentAtomString(eventAtom),
-                                         flags);
+      manager->RemoveEventListenerByType(
+          handler, nsDependentAtomString(eventAtom), flags);
     }
 
     const nsCOMArray<nsXBLKeyEventHandler>* keyHandlers =
-      mPrototypeBinding->GetKeyEventHandlers();
+        mPrototypeBinding->GetKeyEventHandlers();
     int32_t i;
     for (i = 0; i < keyHandlers->Count(); ++i) {
       nsXBLKeyEventHandler* handler = keyHandlers->ObjectAt(i);
@@ -702,7 +640,8 @@ nsXBLBinding::UnhookEventHandlers()
       // If this is a command, remove it from the system event group, otherwise
       // remove it from the standard event group.
 
-      if ((handler->GetType() & (NS_HANDLER_TYPE_XBL_COMMAND | NS_HANDLER_TYPE_SYSTEM)) &&
+      if ((handler->GetType() &
+           (NS_HANDLER_TYPE_XBL_COMMAND | NS_HANDLER_TYPE_SYSTEM)) &&
           (isChromeBinding || mBoundElement->IsInNativeAnonymousSubtree())) {
         flags.mInSystemGroup = true;
       }
@@ -712,11 +651,9 @@ nsXBLBinding::UnhookEventHandlers()
   }
 }
 
-void
-nsXBLBinding::ChangeDocument(nsIDocument* aOldDocument, nsIDocument* aNewDocument)
-{
-  if (aOldDocument == aNewDocument)
-    return;
+void nsXBLBinding::ChangeDocument(nsIDocument* aOldDocument,
+                                  nsIDocument* aNewDocument) {
+  if (aOldDocument == aNewDocument) return;
 
   // Now the binding dies.  Unhook our prototypes.
   if (mPrototypeBinding->HasImplementation()) {
@@ -741,7 +678,7 @@ nsXBLBinding::ChangeDocument(nsIDocument* aOldDocument, nsIDocument* aNewDocumen
 
         JS::Rooted<JSObject*> base(cx, scriptObject);
         JS::Rooted<JSObject*> proto(cx);
-        for ( ; true; base = proto) { // Will break out on null proto
+        for (; true; base = proto) {  // Will break out on null proto
           if (!JS_GetPrototype(cx, base, &proto)) {
             return;
           }
@@ -755,7 +692,7 @@ nsXBLBinding::ChangeDocument(nsIDocument* aOldDocument, nsIDocument* aNewDocumen
           }
 
           RefPtr<nsXBLDocumentInfo> docInfo =
-            static_cast<nsXBLDocumentInfo*>(::JS_GetPrivate(proto));
+              static_cast<nsXBLDocumentInfo*>(::JS_GetPrivate(proto));
           if (!docInfo) {
             // Not the proto we seek
             continue;
@@ -809,42 +746,35 @@ nsXBLBinding::ChangeDocument(nsIDocument* aOldDocument, nsIDocument* aNewDocumen
   }
 }
 
-bool
-nsXBLBinding::InheritsStyle() const
-{
-  // XXX Will have to change if we ever allow multiple bindings to contribute anonymous content.
-  // Most derived binding with anonymous content determines style inheritance for now.
+bool nsXBLBinding::InheritsStyle() const {
+  // XXX Will have to change if we ever allow multiple bindings to contribute
+  // anonymous content. Most derived binding with anonymous content determines
+  // style inheritance for now.
 
-  // XXX What about bindings with <content> but no kids, e.g., my treecell-text binding?
-  if (mContent)
-    return mPrototypeBinding->InheritsStyle();
+  // XXX What about bindings with <content> but no kids, e.g., my treecell-text
+  // binding?
+  if (mContent) return mPrototypeBinding->InheritsStyle();
 
-  if (mNextBinding)
-    return mNextBinding->InheritsStyle();
+  if (mNextBinding) return mNextBinding->InheritsStyle();
 
   return true;
 }
 
 #ifdef MOZ_OLD_STYLE
-void
-nsXBLBinding::WalkRules(nsIStyleRuleProcessor::EnumFunc aFunc, void* aData)
-{
-  if (mNextBinding)
-    mNextBinding->WalkRules(aFunc, aData);
+void nsXBLBinding::WalkRules(nsIStyleRuleProcessor::EnumFunc aFunc,
+                             void* aData) {
+  if (mNextBinding) mNextBinding->WalkRules(aFunc, aData);
 
-  nsIStyleRuleProcessor *rules = mPrototypeBinding->GetRuleProcessor();
-  if (rules)
-    (*aFunc)(rules, aData);
+  nsIStyleRuleProcessor* rules = mPrototypeBinding->GetRuleProcessor();
+  if (rules) (*aFunc)(rules, aData);
 }
 #endif
 
-const RawServoAuthorStyles*
-nsXBLBinding::GetServoStyles() const
-{
+const RawServoAuthorStyles* nsXBLBinding::GetServoStyles() const {
   return mPrototypeBinding->GetServoStyles();
 }
 
-// Internal helper methods ////////////////////////////////////////////////////////////////
+// Internal helper methods /////////////////////////////////////////////////////
 
 // Get or create a WeakMap object on a given XBL-hosting global.
 //
@@ -854,9 +784,9 @@ nsXBLBinding::GetServoStyles() const
 // content before it was bound, and the prototype of the class object that we
 // splice in. The values in the WeakMap are simple dictionary-style objects,
 // mapping from XBL class names to class objects.
-static JSObject*
-GetOrCreateClassObjectMap(JSContext *cx, JS::Handle<JSObject*> scope, const char *mapName)
-{
+static JSObject* GetOrCreateClassObjectMap(JSContext* cx,
+                                           JS::Handle<JSObject*> scope,
+                                           const char* mapName) {
   AssertSameCompartment(cx, scope);
   MOZ_ASSERT(JS_IsGlobalObject(scope));
   MOZ_ASSERT(scope == xpc::GetXBLScopeOrGlobal(cx, scope));
@@ -874,16 +804,14 @@ GetOrCreateClassObjectMap(JSContext *cx, JS::Handle<JSObject*> scope, const char
   // It's not there. Create and define it.
   JS::Rooted<JSObject*> map(cx, JS::NewWeakMapObject(cx));
   if (!map || !JS_DefineProperty(cx, scope, mapName, map,
-                                 JSPROP_PERMANENT | JSPROP_READONLY))
-  {
+                                 JSPROP_PERMANENT | JSPROP_READONLY)) {
     return nullptr;
   }
   return map;
 }
 
-static JSObject*
-GetOrCreateMapEntryForPrototype(JSContext *cx, JS::Handle<JSObject*> proto)
-{
+static JSObject* GetOrCreateMapEntryForPrototype(JSContext* cx,
+                                                 JS::Handle<JSObject*> proto) {
   AssertSameCompartment(cx, proto);
   // We want to hang our class objects off the XBL scope. But since we also
   // hoist anonymous content into the XBL scope, this creates the potential for
@@ -896,8 +824,9 @@ GetOrCreateMapEntryForPrototype(JSContext *cx, JS::Handle<JSObject*> proto)
   // So we define two maps - one class objects that live in content (prototyped
   // to content prototypes), and the other for class objects that live in the
   // XBL scope (prototyped to cross-compartment-wrapped content prototypes).
-  const char* name = xpc::IsInContentXBLScope(proto) ? "__ContentClassObjectMap__"
-                                                     : "__XBLClassObjectMap__";
+  const char* name = xpc::IsInContentXBLScope(proto)
+                         ? "__ContentClassObjectMap__"
+                         : "__XBLClassObjectMap__";
 
   // Now, enter the XBL scope, since that's where we need to operate, and wrap
   // the proto accordingly. We hang the map off of the content XBL scope for
@@ -935,31 +864,26 @@ GetOrCreateMapEntryForPrototype(JSContext *cx, JS::Handle<JSObject*> proto)
   }
   JS::Rooted<JS::Value> entryVal(cx, JS::ObjectValue(*entry));
   if (!JS::SetWeakMapEntry(cx, map, wrappedProto, entryVal)) {
-    NS_WARNING("SetWeakMapEntry failed, probably due to non-preservable WeakMap "
-               "key. XBL binding will fail for this element.");
+    NS_WARNING(
+        "SetWeakMapEntry failed, probably due to non-preservable WeakMap "
+        "key. XBL binding will fail for this element.");
     return nullptr;
   }
   return entry;
 }
 
-static
-nsXBLPrototypeBinding*
-GetProtoBindingFromClassObject(JSObject* obj)
-{
+static nsXBLPrototypeBinding* GetProtoBindingFromClassObject(JSObject* obj) {
   MOZ_ASSERT(JS_GetClass(obj) == &gPrototypeJSClass);
-  return static_cast<nsXBLPrototypeBinding*>(::JS_GetReservedSlot(obj, 0).toPrivate());
+  return static_cast<nsXBLPrototypeBinding*>(
+      ::JS_GetReservedSlot(obj, 0).toPrivate());
 }
 
-
 // static
-nsresult
-nsXBLBinding::DoInitJSClass(JSContext *cx,
-                            JS::Handle<JSObject*> obj,
-                            const nsString& aClassName,
-                            nsXBLPrototypeBinding* aProtoBinding,
-                            JS::MutableHandle<JSObject*> aClassObject,
-                            bool* aNew)
-{
+nsresult nsXBLBinding::DoInitJSClass(JSContext* cx, JS::Handle<JSObject*> obj,
+                                     const nsString& aClassName,
+                                     nsXBLPrototypeBinding* aProtoBinding,
+                                     JS::MutableHandle<JSObject*> aClassObject,
+                                     bool* aNew) {
   MOZ_ASSERT(obj);
 
   // Note that, now that NAC reflectors are created in the XBL scope, the
@@ -997,7 +921,8 @@ nsXBLBinding::DoInitJSClass(JSContext *cx,
     holder = GetOrCreateMapEntryForPrototype(cx, parent_proto);
   } else {
     JSAutoCompartment innerAC(cx, xblScope);
-    holder = GetOrCreateClassObjectMap(cx, xblScope, "__ContentClassObjectMap__");
+    holder =
+        GetOrCreateClassObjectMap(cx, xblScope, "__ContentClassObjectMap__");
   }
   if (NS_WARN_IF(!holder)) {
     return NS_ERROR_FAILURE;
@@ -1010,17 +935,17 @@ nsXBLBinding::DoInitJSClass(JSContext *cx,
   // to create and define it.
   JS::Rooted<JSObject*> proto(cx);
   JS::Rooted<JS::PropertyDescriptor> desc(cx);
-  if (!JS_GetOwnUCPropertyDescriptor(cx, holder, aClassName.get(), &desc)) {
+  if (!JS_GetOwnUCPropertyDescriptor(cx, holder, aClassName.get(),
+                                     aClassName.Length(), &desc)) {
     return NS_ERROR_OUT_OF_MEMORY;
   }
   *aNew = !desc.object();
   if (desc.object()) {
     proto = &desc.value().toObject();
     DebugOnly<nsXBLPrototypeBinding*> cachedBinding =
-      GetProtoBindingFromClassObject(js::UncheckedUnwrap(proto));
+        GetProtoBindingFromClassObject(js::UncheckedUnwrap(proto));
     MOZ_ASSERT(cachedBinding == aProtoBinding);
   } else {
-
     // We need to create the prototype. First, enter the compartment where it's
     // going to live, and create it.
     JSAutoCompartment ac2(cx, global);
@@ -1045,8 +970,7 @@ nsXBLBinding::DoInitJSClass(JSContext *cx,
     JSAutoCompartment ac3(cx, holder);
     if (!JS_WrapObject(cx, &proto) ||
         !JS_DefineUCProperty(cx, holder, aClassName.get(), -1, proto,
-                             JSPROP_READONLY | JSPROP_PERMANENT))
-    {
+                             JSPROP_READONLY | JSPROP_PERMANENT)) {
       return NS_ERROR_OUT_OF_MEMORY;
     }
   }
@@ -1061,24 +985,18 @@ nsXBLBinding::DoInitJSClass(JSContext *cx,
   return NS_OK;
 }
 
-bool
-nsXBLBinding::AllowScripts()
-{
+bool nsXBLBinding::AllowScripts() {
   return mBoundElement && mPrototypeBinding->GetAllowScripts();
 }
 
-nsXBLBinding*
-nsXBLBinding::RootBinding()
-{
-  if (mNextBinding)
-    return mNextBinding->RootBinding();
+nsXBLBinding* nsXBLBinding::RootBinding() {
+  if (mNextBinding) return mNextBinding->RootBinding();
 
   return this;
 }
 
-bool
-nsXBLBinding::ResolveAllFields(JSContext *cx, JS::Handle<JSObject*> obj) const
-{
+bool nsXBLBinding::ResolveAllFields(JSContext* cx,
+                                    JS::Handle<JSObject*> obj) const {
   if (!mPrototypeBinding->ResolveAllFields(cx, obj)) {
     return false;
   }
@@ -1090,10 +1008,9 @@ nsXBLBinding::ResolveAllFields(JSContext *cx, JS::Handle<JSObject*> obj) const
   return true;
 }
 
-bool
-nsXBLBinding::LookupMember(JSContext* aCx, JS::Handle<jsid> aId,
-                           JS::MutableHandle<JS::PropertyDescriptor> aDesc)
-{
+bool nsXBLBinding::LookupMember(
+    JSContext* aCx, JS::Handle<jsid> aId,
+    JS::MutableHandle<JS::PropertyDescriptor> aDesc) {
   // We should never enter this function with a pre-filled property descriptor.
   MOZ_ASSERT(!aDesc.object());
 
@@ -1123,8 +1040,8 @@ nsXBLBinding::LookupMember(JSContext* aCx, JS::Handle<jsid> aId,
   //
   // This code is only called for content XBL, so we don't have to worry about
   // add-on scopes here.
-  JS::Rooted<JSObject*> boundScope(aCx,
-    js::GetGlobalForObjectCrossCompartment(mBoundElement->GetWrapper()));
+  JS::Rooted<JSObject*> boundScope(
+      aCx, js::GetGlobalForObjectCrossCompartment(mBoundElement->GetWrapper()));
   MOZ_RELEASE_ASSERT(!xpc::IsInAddonScope(boundScope));
   MOZ_RELEASE_ASSERT(!xpc::IsInContentXBLScope(boundScope));
   JS::Rooted<JSObject*> xblScope(aCx, xpc::GetXBLScope(aCx, boundScope));
@@ -1144,12 +1061,10 @@ nsXBLBinding::LookupMember(JSContext* aCx, JS::Handle<jsid> aId,
   return JS_WrapPropertyDescriptor(aCx, aDesc);
 }
 
-bool
-nsXBLBinding::LookupMemberInternal(JSContext* aCx, nsString& aName,
-                                   JS::Handle<jsid> aNameAsId,
-                                   JS::MutableHandle<JS::PropertyDescriptor> aDesc,
-                                   JS::Handle<JSObject*> aXBLScope)
-{
+bool nsXBLBinding::LookupMemberInternal(
+    JSContext* aCx, nsString& aName, JS::Handle<jsid> aNameAsId,
+    JS::MutableHandle<JS::PropertyDescriptor> aDesc,
+    JS::Handle<JSObject*> aXBLScope) {
   // First, see if we have an implementation. If we don't, it means that this
   // binding doesn't have a class object, and thus doesn't have any members.
   // Skip it.
@@ -1157,12 +1072,12 @@ nsXBLBinding::LookupMemberInternal(JSContext* aCx, nsString& aName,
     if (!mNextBinding) {
       return true;
     }
-    return mNextBinding->LookupMemberInternal(aCx, aName, aNameAsId,
-                                              aDesc, aXBLScope);
+    return mNextBinding->LookupMemberInternal(aCx, aName, aNameAsId, aDesc,
+                                              aXBLScope);
   }
 
-  // Find our class object. It's in a protected scope and permanent just in case,
-  // so should be there no matter what.
+  // Find our class object. It's in a protected scope and permanent just in
+  // case, so should be there no matter what.
   JS::Rooted<JS::Value> classObject(aCx);
   if (!JS_GetUCProperty(aCx, aXBLScope, PrototypeBinding()->ClassName().get(),
                         -1, &classObject)) {
@@ -1194,24 +1109,18 @@ nsXBLBinding::LookupMemberInternal(JSContext* aCx, nsString& aName,
                                             aXBLScope);
 }
 
-bool
-nsXBLBinding::HasField(nsString& aName)
-{
+bool nsXBLBinding::HasField(nsString& aName) {
   // See if this binding has such a field.
   return mPrototypeBinding->FindField(aName) ||
-    (mNextBinding && mNextBinding->HasField(aName));
+         (mNextBinding && mNextBinding->HasField(aName));
 }
 
-void
-nsXBLBinding::MarkForDeath()
-{
+void nsXBLBinding::MarkForDeath() {
   mMarkedForDeath = true;
   ExecuteDetachedHandler();
 }
 
-bool
-nsXBLBinding::ImplementsInterface(REFNSIID aIID) const
-{
+bool nsXBLBinding::ImplementsInterface(REFNSIID aIID) const {
   return mPrototypeBinding->ImplementsInterface(aIID) ||
-    (mNextBinding && mNextBinding->ImplementsInterface(aIID));
+         (mNextBinding && mNextBinding->ImplementsInterface(aIID));
 }
