@@ -31,12 +31,8 @@
 using namespace mozilla;
 using namespace mozilla::dom;
 
-nsresult
-NS_NewXBLContentSink(nsIXMLContentSink** aResult,
-                     nsIDocument* aDoc,
-                     nsIURI* aURI,
-                     nsISupports* aContainer)
-{
+nsresult NS_NewXBLContentSink(nsIXMLContentSink** aResult, nsIDocument* aDoc,
+                              nsIURI* aURI, nsISupports* aContainer) {
   NS_ENSURE_ARG_POINTER(aResult);
 
   RefPtr<nsXBLContentSink> it = new nsXBLContentSink();
@@ -48,56 +44,43 @@ NS_NewXBLContentSink(nsIXMLContentSink** aResult,
 }
 
 nsXBLContentSink::nsXBLContentSink()
-  : mState(eXBL_InDocument),
-    mSecondaryState(eXBL_None),
-    mDocInfo(nullptr),
-    mIsChromeOrResource(false),
-    mFoundFirstBinding(false),
-    mBinding(nullptr),
-    mHandler(nullptr),
-    mImplementation(nullptr),
-    mImplMember(nullptr),
-    mImplField(nullptr),
-    mProperty(nullptr),
-    mMethod(nullptr),
-    mField(nullptr)
-{
+    : mState(eXBL_InDocument),
+      mSecondaryState(eXBL_None),
+      mDocInfo(nullptr),
+      mIsChromeOrResource(false),
+      mFoundFirstBinding(false),
+      mBinding(nullptr),
+      mHandler(nullptr),
+      mImplementation(nullptr),
+      mImplMember(nullptr),
+      mImplField(nullptr),
+      mProperty(nullptr),
+      mMethod(nullptr),
+      mField(nullptr) {
   mPrettyPrintXML = false;
 }
 
-nsXBLContentSink::~nsXBLContentSink()
-{
-}
+nsXBLContentSink::~nsXBLContentSink() {}
 
-nsresult
-nsXBLContentSink::Init(nsIDocument* aDoc,
-                       nsIURI* aURI,
-                       nsISupports* aContainer)
-{
+nsresult nsXBLContentSink::Init(nsIDocument* aDoc, nsIURI* aURI,
+                                nsISupports* aContainer) {
   nsresult rv;
   rv = nsXMLContentSink::Init(aDoc, aURI, aContainer, nullptr);
   return rv;
 }
 
-void
-nsXBLContentSink::MaybeStartLayout(bool aIgnorePendingSheets)
-{
-}
+void nsXBLContentSink::MaybeStartLayout(bool aIgnorePendingSheets) {}
 
-nsresult
-nsXBLContentSink::FlushText(bool aReleaseTextNode)
-{
+nsresult nsXBLContentSink::FlushText(bool aReleaseTextNode) {
   if (mTextLength != 0) {
-    const nsAString& text = Substring(mText, mText+mTextLength);
+    const nsAString& text = Substring(mText, mText + mTextLength);
     if (mState == eXBL_InHandlers) {
       NS_ASSERTION(mBinding, "Must have binding here");
       // Get the text and add it to the event handler.
-      if (mSecondaryState == eXBL_InHandler)
-        mHandler->AppendHandlerText(text);
+      if (mSecondaryState == eXBL_InHandler) mHandler->AppendHandlerText(text);
       mTextLength = 0;
       return NS_OK;
-    }
-    else if (mState == eXBL_InImplementation) {
+    } else if (mState == eXBL_InImplementation) {
       NS_ASSERTION(mBinding, "Must have binding here");
       if (mSecondaryState == eXBL_InConstructor ||
           mSecondaryState == eXBL_InDestructor) {
@@ -110,36 +93,29 @@ nsXBLContentSink::FlushText(bool aReleaseTextNode)
 
         // Get the text and add it to the constructor/destructor.
         method->AppendBodyText(text);
-      }
-      else if (mSecondaryState == eXBL_InGetter ||
-               mSecondaryState == eXBL_InSetter) {
+      } else if (mSecondaryState == eXBL_InGetter ||
+                 mSecondaryState == eXBL_InSetter) {
         // Get the text and add it to the getter/setter
         if (mSecondaryState == eXBL_InGetter)
           mProperty->AppendGetterText(text);
         else
           mProperty->AppendSetterText(text);
-      }
-      else if (mSecondaryState == eXBL_InBody) {
+      } else if (mSecondaryState == eXBL_InBody) {
         // Get the text and add it to the method
-        if (mMethod)
-          mMethod->AppendBodyText(text);
-      }
-      else if (mSecondaryState == eXBL_InField) {
+        if (mMethod) mMethod->AppendBodyText(text);
+      } else if (mSecondaryState == eXBL_InField) {
         // Get the text and add it to the method
-        if (mField)
-          mField->AppendFieldText(text);
+        if (mField) mField->AppendFieldText(text);
       }
       mTextLength = 0;
       return NS_OK;
     }
 
     nsIContent* content = GetCurrentContent();
-    if (content &&
-        (content->NodeInfo()->NamespaceEquals(kNameSpaceID_XBL) ||
-         (content->IsXULElement() &&
-          !content->IsAnyOfXULElements(nsGkAtoms::label,
-                                       nsGkAtoms::description)))) {
-
+    if (content && (content->NodeInfo()->NamespaceEquals(kNameSpaceID_XBL) ||
+                    (content->IsXULElement() &&
+                     !content->IsAnyOfXULElements(nsGkAtoms::label,
+                                                  nsGkAtoms::description)))) {
       bool isWS = true;
       if (mTextLength > 0) {
         const char16_t* cp = mText;
@@ -167,9 +143,7 @@ nsXBLContentSink::FlushText(bool aReleaseTextNode)
 NS_IMETHODIMP
 nsXBLContentSink::ReportError(const char16_t* aErrorText,
                               const char16_t* aSourceText,
-                              nsIScriptError *aError,
-                              bool *_retval)
-{
+                              nsIScriptError* aError, bool* _retval) {
   NS_PRECONDITION(aError && aSourceText && aErrorText, "Check arguments!!!");
 
   // XXX FIXME This function overrides and calls on
@@ -182,24 +156,18 @@ nsXBLContentSink::ReportError(const char16_t* aErrorText,
 
 #ifdef DEBUG
   // Report the error to stderr.
-  fprintf(stderr,
-          "\n%s\n%s\n\n",
-          NS_LossyConvertUTF16toASCII(aErrorText).get(),
+  fprintf(stderr, "\n%s\n%s\n\n", NS_LossyConvertUTF16toASCII(aErrorText).get(),
           NS_LossyConvertUTF16toASCII(aSourceText).get());
 #endif
 
   // Most of what this does won't be too useful, but whatever...
   // nsXMLContentSink::ReportError will handle the console logging.
-  return nsXMLContentSink::ReportError(aErrorText,
-                                       aSourceText,
-                                       aError,
+  return nsXMLContentSink::ReportError(aErrorText, aSourceText, aError,
                                        _retval);
 }
 
-nsresult
-nsXBLContentSink::ReportUnexpectedElement(nsAtom* aElementName,
-                                          uint32_t aLineNumber)
-{
+nsresult nsXBLContentSink::ReportUnexpectedElement(nsAtom* aElementName,
+                                                   uint32_t aLineNumber) {
   // XXX we should really somehow stop the parse and drop the binding
   // instead of just letting the XML sink build the content model like
   // we do...
@@ -207,58 +175,53 @@ nsXBLContentSink::ReportUnexpectedElement(nsAtom* aElementName,
   nsAutoString elementName;
   aElementName->ToString(elementName);
 
-  const char16_t* params[] = { elementName.get() };
+  const char16_t* params[] = {elementName.get()};
 
-  return nsContentUtils::ReportToConsole(nsIScriptError::errorFlag,
-                                         NS_LITERAL_CSTRING("XBL Content Sink"),
-                                         mDocument,
-                                         nsContentUtils::eXBL_PROPERTIES,
-                                         "UnexpectedElement",
-                                         params, ArrayLength(params),
-                                         nullptr,
-                                         EmptyString() /* source line */,
-                                         aLineNumber);
+  return nsContentUtils::ReportToConsole(
+      nsIScriptError::errorFlag, NS_LITERAL_CSTRING("XBL Content Sink"),
+      mDocument, nsContentUtils::eXBL_PROPERTIES, "UnexpectedElement", params,
+      ArrayLength(params), nullptr, EmptyString() /* source line */,
+      aLineNumber);
 }
 
-void
-nsXBLContentSink::AddMember(nsXBLProtoImplMember* aMember)
-{
+void nsXBLContentSink::AddMember(nsXBLProtoImplMember* aMember) {
   // Add this member to our chain.
   if (mImplMember)
-    mImplMember->SetNext(aMember); // Already have a chain. Just append to the end.
+    mImplMember->SetNext(
+        aMember);  // Already have a chain. Just append to the end.
   else
-    mImplementation->SetMemberList(aMember); // We're the first member in the chain.
+    mImplementation->SetMemberList(
+        aMember);  // We're the first member in the chain.
 
-  mImplMember = aMember; // Adjust our pointer to point to the new last member in the chain.
+  mImplMember = aMember;  // Adjust our pointer to point to the new last member
+                          // in the chain.
 }
 
-void
-nsXBLContentSink::AddField(nsXBLProtoImplField* aField)
-{
+void nsXBLContentSink::AddField(nsXBLProtoImplField* aField) {
   // Add this field to our chain.
   if (mImplField)
-    mImplField->SetNext(aField); // Already have a chain. Just append to the end.
+    mImplField->SetNext(
+        aField);  // Already have a chain. Just append to the end.
   else
-    mImplementation->SetFieldList(aField); // We're the first member in the chain.
+    mImplementation->SetFieldList(
+        aField);  // We're the first member in the chain.
 
-  mImplField = aField; // Adjust our pointer to point to the new last field in the chain.
+  mImplField = aField;  // Adjust our pointer to point to the new last field in
+                        // the chain.
 }
 
 NS_IMETHODIMP
-nsXBLContentSink::HandleStartElement(const char16_t *aName,
-                                     const char16_t **aAtts,
+nsXBLContentSink::HandleStartElement(const char16_t* aName,
+                                     const char16_t** aAtts,
                                      uint32_t aAttsCount,
-                                     uint32_t aLineNumber)
-{
+                                     uint32_t aLineNumber) {
   nsresult rv = nsXMLContentSink::HandleStartElement(aName, aAtts, aAttsCount,
                                                      aLineNumber);
-  if (NS_FAILED(rv))
-    return rv;
+  if (NS_FAILED(rv)) return rv;
 
   if (mState == eXBL_InBinding && !mBinding) {
     rv = ConstructBinding(aLineNumber);
-    if (NS_FAILED(rv))
-      return rv;
+    if (NS_FAILED(rv)) return rv;
 
     // mBinding may still be null, if the binding had no id.  If so,
     // we'll deal with that later in the sink.
@@ -268,8 +231,7 @@ nsXBLContentSink::HandleStartElement(const char16_t *aName,
 }
 
 NS_IMETHODIMP
-nsXBLContentSink::HandleEndElement(const char16_t *aName)
-{
+nsXBLContentSink::HandleEndElement(const char16_t* aName) {
   FlushText();
 
   if (mState != eXBL_InDocument) {
@@ -282,44 +244,35 @@ nsXBLContentSink::HandleEndElement(const char16_t *aName)
       if (mState == eXBL_Error) {
         // Check whether we've opened this tag before; we may not have if
         // it was a real XBL tag before the error occurred.
-        if (!GetCurrentContent()->NodeInfo()->Equals(localName,
-                                                     nameSpaceID)) {
+        if (!GetCurrentContent()->NodeInfo()->Equals(localName, nameSpaceID)) {
           // OK, this tag was never opened as far as the XML sink is
           // concerned.  Just drop the HandleEndElement
           return NS_OK;
         }
-      }
-      else if (mState == eXBL_InHandlers) {
+      } else if (mState == eXBL_InHandlers) {
         if (localName == nsGkAtoms::handlers) {
           mState = eXBL_InBinding;
           mHandler = nullptr;
-        }
-        else if (localName == nsGkAtoms::handler)
+        } else if (localName == nsGkAtoms::handler)
           mSecondaryState = eXBL_None;
         return NS_OK;
-      }
-      else if (mState == eXBL_InResources) {
-        if (localName == nsGkAtoms::resources)
-          mState = eXBL_InBinding;
+      } else if (mState == eXBL_InResources) {
+        if (localName == nsGkAtoms::resources) mState = eXBL_InBinding;
         return NS_OK;
-      }
-      else if (mState == eXBL_InImplementation) {
+      } else if (mState == eXBL_InImplementation) {
         if (localName == nsGkAtoms::implementation)
           mState = eXBL_InBinding;
         else if (localName == nsGkAtoms::property) {
           mSecondaryState = eXBL_None;
           mProperty = nullptr;
-        }
-        else if (localName == nsGkAtoms::method) {
+        } else if (localName == nsGkAtoms::method) {
           mSecondaryState = eXBL_None;
           mMethod = nullptr;
-        }
-        else if (localName == nsGkAtoms::field) {
+        } else if (localName == nsGkAtoms::field) {
           mSecondaryState = eXBL_None;
           mField = nullptr;
-        }
-        else if (localName == nsGkAtoms::constructor ||
-                 localName == nsGkAtoms::destructor)
+        } else if (localName == nsGkAtoms::constructor ||
+                   localName == nsGkAtoms::destructor)
           mSecondaryState = eXBL_None;
         else if (localName == nsGkAtoms::getter ||
                  localName == nsGkAtoms::setter)
@@ -328,21 +281,19 @@ nsXBLContentSink::HandleEndElement(const char16_t *aName)
                  localName == nsGkAtoms::body)
           mSecondaryState = eXBL_InMethod;
         return NS_OK;
-      }
-      else if (mState == eXBL_InBindings &&
-               localName == nsGkAtoms::bindings) {
+      } else if (mState == eXBL_InBindings &&
+                 localName == nsGkAtoms::bindings) {
         mState = eXBL_InDocument;
       }
 
       nsresult rv = nsXMLContentSink::HandleEndElement(aName);
-      if (NS_FAILED(rv))
-        return rv;
+      if (NS_FAILED(rv)) return rv;
 
       if (mState == eXBL_InBinding && localName == nsGkAtoms::binding) {
         mState = eXBL_InBindings;
         if (mBinding) {  // See comment in HandleStartElement()
           mBinding->Initialize();
-          mBinding = nullptr; // Clear our current binding ref.
+          mBinding = nullptr;  // Clear our current binding ref.
         }
       }
 
@@ -354,26 +305,24 @@ nsXBLContentSink::HandleEndElement(const char16_t *aName)
 }
 
 NS_IMETHODIMP
-nsXBLContentSink::HandleCDataSection(const char16_t *aData,
-                                     uint32_t aLength)
-{
+nsXBLContentSink::HandleCDataSection(const char16_t* aData, uint32_t aLength) {
   if (mState == eXBL_InHandlers || mState == eXBL_InImplementation)
     return AddText(aData, aLength);
   return nsXMLContentSink::HandleCDataSection(aData, aLength);
 }
 
-#define ENSURE_XBL_STATE(_cond)                                                       \
-  PR_BEGIN_MACRO                                                                      \
-    if (!(_cond)) { ReportUnexpectedElement(aTagName, aLineNumber); return true; } \
+#define ENSURE_XBL_STATE(_cond)                     \
+  PR_BEGIN_MACRO                                    \
+  if (!(_cond)) {                                   \
+    ReportUnexpectedElement(aTagName, aLineNumber); \
+    return true;                                    \
+  }                                                 \
   PR_END_MACRO
 
-bool
-nsXBLContentSink::OnOpenContainer(const char16_t **aAtts,
-                                  uint32_t aAttsCount,
-                                  int32_t aNameSpaceID,
-                                  nsAtom* aTagName,
-                                  uint32_t aLineNumber)
-{
+bool nsXBLContentSink::OnOpenContainer(const char16_t** aAtts,
+                                       uint32_t aAttsCount,
+                                       int32_t aNameSpaceID, nsAtom* aTagName,
+                                       uint32_t aLineNumber) {
   if (mState == eXBL_Error) {
     return true;
   }
@@ -390,7 +339,8 @@ nsXBLContentSink::OnOpenContainer(const char16_t **aAtts,
     NS_ASSERTION(mDocument, "Must have a document!");
     RefPtr<nsXBLDocumentInfo> info = new nsXBLDocumentInfo(mDocument);
 
-    // We keep a weak ref. We're creating a cycle between doc/binding manager/doc info.
+    // We keep a weak ref. We're creating a cycle between doc/binding
+    // manager/doc info.
     mDocInfo = info;
 
     if (!mDocInfo) {
@@ -400,7 +350,7 @@ nsXBLContentSink::OnOpenContainer(const char16_t **aAtts,
 
     mDocument->BindingManager()->PutXBLDocumentInfo(mDocInfo);
 
-    nsIURI *uri = mDocument->GetDocumentURI();
+    nsIURI* uri = mDocument->GetDocumentURI();
 
     bool isChrome = false;
     bool isRes = false;
@@ -410,41 +360,35 @@ nsXBLContentSink::OnOpenContainer(const char16_t **aAtts,
     mIsChromeOrResource = isChrome || isRes;
 
     mState = eXBL_InBindings;
-  }
-  else if (aTagName == nsGkAtoms::binding) {
+  } else if (aTagName == nsGkAtoms::binding) {
     ENSURE_XBL_STATE(mState == eXBL_InBindings);
     mState = eXBL_InBinding;
-  }
-  else if (aTagName == nsGkAtoms::handlers) {
+  } else if (aTagName == nsGkAtoms::handlers) {
     ENSURE_XBL_STATE(mState == eXBL_InBinding && mBinding);
     mState = eXBL_InHandlers;
     ret = false;
-  }
-  else if (aTagName == nsGkAtoms::handler) {
+  } else if (aTagName == nsGkAtoms::handler) {
     ENSURE_XBL_STATE(mState == eXBL_InHandlers);
     mSecondaryState = eXBL_InHandler;
     ConstructHandler(aAtts, aLineNumber);
     ret = false;
-  }
-  else if (aTagName == nsGkAtoms::resources) {
+  } else if (aTagName == nsGkAtoms::resources) {
     ENSURE_XBL_STATE(mState == eXBL_InBinding && mBinding);
     mState = eXBL_InResources;
     // Note that this mState will cause us to return false, so no need
     // to set ret to false.
-  }
-  else if (aTagName == nsGkAtoms::stylesheet || aTagName == nsGkAtoms::image) {
+  } else if (aTagName == nsGkAtoms::stylesheet ||
+             aTagName == nsGkAtoms::image) {
     ENSURE_XBL_STATE(mState == eXBL_InResources);
     NS_ASSERTION(mBinding, "Must have binding here");
     ConstructResource(aAtts, aTagName);
-  }
-  else if (aTagName == nsGkAtoms::implementation) {
+  } else if (aTagName == nsGkAtoms::implementation) {
     ENSURE_XBL_STATE(mState == eXBL_InBinding && mBinding);
     mState = eXBL_InImplementation;
     ConstructImplementation(aAtts);
     // Note that this mState will cause us to return false, so no need
     // to set ret to false.
-  }
-  else if (aTagName == nsGkAtoms::constructor) {
+  } else if (aTagName == nsGkAtoms::constructor) {
     ENSURE_XBL_STATE(mState == eXBL_InImplementation &&
                      mSecondaryState == eXBL_None);
     NS_ASSERTION(mBinding, "Must have binding here");
@@ -458,12 +402,11 @@ nsXBLContentSink::OnOpenContainer(const char16_t **aAtts,
       name.AppendLiteral("XBL_Constructor");
     }
     nsXBLProtoImplAnonymousMethod* newMethod =
-      new nsXBLProtoImplAnonymousMethod(name.get());
+        new nsXBLProtoImplAnonymousMethod(name.get());
     newMethod->SetLineNumber(aLineNumber);
     mBinding->SetConstructor(newMethod);
     AddMember(newMethod);
-  }
-  else if (aTagName == nsGkAtoms::destructor) {
+  } else if (aTagName == nsGkAtoms::destructor) {
     ENSURE_XBL_STATE(mState == eXBL_InImplementation &&
                      mSecondaryState == eXBL_None);
     NS_ASSERTION(mBinding, "Must have binding here");
@@ -476,50 +419,43 @@ nsXBLContentSink::OnOpenContainer(const char16_t **aAtts,
       name.AppendLiteral("XBL_Destructor");
     }
     nsXBLProtoImplAnonymousMethod* newMethod =
-      new nsXBLProtoImplAnonymousMethod(name.get());
+        new nsXBLProtoImplAnonymousMethod(name.get());
     newMethod->SetLineNumber(aLineNumber);
     mBinding->SetDestructor(newMethod);
     AddMember(newMethod);
-  }
-  else if (aTagName == nsGkAtoms::field) {
+  } else if (aTagName == nsGkAtoms::field) {
     ENSURE_XBL_STATE(mState == eXBL_InImplementation &&
                      mSecondaryState == eXBL_None);
     NS_ASSERTION(mBinding, "Must have binding here");
     mSecondaryState = eXBL_InField;
     ConstructField(aAtts, aLineNumber);
-  }
-  else if (aTagName == nsGkAtoms::property) {
+  } else if (aTagName == nsGkAtoms::property) {
     ENSURE_XBL_STATE(mState == eXBL_InImplementation &&
                      mSecondaryState == eXBL_None);
     NS_ASSERTION(mBinding, "Must have binding here");
     mSecondaryState = eXBL_InProperty;
     ConstructProperty(aAtts, aLineNumber);
-  }
-  else if (aTagName == nsGkAtoms::getter) {
+  } else if (aTagName == nsGkAtoms::getter) {
     ENSURE_XBL_STATE(mSecondaryState == eXBL_InProperty && mProperty);
     NS_ASSERTION(mState == eXBL_InImplementation, "Unexpected state");
     mProperty->SetGetterLineNumber(aLineNumber);
     mSecondaryState = eXBL_InGetter;
-  }
-  else if (aTagName == nsGkAtoms::setter) {
+  } else if (aTagName == nsGkAtoms::setter) {
     ENSURE_XBL_STATE(mSecondaryState == eXBL_InProperty && mProperty);
     NS_ASSERTION(mState == eXBL_InImplementation, "Unexpected state");
     mProperty->SetSetterLineNumber(aLineNumber);
     mSecondaryState = eXBL_InSetter;
-  }
-  else if (aTagName == nsGkAtoms::method) {
+  } else if (aTagName == nsGkAtoms::method) {
     ENSURE_XBL_STATE(mState == eXBL_InImplementation &&
                      mSecondaryState == eXBL_None);
     NS_ASSERTION(mBinding, "Must have binding here");
     mSecondaryState = eXBL_InMethod;
     ConstructMethod(aAtts);
-  }
-  else if (aTagName == nsGkAtoms::parameter) {
+  } else if (aTagName == nsGkAtoms::parameter) {
     ENSURE_XBL_STATE(mSecondaryState == eXBL_InMethod && mMethod);
     NS_ASSERTION(mState == eXBL_InImplementation, "Unexpected state");
     ConstructParameter(aAtts);
-  }
-  else if (aTagName == nsGkAtoms::body) {
+  } else if (aTagName == nsGkAtoms::body) {
     ENSURE_XBL_STATE(mSecondaryState == eXBL_InMethod && mMethod);
     NS_ASSERTION(mState == eXBL_InImplementation, "Unexpected state");
     // stash away the line number
@@ -532,9 +468,7 @@ nsXBLContentSink::OnOpenContainer(const char16_t **aAtts,
 
 #undef ENSURE_XBL_STATE
 
-nsresult
-nsXBLContentSink::ConstructBinding(uint32_t aLineNumber)
-{
+nsresult nsXBLContentSink::ConstructBinding(uint32_t aLineNumber) {
   // This is only called from HandleStartElement, so it'd better be an element.
   RefPtr<Element> binding = GetCurrentContent()->AsElement();
   binding->GetAttr(kNameSpaceID_None, nsGkAtoms::id, mCurrentBindingID);
@@ -560,21 +494,17 @@ nsXBLContentSink::ConstructBinding(uint32_t aLineNumber)
       mBinding = nullptr;
     }
   } else {
-    nsContentUtils::ReportToConsole(nsIScriptError::errorFlag,
-                                    NS_LITERAL_CSTRING("XBL Content Sink"), nullptr,
-                                    nsContentUtils::eXBL_PROPERTIES,
-                                    "MissingIdAttr", nullptr, 0,
-                                    mDocumentURI,
-                                    EmptyString(),
-                                    aLineNumber);
+    nsContentUtils::ReportToConsole(
+        nsIScriptError::errorFlag, NS_LITERAL_CSTRING("XBL Content Sink"),
+        nullptr, nsContentUtils::eXBL_PROPERTIES, "MissingIdAttr", nullptr, 0,
+        mDocumentURI, EmptyString(), aLineNumber);
   }
 
   return rv;
 }
 
-static bool
-FindValue(const char16_t **aAtts, nsAtom *aAtom, const char16_t **aResult)
-{
+static bool FindValue(const char16_t** aAtts, nsAtom* aAtom,
+                      const char16_t** aResult) {
   RefPtr<nsAtom> prefix, localName;
   for (; *aAtts; aAtts += 2) {
     int32_t nameSpaceID;
@@ -592,19 +522,18 @@ FindValue(const char16_t **aAtts, nsAtom *aAtom, const char16_t **aResult)
   return false;
 }
 
-void
-nsXBLContentSink::ConstructHandler(const char16_t **aAtts, uint32_t aLineNumber)
-{
-  const char16_t* event          = nullptr;
-  const char16_t* modifiers      = nullptr;
-  const char16_t* button         = nullptr;
-  const char16_t* clickcount     = nullptr;
-  const char16_t* keycode        = nullptr;
-  const char16_t* charcode       = nullptr;
-  const char16_t* phase          = nullptr;
-  const char16_t* command        = nullptr;
-  const char16_t* action         = nullptr;
-  const char16_t* group          = nullptr;
+void nsXBLContentSink::ConstructHandler(const char16_t** aAtts,
+                                        uint32_t aLineNumber) {
+  const char16_t* event = nullptr;
+  const char16_t* modifiers = nullptr;
+  const char16_t* button = nullptr;
+  const char16_t* clickcount = nullptr;
+  const char16_t* keycode = nullptr;
+  const char16_t* charcode = nullptr;
+  const char16_t* phase = nullptr;
+  const char16_t* command = nullptr;
+  const char16_t* action = nullptr;
+  const char16_t* group = nullptr;
   const char16_t* preventdefault = nullptr;
   const char16_t* allowuntrusted = nullptr;
 
@@ -649,24 +578,19 @@ nsXBLContentSink::ConstructHandler(const char16_t **aAtts, uint32_t aLineNumber)
     // Make sure the XBL doc is chrome or resource if we have a command
     // shorthand syntax.
     mState = eXBL_Error;
-    nsContentUtils::ReportToConsole(nsIScriptError::errorFlag,
-                                    NS_LITERAL_CSTRING("XBL Content Sink"),
-                                    mDocument,
-                                    nsContentUtils::eXBL_PROPERTIES,
-                                    "CommandNotInChrome", nullptr, 0,
-                                    nullptr,
-                                    EmptyString() /* source line */,
-                                    aLineNumber);
-    return; // Don't even make this handler.
+    nsContentUtils::ReportToConsole(
+        nsIScriptError::errorFlag, NS_LITERAL_CSTRING("XBL Content Sink"),
+        mDocument, nsContentUtils::eXBL_PROPERTIES, "CommandNotInChrome",
+        nullptr, 0, nullptr, EmptyString() /* source line */, aLineNumber);
+    return;  // Don't even make this handler.
   }
 
   // All of our pointers are now filled in. Construct our handler with all of
   // these parameters.
   nsXBLPrototypeHandler* newHandler;
-  newHandler = new nsXBLPrototypeHandler(event, phase, action, command,
-                                         keycode, charcode, modifiers, button,
-                                         clickcount, group, preventdefault,
-                                         allowuntrusted, mBinding, aLineNumber);
+  newHandler = new nsXBLPrototypeHandler(
+      event, phase, action, command, keycode, charcode, modifiers, button,
+      clickcount, group, preventdefault, allowuntrusted, mBinding, aLineNumber);
 
   // Add this handler to our chain of handlers.
   if (mHandler) {
@@ -681,12 +605,9 @@ nsXBLContentSink::ConstructHandler(const char16_t **aAtts, uint32_t aLineNumber)
   mHandler = newHandler;
 }
 
-void
-nsXBLContentSink::ConstructResource(const char16_t **aAtts,
-                                    nsAtom* aResourceType)
-{
-  if (!mBinding)
-    return;
+void nsXBLContentSink::ConstructResource(const char16_t** aAtts,
+                                         nsAtom* aResourceType) {
+  if (!mBinding) return;
 
   const char16_t* src = nullptr;
   if (FindValue(aAtts, nsGkAtoms::src, &src)) {
@@ -694,15 +615,12 @@ nsXBLContentSink::ConstructResource(const char16_t **aAtts,
   }
 }
 
-void
-nsXBLContentSink::ConstructImplementation(const char16_t **aAtts)
-{
+void nsXBLContentSink::ConstructImplementation(const char16_t** aAtts) {
   mImplementation = nullptr;
   mImplMember = nullptr;
   mImplField = nullptr;
 
-  if (!mBinding)
-    return;
+  if (!mBinding) return;
 
   const char16_t* name = nullptr;
 
@@ -719,8 +637,7 @@ nsXBLContentSink::ConstructImplementation(const char16_t **aAtts)
     // Is this attribute one of the ones we care about?
     if (localName == nsGkAtoms::name) {
       name = aAtts[1];
-    }
-    else if (localName == nsGkAtoms::implements) {
+    } else if (localName == nsGkAtoms::implements) {
       // Only allow implementation of interfaces via XBL if the principal of
       // our XBL document is the system principal.
       if (nsContentUtils::IsSystemPrincipal(mDocument->NodePrincipal())) {
@@ -732,10 +649,9 @@ nsXBLContentSink::ConstructImplementation(const char16_t **aAtts)
   NS_NewXBLProtoImpl(mBinding, name, &mImplementation);
 }
 
-void
-nsXBLContentSink::ConstructField(const char16_t **aAtts, uint32_t aLineNumber)
-{
-  const char16_t* name     = nullptr;
+void nsXBLContentSink::ConstructField(const char16_t** aAtts,
+                                      uint32_t aLineNumber) {
+  const char16_t* name = nullptr;
   const char16_t* readonly = nullptr;
 
   RefPtr<nsAtom> prefix, localName;
@@ -751,8 +667,7 @@ nsXBLContentSink::ConstructField(const char16_t **aAtts, uint32_t aLineNumber)
     // Is this attribute one of the ones we care about?
     if (localName == nsGkAtoms::name) {
       name = aAtts[1];
-    }
-    else if (localName == nsGkAtoms::readonly) {
+    } else if (localName == nsGkAtoms::readonly) {
       readonly = aAtts[1];
     }
   }
@@ -766,13 +681,12 @@ nsXBLContentSink::ConstructField(const char16_t **aAtts, uint32_t aLineNumber)
   }
 }
 
-void
-nsXBLContentSink::ConstructProperty(const char16_t **aAtts, uint32_t aLineNumber)
-{
-  const char16_t* name     = nullptr;
+void nsXBLContentSink::ConstructProperty(const char16_t** aAtts,
+                                         uint32_t aLineNumber) {
+  const char16_t* name = nullptr;
   const char16_t* readonly = nullptr;
-  const char16_t* onget    = nullptr;
-  const char16_t* onset    = nullptr;
+  const char16_t* onget = nullptr;
+  const char16_t* onset = nullptr;
   bool exposeToUntrustedContent = false;
 
   RefPtr<nsAtom> prefix, localName;
@@ -788,19 +702,14 @@ nsXBLContentSink::ConstructProperty(const char16_t **aAtts, uint32_t aLineNumber
     // Is this attribute one of the ones we care about?
     if (localName == nsGkAtoms::name) {
       name = aAtts[1];
-    }
-    else if (localName == nsGkAtoms::readonly) {
+    } else if (localName == nsGkAtoms::readonly) {
       readonly = aAtts[1];
-    }
-    else if (localName == nsGkAtoms::onget) {
+    } else if (localName == nsGkAtoms::onget) {
       onget = aAtts[1];
-    }
-    else if (localName == nsGkAtoms::onset) {
+    } else if (localName == nsGkAtoms::onset) {
       onset = aAtts[1];
-    }
-    else if (localName == nsGkAtoms::exposeToUntrustedContent &&
-             nsDependentString(aAtts[1]).EqualsLiteral("true"))
-    {
+    } else if (localName == nsGkAtoms::exposeToUntrustedContent &&
+               nsDependentString(aAtts[1]).EqualsLiteral("true")) {
       exposeToUntrustedContent = true;
     }
   }
@@ -808,7 +717,8 @@ nsXBLContentSink::ConstructProperty(const char16_t **aAtts, uint32_t aLineNumber
   if (name) {
     // All of our pointers are now filled in. Construct our property with all of
     // these parameters.
-    mProperty = new nsXBLProtoImplProperty(name, onget, onset, readonly, aLineNumber);
+    mProperty =
+        new nsXBLProtoImplProperty(name, onget, onset, readonly, aLineNumber);
     if (exposeToUntrustedContent) {
       mProperty->SetExposeToUntrustedContent(true);
     }
@@ -816,9 +726,7 @@ nsXBLContentSink::ConstructProperty(const char16_t **aAtts, uint32_t aLineNumber
   }
 }
 
-void
-nsXBLContentSink::ConstructMethod(const char16_t **aAtts)
-{
+void nsXBLContentSink::ConstructMethod(const char16_t** aAtts) {
   mMethod = nullptr;
 
   const char16_t* name = nullptr;
@@ -826,8 +734,7 @@ nsXBLContentSink::ConstructMethod(const char16_t **aAtts)
   if (FindValue(aAtts, nsGkAtoms::name, &name)) {
     mMethod = new nsXBLProtoImplMethod(name);
     if (FindValue(aAtts, nsGkAtoms::exposeToUntrustedContent, &expose) &&
-        nsDependentString(expose).EqualsLiteral("true"))
-    {
+        nsDependentString(expose).EqualsLiteral("true")) {
       mMethod->SetExposeToUntrustedContent(true);
     }
   }
@@ -837,11 +744,8 @@ nsXBLContentSink::ConstructMethod(const char16_t **aAtts)
   }
 }
 
-void
-nsXBLContentSink::ConstructParameter(const char16_t **aAtts)
-{
-  if (!mMethod)
-    return;
+void nsXBLContentSink::ConstructParameter(const char16_t** aAtts) {
+  if (!mMethod) return;
 
   const char16_t* name = nullptr;
   if (FindValue(aAtts, nsGkAtoms::name, &name)) {
@@ -849,22 +753,21 @@ nsXBLContentSink::ConstructParameter(const char16_t **aAtts)
   }
 }
 
-nsresult
-nsXBLContentSink::CreateElement(const char16_t** aAtts, uint32_t aAttsCount,
-                                mozilla::dom::NodeInfo* aNodeInfo, uint32_t aLineNumber,
-                                nsIContent** aResult, bool* aAppendContent,
-                                FromParser aFromParser)
-{
+nsresult nsXBLContentSink::CreateElement(
+    const char16_t** aAtts, uint32_t aAttsCount,
+    mozilla::dom::NodeInfo* aNodeInfo, uint32_t aLineNumber,
+    nsIContent** aResult, bool* aAppendContent, FromParser aFromParser) {
 #ifdef MOZ_XUL
   if (!aNodeInfo->NamespaceEquals(kNameSpaceID_XUL)) {
 #endif
     return nsXMLContentSink::CreateElement(aAtts, aAttsCount, aNodeInfo,
-                                           aLineNumber, aResult,
-                                           aAppendContent, aFromParser);
+                                           aLineNumber, aResult, aAppendContent,
+                                           aFromParser);
 #ifdef MOZ_XUL
   }
 
-  // Note that this needs to match the code in nsXBLPrototypeBinding::ReadContentNode.
+  // Note that this needs to match the code in
+  // nsXBLPrototypeBinding::ReadContentNode.
 
   *aAppendContent = true;
   RefPtr<nsXULPrototypeElement> prototype = new nsXULPrototypeElement();
@@ -874,27 +777,25 @@ nsXBLContentSink::CreateElement(const char16_t** aAtts, uint32_t aAttsCount,
   AddAttributesToXULPrototype(aAtts, aAttsCount, prototype);
 
   Element* result;
-  nsresult rv = nsXULElement::Create(prototype, mDocument, false, false, &result);
+  nsresult rv =
+      nsXULElement::Create(prototype, mDocument, false, false, &result);
   *aResult = result;
   return rv;
 #endif
 }
 
-nsresult
-nsXBLContentSink::AddAttributes(const char16_t** aAtts, Element* aElement)
-{
+nsresult nsXBLContentSink::AddAttributes(const char16_t** aAtts,
+                                         Element* aElement) {
   if (aElement->IsXULElement())
-    return NS_OK; // Nothing to do, since the proto already has the attrs.
+    return NS_OK;  // Nothing to do, since the proto already has the attrs.
 
   return nsXMLContentSink::AddAttributes(aAtts, aElement);
 }
 
 #ifdef MOZ_XUL
-nsresult
-nsXBLContentSink::AddAttributesToXULPrototype(const char16_t **aAtts,
-                                              uint32_t aAttsCount,
-                                              nsXULPrototypeElement* aElement)
-{
+nsresult nsXBLContentSink::AddAttributesToXULPrototype(
+    const char16_t** aAtts, uint32_t aAttsCount,
+    nsXULPrototypeElement* aElement) {
   // Add tag attributes to the element
   nsresult rv;
 
@@ -904,7 +805,7 @@ nsXBLContentSink::AddAttributesToXULPrototype(const char16_t **aAtts,
     attrs = new nsXULPrototypeAttribute[aAttsCount];
   }
 
-  aElement->mAttributes    = attrs;
+  aElement->mAttributes = attrs;
   aElement->mNumAttributes = aAttsCount;
 
   // Copy the attributes into the prototype
@@ -918,8 +819,7 @@ nsXBLContentSink::AddAttributesToXULPrototype(const char16_t **aAtts,
 
     if (nameSpaceID == kNameSpaceID_None) {
       attrs[i].mName.SetTo(localName);
-    }
-    else {
+    } else {
       RefPtr<NodeInfo> ni;
       ni = mNodeInfoManager->GetNodeInfo(localName, prefix, nameSpaceID,
                                          nsINode::ATTRIBUTE_NODE);
