@@ -40,9 +40,8 @@ using namespace mozilla;
 using namespace mozilla::dom;
 using namespace mozilla::layers;
 
-class nsXBLSpecialDocInfo : public nsIObserver
-{
-public:
+class nsXBLSpecialDocInfo : public nsIObserver {
+ public:
   RefPtr<nsXBLDocumentInfo> mHTMLBindings;
   RefPtr<nsXBLDocumentInfo> mUserHTMLBindings;
 
@@ -51,35 +50,30 @@ public:
 
   bool mInitialized;
 
-public:
+ public:
   NS_DECL_ISUPPORTS
   NS_DECL_NSIOBSERVER
 
   void LoadDocInfo();
-  void GetAllHandlers(const char* aType,
-                      nsXBLPrototypeHandler** handler,
+  void GetAllHandlers(const char* aType, nsXBLPrototypeHandler** handler,
                       nsXBLPrototypeHandler** userHandler);
-  void GetHandlers(nsXBLDocumentInfo* aInfo,
-                   const nsACString& aRef,
+  void GetHandlers(nsXBLDocumentInfo* aInfo, const nsACString& aRef,
                    nsXBLPrototypeHandler** aResult);
 
   nsXBLSpecialDocInfo() : mInitialized(false) {}
 
-protected:
+ protected:
   virtual ~nsXBLSpecialDocInfo() {}
-
 };
 
 const char nsXBLSpecialDocInfo::sHTMLBindingStr[] =
-  "chrome://global/content/platformHTMLBindings.xml";
+    "chrome://global/content/platformHTMLBindings.xml";
 
 NS_IMPL_ISUPPORTS(nsXBLSpecialDocInfo, nsIObserver)
 
 NS_IMETHODIMP
-nsXBLSpecialDocInfo::Observe(nsISupports* aSubject,
-                             const char* aTopic,
-                             const char16_t* aData)
-{
+nsXBLSpecialDocInfo::Observe(nsISupports* aSubject, const char* aTopic,
+                             const char16_t* aData) {
   MOZ_ASSERT(!strcmp(aTopic, "xpcom-shutdown"), "wrong topic");
 
   // On shutdown, clear our fields to avoid an extra cycle collection.
@@ -91,16 +85,13 @@ nsXBLSpecialDocInfo::Observe(nsISupports* aSubject,
   return NS_OK;
 }
 
-void nsXBLSpecialDocInfo::LoadDocInfo()
-{
-  if (mInitialized)
-    return;
+void nsXBLSpecialDocInfo::LoadDocInfo() {
+  if (mInitialized) return;
   mInitialized = true;
   nsContentUtils::RegisterShutdownObserver(this);
 
   nsXBLService* xblService = nsXBLService::GetInstance();
-  if (!xblService)
-    return;
+  if (!xblService) return;
 
   // Obtain the platform doc info
   nsCOMPtr<nsIURI> bindingURI;
@@ -108,36 +99,28 @@ void nsXBLSpecialDocInfo::LoadDocInfo()
   if (!bindingURI) {
     return;
   }
-  xblService->LoadBindingDocumentInfo(nullptr, nullptr,
-                                      bindingURI,
-                                      nullptr,
-                                      true,
-                                      getter_AddRefs(mHTMLBindings));
+  xblService->LoadBindingDocumentInfo(nullptr, nullptr, bindingURI, nullptr,
+                                      true, getter_AddRefs(mHTMLBindings));
 }
 
 //
 // GetHandlers
 //
 //
-void
-nsXBLSpecialDocInfo::GetHandlers(nsXBLDocumentInfo* aInfo,
-                                 const nsACString& aRef,
-                                 nsXBLPrototypeHandler** aResult)
-{
+void nsXBLSpecialDocInfo::GetHandlers(nsXBLDocumentInfo* aInfo,
+                                      const nsACString& aRef,
+                                      nsXBLPrototypeHandler** aResult) {
   nsXBLPrototypeBinding* binding = aInfo->GetPrototypeBinding(aRef);
 
   NS_ASSERTION(binding, "No binding found for the XBL window key handler.");
-  if (!binding)
-    return;
+  if (!binding) return;
 
   *aResult = binding->GetPrototypeHandlers();
 }
 
-void
-nsXBLSpecialDocInfo::GetAllHandlers(const char* aType,
-                                    nsXBLPrototypeHandler** aHandler,
-                                    nsXBLPrototypeHandler** aUserHandler)
-{
+void nsXBLSpecialDocInfo::GetAllHandlers(const char* aType,
+                                         nsXBLPrototypeHandler** aHandler,
+                                         nsXBLPrototypeHandler** aUserHandler) {
   if (mUserHTMLBindings) {
     nsAutoCString type(aType);
     type.AppendLiteral("User");
@@ -152,9 +135,7 @@ nsXBLSpecialDocInfo::GetAllHandlers(const char* aType,
 static StaticRefPtr<nsXBLSpecialDocInfo> sXBLSpecialDocInfo;
 uint32_t nsXBLWindowKeyHandler::sRefCnt = 0;
 
-/* static */ void
-nsXBLWindowKeyHandler::EnsureSpecialDocInfo()
-{
+/* static */ void nsXBLWindowKeyHandler::EnsureSpecialDocInfo() {
   if (!sXBLSpecialDocInfo) {
     sXBLSpecialDocInfo = new nsXBLSpecialDocInfo();
   }
@@ -163,19 +144,14 @@ nsXBLWindowKeyHandler::EnsureSpecialDocInfo()
 
 nsXBLWindowKeyHandler::nsXBLWindowKeyHandler(nsIDOMElement* aElement,
                                              EventTarget* aTarget)
-  : mTarget(aTarget),
-    mHandler(nullptr),
-    mUserHandler(nullptr)
-{
+    : mTarget(aTarget), mHandler(nullptr), mUserHandler(nullptr) {
   mWeakPtrForElement = do_GetWeakReference(aElement);
   ++sRefCnt;
 }
 
-nsXBLWindowKeyHandler::~nsXBLWindowKeyHandler()
-{
+nsXBLWindowKeyHandler::~nsXBLWindowKeyHandler() {
   // If mWeakPtrForElement is non-null, we created a prototype handler.
-  if (mWeakPtrForElement)
-    delete mHandler;
+  if (mWeakPtrForElement) delete mHandler;
 
   --sRefCnt;
   if (!sRefCnt) {
@@ -183,19 +159,16 @@ nsXBLWindowKeyHandler::~nsXBLWindowKeyHandler()
   }
 }
 
-NS_IMPL_ISUPPORTS(nsXBLWindowKeyHandler,
-                  nsIDOMEventListener)
+NS_IMPL_ISUPPORTS(nsXBLWindowKeyHandler, nsIDOMEventListener)
 
-static void
-BuildHandlerChain(nsIContent* aContent, nsXBLPrototypeHandler** aResult)
-{
+static void BuildHandlerChain(nsIContent* aContent,
+                              nsXBLPrototypeHandler** aResult) {
   *aResult = nullptr;
 
   // Since we chain each handler onto the next handler,
   // we'll enumerate them here in reverse so that when we
   // walk the chain they'll come out in the original order
-  for (nsIContent* key = aContent->GetLastChild();
-       key;
+  for (nsIContent* key = aContent->GetLastChild(); key;
        key = key->GetPreviousSibling()) {
     if (!key->NodeInfo()->Equals(nsGkAtoms::key, kNameSpaceID_XUL)) {
       continue;
@@ -207,11 +180,12 @@ BuildHandlerChain(nsIContent* aContent, nsXBLPrototypeHandler** aResult)
     // definition on the locale. See bug 426501.
     nsAutoString valKey, valCharCode, valKeyCode;
     bool attrExists =
-      keyElement->GetAttr(kNameSpaceID_None, nsGkAtoms::key, valKey) ||
-      keyElement->GetAttr(kNameSpaceID_None, nsGkAtoms::charcode, valCharCode) ||
-      keyElement->GetAttr(kNameSpaceID_None, nsGkAtoms::keycode, valKeyCode);
-    if (attrExists &&
-        valKey.IsEmpty() && valCharCode.IsEmpty() && valKeyCode.IsEmpty())
+        keyElement->GetAttr(kNameSpaceID_None, nsGkAtoms::key, valKey) ||
+        keyElement->GetAttr(kNameSpaceID_None, nsGkAtoms::charcode,
+                            valCharCode) ||
+        keyElement->GetAttr(kNameSpaceID_None, nsGkAtoms::keycode, valKeyCode);
+    if (attrExists && valKey.IsEmpty() && valCharCode.IsEmpty() &&
+        valKeyCode.IsEmpty())
       continue;
 
     // reserved="pref" is the default for <key> elements.
@@ -219,14 +193,13 @@ BuildHandlerChain(nsIContent* aContent, nsXBLPrototypeHandler** aResult)
     if (keyElement->AttrValueIs(kNameSpaceID_None, nsGkAtoms::reserved,
                                 nsGkAtoms::_true, eCaseMatters)) {
       reserved = XBLReservedKey_True;
-    } else if (keyElement->AttrValueIs(kNameSpaceID_None,
-                                       nsGkAtoms::reserved,
+    } else if (keyElement->AttrValueIs(kNameSpaceID_None, nsGkAtoms::reserved,
                                        nsGkAtoms::_false, eCaseMatters)) {
       reserved = XBLReservedKey_False;
     }
 
     nsXBLPrototypeHandler* handler =
-      new nsXBLPrototypeHandler(keyElement, reserved);
+        new nsXBLPrototypeHandler(keyElement, reserved);
 
     handler->SetNextHandler(*aResult);
     *aResult = handler;
@@ -239,26 +212,22 @@ BuildHandlerChain(nsIContent* aContent, nsXBLPrototypeHandler** aResult)
 // Lazily load the XBL handlers. Overridden to handle being attached
 // to a particular element rather than the document
 //
-nsresult
-nsXBLWindowKeyHandler::EnsureHandlers()
-{
+nsresult nsXBLWindowKeyHandler::EnsureHandlers() {
   nsCOMPtr<Element> el = GetElement();
   NS_ENSURE_STATE(!mWeakPtrForElement || el);
   if (el) {
     // We are actually a XUL <keyset>.
-    if (mHandler)
-      return NS_OK;
+    if (mHandler) return NS_OK;
 
     nsCOMPtr<nsIContent> content(do_QueryInterface(el));
     BuildHandlerChain(content, &mHandler);
-  } else { // We are an XBL file of handlers.
+  } else {  // We are an XBL file of handlers.
     EnsureSpecialDocInfo();
 
     // Now determine which handlers we should be using.
     if (IsHTMLEditableFieldFocused()) {
       sXBLSpecialDocInfo->GetAllHandlers("editor", &mHandler, &mUserHandler);
-    }
-    else {
+    } else {
       sXBLSpecialDocInfo->GetAllHandlers("browser", &mHandler, &mUserHandler);
     }
   }
@@ -266,9 +235,8 @@ nsXBLWindowKeyHandler::EnsureHandlers()
   return NS_OK;
 }
 
-nsresult
-nsXBLWindowKeyHandler::WalkHandlers(KeyboardEvent* aKeyEvent, nsAtom* aEventType)
-{
+nsresult nsXBLWindowKeyHandler::WalkHandlers(KeyboardEvent* aKeyEvent,
+                                             nsAtom* aEventType) {
   if (aKeyEvent->DefaultPrevented()) {
     return NS_OK;
   }
@@ -287,7 +255,7 @@ nsXBLWindowKeyHandler::WalkHandlers(KeyboardEvent* aKeyEvent, nsAtom* aEventType
     if (mUserHandler) {
       WalkHandlersInternal(aKeyEvent, aEventType, mUserHandler, true);
       if (aKeyEvent->DefaultPrevented()) {
-        return NS_OK; // Handled by the user bindings. Our work here is done.
+        return NS_OK;  // Handled by the user bindings. Our work here is done.
       }
     }
   }
@@ -302,130 +270,102 @@ nsXBLWindowKeyHandler::WalkHandlers(KeyboardEvent* aKeyEvent, nsAtom* aEventType
   return NS_OK;
 }
 
-void
-nsXBLWindowKeyHandler::InstallKeyboardEventListenersTo(
-                         EventListenerManager* aEventListenerManager)
-{
+void nsXBLWindowKeyHandler::InstallKeyboardEventListenersTo(
+    EventListenerManager* aEventListenerManager) {
   // For marking each keyboard event as if it's reserved by chrome,
   // nsXBLWindowKeyHandlers need to listen each keyboard events before
   // web contents.
   aEventListenerManager->AddEventListenerByType(
-                           this, NS_LITERAL_STRING("keydown"),
-                           TrustedEventsAtCapture());
+      this, NS_LITERAL_STRING("keydown"), TrustedEventsAtCapture());
   aEventListenerManager->AddEventListenerByType(
-                           this, NS_LITERAL_STRING("keyup"),
-                           TrustedEventsAtCapture());
+      this, NS_LITERAL_STRING("keyup"), TrustedEventsAtCapture());
   aEventListenerManager->AddEventListenerByType(
-                           this, NS_LITERAL_STRING("keypress"),
-                           TrustedEventsAtCapture());
+      this, NS_LITERAL_STRING("keypress"), TrustedEventsAtCapture());
   aEventListenerManager->AddEventListenerByType(
-                           this, NS_LITERAL_STRING("mozkeydownonplugin"),
-                           TrustedEventsAtCapture());
+      this, NS_LITERAL_STRING("mozkeydownonplugin"), TrustedEventsAtCapture());
   aEventListenerManager->AddEventListenerByType(
-                           this, NS_LITERAL_STRING("mozkeyuponplugin"),
-                           TrustedEventsAtCapture());
+      this, NS_LITERAL_STRING("mozkeyuponplugin"), TrustedEventsAtCapture());
 
   // For reducing the IPC cost, preventing to dispatch reserved keyboard
   // events into the content process.
   aEventListenerManager->AddEventListenerByType(
-                           this, NS_LITERAL_STRING("keydown"),
-                           TrustedEventsAtSystemGroupCapture());
+      this, NS_LITERAL_STRING("keydown"), TrustedEventsAtSystemGroupCapture());
   aEventListenerManager->AddEventListenerByType(
-                           this, NS_LITERAL_STRING("keyup"),
-                           TrustedEventsAtSystemGroupCapture());
+      this, NS_LITERAL_STRING("keyup"), TrustedEventsAtSystemGroupCapture());
   aEventListenerManager->AddEventListenerByType(
-                           this, NS_LITERAL_STRING("keypress"),
-                           TrustedEventsAtSystemGroupCapture());
+      this, NS_LITERAL_STRING("keypress"), TrustedEventsAtSystemGroupCapture());
   aEventListenerManager->AddEventListenerByType(
-                           this, NS_LITERAL_STRING("mozkeydownonplugin"),
-                           TrustedEventsAtSystemGroupCapture());
+      this, NS_LITERAL_STRING("mozkeydownonplugin"),
+      TrustedEventsAtSystemGroupCapture());
   aEventListenerManager->AddEventListenerByType(
-                           this, NS_LITERAL_STRING("mozkeyuponplugin"),
-                           TrustedEventsAtSystemGroupCapture());
+      this, NS_LITERAL_STRING("mozkeyuponplugin"),
+      TrustedEventsAtSystemGroupCapture());
 
   // Handle keyboard events in bubbling phase of the system event group.
   aEventListenerManager->AddEventListenerByType(
-                           this, NS_LITERAL_STRING("keydown"),
-                           TrustedEventsAtSystemGroupBubble());
+      this, NS_LITERAL_STRING("keydown"), TrustedEventsAtSystemGroupBubble());
   aEventListenerManager->AddEventListenerByType(
-                           this, NS_LITERAL_STRING("keyup"),
-                           TrustedEventsAtSystemGroupBubble());
+      this, NS_LITERAL_STRING("keyup"), TrustedEventsAtSystemGroupBubble());
   aEventListenerManager->AddEventListenerByType(
-                           this, NS_LITERAL_STRING("keypress"),
-                           TrustedEventsAtSystemGroupBubble());
+      this, NS_LITERAL_STRING("keypress"), TrustedEventsAtSystemGroupBubble());
   // mozaccesskeynotfound event is fired when modifiers of keypress event
   // matches with modifier of content access key but it's not consumed by
   // remote content.
   aEventListenerManager->AddEventListenerByType(
-                           this, NS_LITERAL_STRING("mozaccesskeynotfound"),
-                           TrustedEventsAtSystemGroupBubble());
+      this, NS_LITERAL_STRING("mozaccesskeynotfound"),
+      TrustedEventsAtSystemGroupBubble());
   aEventListenerManager->AddEventListenerByType(
-                           this, NS_LITERAL_STRING("mozkeydownonplugin"),
-                           TrustedEventsAtSystemGroupBubble());
+      this, NS_LITERAL_STRING("mozkeydownonplugin"),
+      TrustedEventsAtSystemGroupBubble());
   aEventListenerManager->AddEventListenerByType(
-                           this, NS_LITERAL_STRING("mozkeyuponplugin"),
-                           TrustedEventsAtSystemGroupBubble());
+      this, NS_LITERAL_STRING("mozkeyuponplugin"),
+      TrustedEventsAtSystemGroupBubble());
 }
 
-void
-nsXBLWindowKeyHandler::RemoveKeyboardEventListenersFrom(
-                         EventListenerManager* aEventListenerManager)
-{
+void nsXBLWindowKeyHandler::RemoveKeyboardEventListenersFrom(
+    EventListenerManager* aEventListenerManager) {
   aEventListenerManager->RemoveEventListenerByType(
-                           this, NS_LITERAL_STRING("keydown"),
-                           TrustedEventsAtCapture());
+      this, NS_LITERAL_STRING("keydown"), TrustedEventsAtCapture());
   aEventListenerManager->RemoveEventListenerByType(
-                           this, NS_LITERAL_STRING("keyup"),
-                           TrustedEventsAtCapture());
+      this, NS_LITERAL_STRING("keyup"), TrustedEventsAtCapture());
   aEventListenerManager->RemoveEventListenerByType(
-                           this, NS_LITERAL_STRING("keypress"),
-                           TrustedEventsAtCapture());
+      this, NS_LITERAL_STRING("keypress"), TrustedEventsAtCapture());
   aEventListenerManager->RemoveEventListenerByType(
-                           this, NS_LITERAL_STRING("mozkeydownonplugin"),
-                           TrustedEventsAtCapture());
+      this, NS_LITERAL_STRING("mozkeydownonplugin"), TrustedEventsAtCapture());
   aEventListenerManager->RemoveEventListenerByType(
-                           this, NS_LITERAL_STRING("mozkeyuponplugin"),
-                           TrustedEventsAtCapture());
+      this, NS_LITERAL_STRING("mozkeyuponplugin"), TrustedEventsAtCapture());
 
   aEventListenerManager->RemoveEventListenerByType(
-                           this, NS_LITERAL_STRING("keydown"),
-                           TrustedEventsAtSystemGroupCapture());
+      this, NS_LITERAL_STRING("keydown"), TrustedEventsAtSystemGroupCapture());
   aEventListenerManager->RemoveEventListenerByType(
-                           this, NS_LITERAL_STRING("keyup"),
-                           TrustedEventsAtSystemGroupCapture());
+      this, NS_LITERAL_STRING("keyup"), TrustedEventsAtSystemGroupCapture());
   aEventListenerManager->RemoveEventListenerByType(
-                           this, NS_LITERAL_STRING("keypress"),
-                           TrustedEventsAtSystemGroupCapture());
+      this, NS_LITERAL_STRING("keypress"), TrustedEventsAtSystemGroupCapture());
   aEventListenerManager->RemoveEventListenerByType(
-                           this, NS_LITERAL_STRING("mozkeydownonplugin"),
-                           TrustedEventsAtSystemGroupCapture());
+      this, NS_LITERAL_STRING("mozkeydownonplugin"),
+      TrustedEventsAtSystemGroupCapture());
   aEventListenerManager->RemoveEventListenerByType(
-                           this, NS_LITERAL_STRING("mozkeyuponplugin"),
-                           TrustedEventsAtSystemGroupCapture());
+      this, NS_LITERAL_STRING("mozkeyuponplugin"),
+      TrustedEventsAtSystemGroupCapture());
 
   aEventListenerManager->RemoveEventListenerByType(
-                           this, NS_LITERAL_STRING("keydown"),
-                           TrustedEventsAtSystemGroupBubble());
+      this, NS_LITERAL_STRING("keydown"), TrustedEventsAtSystemGroupBubble());
   aEventListenerManager->RemoveEventListenerByType(
-                           this, NS_LITERAL_STRING("keyup"),
-                           TrustedEventsAtSystemGroupBubble());
+      this, NS_LITERAL_STRING("keyup"), TrustedEventsAtSystemGroupBubble());
   aEventListenerManager->RemoveEventListenerByType(
-                           this, NS_LITERAL_STRING("keypress"),
-                           TrustedEventsAtSystemGroupBubble());
+      this, NS_LITERAL_STRING("keypress"), TrustedEventsAtSystemGroupBubble());
   aEventListenerManager->RemoveEventListenerByType(
-                           this, NS_LITERAL_STRING("mozaccesskeynotfound"),
-                           TrustedEventsAtSystemGroupBubble());
+      this, NS_LITERAL_STRING("mozaccesskeynotfound"),
+      TrustedEventsAtSystemGroupBubble());
   aEventListenerManager->RemoveEventListenerByType(
-                           this, NS_LITERAL_STRING("mozkeydownonplugin"),
-                           TrustedEventsAtSystemGroupBubble());
+      this, NS_LITERAL_STRING("mozkeydownonplugin"),
+      TrustedEventsAtSystemGroupBubble());
   aEventListenerManager->RemoveEventListenerByType(
-                           this, NS_LITERAL_STRING("mozkeyuponplugin"),
-                           TrustedEventsAtSystemGroupBubble());
+      this, NS_LITERAL_STRING("mozkeyuponplugin"),
+      TrustedEventsAtSystemGroupBubble());
 }
 
-/* static */ KeyboardMap
-nsXBLWindowKeyHandler::CollectKeyboardShortcuts()
-{
+/* static */ KeyboardMap nsXBLWindowKeyHandler::CollectKeyboardShortcuts() {
   // Load the XBL handlers
   EnsureSpecialDocInfo();
 
@@ -434,14 +374,14 @@ nsXBLWindowKeyHandler::CollectKeyboardShortcuts()
   sXBLSpecialDocInfo->GetAllHandlers("browser", &handlers, &userHandlers);
 
   // Convert the handlers into keyboard shortcuts, using an AutoTArray with
-  // the maximum amount of shortcuts used on any platform to minimize allocations
+  // the maximum amount of shortcuts used on any platform to minimize
+  // allocations
   AutoTArray<KeyboardShortcut, 48> shortcuts;
 
   // Append keyboard shortcuts for hardcoded actions like tab
   KeyboardShortcut::AppendHardcodedShortcuts(shortcuts);
 
-  for (nsXBLPrototypeHandler* handler = handlers;
-       handler;
+  for (nsXBLPrototypeHandler* handler = handlers; handler;
        handler = handler->GetNextHandler()) {
     KeyboardShortcut shortcut;
     if (handler->TryConvertToKeyboardShortcut(&shortcut)) {
@@ -449,8 +389,7 @@ nsXBLWindowKeyHandler::CollectKeyboardShortcuts()
     }
   }
 
-  for (nsXBLPrototypeHandler* handler = userHandlers;
-       handler;
+  for (nsXBLPrototypeHandler* handler = userHandlers; handler;
        handler = handler->GetNextHandler()) {
     KeyboardShortcut shortcut;
     if (handler->TryConvertToKeyboardShortcut(&shortcut)) {
@@ -461,10 +400,8 @@ nsXBLWindowKeyHandler::CollectKeyboardShortcuts()
   return KeyboardMap(mozilla::Move(shortcuts));
 }
 
-nsAtom*
-nsXBLWindowKeyHandler::ConvertEventToDOMEventType(
-                         const WidgetKeyboardEvent& aWidgetKeyboardEvent) const
-{
+nsAtom* nsXBLWindowKeyHandler::ConvertEventToDOMEventType(
+    const WidgetKeyboardEvent& aWidgetKeyboardEvent) const {
   if (aWidgetKeyboardEvent.IsKeyDownOrKeyDownOnPlugin()) {
     return nsGkAtoms::keydown;
   }
@@ -481,15 +418,14 @@ nsXBLWindowKeyHandler::ConvertEventToDOMEventType(
     return nsGkAtoms::keypress;
   }
   MOZ_ASSERT_UNREACHABLE(
-    "All event messages which this instance listens to should be handled");
+      "All event messages which this instance listens to should be handled");
   return nullptr;
 }
 
 NS_IMETHODIMP
-nsXBLWindowKeyHandler::HandleEvent(nsIDOMEvent* aEvent)
-{
+nsXBLWindowKeyHandler::HandleEvent(nsIDOMEvent* aEvent) {
   RefPtr<KeyboardEvent> keyEvent =
-    aEvent->InternalDOMEvent()->AsKeyboardEvent();
+      aEvent->InternalDOMEvent()->AsKeyboardEvent();
   NS_ENSURE_TRUE(keyEvent, NS_ERROR_INVALID_ARG);
 
   uint16_t eventPhase;
@@ -504,7 +440,7 @@ nsXBLWindowKeyHandler::HandleEvent(nsIDOMEvent* aEvent)
   }
 
   WidgetKeyboardEvent* widgetKeyboardEvent =
-    aEvent->WidgetEventPtr()->AsKeyboardEvent();
+      aEvent->WidgetEventPtr()->AsKeyboardEvent();
   if (widgetKeyboardEvent->IsKeyEventOnPlugin()) {
     // key events on plugin shouldn't execute shortcut key handlers which are
     // not reserved.
@@ -536,16 +472,14 @@ nsXBLWindowKeyHandler::HandleEvent(nsIDOMEvent* aEvent)
   }
 
   RefPtr<nsAtom> eventTypeAtom =
-    ConvertEventToDOMEventType(*widgetKeyboardEvent);
+      ConvertEventToDOMEventType(*widgetKeyboardEvent);
   return WalkHandlers(keyEvent, eventTypeAtom);
 }
 
-void
-nsXBLWindowKeyHandler::HandleEventOnCaptureInDefaultEventGroup(
-                         KeyboardEvent* aEvent)
-{
+void nsXBLWindowKeyHandler::HandleEventOnCaptureInDefaultEventGroup(
+    KeyboardEvent* aEvent) {
   WidgetKeyboardEvent* widgetKeyboardEvent =
-    aEvent->WidgetEventPtr()->AsKeyboardEvent();
+      aEvent->WidgetEventPtr()->AsKeyboardEvent();
 
   if (widgetKeyboardEvent->IsReservedByChrome()) {
     return;
@@ -557,12 +491,10 @@ nsXBLWindowKeyHandler::HandleEventOnCaptureInDefaultEventGroup(
   }
 }
 
-void
-nsXBLWindowKeyHandler::HandleEventOnCaptureInSystemEventGroup(
-                         KeyboardEvent* aEvent)
-{
+void nsXBLWindowKeyHandler::HandleEventOnCaptureInSystemEventGroup(
+    KeyboardEvent* aEvent) {
   WidgetKeyboardEvent* widgetEvent =
-    aEvent->WidgetEventPtr()->AsKeyboardEvent();
+      aEvent->WidgetEventPtr()->AsKeyboardEvent();
 
   // If the event won't be sent to remote process, this listener needs to do
   // nothing.  Note that even if mOnlySystemGroupDispatchInContent is true,
@@ -589,20 +521,16 @@ nsXBLWindowKeyHandler::HandleEventOnCaptureInSystemEventGroup(
   widgetEvent->MarkAsWaitingReplyFromRemoteProcess();
 }
 
-bool
-nsXBLWindowKeyHandler::IsHTMLEditableFieldFocused()
-{
+bool nsXBLWindowKeyHandler::IsHTMLEditableFieldFocused() {
   nsIFocusManager* fm = nsFocusManager::GetFocusManager();
-  if (!fm)
-    return false;
+  if (!fm) return false;
 
   nsCOMPtr<mozIDOMWindowProxy> focusedWindow;
   fm->GetFocusedWindow(getter_AddRefs(focusedWindow));
-  if (!focusedWindow)
-    return false;
+  if (!focusedWindow) return false;
 
   auto* piwin = nsPIDOMWindowOuter::From(focusedWindow);
-  nsIDocShell *docShell = piwin->GetDocShell();
+  nsIDocShell* docShell = piwin->GetDocShell();
   if (!docShell) {
     return false;
   }
@@ -631,7 +559,8 @@ nsXBLWindowKeyHandler::IsHTMLEditableFieldFocused()
     if (!activeEditingHost) {
       return false;
     }
-    return nsContentUtils::ContentIsDescendantOf(focusedNode, activeEditingHost);
+    return nsContentUtils::ContentIsDescendantOf(focusedNode,
+                                                 activeEditingHost);
   }
 
   return false;
@@ -641,66 +570,57 @@ nsXBLWindowKeyHandler::IsHTMLEditableFieldFocused()
 // WalkHandlersInternal and WalkHandlersAndExecute
 //
 // Given a particular DOM event and a pointer to the first handler in the list,
-// scan through the list to find something to handle the event. If aExecute = true,
-// the handler will be executed; otherwise just return an answer telling if a handler
-// for that event was found.
+// scan through the list to find something to handle the event. If aExecute =
+// true, the handler will be executed; otherwise just return an answer telling
+// if a handler for that event was found.
 //
-bool
-nsXBLWindowKeyHandler::WalkHandlersInternal(KeyboardEvent* aKeyEvent,
-                                            nsAtom* aEventType,
-                                            nsXBLPrototypeHandler* aHandler,
-                                            bool aExecute,
-                                            bool* aOutReservedForChrome)
-{
+bool nsXBLWindowKeyHandler::WalkHandlersInternal(
+    KeyboardEvent* aKeyEvent, nsAtom* aEventType,
+    nsXBLPrototypeHandler* aHandler, bool aExecute,
+    bool* aOutReservedForChrome) {
   WidgetKeyboardEvent* nativeKeyboardEvent =
-    aKeyEvent->WidgetEventPtr()->AsKeyboardEvent();
+      aKeyEvent->WidgetEventPtr()->AsKeyboardEvent();
   MOZ_ASSERT(nativeKeyboardEvent);
 
   AutoShortcutKeyCandidateArray shortcutKeys;
   nativeKeyboardEvent->GetShortcutKeyCandidates(shortcutKeys);
 
   if (shortcutKeys.IsEmpty()) {
-    return WalkHandlersAndExecute(aKeyEvent, aEventType, aHandler,
-                                  0, IgnoreModifierState(),
-                                  aExecute, aOutReservedForChrome);
+    return WalkHandlersAndExecute(aKeyEvent, aEventType, aHandler, 0,
+                                  IgnoreModifierState(), aExecute,
+                                  aOutReservedForChrome);
   }
 
   for (uint32_t i = 0; i < shortcutKeys.Length(); ++i) {
     ShortcutKeyCandidate& key = shortcutKeys[i];
     IgnoreModifierState ignoreModifierState;
     ignoreModifierState.mShift = key.mIgnoreShift;
-    if (WalkHandlersAndExecute(aKeyEvent, aEventType, aHandler,
-                               key.mCharCode, ignoreModifierState,
-                               aExecute, aOutReservedForChrome)) {
+    if (WalkHandlersAndExecute(aKeyEvent, aEventType, aHandler, key.mCharCode,
+                               ignoreModifierState, aExecute,
+                               aOutReservedForChrome)) {
       return true;
     }
   }
   return false;
 }
 
-bool
-nsXBLWindowKeyHandler::WalkHandlersAndExecute(
-                         KeyboardEvent* aKeyEvent,
-                         nsAtom* aEventType,
-                         nsXBLPrototypeHandler* aFirstHandler,
-                         uint32_t aCharCode,
-                         const IgnoreModifierState& aIgnoreModifierState,
-                         bool aExecute,
-                         bool* aOutReservedForChrome)
-{
+bool nsXBLWindowKeyHandler::WalkHandlersAndExecute(
+    KeyboardEvent* aKeyEvent, nsAtom* aEventType,
+    nsXBLPrototypeHandler* aFirstHandler, uint32_t aCharCode,
+    const IgnoreModifierState& aIgnoreModifierState, bool aExecute,
+    bool* aOutReservedForChrome) {
   if (aOutReservedForChrome) {
     *aOutReservedForChrome = false;
   }
 
   WidgetKeyboardEvent* widgetKeyboardEvent =
-    aKeyEvent->WidgetEventPtr()->AsKeyboardEvent();
+      aKeyEvent->WidgetEventPtr()->AsKeyboardEvent();
   if (NS_WARN_IF(!widgetKeyboardEvent)) {
     return false;
   }
 
   // Try all of the handlers until we find one that matches the event.
-  for (nsXBLPrototypeHandler* handler = aFirstHandler;
-       handler;
+  for (nsXBLPrototypeHandler* handler = aFirstHandler; handler;
        handler = handler->GetNextHandler()) {
     bool stopped = aKeyEvent->IsDispatchStopped();
     if (stopped) {
@@ -717,8 +637,8 @@ nsXBLWindowKeyHandler::WalkHandlersAndExecute(
             !handler->EventTypeEquals(nsGkAtoms::keypress)) {
           continue;
         }
-      // The other event types should exactly be matched with the handler's
-      // event type.
+        // The other event types should exactly be matched with the handler's
+        // event type.
       } else if (!handler->EventTypeEquals(aEventType)) {
         continue;
       }
@@ -828,10 +748,8 @@ nsXBLWindowKeyHandler::WalkHandlersAndExecute(
   return false;
 }
 
-bool
-nsXBLWindowKeyHandler::IsReservedKey(WidgetKeyboardEvent* aKeyEvent,
-                                     nsXBLPrototypeHandler* aHandler)
-{
+bool nsXBLWindowKeyHandler::IsReservedKey(WidgetKeyboardEvent* aKeyEvent,
+                                          nsXBLPrototypeHandler* aHandler) {
   XBLReservedKey reserved = aHandler->GetIsReserved();
   // reserved="true" means that the key is always reserved. reserved="false"
   // means that the key is never reserved. Otherwise, we check site-specific
@@ -847,12 +765,10 @@ nsXBLWindowKeyHandler::IsReservedKey(WidgetKeyboardEvent* aKeyEvent,
   return nsContentUtils::ShouldBlockReservedKeys(aKeyEvent);
 }
 
-bool
-nsXBLWindowKeyHandler::HasHandlerForEvent(KeyboardEvent* aEvent,
-                                          bool* aOutReservedForChrome)
-{
+bool nsXBLWindowKeyHandler::HasHandlerForEvent(KeyboardEvent* aEvent,
+                                               bool* aOutReservedForChrome) {
   WidgetKeyboardEvent* widgetKeyboardEvent =
-    aEvent->WidgetEventPtr()->AsKeyboardEvent();
+      aEvent->WidgetEventPtr()->AsKeyboardEvent();
   if (NS_WARN_IF(!widgetKeyboardEvent) || !widgetKeyboardEvent->IsTrusted()) {
     return false;
   }
@@ -867,14 +783,12 @@ nsXBLWindowKeyHandler::HasHandlerForEvent(KeyboardEvent* aEvent,
   }
 
   RefPtr<nsAtom> eventTypeAtom =
-    ConvertEventToDOMEventType(*widgetKeyboardEvent);
+      ConvertEventToDOMEventType(*widgetKeyboardEvent);
   return WalkHandlersInternal(aEvent, eventTypeAtom, mHandler, false,
                               aOutReservedForChrome);
 }
 
-already_AddRefed<Element>
-nsXBLWindowKeyHandler::GetElement(bool* aIsDisabled)
-{
+already_AddRefed<Element> nsXBLWindowKeyHandler::GetElement(bool* aIsDisabled) {
   nsCOMPtr<Element> element = do_QueryReferent(mWeakPtrForElement);
   if (element && aIsDisabled) {
     *aIsDisabled = element->AttrValueIs(kNameSpaceID_None, nsGkAtoms::disabled,
@@ -883,16 +797,14 @@ nsXBLWindowKeyHandler::GetElement(bool* aIsDisabled)
   return element.forget();
 }
 
-bool
-nsXBLWindowKeyHandler::GetElementForHandler(nsXBLPrototypeHandler* aHandler,
-                                            Element** aElementForHandler)
-{
+bool nsXBLWindowKeyHandler::GetElementForHandler(
+    nsXBLPrototypeHandler* aHandler, Element** aElementForHandler) {
   MOZ_ASSERT(aElementForHandler);
   *aElementForHandler = nullptr;
 
   RefPtr<Element> keyContent = aHandler->GetHandlerElement();
   if (!keyContent) {
-    return true; // XXX Even though no key element?
+    return true;  // XXX Even though no key element?
   }
 
   nsCOMPtr<Element> chromeHandlerElement = GetElement();
@@ -921,10 +833,11 @@ nsXBLWindowKeyHandler::GetElementForHandler(nsXBLPrototypeHandler* aHandler,
   }
 
   nsCOMPtr<Element> commandElement =
-    do_QueryInterface(doc->GetElementById(command));
+      do_QueryInterface(doc->GetElementById(command));
   if (!commandElement) {
-    NS_ERROR("A XUL <key> is observing a command that doesn't exist. "
-             "Unable to execute key binding!");
+    NS_ERROR(
+        "A XUL <key> is observing a command that doesn't exist. "
+        "Unable to execute key binding!");
     return false;
   }
 
@@ -932,9 +845,7 @@ nsXBLWindowKeyHandler::GetElementForHandler(nsXBLPrototypeHandler* aHandler,
   return true;
 }
 
-bool
-nsXBLWindowKeyHandler::IsExecutableElement(Element* aElement) const
-{
+bool nsXBLWindowKeyHandler::IsExecutableElement(Element* aElement) const {
   if (!aElement) {
     return false;
   }
@@ -955,10 +866,9 @@ nsXBLWindowKeyHandler::IsExecutableElement(Element* aElement) const
 
 ///////////////////////////////////////////////////////////////////////////////////
 
-already_AddRefed<nsXBLWindowKeyHandler>
-NS_NewXBLWindowKeyHandler(nsIDOMElement* aElement, EventTarget* aTarget)
-{
+already_AddRefed<nsXBLWindowKeyHandler> NS_NewXBLWindowKeyHandler(
+    nsIDOMElement* aElement, EventTarget* aTarget) {
   RefPtr<nsXBLWindowKeyHandler> result =
-    new nsXBLWindowKeyHandler(aElement, aTarget);
+      new nsXBLWindowKeyHandler(aElement, aTarget);
   return result.forget();
 }
