@@ -12,35 +12,28 @@
 namespace mozilla {
 namespace dom {
 
-class XMLHttpRequestUpload final : public XMLHttpRequestEventTarget
-{
-public:
+class XMLHttpRequestUpload final : public XMLHttpRequestEventTarget {
+ public:
   explicit XMLHttpRequestUpload(DOMEventTargetHelper* aOwner)
-    : XMLHttpRequestEventTarget(aOwner)
-  {}
+      : XMLHttpRequestEventTarget(aOwner) {}
 
-  explicit XMLHttpRequestUpload()
-  {}
+  explicit XMLHttpRequestUpload() {}
 
   NS_DECL_ISUPPORTS_INHERITED
   NS_REALLY_FORWARD_NSIDOMEVENTTARGET(XMLHttpRequestEventTarget)
 
-  virtual JSObject*
-  WrapObject(JSContext *cx, JS::Handle<JSObject*> aGivenProto) override;
+  virtual JSObject* WrapObject(JSContext* cx,
+                               JS::Handle<JSObject*> aGivenProto) override;
 
-  bool HasListeners()
-  {
+  bool HasListeners() {
     return mListenerManager && mListenerManager->HasListeners();
   }
 
-private:
-  virtual ~XMLHttpRequestUpload()
-  {}
+ private:
+  virtual ~XMLHttpRequestUpload() {}
 };
 
+}  // namespace dom
+}  // namespace mozilla
 
-} // dom namespace
-} // mozilla namespace
-
-#endif // mozilla_dom_XMLHttpRequestUpload_h
-
+#endif  // mozilla_dom_XMLHttpRequestUpload_h
